-- Created by Giseldah

local p = _G; --p stands for package

-- ****************************** Start CalcStat ******************************

-- Floating point numbers bring errors into the calculation, both inside the Lotro-client and in this function collection. This is why a 100% match with the stats in Lotro is impossible.
-- Anyway, to compensate for some errors, we use a calculation deviation correction value. This makes for instance 24.49999999 round to 25, as it's assumed that 24.5 was intended as outcome of a formula.
DblCalcDev = 0.00000001;

function CalcStat(SName, SLvl, SParam)

	-- process parameters and parameter defaults

	if type(SName) ~= "string" then
		return "Missing stat name";
	end
	local SN = string.match(SName:upper(),"^%s*(-?%a+%d*%a+)%s*$"); -- allow nested digits in stat name and a starting -
	if SN == nil then
		SN = string.match(SName,"^%s*(-?%a+)%s*$"); -- to allow single character stat name
		if SN == nil then
			return "Illegal stat name";
		end
	end
	SN = string.upper(SN);

	local L = 1; -- default L
	if type(SLvl) == "number" then
		L = SLvl;
	elseif type(SLvl) ~= "nil" then
		return "Illegal level";
	end
	local Lm = L-DblCalcDev;
	local Lp = L+DblCalcDev;

	local N = 1; -- default N
	local C = ""; -- default C
	if type(SParam) == "number" then
		N = SParam;
	elseif type(SParam) == "string" then
		C = SParam;
	elseif type(SParam) ~= "nil" then
		return "Illegal N or C";
	end

	-- binary search tree (generated code)

	if SN < "MINSTRELCDBASEWILL" then
		if SN < "CREEPAUDACITYRNGDMGP" then
			if SN < "BURGLARCDBASEAGILITY" then
				if SN < "BEORNINGCDFATETOFINESSE" then
					if SN < "AWARDILVLDG" then
						if SN < "ARMQTYCOMMMP" then
							if SN < "ARMCATMP" then
								if SN < "ADJITEMPROGRATINGS" then
									if SN < "ACIDMITT" then
										if SN > "-VERSION" then
											if SN == "ACIDMIT" then
												return CalcStat("DmgTypeMit",L,N);
											else
												return 0;
											end
										elseif SN == "-VERSION" then
											return "2.1.3f";
										else
											return 0;
										end
									elseif SN > "ACIDMITT" then
										if SN < "ADJITEMPROGMORREG" then
											if SN == "ADJITEMPROGLOW" then
												if Lm <= 25 then
													return 0.5;
												else
													return 1;
												end
											else
												return 0;
											end
										elseif SN > "ADJITEMPROGMORREG" then
											if SN == "ADJITEMPROGPOWER" then
												if Lm <= 1 then
													return 7.5;
												elseif Lm <= 79 then
													return 0.81;
												elseif Lm <= 80 then
													return 728/900;
												elseif Lm <= 449 then
													return 0.81;
												else
													return 1;
												end
											else
												return 0;
											end
										else
											if Lm <= 1 then
												return 1;
											elseif Lm <= 79 then
												return 1.04;
											elseif Lm <= 349 then
												return 1;
											elseif Lm <= 350 then
												return 95/99;
											elseif Lm <= 399 then
												return 38/45;
											elseif Lm <= 400 then
												return 76/105;
											elseif Lm <= 449 then
												return 38/63;
											elseif Lm <= 450 then
												return 191/300;
											else
												return 0.5026;
											end
										end
									else
										return CalcStat("DmgTypeMitT",L,N);
									end
								elseif SN > "ADJITEMPROGRATINGS" then
									if SN < "ADJTRAITPROGPOWER" then
										if SN > "ADJTRAITPROGMORALE" then
											if SN == "ADJTRAITPROGMORREG" then
												if Lm <= 121 then
													return CalcStat("AdjTraitProgMorale",L);
												elseif Lm <= 130 then
													return 1.14*0.5026;
												elseif Lm <= 131 then
													return 1.2*0.5026;
												else
													return 0.5026;
												end
											else
												return 0;
											end
										elseif SN == "ADJTRAITPROGMORALE" then
											if Lm <= 1 then
												return 1;
											elseif Lm <= 75 then
												return 1.04;
											elseif Lm <= 115 then
												return 1;
											elseif Lm <= 116 then
												return 95/99;
											elseif Lm <= 120 then
												return 38/45;
											elseif Lm <= 121 then
												return 76/105;
											elseif Lm <= 130 then
												return 38/63;
											else
												return 70.37/105;
											end
										else
											return 0;
										end
									elseif SN > "ADJTRAITPROGPOWER" then
										if SN < "AGILITY" then
											if SN == "ADJTRAITPROGRATINGS" then
												if Lm <= 75 then
													return 1;
												elseif Lm <= 105 then
													return 0.8;
												elseif Lm <= 121 then
													return 1;
												else
													return 0.9;
												end
											else
												return 0;
											end
										elseif SN > "AGILITY" then
											if SN == "AGILITYT" then
												return CalcStat("MainT",L,N);
											else
												return 0;
											end
										else
											return CalcStat("Main",L,N);
										end
									else
										if Lm <= 1 then
											return 221/30;
										elseif Lm <= 75 then
											return 0.81;
										elseif Lm <= 76 then
											return 728/900;
										elseif Lm <= 130 then
											return 0.81;
										else
											return 1;
										end
									end
								else
									if Lm <= 25 then
										return 0.5;
									elseif Lm <= 200 then
										return 0.8;
									elseif Lm <= 400 then
										return 1;
									else
										return 0.9;
									end
								end
							elseif SN > "ARMCATMP" then
								if SN < "ARMOURLOWPNTMP" then
									if SN < "ARMCATPROGB" then
										if SN > "ARMCATNEWMP" then
											if SN == "ARMCATOLDMP" then
												if Lm <= 0 then
													return 0;
												else
													return DataTableValue({3/260,3/228,3/210},L);
												end
											else
												return 0;
											end
										elseif SN == "ARMCATNEWMP" then
											if Lm <= 0 then
												return 0;
											else
												return DataTableValue({3/260.04,3/227.997,3/209.901},L);
											end
										else
											return 0;
										end
									elseif SN > "ARMCATPROGB" then
										if SN < "ARMOURADJ" then
											if SN == "ARMOUR" then
												return FloorDbl(StatLinInter("ArmourPntMP","ItemMedProg","ArmourProgB","ArmourAdj",L,C));
											else
												return 0;
											end
										elseif SN > "ARMOURADJ" then
											if SN == "ARMOURLOW" then
												return FloorDbl(StatLinInter("ArmourLowPntMP","ItemMedProg","ArmourProgB","ArmourAdj",L,C));
											else
												return 0;
											end
										else
											if Lm <= 399 then
												return 1;
											elseif Lm <= 449 then
												return 0.9;
											elseif Lm <= 450 then
												return 83/90;
											else
												return 60/90;
											end
										end
									else
										if Lm <= 0 then
											return 0;
										elseif Lm <= 1 then
											return CalcStat("ProgBMitHeavy",L);
										elseif Lm <= 2 then
											return CalcStat("ProgBMitMedium",L);
										else
											return CalcStat("ProgBMitLight",L);
										end
									end
								elseif SN > "ARMOURLOWPNTMP" then
									if SN < "ARMOURPNTMP" then
										if SN > "ARMOURPENT" then
											if SN == "ARMOURPENTADJ" then
												if Lm <= 75 then
													return 1;
												elseif Lm <= 105 then
													return 0.8;
												elseif Lm <= 121 then
													return 1;
												elseif Lm <= 130 then
													return 0.9;
												elseif Lm <= 140 then
													return 80/90;
												else
													return 70/90;
												end
											else
												return 0;
											end
										elseif SN == "ARMOURPENT" then
											return StatLinInter("PntMPArmour","TraitProg","ProgBMitigation","ArmourPenTAdj",L,N);
										else
											return 0;
										end
									elseif SN > "ARMOURPNTMP" then
										if SN < "ARMOURT" then
											if SN == "ARMOURPROGB" then
												return CalcStat("ArmCatProgB",ArmCodeIndex(C,1));
											else
												return 0;
											end
										elseif SN > "ARMOURT" then
											if SN == "ARMOURTADJ" then
												if Lm <= 75 then
													return 1;
												elseif Lm <= 105 then
													return 0.9;
												elseif Lm <= 106 then
													return 1;
												elseif Lm <= 115 then
													return 0.9;
												elseif Lm <= 116 then
													return 1;
												elseif Lm <= 120 then
													return 0.82;
												elseif Lm <= 121 then
													return 0.9;
												elseif Lm <= 130 then
													return 0.747;
												elseif Lm <= 131 then
													return 83/90;
												elseif Lm <= 140 then
													return 0.5464;
												elseif Lm <= 141 then
													return 60/90;
												else
													return 48/90;
												end
											else
												return 0;
											end
										else
											return StatLinInter("PntMPArmour","TraitProg","ProgBMitigation","ArmourTAdj",L,N);
										end
									else
										return CalcStat("ArmTypeMP",ArmCodeIndex(C,2))*CalcStat("ArmQtyMP",ArmCodeIndex(C,3),ArmCodeIndex(C,2))*CalcStat("ArmCatMP",L,ArmCodeIndex(C,1));
									end
								else
									return CalcStat("ArmTypeMP",ArmCodeIndex(C,2))*CalcStat("ArmQtyLowMP",ArmCodeIndex(C,2))*CalcStat("ArmCatMP",L,ArmCodeIndex(C,1));
								end
							else
								if Lm <= 449 then
									return CalcStat("ArmCatOldMP",N);
								else
									return CalcStat("ArmCatNewMP",N);
								end
							end
						elseif SN > "ARMQTYCOMMMP" then
							if SN < "AWARDILVLB" then
								if SN < "ARMTYPEMP" then
									if SN < "ARMQTYLOWMP" then
										if SN > "ARMQTYEPICMP" then
											if SN == "ARMQTYINCOMPMP" then
												if Lm <= 0 then
													return 0;
												else
													return DataTableValue({28/30,28/30,0.95,0.95,0.94,0.948,0.95,0.95},L);
												end
											else
												return 0;
											end
										elseif SN == "ARMQTYEPICMP" then
											if Lm <= 0 then
												return 0;
											else
												return DataTableValue({1,1,1,1,1,1.002,1,1},L);
											end
										else
											return 0;
										end
									elseif SN > "ARMQTYLOWMP" then
										if SN < "ARMQTYRAREMP" then
											if SN == "ARMQTYMP" then
												if Lm <= 0 then
													return 0;
												elseif Lm <= 1 then
													return CalcStat("ArmQtyCommMP",N);
												elseif Lm <= 2 then
													return CalcStat("ArmQtyUncomMP",N);
												elseif Lm <= 3 then
													return CalcStat("ArmQtyRareMP",N);
												elseif Lm <= 4 then
													return CalcStat("ArmQtyIncompMP",N);
												else
													return CalcStat("ArmQtyEpicMP",N);
												end
											else
												return 0;
											end
										elseif SN > "ARMQTYRAREMP" then
											if SN == "ARMQTYUNCOMMP" then
												if Lm <= 0 then
													return 0;
												else
													return DataTableValue({22/30,22/30,0.85,0.85,0.82,0.852,0.85,0.75},L);
												end
											else
												return 0;
											end
										else
											if Lm <= 0 then
												return 0;
											else
												return DataTableValue({26/30,26/30,0.9,0.9,0.88,0.9,0.9,0.8},L);
											end
										end
									else
										if Lm <= 0 then
											return 0;
										else
											return DataTableValue({0.4,0.4,0.4,0.4,0.4,0.3984,0.4,0.4},L);
										end
									end
								elseif SN > "ARMTYPEMP" then
									if SN < "AWARDILVLAA" then
										if SN > "AUTOLVLTOILVL" then
											if SN == "AWARDILVLA" then
												if Lm <= 75 then
													return L;
												elseif Lm <= 94 then
													return 5*L-304;
												elseif Lm <= 95 then
													return 173;
												elseif Lm <= 100 then
													return 5*L-304;
												elseif Lm <= 101 then
													return 197;
												elseif Lm <= 104 then
													return 4*L-206;
												elseif Lm <= 105 then
													return 218;
												elseif Lm <= 114 then
													return 3*L-30;
												elseif Lm <= 115 then
													return 314;
												elseif Lm <= 120 then
													return 5*L-245;
												elseif Lm <= 130 then
													return 2*L+143;
												elseif Lm <= 140 then
													return RoundDbl(LinFmod(1,435.4,445.4,131,140,L));
												else
													return CalcStat("AwardILvlA",140);
												end
											else
												return 0;
											end
										elseif SN == "AUTOLVLTOILVL" then
											return CalcStat("AwardILvlCC",L);
										else
											return 0;
										end
									elseif SN > "AWARDILVLAA" then
										if SN < "AWARDILVLAC" then
											if SN == "AWARDILVLAB" then
												if Lm <= 74 then
													return CalcStat("AwardILvlA",L);
												elseif Lm <= 75 then
													return CalcStat("AwardILvlA",L)+1;
												else
													return CalcStat("AwardILvlA",L);
												end
											else
												return 0;
											end
										elseif SN > "AWARDILVLAC" then
											if SN == "AWARDILVLAOLD" then
												if Lm <= 120 then
													return CalcStat("AwardILvlA",L);
												elseif Lm <= 130 then
													return RoundDbl((14/15)*L+4081/15);
												elseif Lm <= 140 then
													return RoundDbl(LinFmod(1,435.4,445.4,131,140,L));
												else
													return CalcStat("AwardILvlAOld",140);
												end
											else
												return 0;
											end
										else
											if Lm <= 74 then
												return CalcStat("AwardILvlA",L);
											elseif Lm <= 75 then
												return CalcStat("AwardILvlA",L)+2;
											else
												return CalcStat("AwardILvlA",L);
											end
										end
									else
										if Lm <= 74 then
											return CalcStat("AwardILvlAOld",L);
										elseif Lm <= 75 then
											return CalcStat("AwardILvlAOld",L)+3;
										else
											return CalcStat("AwardILvlAOld",L);
										end
									end
								else
									if Lm <= 0 then
										return 0;
									else
										return DataTableValue({9,9,21,30,15,25,12,36},L);
									end
								end
							elseif SN > "AWARDILVLB" then
								if SN < "AWARDILVLCD" then
									if SN < "AWARDILVLC" then
										if SN > "AWARDILVLBA" then
											if SN == "AWARDILVLBOLD" then
												if Lm <= 4 then
													return CalcStat("AwardILvlA",1);
												elseif Lm <= 50 then
													return CalcStat("AwardILvlA",L-4);
												elseif Lm <= 54 then
													return CalcStat("AwardILvlA",51);
												elseif Lm <= 75 then
													return CalcStat("AwardILvlA",L-4);
												elseif Lm <= 95 then
													return CalcStat("AwardILvlA",L)+4;
												elseif Lm <= 130 then
													return CalcStat("AwardILvlA",L);
												elseif Lm <= 135 then
													return RoundDbl(LinFmod(1,438.4,443.4,131,135,L));
												elseif Lm <= 140 then
													return RoundDbl(LinFmod(1,444.4,446.4,136,140,L));
												else
													return CalcStat("AwardILvlBOld",140);
												end
											else
												return 0;
											end
										elseif SN == "AWARDILVLBA" then
											return CalcStat("AwardILvlB",L);
										else
											return 0;
										end
									elseif SN > "AWARDILVLC" then
										if SN < "AWARDILVLCB" then
											if SN == "AWARDILVLCA" then
												if Lm <= 95 then
													return CalcStat("AwardILvlC",L);
												elseif Lm <= 100 then
													return CalcStat("AwardILvlC",L)+4;
												else
													return CalcStat("AwardILvlC",L);
												end
											else
												return 0;
											end
										elseif SN > "AWARDILVLCB" then
											if SN == "AWARDILVLCC" then
												if Lm <= 75 then
													return CalcStat("AwardILvlC",L);
												elseif Lm <= 95 then
													return CalcStat("AwardILvlC",L)+2;
												else
													return CalcStat("AwardILvlC",L);
												end
											else
												return 0;
											end
										else
											if Lm <= 95 then
												return CalcStat("AwardILvlC",L);
											elseif Lm <= 99 then
												return CalcStat("AwardILvlC",L)+4;
											elseif Lm <= 100 then
												return CalcStat("AwardILvlC",L)+6;
											else
												return CalcStat("AwardILvlC",L);
											end
										end
									else
										if Lm <= 75 then
											return CalcStat("AwardILvlBOld",L);
										elseif Lm <= 95 then
											return CalcStat("AwardILvlA",L);
										else
											return CalcStat("AwardILvlBOld",L);
										end
									end
								elseif SN > "AWARDILVLCD" then
									if SN < "AWARDILVLDC" then
										if SN < "AWARDILVLDA" then
											if SN == "AWARDILVLD" then
												if Lm <= 105 then
													return CalcStat("AwardILvlC",L);
												elseif Lm <= 115 then
													return 300;
												elseif Lm <= 130 then
													return CalcStat("AwardILvlC",L)+3;
												else
													return CalcStat("AwardILvlC",L);
												end
											else
												return 0;
											end
										elseif SN > "AWARDILVLDA" then
											if SN == "AWARDILVLDB" then
												if Lm <= 105 then
													return CalcStat("AwardILvlD",L);
												elseif Lm <= 115 then
													return RoundDbl(LinFmod(1,300,345,106,115,L));
												else
													return CalcStat("AwardILvlD",L);
												end
											else
												return 0;
											end
										else
											if Lm <= 105 then
												return CalcStat("AwardILvlD",L);
											elseif Lm <= 115 then
												return RoundDbl(LinFmod(1,300,336.5,106,115,L));
											else
												return CalcStat("AwardILvlD",L);
											end
										end
									elseif SN > "AWARDILVLDC" then
										if SN < "AWARDILVLDE" then
											if SN == "AWARDILVLDD" then
												if Lm <= 105 then
													return CalcStat("AwardILvlD",L);
												elseif Lm <= 114 then
													return RoundDbl(LinFmod(1,300,327,106,115,L));
												elseif Lm <= 115 then
													return CalcStat("AwardILvlD",115)+30;
												else
													return CalcStat("AwardILvlD",L);
												end
											else
												return 0;
											end
										elseif SN > "AWARDILVLDE" then
											if SN == "AWARDILVLDF" then
												if Lm <= 105 then
													return CalcStat("AwardILvlD",L);
												elseif Lm <= 110 then
													return CalcStat("AwardILvlDF",111);
												elseif Lm <= 115 then
													return RoundDbl(LinFmod(1,299.5,320.5,106,115,L));
												else
													return CalcStat("AwardILvlD",L);
												end
											else
												return 0;
											end
										else
											if Lm <= 105 then
												return CalcStat("AwardILvlD",L);
											elseif Lm <= 115 then
												return RoundDbl(LinFmod(1,300.4,326.4,106,115,L));
											else
												return CalcStat("AwardILvlD",L);
											end
										end
									else
										if Lm <= 105 then
											return CalcStat("AwardILvlD",L);
										elseif Lm <= 110 then
											return RoundDbl(LinFmod(1,300,320,106,115,L));
										elseif Lm <= 115 then
											return CalcStat("AwardILvlDC",110);
										else
											return CalcStat("AwardILvlD",L);
										end
									end
								else
									if Lm <= 100 then
										return CalcStat("AwardILvlC",L);
									elseif Lm <= 105 then
										return CalcStat("AwardILvlC",L)+4;
									else
										return CalcStat("AwardILvlC",L);
									end
								end
							else
								if Lm <= 95 then
									return CalcStat("AwardILvlBOld",L);
								elseif Lm <= 96 then
									return CalcStat("AwardILvlBOld",95);
								else
									return CalcStat("AwardILvlBOld",L);
								end
							end
						else
							if Lm <= 0 then
								return 0;
							else
								return DataTableValue({22/30,22/30,0.8,0.8,0.76,0.804,0.8,0.7},L);
							end
						end
					elseif SN > "AWARDILVLDG" then
						if SN < "BALANCEOFMANAVOID" then
							if SN < "AWARDILVLGD" then
								if SN < "AWARDILVLF" then
									if SN < "AWARDILVLEB" then
										if SN > "AWARDILVLE" then
											if SN == "AWARDILVLEA" then
												if Lm <= 115 then
													return CalcStat("AwardILvlE",L);
												elseif Lm <= 119 then
													return RoundDbl(LinFmod(1,350,378,116,120,L));
												elseif Lm <= 120 then
													return CalcStat("AwardILvlE",120)+26;
												else
													return CalcStat("AwardILvlE",L);
												end
											else
												return 0;
											end
										elseif SN == "AWARDILVLE" then
											if Lm <= 115 then
												return CalcStat("AwardILvlC",L);
											elseif Lm <= 120 then
												return 350;
											else
												return CalcStat("AwardILvlD",L);
											end
										else
											return 0;
										end
									elseif SN > "AWARDILVLEB" then
										if SN < "AWARDILVLED" then
											if SN == "AWARDILVLEC" then
												if Lm <= 115 then
													return CalcStat("AwardILvlE",L);
												elseif Lm <= 120 then
													return RoundDbl(LinFmod(1,350,382,116,120,L));
												else
													return CalcStat("AwardILvlE",L);
												end
											else
												return 0;
											end
										elseif SN > "AWARDILVLED" then
											if SN == "AWARDILVLEE" then
												if Lm <= 115 then
													return CalcStat("AwardILvlE",L);
												elseif Lm <= 119 then
													return RoundDbl(LinFmod(1,350,366,116,120,L));
												elseif Lm <= 120 then
													return CalcStat("AwardILvlE",120)+14;
												else
													return CalcStat("AwardILvlE",L);
												end
											else
												return 0;
											end
										else
											if Lm <= 115 then
												return CalcStat("AwardILvlE",L);
											elseif Lm <= 120 then
												return RoundDbl(LinFmod(1,350,370,116,120,L));
											else
												return CalcStat("AwardILvlE",L);
											end
										end
									else
										if Lm <= 115 then
											return CalcStat("AwardILvlE",L);
										elseif Lm <= 119 then
											return RoundDbl(LinFmod(1,350,390,116,120,L));
										elseif Lm <= 120 then
											return CalcStat("AwardILvlE",120)+38;
										else
											return CalcStat("AwardILvlE",L);
										end
									end
								elseif SN > "AWARDILVLF" then
									if SN < "AWARDILVLG" then
										if SN > "AWARDILVLFA" then
											if SN == "AWARDILVLFB" then
												if Lm <= 119 then
													return CalcStat("AwardILvlF",L);
												elseif Lm <= 120 then
													return 380;
												elseif Lm <= 129 then
													return CalcStat("AwardILvlF",L);
												elseif Lm <= 130 then
													return 432;
												elseif Lm <= 140 then
													return RoundDbl(LinFmod(1,450.4,470.4,131,140,L));
												else
													return CalcStat("AwardILvlFB",140);
												end
											else
												return 0;
											end
										elseif SN == "AWARDILVLFA" then
											if Lm <= 130 then
												return CalcStat("AwardILvlF",L);
											elseif Lm <= 140 then
												return RoundDbl(LinFmod(1,438.4,447.4,131,140,L));
											else
												return CalcStat("AwardILvlFA",140);
											end
										else
											return 0;
										end
									elseif SN > "AWARDILVLG" then
										if SN < "AWARDILVLGB" then
											if SN == "AWARDILVLGA" then
												if Lm <= 120 then
													return CalcStat("AwardILvlG",L);
												elseif Lm <= 130 then
													return RoundDbl(LinFmod(1,400.4,412.4,121,130,L));
												else
													return CalcStat("AwardILvlG",L);
												end
											else
												return 0;
											end
										elseif SN > "AWARDILVLGB" then
											if SN == "AWARDILVLGC" then
												if Lm <= 120 then
													return CalcStat("AwardILvlG",L);
												elseif Lm <= 130 then
													return RoundDbl(LinFmod(1,400.4,408.3,121,130,L));
												else
													return CalcStat("AwardILvlG",L);
												end
											else
												return 0;
											end
										else
											if Lm <= 120 then
												return CalcStat("AwardILvlG",L);
											elseif Lm <= 130 then
												return RoundDbl(LinFmod(1,400.4,418.4,121,130,L));
											else
												return CalcStat("AwardILvlG",L);
											end
										end
									else
										if Lm <= 115 then
											return CalcStat("AwardILvlC",L);
										elseif Lm <= 120 then
											return CalcStat("AwardILvlC",L)+3;
										elseif Lm <= 130 then
											return 400;
										else
											return CalcStat("AwardILvlC",L);
										end
									end
								else
									if Lm <= 40 then
										return LinFmod(1,1,40,1,40,L);
									elseif Lm <= 41 then
										return CalcStat("AwardILvlF",L-1);
									elseif Lm <= 49 then
										return LinFmod(1,41,48,42,49,L);
									elseif Lm <= 50 then
										return CalcStat("AwardILvlF",L-1);
									elseif Lm <= 55 then
										return LinFmod(1,51,55,51,55,L);
									elseif Lm <= 56 then
										return CalcStat("AwardILvlF",L-1);
									elseif Lm <= 59 then
										return LinFmod(1,56,58,57,59,L);
									elseif Lm <= 60 then
										return CalcStat("AwardILvlF",L-1);
									elseif Lm <= 64 then
										return RoundDbl(LinFmod(1,60.6,63,61,64,L));
									elseif Lm <= 65 then
										return CalcStat("AwardILvlF",L-1);
									elseif Lm <= 70 then
										return LinFmod(1,66,70,66,70,L);
									elseif Lm <= 71 then
										return CalcStat("AwardILvlF",L-1);
									elseif Lm <= 74 then
										return LinFmod(1,71,73,72,74,L);
									elseif Lm <= 75 then
										return CalcStat("AwardILvlF",L-1);
									elseif Lm <= 85 then
										return RoundDbl(LinFmod(1,80.4,123.4,76,85,L));
									elseif Lm <= 94 then
										return RoundDbl(LinFmod(1,130,169,86,94,L));
									elseif Lm <= 100 then
										return RoundDbl(LinFmod(1,175,198.4,95,100,L));
									elseif Lm <= 104 then
										return LinFmod(1,201,213,101,104,L);
									elseif Lm <= 105 then
										return 220;
									elseif Lm <= 114 then
										return RoundDbl(LinFmod(1,300,323,106,114,L));
									elseif Lm <= 115 then
										return 324;
									elseif Lm <= 120 then
										return RoundDbl(LinFmod(1,349.6,368.4,116,120,L));
									elseif Lm <= 130 then
										return RoundDbl(LinFmod(1,400.4,416.4,121,130,L));
									else
										return CalcStat("AwardILvlF",130);
									end
								end
							elseif SN > "AWARDILVLGD" then
								if SN < "AWARDILVLJA" then
									if SN < "AWARDILVLH" then
										if SN > "AWARDILVLGE" then
											if SN == "AWARDILVLGF" then
												if Lm <= 120 then
													return CalcStat("AwardILvlG",L);
												elseif Lm <= 130 then
													return RoundDbl(LinFmod(1,400.4,440.4,121,130,L));
												else
													return CalcStat("AwardILvlG",L);
												end
											else
												return 0;
											end
										elseif SN == "AWARDILVLGE" then
											if Lm <= 120 then
												return CalcStat("AwardILvlG",L);
											elseif Lm <= 130 then
												return RoundDbl(LinFmod(1,400.4,434.4,121,130,L));
											else
												return CalcStat("AwardILvlG",L);
											end
										else
											return 0;
										end
									elseif SN > "AWARDILVLH" then
										if SN < "AWARDILVLIA" then
											if SN == "AWARDILVLI" then
												if Lm <= 44 then
													return 1;
												elseif Lm <= 55 then
													return 52;
												elseif Lm <= 75 then
													return FloorDbl((L-56)/5)*5+60;
												elseif Lm <= 85 then
													return FloorDbl((L-76)/5)*29+100;
												elseif Lm <= 95 then
													return FloorDbl((L-86)/5)*20+155;
												elseif Lm <= 100 then
													return FloorDbl((L-96)/4)*10+190;
												elseif Lm <= 105 then
													return FloorDbl((L-101)/4)*35+215;
												elseif Lm <= 110 then
													return CalcStat("LvlToILvl",106)+15;
												elseif Lm <= 115 then
													return CalcStat("LvlToILvl",115);
												elseif Lm <= 119 then
													return CalcStat("LvlToILvl",116)+15;
												elseif Lm <= 120 then
													return CalcStat("LvlToILvl",120);
												elseif Lm <= 125 then
													return CalcStat("LvlToILvl",121)+15;
												elseif Lm <= 130 then
													return CalcStat("LvlToILvl",130);
												elseif Lm <= 135 then
													return CalcStat("LvlToILvl",131)+15;
												elseif Lm <= 140 then
													return CalcStat("LvlToILvl",140);
												else
													return CalcStat("AwardILvlI",140);
												end
											else
												return 0;
											end
										elseif SN > "AWARDILVLIA" then
											if SN == "AWARDILVLJ" then
												if Lm <= 19 then
													return CalcStat("AwardILvlB",L);
												elseif Lm <= 40 then
													return CalcStat("AwardILvlA",L);
												elseif Lm <= 50 then
													return RoundDbl(LinFmod(1,40.4,47.6,41,50,L));
												elseif Lm <= 120 then
													return CalcStat("AwardILvlG",L);
												elseif Lm <= 130 then
													return CalcStat("AwardILvlD",L);
												elseif Lm <= 140 then
													return RoundDbl(LinFmod(1,450.4,460.4,131,140,L));
												else
													return CalcStat("AwardILvlJ",140);
												end
											else
												return 0;
											end
										else
											if Lm <= 44 then
												return CalcStat("AwardILvlI",L);
											elseif Lm <= 55 then
												return FloorDbl((L-45)/6)+51;
											elseif Lm <= 90 then
												return CalcStat("AwardILvlI",L);
											elseif Lm <= 104 then
												return FloorDbl((L-91)/5)*25+165;
											elseif Lm <= 105 then
												return CalcStat("LvlToILvl",L);
											elseif Lm <= 110 then
												return CalcStat("LvlToILvl",106)+15;
											elseif Lm <= 115 then
												return CalcStat("LvlToILvl",115)-20;
											elseif Lm <= 120 then
												return CalcStat("LvlToILvl",116)+15;
											elseif Lm <= 125 then
												return CalcStat("LvlToILvl",121)+15;
											elseif Lm <= 130 then
												return CalcStat("LvlToILvl",130)-20;
											elseif Lm <= 135 then
												return CalcStat("LvlToILvl",131)+15;
											elseif Lm <= 140 then
												return CalcStat("LvlToILvl",140)-14;
											else
												return CalcStat("AwardILvlIA",140);
											end
										end
									else
										if Lm <= 4 then
											return CalcStat("AwardILvlA",1);
										elseif Lm <= 50 then
											return CalcStat("AwardILvlA",L-4);
										elseif Lm <= 54 then
											return CalcStat("AwardILvlA",51);
										elseif Lm <= 75 then
											return CalcStat("AwardILvlA",L-4);
										else
											return L-4;
										end
									end
								elseif SN > "AWARDILVLJA" then
									if SN < "AWARDLVLCAP" then
										if SN < "AWARDILVLJC" then
											if SN == "AWARDILVLJB" then
												if Lm <= 130 then
													return CalcStat("AwardILvlJ",L);
												elseif Lm <= 140 then
													return RoundDbl(LinFmod(1,450.4,470.4,131,140,L));
												else
													return CalcStat("AwardILvlJB",140);
												end
											else
												return 0;
											end
										elseif SN > "AWARDILVLJC" then
											if SN == "AWARDILVLJD" then
												if Lm <= 130 then
													return CalcStat("AwardILvlJ",L);
												elseif Lm <= 140 then
													return RoundDbl(LinFmod(1,450.4,480.4,131,140,L));
												else
													return CalcStat("AwardILvlJD",140);
												end
											else
												return 0;
											end
										else
											if Lm <= 130 then
												return CalcStat("AwardILvlJ",L);
											elseif Lm <= 140 then
												return RoundDbl(LinFmod(1,450.4,475.4,131,140,L));
											else
												return CalcStat("AwardILvlJC",140);
											end
										end
									elseif SN > "AWARDLVLCAP" then
										if SN < "AXEARMOURREND" then
											if SN == "AWARDLVLTOILVL" then
												return CalcStat("AwardILvlC",L);
											else
												return 0;
											end
										elseif SN > "AXEARMOURREND" then
											if SN == "AXEARMRENDPOS" then
												if Lm <= 7 then
													return RoundDbl(LinFmod(1,0.5,3.25,1,7,L));
												elseif Lm <= 14 then
													return RoundDbl(LinFmod(1,3.75,8.5,8,14,L));
												elseif Lm <= 30 then
													return RoundDbl(LinFmod(1,9,24.7,15,30,L));
												elseif Lm <= 39 then
													return RoundDbl(LinFmod(1,26.5,37,31,39,L));
												elseif Lm <= 50 then
													return RoundDbl(LinFmod(1,38.5,53,40,50,L));
												elseif Lm <= 52 then
													return 53;
												elseif Lm <= 60 then
													return RoundDbl(LinFmod(1,53.2,64.8,53,60,L));
												elseif Lm <= 77 then
													return RoundDbl(LinFmod(1,66.15,94.8,61,77,L));
												elseif Lm <= 113 then
													return RoundDbl(RoundDbl(L/3-0.5)*1.95+44.1);
												elseif Lm <= 141 then
													return 116;
												elseif Lm <= 181 then
													return RoundDbl(RoundDbl(L/4)*2+46);
												elseif Lm <= 217 then
													return RoundDbl(RoundDbl(L/4)*2+45);
												elseif Lm <= 221 then
													return 153;
												elseif Lm <= 299 then
													return 155;
												elseif Lm <= 308 then
													return RoundDbl(RoundDbl(L/2.6-0.4)*2-73);
												elseif Lm <= 317 then
													return RoundDbl(RoundDbl(L/2.74-0.75)*2-60);
												elseif Lm <= 325 then
													return 172;
												elseif Lm <= 326 then
													return 174;
												elseif Lm <= 500 then
													return ExpFmod(CalcStat("AxeArmRendPos",326),327,1,L,1);
												else
													return CalcStat("AxeArmRendPos",500);
												end
											else
												return 0;
											end
										else
											return -CalcStat("AxeArmRendPos",L);
										end
									else
										return 140;
									end
								else
									if Lm <= 130 then
										return CalcStat("AwardILvlJ",L);
									elseif Lm <= 140 then
										return RoundDbl(LinFmod(1,450.4,465.4,131,140,L));
									else
										return CalcStat("AwardILvlJA",140);
									end
								end
							else
								if Lm <= 120 then
									return CalcStat("AwardILvlG",L);
								elseif Lm <= 130 then
									return RoundDbl(LinFmod(1,400.4,426.4,121,130,L));
								else
									return CalcStat("AwardILvlG",L);
								end
							end
						elseif SN > "BALANCEOFMANAVOID" then
							if SN < "BEORNINGCDARMOURTOTACMIT" then
								if SN < "BEOFEWINNUMBERFATE" then
									if SN < "BATTLELORETACMAS" then
										if SN > "BATTLELOREMAS" then
											if SN == "BATTLELOREPHYMAS" then
												return CalcStat("BattleLoreMas",L);
											else
												return 0;
											end
										elseif SN == "BATTLELOREMAS" then
											if Lm <= 105 then
												return CalcStat("Mastery",L,2.5);
											elseif Lm <= 119 then
												return CalcStat("MasteryT",L,1.2);
											elseif Lm <= 120 then
												return CalcStat("MasteryT",L,1.6);
											elseif Lm <= 129 then
												return CalcStat("MasteryT",L,1.2);
											elseif Lm <= 130 then
												return CalcStat("MasteryT",L,1.6);
											elseif Lm <= 139 then
												return CalcStat("MasteryT",L,1.2);
											else
												return CalcStat("MasteryT",L,1.6);
											end
										else
											return 0;
										end
									elseif SN > "BATTLELORETACMAS" then
										if SN < "BEOFATE" then
											if SN == "BEOEMISSARYFATE" then
												return CalcStat("FateT",L,1.0);
											else
												return 0;
											end
										elseif SN > "BEOFATE" then
											if SN == "BEOFERALPRESFATE" then
												if Lm <= 105 then
													return RoundDbl(1.6*L+0.4);
												else
													return CalcStat("ProgExtMpExpRnd",L,CalcStat("BeoFeralPresFate",105));
												end
											else
												return 0;
											end
										else
											return CalcStat("FateT",L,CalcStat("Trait567810Choice",N)*0.4);
										end
									else
										return CalcStat("BattleLoreMas",L);
									end
								elseif SN > "BEOFEWINNUMBERFATE" then
									if SN < "BEORNINGCDAGILITYTOEVADE" then
										if SN > "BEOMIGHTOFTHEWILDMIGHT" then
											if SN == "BEORNINGCDAGILITYTOCRITHIT" then
												return 1;
											else
												return 0;
											end
										elseif SN == "BEOMIGHTOFTHEWILDMIGHT" then
											return 15;
										else
											return 0;
										end
									elseif SN > "BEORNINGCDAGILITYTOEVADE" then
										if SN < "BEORNINGCDARMOURTOOFMIT" then
											if SN == "BEORNINGCDAGILITYTOPHYMAS" then
												return 2;
											else
												return 0;
											end
										elseif SN > "BEORNINGCDARMOURTOOFMIT" then
											if SN == "BEORNINGCDARMOURTOPHYMIT" then
												return 1;
											else
												return 0;
											end
										else
											return 0.2;
										end
									else
										return 2;
									end
								else
									return -7;
								end
							elseif SN > "BEORNINGCDARMOURTOTACMIT" then
								if SN < "BEORNINGCDBASEMORALE" then
									if SN < "BEORNINGCDBASEFATE" then
										if SN > "BEORNINGCDARMOURTYPE" then
											if SN == "BEORNINGCDBASEAGILITY" then
												return CalcStat("ClassBaseMainA",L);
											else
												return 0;
											end
										elseif SN == "BEORNINGCDARMOURTYPE" then
											return 3;
										else
											return 0;
										end
									elseif SN > "BEORNINGCDBASEFATE" then
										if SN < "BEORNINGCDBASEICPR" then
											if SN == "BEORNINGCDBASEICMR" then
												return CalcStat("ClassBaseICMRM",L);
											else
												return 0;
											end
										elseif SN > "BEORNINGCDBASEICPR" then
											if SN == "BEORNINGCDBASEMIGHT" then
												return CalcStat("ClassBaseMainH",L);
											else
												return 0;
											end
										else
											return CalcStat("ClassBaseICPR",L);
										end
									else
										return CalcStat("ClassBaseMainJ",L);
									end
								elseif SN > "BEORNINGCDBASEMORALE" then
									if SN < "BEORNINGCDBASEVITALITY" then
										if SN < "BEORNINGCDBASENCPR" then
											if SN == "BEORNINGCDBASENCMR" then
												return CalcStat("ClassBaseNCMRM",L);
											else
												return 0;
											end
										elseif SN > "BEORNINGCDBASENCPR" then
											if SN == "BEORNINGCDBASEPOWER" then
												return 20;
											else
												return 0;
											end
										else
											return CalcStat("ClassBaseNCPR",L);
										end
									elseif SN > "BEORNINGCDBASEVITALITY" then
										if SN < "BEORNINGCDCANBLOCK" then
											if SN == "BEORNINGCDBASEWILL" then
												return CalcStat("ClassBaseMainF",L);
											else
												return 0;
											end
										elseif SN > "BEORNINGCDCANBLOCK" then
											if SN == "BEORNINGCDFATETOCRITHIT" then
												return 2.5;
											else
												return 0;
											end
										else
											if Lm <= 5 then
												return 0;
											else
												return 1;
											end
										end
									else
										return CalcStat("ClassBaseMainC",L);
									end
								else
									return CalcStat("ClassBaseMoraleMb",L);
								end
							else
								return 0.2;
							end
						else
							if Lm <= 105 then
								return RoundDbl(8.08*L);
							else
								return CalcStat("ProgExtHighLinExpRnd",L,CalcStat("BalanceOfManAvoid",105));
							end
						end
					else
						if Lm <= 105 then
							return CalcStat("AwardILvlD",L);
						elseif Lm <= 114 then
							return RoundDbl(LinFmod(1,300,336,106,115,L));
						elseif Lm <= 115 then
							return CalcStat("AwardILvlD",115)+40;
						else
							return CalcStat("AwardILvlD",L);
						end
					end
				elseif SN > "BEORNINGCDFATETOFINESSE" then
					if SN < "BRAWLERCDBASEFATE" then
						if SN < "BLOCKPPRAT" then
							if SN < "BEORNINGCDVITALITYTORESIST" then
								if SN < "BEORNINGCDMIGHTTOPARRY" then
									if SN < "BEORNINGCDFATETOTACMIT" then
										if SN > "BEORNINGCDFATETOICMR" then
											if SN == "BEORNINGCDFATETORESIST" then
												return 1;
											else
												return 0;
											end
										elseif SN == "BEORNINGCDFATETOICMR" then
											return 0.05;
										else
											return 0;
										end
									elseif SN > "BEORNINGCDFATETOTACMIT" then
										if SN < "BEORNINGCDMIGHTTOCRITHIT" then
											if SN == "BEORNINGCDMIGHTTOBLOCK" then
												return 2;
											else
												return 0;
											end
										elseif SN > "BEORNINGCDMIGHTTOCRITHIT" then
											if SN == "BEORNINGCDMIGHTTOEVADE" then
												return 1;
											else
												return 0;
											end
										else
											return 1;
										end
									else
										return 2;
									end
								elseif SN > "BEORNINGCDMIGHTTOPARRY" then
									if SN < "BEORNINGCDPHYMITTOOFMIT" then
										if SN > "BEORNINGCDMIGHTTOPHYMAS" then
											if SN == "BEORNINGCDMIGHTTOTACMAS" then
												return 2.5;
											else
												return 0;
											end
										elseif SN == "BEORNINGCDMIGHTTOPHYMAS" then
											return 2.5;
										else
											return 0;
										end
									elseif SN > "BEORNINGCDPHYMITTOOFMIT" then
										if SN < "BEORNINGCDVITALITYTOMORALE" then
											if SN == "BEORNINGCDTACMASTOOUTHEAL" then
												return 1;
											else
												return 0;
											end
										elseif SN > "BEORNINGCDVITALITYTOMORALE" then
											if SN == "BEORNINGCDVITALITYTONCMR" then
												return 0.12;
											else
												return 0;
											end
										else
											return 4.8;
										end
									else
										return 1;
									end
								else
									return 3;
								end
							elseif SN > "BEORNINGCDVITALITYTORESIST" then
								if SN < "BEORNINGRDPSVTWONAME" then
									if SN < "BEORNINGCDWILLTOTACMAS" then
										if SN > "BEORNINGCDWILLTOEVADE" then
											if SN == "BEORNINGCDWILLTORESIST" then
												return 1;
											else
												return 0;
											end
										elseif SN == "BEORNINGCDWILLTOEVADE" then
											return 1;
										else
											return 0;
										end
									elseif SN > "BEORNINGCDWILLTOTACMAS" then
										if SN < "BEORNINGRDPSVONEFATE" then
											if SN == "BEORNINGCDWILLTOTACMIT" then
												return 1;
											else
												return 0;
											end
										elseif SN > "BEORNINGRDPSVONEFATE" then
											if SN == "BEORNINGRDPSVONENAME" then
												return "Emissary";
											else
												return 0;
											end
										else
											return CalcStat("BeoEmissaryFate",L);
										end
									else
										return 2;
									end
								elseif SN > "BEORNINGRDPSVTWONAME" then
									if SN < "BEOTHICKHIDEVITALITY" then
										if SN < "BEORNINGRDTRAITMIGHT" then
											if SN == "BEORNINGRDTRAITFATE" then
												return CalcStat("BeoFewinNumberFate",L);
											else
												return 0;
											end
										elseif SN > "BEORNINGRDTRAITMIGHT" then
											if SN == "BEORNINGRDTRAITVITALITY" then
												return CalcStat("BeoThickHideVitality",L);
											else
												return 0;
											end
										else
											return CalcStat("BeoMightoftheWildMight",L);
										end
									elseif SN > "BEOTHICKHIDEVITALITY" then
										if SN < "BLOCK" then
											if SN == "BEOVITALITYINCREASE" then
												return CalcStat("VitalityT",L,CalcStat("Trait567810Choice",N)*0.4);
											else
												return 0;
											end
										elseif SN > "BLOCK" then
											if SN == "BLOCKPBONUS" then
												return CalcStat("BPEPBonus",L);
											else
												return 0;
											end
										else
											return CalcStat("BPE",L,N);
										end
									else
										return 15;
									end
								else
									return "";
								end
							else
								return 1;
							end
						elseif SN > "BLOCKPPRAT" then
							if SN < "BPEPRATPB" then
								if SN < "BLOCKT" then
									if SN < "BLOCKPRATPB" then
										if SN > "BLOCKPRATP" then
											if SN == "BLOCKPRATPA" then
												return CalcStat("BPEPRatPA",L);
											else
												return 0;
											end
										elseif SN == "BLOCKPRATP" then
											return CalcStat("BPEPRatP",L,N);
										else
											return 0;
										end
									elseif SN > "BLOCKPRATPB" then
										if SN < "BLOCKPRATPCAP" then
											if SN == "BLOCKPRATPC" then
												return CalcStat("BPEPRatPC",L);
											else
												return 0;
											end
										elseif SN > "BLOCKPRATPCAP" then
											if SN == "BLOCKPRATPCAPR" then
												return CalcStat("BPEPRatPCapR",L);
											else
												return 0;
											end
										else
											return CalcStat("BPEPRatPCap",L);
										end
									else
										return CalcStat("BPEPRatPB",L);
									end
								elseif SN > "BLOCKT" then
									if SN < "BPEPBONUS" then
										if SN > "BPE" then
											if SN == "BPEADJ" then
												if Lm <= 449 then
													return CalcStat("AdjItemProgRatings",L);
												elseif Lm <= 450 then
													return 1;
												else
													return 40/30;
												end
											else
												return 0;
											end
										elseif SN == "BPE" then
											return StatLinInter("PntMPRatings","ItemMedProgAlt","ProgBLow","BPEAdj",L,N);
										else
											return 0;
										end
									elseif SN > "BPEPBONUS" then
										if SN < "BPEPRATP" then
											if SN == "BPEPPRAT" then
												return CalcRatAB(CalcStat("BPEPRatPA",L),CalcStat("BPEPRatPB",L),CalcStat("BPEPRatPCapR",L),N);
											else
												return 0;
											end
										elseif SN > "BPEPRATP" then
											if SN == "BPEPRATPA" then
												if Lm <= 130 then
													return 26;
												else
													return 39;
												end
											else
												return 0;
											end
										else
											return CalcPercAB(CalcStat("BPEPRatPA",L),CalcStat("BPEPRatPB",L),CalcStat("BPEPRatPCap",L),N);
										end
									else
										return 0;
									end
								else
									return CalcStat("BPET",L,N);
								end
							elseif SN > "BPEPRATPB" then
								if SN < "BRATPROGALT" then
									if SN < "BPEPRATPCAPR" then
										if SN > "BPEPRATPC" then
											if SN == "BPEPRATPCAP" then
												return 13;
											else
												return 0;
											end
										elseif SN == "BPEPRATPC" then
											if Lm <= 130 then
												return 1;
											else
												return 0.5;
											end
										else
											return 0;
										end
									elseif SN > "BPEPRATPCAPR" then
										if SN < "BPETADJ" then
											if SN == "BPET" then
												return StatLinInter("PntMPRatings","TraitProgAlt","ProgBLow","BPETAdj",L,N);
											else
												return 0;
											end
										elseif SN > "BPETADJ" then
											if SN == "BRATPROG" then
												if Lm <= 75 then
													return LinFmod(RoundDbl(N),1,75,1,75,L);
												elseif Lm <= 76 then
													return LinFmod(1,RoundDbl(N)*75,CalcStat("StdProg",76,N),75,76,L);
												elseif Lm <= 100 then
													return LinFmod(1,CalcStat("StdProg",76,N),CalcStat("StdProg",100,N),75,100,L,-1);
												elseif Lm <= 101 then
													return CalcStat("StdProg",L,N);
												elseif Lm <= 105 then
													return LinFmod(1,CalcStat("StdProg",101,N),CalcStat("StdProg",105,N),100,105,L,-1);
												elseif Lm <= 106 then
													return CalcStat("StdProg",L,N);
												elseif Lm <= 115 then
													return LinFmod(1,CalcStat("StdProg",106,N),CalcStat("StdProg",115,N),106,115,L,-1);
												elseif Lm <= 116 then
													return CalcStat("StdProg",L,N);
												elseif Lm <= 120 then
													return LinFmod(1,CalcStat("StdProg",116,N),CalcStat("StdProg",120,N),116,120,L,-1);
												elseif Lm <= 121 then
													return CalcStat("StdProg",L,N);
												elseif Lm <= 130 then
													return LinFmod(1,CalcStat("StdProg",121,N),CalcStat("StdProg",130,N),121,130,L,-1);
												elseif Lm <= 131 then
													return LinFmod(1,CalcStat("StdProg",130,N),RoundDbl(CalcStat("StdProg",131,N),-3),130,131,L);
												else
													return LinFmod(1,RoundDbl(CalcStat("StdProg",131,N),-3),RoundDbl(CalcStat("StdProg",131,N),-3)*2,131,140,L,-1);
												end
											else
												return 0;
											end
										else
											if Lm <= 130 then
												return CalcStat("AdjTraitProgRatings",L);
											elseif Lm <= 131 then
												return 11/9.0;
											else
												return 40/30;
											end
										end
									else
										return CalcStat("BPEPRatPB",L)*CalcStat("BPEPRatPC",L);
									end
								elseif SN > "BRATPROGALT" then
									if SN < "BRAWLERCDARMOURTOPHYMIT" then
										if SN < "BRAWLERCDAGILITYTOPARRY" then
											if SN == "BRAWLERCDAGILITYTOEVADE" then
												return 3;
											else
												return 0;
											end
										elseif SN > "BRAWLERCDAGILITYTOPARRY" then
											if SN == "BRAWLERCDARMOURTOOFMIT" then
												return 0.2;
											else
												return 0;
											end
										else
											return 2;
										end
									elseif SN > "BRAWLERCDARMOURTOPHYMIT" then
										if SN < "BRAWLERCDARMOURTYPE" then
											if SN == "BRAWLERCDARMOURTOTACMIT" then
												return 0.2;
											else
												return 0;
											end
										elseif SN > "BRAWLERCDARMOURTYPE" then
											if SN == "BRAWLERCDBASEAGILITY" then
												return CalcStat("ClassBaseMainC",L);
											else
												return 0;
											end
										else
											return 3;
										end
									else
										return 1;
									end
								else
									if Lm <= 75 then
										return LinFmod(RoundDbl(N),1,75,1,75,L);
									elseif Lm <= 76 then
										return LinFmod(1,RoundDbl(N)*75,CalcStat("StdProgAlt",76,N),75,76,L);
									elseif Lm <= 100 then
										return LinFmod(1,CalcStat("StdProgAlt",76,N),CalcStat("StdProgAlt",100,N),75,100,L,-1);
									elseif Lm <= 101 then
										return CalcStat("StdProgAlt",L,N);
									elseif Lm <= 105 then
										return LinFmod(1,CalcStat("StdProgAlt",101,N),CalcStat("StdProgAlt",105,N),100,105,L,-1);
									elseif Lm <= 106 then
										return CalcStat("StdProgAlt",L,N);
									elseif Lm <= 115 then
										return LinFmod(1,CalcStat("StdProgAlt",106,N),CalcStat("StdProgAlt",115,N),106,115,L,-1);
									elseif Lm <= 116 then
										return CalcStat("StdProgAlt",L,N);
									elseif Lm <= 120 then
										return LinFmod(1,CalcStat("StdProgAlt",116,N),CalcStat("StdProgAlt",120,N),116,120,L,-1);
									elseif Lm <= 121 then
										return CalcStat("StdProgAlt",L,N);
									elseif Lm <= 130 then
										return LinFmod(1,CalcStat("StdProgAlt",121,N),CalcStat("StdProgAlt",130,N),121,130,L,-1);
									elseif Lm <= 131 then
										return CalcStat("StdProgAlt",L,N);
									else
										return LinFmod(1,CalcStat("StdProgAlt",131,N),CalcStat("StdProgAlt",131,N)*2,131,140,L,-1);
									end
								end
							else
								if Lm <= 130 then
									return CalcStat("BratProgAlt",L,CalcStat("ProgBLow",L));
								else
									return CalcStat("BratProgAlt",L,CalcStat("ProgBLowNew",L));
								end
							end
						else
							return CalcStat("BPEPPRat",L,N);
						end
					elseif SN > "BRAWLERCDBASEFATE" then
						if SN < "BRAWLERCDWILLTOTACMIT" then
							if SN < "BRAWLERCDFATETOPOWER" then
								if SN < "BRAWLERCDBASEPOWER" then
									if SN < "BRAWLERCDBASEMIGHT" then
										if SN > "BRAWLERCDBASEICMR" then
											if SN == "BRAWLERCDBASEICPR" then
												return CalcStat("ClassBaseICPR",L);
											else
												return 0;
											end
										elseif SN == "BRAWLERCDBASEICMR" then
											return CalcStat("ClassBaseICMRL",L);
										else
											return 0;
										end
									elseif SN > "BRAWLERCDBASEMIGHT" then
										if SN < "BRAWLERCDBASENCMR" then
											if SN == "BRAWLERCDBASEMORALE" then
												if Lm <= 120 then
													return CalcStat("ClassBaseMoraleMa",L);
												else
													return CalcStat("ClassBaseMoraleMa",120);
												end
											else
												return 0;
											end
										elseif SN > "BRAWLERCDBASENCMR" then
											if SN == "BRAWLERCDBASENCPR" then
												return CalcStat("ClassBaseNCPR",L);
											else
												return 0;
											end
										else
											return CalcStat("ClassBaseNCMRL",L);
										end
									else
										return CalcStat("ClassBaseMainH",L);
									end
								elseif SN > "BRAWLERCDBASEPOWER" then
									if SN < "BRAWLERCDFATETOCRITHIT" then
										if SN > "BRAWLERCDBASEVITALITY" then
											if SN == "BRAWLERCDBASEWILL" then
												return CalcStat("ClassBaseMainF",L);
											else
												return 0;
											end
										elseif SN == "BRAWLERCDBASEVITALITY" then
											return CalcStat("ClassBaseMainJ",L);
										else
											return 0;
										end
									elseif SN > "BRAWLERCDFATETOCRITHIT" then
										if SN < "BRAWLERCDFATETOICMR" then
											if SN == "BRAWLERCDFATETOFINESSE" then
												return 1;
											else
												return 0;
											end
										elseif SN > "BRAWLERCDFATETOICMR" then
											if SN == "BRAWLERCDFATETONCPR" then
												return 0.05;
											else
												return 0;
											end
										else
											return 0.025;
										end
									else
										return 2.5;
									end
								else
									return CalcStat("ClassBasePowerL",L);
								end
							elseif SN > "BRAWLERCDFATETOPOWER" then
								if SN < "BRAWLERCDMIGHTTOPHYMAS" then
									if SN < "BRAWLERCDHASPOWER" then
										if SN > "BRAWLERCDFATETORESIST" then
											if SN == "BRAWLERCDFATETOTACMIT" then
												return 1;
											else
												return 0;
											end
										elseif SN == "BRAWLERCDFATETORESIST" then
											return 1;
										else
											return 0;
										end
									elseif SN > "BRAWLERCDHASPOWER" then
										if SN < "BRAWLERCDMIGHTTOFINESSE" then
											if SN == "BRAWLERCDMIGHTTOEVADE" then
												return 3;
											else
												return 0;
											end
										elseif SN > "BRAWLERCDMIGHTTOFINESSE" then
											if SN == "BRAWLERCDMIGHTTOPARRY" then
												return 2;
											else
												return 0;
											end
										else
											return 1;
										end
									else
										return 1;
									end
								elseif SN > "BRAWLERCDMIGHTTOPHYMAS" then
									if SN < "BRAWLERCDVITALITYTONCMR" then
										if SN < "BRAWLERCDTACMASTOOUTHEAL" then
											if SN == "BRAWLERCDPHYMITTOOFMIT" then
												return 1;
											else
												return 0;
											end
										elseif SN > "BRAWLERCDTACMASTOOUTHEAL" then
											if SN == "BRAWLERCDVITALITYTOMORALE" then
												return 5;
											else
												return 0;
											end
										else
											return 1;
										end
									elseif SN > "BRAWLERCDVITALITYTONCMR" then
										if SN < "BRAWLERCDWILLTORESIST" then
											if SN == "BRAWLERCDVITALITYTORESIST" then
												return 1;
											else
												return 0;
											end
										elseif SN > "BRAWLERCDWILLTORESIST" then
											if SN == "BRAWLERCDWILLTOTACMAS" then
												return 1;
											else
												return 0;
											end
										else
											return 1;
										end
									else
										return 0.12;
									end
								else
									return 3;
								end
							else
								return 1;
							end
						elseif SN > "BRAWLERCDWILLTOTACMIT" then
							if SN < "BRWRETINTENSITYCRITHIT" then
								if SN < "BRGTRICKCNTDEFCRITDEF" then
									if SN < "BRGREVWEAKNCRITDEF" then
										if SN > "BRGALLINFINESSE" then
											if SN == "BRGALLINONEXPFINESSE" then
												return -CalcStat("FinesseT",L,2);
											else
												return 0;
											end
										elseif SN == "BRGALLINFINESSE" then
											return CalcStat("Finesse",L,2);
										else
											return 0;
										end
									elseif SN > "BRGREVWEAKNCRITDEF" then
										if SN < "BRGREVWEAKNRESIST" then
											if SN == "BRGREVWEAKNFINESSE" then
												return -CalcStat("FinesseT",L,0.4);
											else
												return 0;
											end
										elseif SN > "BRGREVWEAKNRESIST" then
											if SN == "BRGTRICKCNTDEFBPE" then
												return -CalcStat("BPET",L,1.2);
											else
												return 0;
											end
										else
											return -CalcStat("ResistT",L,0.4);
										end
									else
										return -CalcStat("CritDefT",L,0.4);
									end
								elseif SN > "BRGTRICKCNTDEFCRITDEF" then
									if SN < "BRWINNSTRCLEVTECHFINESSE" then
										if SN > "BRWAGGPOSTUREPHYMIT" then
											if SN == "BRWDEFPOSTUREPHYMAS" then
												return -CalcStat("PhyMasT",L,4);
											else
												return 0;
											end
										elseif SN == "BRWAGGPOSTUREPHYMIT" then
											return -CalcStat("PhyMitT",L,3);
										else
											return 0;
										end
									elseif SN > "BRWINNSTRCLEVTECHFINESSE" then
										if SN < "BRWMAELSTROMMIGHT" then
											if SN == "BRWINNSTRPRECISIONCRITHIT" then
												return CalcStat("CritHitT",L,CalcStat("Trait13510Choice",N)*0.2);
											else
												return 0;
											end
										elseif SN > "BRWMAELSTROMMIGHT" then
											if SN == "BRWMIGHTINCREASE" then
												return CalcStat("MightT",L,CalcStat("Trait567810Choice",N)*0.4);
											else
												return 0;
											end
										else
											return CalcStat("MightT",L,2);
										end
									else
										return CalcStat("FinesseT",L,CalcStat("Trait13510Choice",N)*0.2);
									end
								else
									return -CalcStat("CritDefT",L,0.8);
								end
							elseif SN > "BRWRETINTENSITYCRITHIT" then
								if SN < "BURGLARCDAGILITYTOCRITHIT" then
									if SN < "BRWSHAREISHEAVYCRITHIT" then
										if SN > "BRWRETPRECISIONFINESSE" then
											if SN == "BRWSHAREISBALANCEFINESSE" then
												return CalcStat("BrwInnStrClevTechFinesse",L,3);
											else
												return 0;
											end
										elseif SN == "BRWRETPRECISIONFINESSE" then
											return CalcStat("FinesseT",L,CalcStat("Trait234Choice",N));
										else
											return 0;
										end
									elseif SN > "BRWSHAREISHEAVYCRITHIT" then
										if SN < "BRWTACMIT" then
											if SN == "BRWSHATTFISTARMOUR" then
												return -CalcStat("ArmourT",L,1.6);
											else
												return 0;
											end
										elseif SN > "BRWTACMIT" then
											if SN == "BRWVITALITYINCREASE" then
												return CalcStat("VitalityT",L,CalcStat("Trait567810Choice",N)*0.4);
											else
												return 0;
											end
										else
											return CalcStat("TacMitT",L,CalcStat("Trait12345Choice",N)*0.4);
										end
									else
										return CalcStat("BrwInnStrPrecisionCritHit",L,3);
									end
								elseif SN > "BURGLARCDAGILITYTOCRITHIT" then
									if SN < "BURGLARCDARMOURTOOFMIT" then
										if SN < "BURGLARCDAGILITYTOPARRY" then
											if SN == "BURGLARCDAGILITYTOEVADE" then
												return 3;
											else
												return 0;
											end
										elseif SN > "BURGLARCDAGILITYTOPARRY" then
											if SN == "BURGLARCDAGILITYTOPHYMAS" then
												return 3;
											else
												return 0;
											end
										else
											return 2;
										end
									elseif SN > "BURGLARCDARMOURTOOFMIT" then
										if SN < "BURGLARCDARMOURTOTACMIT" then
											if SN == "BURGLARCDARMOURTOPHYMIT" then
												return 1;
											else
												return 0;
											end
										elseif SN > "BURGLARCDARMOURTOTACMIT" then
											if SN == "BURGLARCDARMOURTYPE" then
												return 2;
											else
												return 0;
											end
										else
											return 0.2;
										end
									else
										return 0.2;
									end
								else
									return 1;
								end
							else
								return CalcStat("CritHitT",L,CalcStat("Trait234Choice",N));
							end
						else
							return 2;
						end
					else
						return CalcStat("ClassBaseMainC",L);
					end
				else
					return 0.5;
				end
			elseif SN > "BURGLARCDBASEAGILITY" then
				if SN < "CHPCONTRBURNICPR" then
					if SN < "CAPTAINCDMIGHTTOPHYMAS" then
						if SN < "C" then
							if SN < "BURGLARCDFATETONCPR" then
								if SN < "BURGLARCDBASENCPR" then
									if SN < "BURGLARCDBASEICPR" then
										if SN > "BURGLARCDBASEFATE" then
											if SN == "BURGLARCDBASEICMR" then
												return CalcStat("ClassBaseICMRL",L);
											else
												return 0;
											end
										elseif SN == "BURGLARCDBASEFATE" then
											return CalcStat("ClassBaseMainC",L);
										else
											return 0;
										end
									elseif SN > "BURGLARCDBASEICPR" then
										if SN < "BURGLARCDBASEMORALE" then
											if SN == "BURGLARCDBASEMIGHT" then
												return CalcStat("ClassBaseMainH",L);
											else
												return 0;
											end
										elseif SN > "BURGLARCDBASEMORALE" then
											if SN == "BURGLARCDBASENCMR" then
												return CalcStat("ClassBaseNCMRL",L);
											else
												return 0;
											end
										else
											if Lm <= 120 then
												return CalcStat("ClassBaseMoraleMa",L);
											else
												return CalcStat("ClassBaseMoraleMa",120);
											end
										end
									else
										return CalcStat("ClassBaseICPR",L);
									end
								elseif SN > "BURGLARCDBASENCPR" then
									if SN < "BURGLARCDBASEWILL" then
										if SN > "BURGLARCDBASEPOWER" then
											if SN == "BURGLARCDBASEVITALITY" then
												return CalcStat("ClassBaseMainA",L);
											else
												return 0;
											end
										elseif SN == "BURGLARCDBASEPOWER" then
											return CalcStat("ClassBasePowerL",L);
										else
											return 0;
										end
									elseif SN > "BURGLARCDBASEWILL" then
										if SN < "BURGLARCDFATETOFINESSE" then
											if SN == "BURGLARCDFATETOCRITHIT" then
												return 2.5;
											else
												return 0;
											end
										elseif SN > "BURGLARCDFATETOFINESSE" then
											if SN == "BURGLARCDFATETOICMR" then
												return 0.025;
											else
												return 0;
											end
										else
											return 1;
										end
									else
										return CalcStat("ClassBaseMainF",L);
									end
								else
									return CalcStat("ClassBaseNCPR",L);
								end
							elseif SN > "BURGLARCDFATETONCPR" then
								if SN < "BURGLARCDPHYMITTOOFMIT" then
									if SN < "BURGLARCDFATETOTACMIT" then
										if SN > "BURGLARCDFATETOPOWER" then
											if SN == "BURGLARCDFATETORESIST" then
												return 1;
											else
												return 0;
											end
										elseif SN == "BURGLARCDFATETOPOWER" then
											return 1;
										else
											return 0;
										end
									elseif SN > "BURGLARCDFATETOTACMIT" then
										if SN < "BURGLARCDMIGHTTOBLOCK" then
											if SN == "BURGLARCDHASPOWER" then
												return 1;
											else
												return 0;
											end
										elseif SN > "BURGLARCDMIGHTTOBLOCK" then
											if SN == "BURGLARCDMIGHTTOPARRY" then
												return 2;
											else
												return 0;
											end
										else
											return 3;
										end
									else
										return 1;
									end
								elseif SN > "BURGLARCDPHYMITTOOFMIT" then
									if SN < "BURGLARCDVITALITYTORESIST" then
										if SN < "BURGLARCDVITALITYTOMORALE" then
											if SN == "BURGLARCDTACMASTOOUTHEAL" then
												return 1;
											else
												return 0;
											end
										elseif SN > "BURGLARCDVITALITYTOMORALE" then
											if SN == "BURGLARCDVITALITYTONCMR" then
												return 0.12;
											else
												return 0;
											end
										else
											return 4.5;
										end
									elseif SN > "BURGLARCDVITALITYTORESIST" then
										if SN < "BURGLARCDWILLTOTACMAS" then
											if SN == "BURGLARCDWILLTORESIST" then
												return 2;
											else
												return 0;
											end
										elseif SN > "BURGLARCDWILLTOTACMAS" then
											if SN == "BURGLARCDWILLTOTACMIT" then
												return 1;
											else
												return 0;
											end
										else
											return 1;
										end
									else
										return 1;
									end
								else
									return 1;
								end
							else
								return 0.05;
							end
						elseif SN > "C" then
							if SN < "CAPTAINCDBASENCMR" then
								if SN < "CAPTAINCDARMOURTYPE" then
									if SN < "CAPTAINCDAGILITYTOPARRY" then
										if SN > "CAPTAINCDAGILITYTOCRITHIT" then
											if SN == "CAPTAINCDAGILITYTOEVADE" then
												return 3;
											else
												return 0;
											end
										elseif SN == "CAPTAINCDAGILITYTOCRITHIT" then
											return 1;
										else
											return 0;
										end
									elseif SN > "CAPTAINCDAGILITYTOPARRY" then
										if SN < "CAPTAINCDARMOURTOPHYMIT" then
											if SN == "CAPTAINCDARMOURTOOFMIT" then
												return 0.2;
											else
												return 0;
											end
										elseif SN > "CAPTAINCDARMOURTOPHYMIT" then
											if SN == "CAPTAINCDARMOURTOTACMIT" then
												return 0.2;
											else
												return 0;
											end
										else
											return 1;
										end
									else
										return 2;
									end
								elseif SN > "CAPTAINCDARMOURTYPE" then
									if SN < "CAPTAINCDBASEICMR" then
										if SN > "CAPTAINCDBASEAGILITY" then
											if SN == "CAPTAINCDBASEFATE" then
												return CalcStat("ClassBaseMainJ",L);
											else
												return 0;
											end
										elseif SN == "CAPTAINCDBASEAGILITY" then
											return CalcStat("ClassBaseMainA",L);
										else
											return 0;
										end
									elseif SN > "CAPTAINCDBASEICMR" then
										if SN < "CAPTAINCDBASEMIGHT" then
											if SN == "CAPTAINCDBASEICPR" then
												return CalcStat("ClassBaseICPR",L);
											else
												return 0;
											end
										elseif SN > "CAPTAINCDBASEMIGHT" then
											if SN == "CAPTAINCDBASEMORALE" then
												if Lm <= 120 then
													return CalcStat("ClassBaseMoraleMb",L);
												else
													return CalcStat("ClassBaseMoraleMb",120);
												end
											else
												return 0;
											end
										else
											return CalcStat("ClassBaseMainH",L);
										end
									else
										return CalcStat("ClassBaseICMRM",L);
									end
								else
									return 3;
								end
							elseif SN > "CAPTAINCDBASENCMR" then
								if SN < "CAPTAINCDFATETOFINESSE" then
									if SN < "CAPTAINCDBASEVITALITY" then
										if SN > "CAPTAINCDBASENCPR" then
											if SN == "CAPTAINCDBASEPOWER" then
												return CalcStat("ClassBasePowerL",L);
											else
												return 0;
											end
										elseif SN == "CAPTAINCDBASENCPR" then
											return CalcStat("ClassBaseNCPR",L);
										else
											return 0;
										end
									elseif SN > "CAPTAINCDBASEVITALITY" then
										if SN < "CAPTAINCDCANBLOCK" then
											if SN == "CAPTAINCDBASEWILL" then
												return CalcStat("ClassBaseMainF",L);
											else
												return 0;
											end
										elseif SN > "CAPTAINCDCANBLOCK" then
											if SN == "CAPTAINCDFATETOCRITHIT" then
												return 2.5;
											else
												return 0;
											end
										else
											if Lm <= 14 then
												return 0;
											else
												return 1;
											end
										end
									else
										return CalcStat("ClassBaseMainC",L);
									end
								elseif SN > "CAPTAINCDFATETOFINESSE" then
									if SN < "CAPTAINCDFATETOTACMIT" then
										if SN < "CAPTAINCDFATETONCPR" then
											if SN == "CAPTAINCDFATETOICMR" then
												return 0.025;
											else
												return 0;
											end
										elseif SN > "CAPTAINCDFATETONCPR" then
											if SN == "CAPTAINCDFATETOPOWER" then
												return 1;
											else
												return 0;
											end
										else
											return 0.05;
										end
									elseif SN > "CAPTAINCDFATETOTACMIT" then
										if SN < "CAPTAINCDMIGHTTOBLOCK" then
											if SN == "CAPTAINCDHASPOWER" then
												return 1;
											else
												return 0;
											end
										elseif SN > "CAPTAINCDMIGHTTOBLOCK" then
											if SN == "CAPTAINCDMIGHTTOPARRY" then
												return 2;
											else
												return 0;
											end
										else
											return 3;
										end
									else
										return 1;
									end
								else
									return 1;
								end
							else
								return CalcStat("ClassBaseNCMRM",L);
							end
						else
							return C;
						end
					elseif SN > "CAPTAINCDMIGHTTOPHYMAS" then
						if SN < "CHAMPIONCDFATETOCRITHIT" then
							if SN < "CHAMPIONCDARMOURTOPHYMIT" then
								if SN < "CAPTAINCDWILLTORESIST" then
									if SN < "CAPTAINCDTACMASTOOUTHEAL" then
										if SN > "CAPTAINCDMIGHTTOTACMAS" then
											if SN == "CAPTAINCDPHYMITTOOFMIT" then
												return 1;
											else
												return 0;
											end
										elseif SN == "CAPTAINCDMIGHTTOTACMAS" then
											return 2.5;
										else
											return 0;
										end
									elseif SN > "CAPTAINCDTACMASTOOUTHEAL" then
										if SN < "CAPTAINCDVITALITYTONCMR" then
											if SN == "CAPTAINCDVITALITYTOMORALE" then
												return 4.5;
											else
												return 0;
											end
										elseif SN > "CAPTAINCDVITALITYTONCMR" then
											if SN == "CAPTAINCDVITALITYTORESIST" then
												return 2;
											else
												return 0;
											end
										else
											return 0.12;
										end
									else
										return 1;
									end
								elseif SN > "CAPTAINCDWILLTORESIST" then
									if SN < "CHAMPIONCDAGILITYTOCRITHIT" then
										if SN > "CAPTAINCDWILLTOTACMIT" then
											if SN == "CATMINTBEARARMOUR" then
												return CalcStat("LMCatmintBearArmour",L);
											else
												return 0;
											end
										elseif SN == "CAPTAINCDWILLTOTACMIT" then
											return 1;
										else
											return 0;
										end
									elseif SN > "CHAMPIONCDAGILITYTOCRITHIT" then
										if SN < "CHAMPIONCDAGILITYTOPARRY" then
											if SN == "CHAMPIONCDAGILITYTOEVADE" then
												return 3;
											else
												return 0;
											end
										elseif SN > "CHAMPIONCDAGILITYTOPARRY" then
											if SN == "CHAMPIONCDARMOURTOOFMIT" then
												return 0.2;
											else
												return 0;
											end
										else
											return 2;
										end
									else
										return 1;
									end
								else
									return 2;
								end
							elseif SN > "CHAMPIONCDARMOURTOPHYMIT" then
								if SN < "CHAMPIONCDBASEMIGHT" then
									if SN < "CHAMPIONCDBASEAGILITY" then
										if SN > "CHAMPIONCDARMOURTOTACMIT" then
											if SN == "CHAMPIONCDARMOURTYPE" then
												return 3;
											else
												return 0;
											end
										elseif SN == "CHAMPIONCDARMOURTOTACMIT" then
											return 0.2;
										else
											return 0;
										end
									elseif SN > "CHAMPIONCDBASEAGILITY" then
										if SN < "CHAMPIONCDBASEICMR" then
											if SN == "CHAMPIONCDBASEFATE" then
												return CalcStat("ClassBaseMainG",L);
											else
												return 0;
											end
										elseif SN > "CHAMPIONCDBASEICMR" then
											if SN == "CHAMPIONCDBASEICPR" then
												return CalcStat("ClassBaseICPR",L);
											else
												return 0;
											end
										else
											return CalcStat("ClassBaseICMRH",L);
										end
									else
										return CalcStat("ClassBaseMainH",L);
									end
								elseif SN > "CHAMPIONCDBASEMIGHT" then
									if SN < "CHAMPIONCDBASEPOWER" then
										if SN < "CHAMPIONCDBASENCMR" then
											if SN == "CHAMPIONCDBASEMORALE" then
												if Lm <= 120 then
													return CalcStat("ClassBaseMoraleHa",L);
												else
													return CalcStat("ClassBaseMoraleHa",120);
												end
											else
												return 0;
											end
										elseif SN > "CHAMPIONCDBASENCMR" then
											if SN == "CHAMPIONCDBASENCPR" then
												return CalcStat("ClassBaseNCPR",L);
											else
												return 0;
											end
										else
											return CalcStat("ClassBaseNCMRH",L);
										end
									elseif SN > "CHAMPIONCDBASEPOWER" then
										if SN < "CHAMPIONCDBASEWILL" then
											if SN == "CHAMPIONCDBASEVITALITY" then
												return CalcStat("ClassBaseMainC",L);
											else
												return 0;
											end
										elseif SN > "CHAMPIONCDBASEWILL" then
											if SN == "CHAMPIONCDCANBLOCK" then
												if Lm <= 9 then
													return 0;
												else
													return 1;
												end
											else
												return 0;
											end
										else
											return CalcStat("ClassBaseMainB",L);
										end
									else
										return CalcStat("ClassBasePowerL",L);
									end
								else
									return CalcStat("ClassBaseMainJ",L);
								end
							else
								return 1;
							end
						elseif SN > "CHAMPIONCDFATETOCRITHIT" then
							if SN < "CHAMPIONCDTACMASTOOUTHEAL" then
								if SN < "CHAMPIONCDHASPOWER" then
									if SN < "CHAMPIONCDFATETONCPR" then
										if SN > "CHAMPIONCDFATETOFINESSE" then
											if SN == "CHAMPIONCDFATETOICMR" then
												return 0.025;
											else
												return 0;
											end
										elseif SN == "CHAMPIONCDFATETOFINESSE" then
											return 1;
										else
											return 0;
										end
									elseif SN > "CHAMPIONCDFATETONCPR" then
										if SN < "CHAMPIONCDFATETORESIST" then
											if SN == "CHAMPIONCDFATETOPOWER" then
												return 1;
											else
												return 0;
											end
										elseif SN > "CHAMPIONCDFATETORESIST" then
											if SN == "CHAMPIONCDFATETOTACMIT" then
												return 1;
											else
												return 0;
											end
										else
											return 1;
										end
									else
										return 0.05;
									end
								elseif SN > "CHAMPIONCDHASPOWER" then
									if SN < "CHAMPIONCDMIGHTTOPARRY" then
										if SN > "CHAMPIONCDMIGHTTOCRITHIT" then
											if SN == "CHAMPIONCDMIGHTTOEVADE" then
												return 2;
											else
												return 0;
											end
										elseif SN == "CHAMPIONCDMIGHTTOCRITHIT" then
											return 1;
										else
											return 0;
										end
									elseif SN > "CHAMPIONCDMIGHTTOPARRY" then
										if SN < "CHAMPIONCDMIGHTTOPHYMIT" then
											if SN == "CHAMPIONCDMIGHTTOPHYMAS" then
												return 3;
											else
												return 0;
											end
										elseif SN > "CHAMPIONCDMIGHTTOPHYMIT" then
											if SN == "CHAMPIONCDPHYMITTOOFMIT" then
												return 1;
											else
												return 0;
											end
										else
											return 1;
										end
									else
										return 2;
									end
								else
									return 1;
								end
							elseif SN > "CHAMPIONCDTACMASTOOUTHEAL" then
								if SN < "CHAMPIONCDWILLTOTACMIT" then
									if SN < "CHAMPIONCDVITALITYTONCMR" then
										if SN > "CHAMPIONCDVITALITYTOBLOCK" then
											if SN == "CHAMPIONCDVITALITYTOMORALE" then
												return 4.5;
											else
												return 0;
											end
										elseif SN == "CHAMPIONCDVITALITYTOBLOCK" then
											return 1;
										else
											return 0;
										end
									elseif SN > "CHAMPIONCDVITALITYTONCMR" then
										if SN < "CHAMPIONCDWILLTORESIST" then
											if SN == "CHAMPIONCDVITALITYTORESIST" then
												return 1;
											else
												return 0;
											end
										elseif SN > "CHAMPIONCDWILLTORESIST" then
											if SN == "CHAMPIONCDWILLTOTACMAS" then
												return 1;
											else
												return 0;
											end
										else
											return 2;
										end
									else
										return 0.12;
									end
								elseif SN > "CHAMPIONCDWILLTOTACMIT" then
									if SN < "CHISELFINESSEL" then
										if SN < "CHISELCRITHITL" then
											if SN == "CHISELCRITHITH" then
												if Lm <= 105 then
													return RoundDbl(24.24*L);
												else
													return CalcStat("ProgExtHighLinExpRnd",L,CalcStat("ChiselCritHitH",105));
												end
											else
												return 0;
											end
										elseif SN > "CHISELCRITHITL" then
											if SN == "CHISELFINESSEH" then
												if Lm <= 105 then
													return RoundDbl(8.08*L);
												else
													return CalcStat("ProgExtHighLinExpRnd",L,CalcStat("ChiselFinesseH",105));
												end
											else
												return 0;
											end
										else
											if Lm <= 105 then
												return RoundDbl(16.16*L);
											else
												return CalcStat("ProgExtHighLinExpRnd",L,CalcStat("ChiselCritHitL",105));
											end
										end
									elseif SN > "CHISELFINESSEL" then
										if SN < "CHISELICPRL" then
											if SN == "CHISELICPRH" then
												if Lm <= 8 then
													return 0;
												elseif Lm <= 31 then
													return 1;
												elseif Lm <= 55 then
													return 2;
												elseif Lm <= 79 then
													return 3;
												elseif Lm <= 104 then
													return 4;
												else
													return 5;
												end
											else
												return 0;
											end
										elseif SN > "CHISELICPRL" then
											if SN == "CHP2HWPNBLOCK" then
												return CalcStat("BlockT",L,4);
											else
												return 0;
											end
										else
											if Lm <= 10 then
												return 0;
											elseif Lm <= 40 then
												return 1;
											elseif Lm <= 70 then
												return 2;
											elseif Lm <= 100 then
												return 3;
											else
												return 4;
											end
										end
									else
										if Lm <= 105 then
											return RoundDbl(4.04*L);
										else
											return CalcStat("ProgExtHighLinExpRnd",L,CalcStat("ChiselFinesseL",105));
										end
									end
								else
									return 1;
								end
							else
								return 1;
							end
						else
							return 2.5;
						end
					else
						return 2.5;
					end
				elseif SN > "CHPCONTRBURNICPR" then
					if SN < "CORSAIRCDAGILITYTOEVADE" then
						if SN < "CLASSBASEMORALEMB" then
							if SN < "CLASSBASEMAINB" then
								if SN < "CLASSBASEICMRHBASE" then
									if SN < "CHPMIGHTINCREASE" then
										if SN > "CHPFINESSEINCREASE" then
											if SN == "CHPFLURRYINCRCRITHIT" then
												if Lm <= 80 then
													return RoundDbl(16.16*L);
												else
													return CalcStat("ChpFlurryIncrCritHit",80);
												end
											else
												return 0;
											end
										elseif SN == "CHPFINESSEINCREASE" then
											return CalcStat("FinesseT",L,CalcStat("Trait12345Choice",N)*0.4);
										else
											return 0;
										end
									elseif SN > "CHPMIGHTINCREASE" then
										if SN < "CHPUNBREAKTACMIT" then
											if SN == "CHPSTALWBLADEVITALITY" then
												return CalcStat("VitalityT",L,CalcStat("Trait567810Choice",N)*0.4);
											else
												return 0;
											end
										elseif SN > "CHPUNBREAKTACMIT" then
											if SN == "CLASSBASEICMRH" then
												return CalcStat("ClassBaseICMRHBase",L);
											else
												return 0;
											end
										else
											return CalcStat("TacMitT",L,0.4);
										end
									else
										return CalcStat("MightT",L,CalcStat("Trait567810Choice",N)*0.4);
									end
								elseif SN > "CLASSBASEICMRHBASE" then
									if SN < "CLASSBASEICMRM" then
										if SN > "CLASSBASEICMRL" then
											if SN == "CLASSBASEICMRLBASE" then
												if Lm <= 50 then
													return RoundDbl(((L+1.6)/((L+1.6)+20.79))*2.334,2);
												elseif Lm <= 120 then
													return CalcStat("ClassBaseICMRLBase",50)+(L-50)*0.01;
												else
													return 2.5;
												end
											else
												return 0;
											end
										elseif SN == "CLASSBASEICMRL" then
											return CalcStat("ClassBaseICMRLBase",L);
										else
											return 0;
										end
									elseif SN > "CLASSBASEICMRM" then
										if SN < "CLASSBASEICPR" then
											if SN == "CLASSBASEICMRMBASE" then
												if Lm <= 50 then
													return RoundDbl(((L+1.5)/((L+1.5)+20.79))*2.6646,2);
												elseif Lm <= 120 then
													return CalcStat("ClassBaseICMRMBase",50)+(L-50)*0.0111;
												else
													return 2.5;
												end
											else
												return 0;
											end
										elseif SN > "CLASSBASEICPR" then
											if SN == "CLASSBASEMAINA" then
												if Lm <= 50 then
													return L+7;
												else
													return 57;
												end
											else
												return 0;
											end
										else
											if Lm <= 20 then
												return LinFmod(1,3,3,1,20,L);
											elseif Lm <= 75 then
												return LinFmod(1,3,11,20,75,L);
											elseif Lm <= 105 then
												return LinFmod(1,11,31,75,105,L);
											elseif Lm <= 115 then
												return LinFmod(1,37,61,106,115,L);
											elseif Lm <= 120 then
												return LinFmod(1,67,152,116,120,L);
											elseif Lm <= 130 then
												return LinFmod(1,213,426,121,130,L);
											else
												return LinFmod(1,520,1040,131,140,L);
											end
										end
									else
										return CalcStat("ClassBaseICMRMBase",L);
									end
								else
									if Lm <= 50 then
										return RoundDbl(((L+1.57)/((L+1.57)+20.79))*3,2);
									elseif Lm <= 120 then
										return CalcStat("ClassBaseICMRHBase",50)+(L-50)*0.0124;
									else
										return 3;
									end
								end
							elseif SN > "CLASSBASEMAINB" then
								if SN < "CLASSBASEMAINI" then
									if SN < "CLASSBASEMAINE" then
										if SN > "CLASSBASEMAINC" then
											if SN == "CLASSBASEMAIND" then
												if Lm <= 50 then
													return L+9;
												else
													return 60;
												end
											else
												return 0;
											end
										elseif SN == "CLASSBASEMAINC" then
											if Lm <= 50 then
												return L+9;
											else
												return 59;
											end
										else
											return 0;
										end
									elseif SN > "CLASSBASEMAINE" then
										if SN < "CLASSBASEMAING" then
											if SN == "CLASSBASEMAINF" then
												if Lm <= 50 then
													return RoundDbl(1.4*L+9.6);
												else
													return 80;
												end
											else
												return 0;
											end
										elseif SN > "CLASSBASEMAING" then
											if SN == "CLASSBASEMAINH" then
												if Lm <= 50 then
													return RoundDbl(1.4*L+12.6);
												else
													return 83;
												end
											else
												return 0;
											end
										else
											if Lm <= 50 then
												return RoundDbl(1.4*L+9.6);
											else
												return 81;
											end
										end
									else
										if Lm <= 50 then
											return L+10;
										else
											return 60;
										end
									end
								elseif SN > "CLASSBASEMAINI" then
									if SN < "CLASSBASEMORALEHA" then
										if SN < "CLASSBASEMAINK" then
											if SN == "CLASSBASEMAINJ" then
												if Lm <= 29 then
													return 2*L+12;
												elseif Lm <= 50 then
													return RoundDbl(1.05*L+39.65);
												else
													return 92;
												end
											else
												return 0;
											end
										elseif SN > "CLASSBASEMAINK" then
											if SN == "CLASSBASEMAINL" then
												if Lm <= 50 then
													return 2*L+12;
												else
													return 112;
												end
											else
												return 0;
											end
										else
											if Lm <= 29 then
												return 2*L+12;
											elseif Lm <= 50 then
												return RoundDbl(1.05*L+39.65);
											else
												return 93;
											end
										end
									elseif SN > "CLASSBASEMORALEHA" then
										if SN < "CLASSBASEMORALEL" then
											if SN == "CLASSBASEMORALEHB" then
												if Lm <= 20 then
													return 39*L+61;
												elseif Lm <= 65 then
													return 27*L+301;
												elseif Lm <= 71 then
													return DataTableValue({2089,2129,2176,2230,2290,2357},L-65);
												else
													return 81*L-3401;
												end
											else
												return 0;
											end
										elseif SN > "CLASSBASEMORALEL" then
											if SN == "CLASSBASEMORALEMA" then
												if Lm <= 20 then
													return 29*L+46;
												elseif Lm <= 65 then
													return 22*L+186;
												elseif Lm <= 71 then
													return DataTableValue({1643,1676,1714,1758,1807,1862},L-65);
												else
													return 66*L-2830;
												end
											else
												return 0;
											end
										else
											if Lm <= 20 then
												return 22*L+53;
											elseif Lm <= 65 then
												return 15*L+193;
											elseif Lm <= 71 then
												return DataTableValue({1186,1208,1234,1264,1297,1334},L-65);
											else
												return 45*L-1865;
											end
										end
									else
										if Lm <= 10 then
											return 39*L+61;
										elseif Lm <= 20 then
											return 39*L+46;
										elseif Lm <= 50 then
											return 27*L+286;
										elseif Lm <= 65 then
											return 27*L+274;
										elseif Lm <= 71 then
											return DataTableValue({2062,2102,2149,2203,2263,2330},L-65);
										else
											return 81*L-3428;
										end
									end
								else
									if Lm <= 50 then
										return RoundDbl(1.4*L+12.6);
									else
										return 84;
									end
								end
							else
								if Lm <= 50 then
									return L+7;
								else
									return 58;
								end
							end
						elseif SN > "CLASSBASEMORALEMB" then
							if SN < "COMBATBASELQTYMP" then
								if SN < "CLASSBASEPOWERL" then
									if SN < "CLASSBASENCMRM" then
										if SN > "CLASSBASENCMRH" then
											if SN == "CLASSBASENCMRL" then
												if Lm <= 4 then
													return 1;
												else
													return 2;
												end
											else
												return 0;
											end
										elseif SN == "CLASSBASENCMRH" then
											if Lm <= 3 then
												return 2;
											elseif Lm <= 9 then
												return 3;
											elseif Lm <= 30 then
												return 4;
											else
												return 5;
											end
										else
											return 0;
										end
									elseif SN > "CLASSBASENCMRM" then
										if SN < "CLASSBASEPOWER" then
											if SN == "CLASSBASENCPR" then
												if Lm <= 20 then
													return LinFmod(1,5,5,1,20,L);
												elseif Lm <= 75 then
													return LinFmod(1,5,21,20,75,L);
												elseif Lm <= 105 then
													return LinFmod(1,21,61,75,105,L);
												elseif Lm <= 115 then
													return LinFmod(1,73,122,106,115,L);
												elseif Lm <= 120 then
													return LinFmod(1,134,304,116,120,L);
												elseif Lm <= 130 then
													return LinFmod(1,426,851,121,130,L);
												else
													return LinFmod(1,1040,2080,131,140,L);
												end
											else
												return 0;
											end
										elseif SN > "CLASSBASEPOWER" then
											if SN == "CLASSBASEPOWERH" then
												return FloorDbl(CalcStat("ClassBasePower",L)*2.5);
											else
												return 0;
											end
										else
											if Lm <= 20 then
												return LinFmod(1,20,39,1,20,L);
											elseif Lm <= 75 then
												return LinFmod(45.4,1,3.569,21,75,L);
											elseif Lm <= 76 then
												return 1.1*CalcStat("ClassBasePower",75);
											elseif Lm <= 100 then
												return LinFmod(CalcStat("ClassBasePower",75),1.1,2,75,100,L);
											elseif Lm <= 101 then
												return 1.1*CalcStat("ClassBasePower",100);
											elseif Lm <= 105 then
												return LinFmod(RoundDbl(CalcStat("ClassBasePower",100)),1.1,1.5,100,105,L,0);
											elseif Lm <= 115 then
												return LinFmod(CalcStat("ClassBasePower",105),1.2,2,106,115,L,0);
											elseif Lm <= 120 then
												return LinFmod(CalcStat("ClassBasePower",115),1.1,2.5,116,120,L,0);
											elseif Lm <= 130 then
												return LinFmod(CalcStat("ClassBasePower",120),1.4,2.8,121,130,L,0);
											else
												return LinFmod(24940/3,1,2,131,140,L,0);
											end
										end
									else
										if Lm <= 1 then
											return 1;
										elseif Lm <= 5 then
											return 2;
										elseif Lm <= 15 then
											return 3;
										else
											return 4;
										end
									end
								elseif SN > "CLASSBASEPOWERL" then
									if SN < "COMBATBASECAT" then
										if SN > "CLOTHARMOUR" then
											if SN == "COMBATBASE" then
												return CalcStat("CombatBaseCat",WpnCodeIndex(C,1),L)*CalcStat("CombatBaseTypeMP",WpnCodeIndex(C,2))*CalcStat("CombatBaseQtyMPCat",WpnCodeIndex(C,1),WpnCodeIndex(C,3));
											else
												return 0;
											end
										elseif SN == "CLOTHARMOUR" then
											if Lm <= 50 then
												return L;
											else
												return 50;
											end
										else
											return 0;
										end
									elseif SN > "COMBATBASECAT" then
										if SN < "COMBATBASEHQTYMP" then
											if SN == "COMBATBASEH" then
												if Lm <= 50 then
													return LinFmod(1,5.01313176,66,1,50,L);
												elseif Lm <= 68 then
													return LinFmod(1,67,124,51,68,L);
												elseif Lm <= 83 then
													return LinFmod(1,130,215,69,83,L);
												elseif Lm <= 181 then
													return RoundDbl(LinFmod(1,220,400,84,181,L));
												elseif Lm <= 201 then
													return RoundDbl(LinFmod(1,401,436,182,201,L));
												elseif Lm <= 258 then
													return RoundDbl(LinFmod(1,438,537.3,202,258,L));
												elseif Lm <= 259 then
													return 541;
												elseif Lm <= 300 then
													return RoundDbl(LinFmod(1,539,610,260,300,L));
												elseif Lm <= 350 then
													return RoundDbl(LinFmod(1,672,1100,301,350,L));
												elseif Lm <= 400 then
													return RoundDbl(LinFmod(1,1110,1790,351,400,L));
												elseif Lm <= 450 then
													return RoundDbl(LinFmod(1,1800,3000,401,450,L));
												elseif Lm <= 500 then
													return RoundDbl(LinFmod(1,3025,5000,451,500,L));
												else
													return 5100;
												end
											else
												return 0;
											end
										elseif SN > "COMBATBASEHQTYMP" then
											if SN == "COMBATBASEL" then
												if Lm <= 50 then
													return L+3;
												elseif Lm <= 56 then
													return RoundDbl(2.2*L-58.6);
												elseif Lm <= 58 then
													return 4*L-160;
												elseif Lm <= 64 then
													return 2*L-43;
												elseif Lm <= 69 then
													return RoundDbl(3.8*L-158.5);
												elseif Lm <= 71 then
													return 3*L-99;
												elseif Lm <= 72 then
													return 120;
												elseif Lm <= 85 then
													return RoundDbl(4.69*L-216.5);
												elseif Lm <= 86 then
													return 183;
												elseif Lm <= 258 then
													return RoundDbl(1.434*L+60.35);
												elseif Lm <= 259 then
													return 433;
												elseif Lm <= 300 then
													return RoundDbl(1.435*L+58.65);
												elseif Lm <= 309 then
													return RoundDbl(6.15*L-1313.5);
												elseif Lm <= 317 then
													return RoundDbl(6.725*L-1491.25);
												elseif Lm <= 324 then
													return RoundDbl(7.39*L-1702.5);
												elseif Lm <= 326 then
													return 7*L-1575;
												elseif Lm <= 335 then
													return RoundDbl(8.19*L-1963.6);
												elseif Lm <= 337 then
													return 9*L-2235;
												elseif Lm <= 346 then
													return RoundDbl(9.3*L-2337.9);
												elseif Lm <= 351 then
													return 880;
												elseif Lm <= 359 then
													return RoundDbl(9.19*L-2346.35);
												elseif Lm <= 368 then
													return RoundDbl(9.99*L-2633.9);
												elseif Lm <= 377 then
													return RoundDbl(10.99*L-3002.81);
												elseif Lm <= 383 then
													return RoundDbl(11.6*L-3233.3);
												elseif Lm <= 388 then
													return RoundDbl(12.49*L-3574.14);
												elseif Lm <= 396 then
													return RoundDbl(13.19*L-3846.4);
												elseif Lm <= 400 then
													return RoundDbl(13.9*L-4127);
												elseif Lm <= 450 then
													return LinFmod(1,1440,2400,401,450,L);
												else
													return RoundDbl(CalcStat("CombatBaseH",L)*0.8);
												end
											else
												return 0;
											end
										else
											if Lm <= 0 then
												return 0;
											else
												return DataTableValue({1,1.02,1.04,1.08,1.12},L);
											end
										end
									else
										if Lm <= 0 then
											return 0;
										elseif Lm <= 1 then
											return CalcStat("CombatBaseH",N);
										else
											return CalcStat("CombatBaseL",N);
										end
									end
								else
									return FloorDbl(CalcStat("ClassBasePower",L)*2.5);
								end
							elseif SN > "COMBATBASELQTYMP" then
								if SN < "COMBATBASEQTYMPCAT" then
									if SN < "COMBATBASEMODMPPOWERDMG" then
										if SN > "COMBATBASEMODMPMORALEDMG" then
											if SN == "COMBATBASEMODMPMORALEHEAL" then
												if Lm <= 115 then
													return LinFmod(1,LotroDbl(N*50.13),LotroDbl(N*8990),1,115,L);
												elseif Lm <= 120 then
													return LinFmod(1,LotroDbl(N*8990*1.234),LotroDbl(N*8990*1.48148),116,120,L);
												elseif Lm <= 130 then
													return LinFmod(1,LotroDbl(N*8990*2.002),LotroDbl(N*8990*2.33),121,130,L);
												elseif Lm <= 140 then
													return LinFmod(1,LotroDbl(N*8990*3.334),LotroDbl(N*8990*5.56),131,140,L);
												else
													return LinFmod(1,LotroDbl(N*8990*1.001),LotroDbl(N*8990*2.002),141,150,L);
												end
											else
												return 0;
											end
										elseif SN == "COMBATBASEMODMPMORALEDMG" then
											return CalcStat("MoraleT",L,N*0.15625);
										else
											return 0;
										end
									elseif SN > "COMBATBASEMODMPPOWERDMG" then
										if SN < "COMBATBASEMODPETEXP" then
											if SN == "COMBATBASEMODMPPOWERHEAL" then
												return CalcStat("PowerT",L,N);
											else
												return 0;
											end
										elseif SN > "COMBATBASEMODPETEXP" then
											if SN == "COMBATBASEMODPETLINEXP" then
												if Lm <= 105 then
													return RoundDbl((L+(N-FloorDbl(N/1000)*1000)/200)*FloorDbl(N/1000)/300);
												else
													return CalcStat("ProgExtMedExpRaw",L,CalcStat("CombatBaseModPetLinExp",105,N));
												end
											else
												return 0;
											end
										else
											if Lm <= 1 then
												return N;
											elseif Lm <= 50 then
												return ExpFmod(CalcStat("CombatBaseModPetExp",1,N),2,5,L,nil);
											elseif Lm <= 51 then
												return ExpFmod(CalcStat("CombatBaseModPetExp",50,N),51,10,L,nil);
											elseif Lm <= 65 then
												return ExpFmod(CalcStat("CombatBaseModPetExp",51,N),52,2,L,nil);
											elseif Lm <= 66 then
												return ExpFmod(CalcStat("CombatBaseModPetExp",65,N),66,10,L,nil);
											elseif Lm <= 75 then
												return ExpFmod(CalcStat("CombatBaseModPetExp",66,N),67,3.8,L,nil);
											elseif Lm <= 76 then
												return ExpFmod(CalcStat("CombatBaseModPetExp",75,N),76,10,L,nil);
											elseif Lm <= 85 then
												return ExpFmod(CalcStat("CombatBaseModPetExp",76,N),77,4,L,nil);
											elseif Lm <= 86 then
												return ExpFmod(CalcStat("CombatBaseModPetExp",85,N),86,10,L,nil);
											elseif Lm <= 105 then
												return ExpFmod(CalcStat("CombatBaseModPetExp",86,N),87,4,L,nil);
											elseif Lm <= 106 then
												return ExpFmod(CalcStat("CombatBaseModPetExp",105,N),106,10,L,nil);
											elseif Lm <= 115 then
												return ExpFmod(CalcStat("CombatBaseModPetExp",106,N),107,5.5,L,nil);
											elseif Lm <= 116 then
												return ExpFmod(CalcStat("CombatBaseModPetExp",115,N),116,20,L,nil);
											elseif Lm <= 120 then
												return ExpFmod(CalcStat("CombatBaseModPetExp",116,N),117,5,L,nil);
											elseif Lm <= 121 then
												return ExpFmod(CalcStat("CombatBaseModPetExp",120,N),121,20,L,nil);
											elseif Lm <= 125 then
												return ExpFmod(CalcStat("CombatBaseModPetExp",121,N),122,6,L,nil);
											elseif Lm <= 126 then
												return ExpFmod(CalcStat("CombatBaseModPetExp",125,N),126,20,L,nil);
											elseif Lm <= 130 then
												return ExpFmod(CalcStat("CombatBaseModPetExp",126,N),127,6,L,nil);
											elseif Lm <= 131 then
												return ExpFmod(CalcStat("CombatBaseModPetExp",130,N),131,20,L,nil);
											elseif Lm <= 140 then
												return ExpFmod(CalcStat("CombatBaseModPetExp",131,N),132,6,L,nil);
											else
												return CalcStat("CombatBaseModPetExp",140,N);
											end
										end
									else
										if Lm <= 115 then
											return LinFmod(1,RoundDbl(N/3+1.5),CalcStat("PowerT",115,N*0.025),1,115,L);
										else
											return CalcStat("PowerT",L,N*0.025);
										end
									end
								elseif SN > "COMBATBASEQTYMPCAT" then
									if SN < "COMBATBASETYPEMP" then
										if SN < "COMBATBASETACHPS" then
											if SN == "COMBATBASETACDPS" then
												if Lm <= 258 then
													return 0.74*CalcStat("CombatBaseH",L);
												elseif Lm <= 449 then
													return 0.74*CalcStat("CombatBaseH",L+1);
												else
													return 0.74*1.1*CalcStat("CombatBaseH",L+1);
												end
											else
												return 0;
											end
										elseif SN > "COMBATBASETACHPS" then
											if SN == "COMBATBASETACHPSNOCLASS" then
												if Lm <= 0 then
													return 0;
												elseif Lm <= 50 then
													return LinFmod(2.5,1,30,1,50,L,0);
												elseif Lm <= 76 then
													return LinFmod(2.5,30,80,50,76,L,0);
												elseif Lm <= 100 then
													return LinFmod(2.5,80,150,76,100,L,0);
												elseif Lm <= 105 then
													return LinFmod(2.5,150,225,100,105,L,0);
												elseif Lm <= 115 then
													return LinFmod(2.5,270,450,106,115,L,0);
												elseif Lm <= 120 then
													return LinFmod(2.5,475,950,116,120,L,0);
												elseif Lm <= 130 then
													return LinFmod(2.5,1140,1900,121,130,L,0);
												elseif Lm <= 140 then
													return LinFmod(2.5,2660,6650,131,140,L,-1);
												else
													return CalcStat("CombatBaseTacHPSNoClass",140);
												end
											else
												return 0;
											end
										else
											if Lm <= 84 then
												return 0.47*1.02*CalcStat("CombatBaseH",L);
											elseif Lm <= 180 then
												return 0.47*RoundDbl(1.02*CalcStat("CombatBaseH",L));
											elseif Lm <= 182 then
												return 0.47*1.02*CalcStat("CombatBaseH",L);
											elseif Lm <= 200 then
												return 0.47*RoundDbl(1.02*CalcStat("CombatBaseH",L));
											elseif Lm <= 202 then
												return 0.47*1.02*CalcStat("CombatBaseH",L);
											elseif Lm <= 258 then
												return 0.47*RoundDbl(1.02*CalcStat("CombatBaseH",L));
											elseif Lm <= 298 then
												return 0.47*RoundDbl(1.02*CalcStat("CombatBaseH",L+1));
											elseif Lm <= 300 then
												return 0.47*1.02*CalcStat("CombatBaseH",L+1);
											elseif Lm <= 348 then
												return 0.47*RoundDbl(1.02*CalcStat("CombatBaseH",L+1));
											elseif Lm <= 350 then
												return 0.47*1.02*CalcStat("CombatBaseH",L+1);
											elseif Lm <= 398 then
												return 0.47*RoundDbl(1.02*CalcStat("CombatBaseH",L+1));
											elseif Lm <= 400 then
												return 0.47*1.02*CalcStat("CombatBaseH",L+1);
											elseif Lm <= 448 then
												return 0.47*RoundDbl(1.02*CalcStat("CombatBaseH",L+1));
											elseif Lm <= 449 then
												return 0.47*1.02*CalcStat("CombatBaseH",L+1);
											elseif Lm <= 499 then
												return RoundDbl(LinFmod(1,1800,2600,450,499,L));
											else
												return 2600;
											end
										end
									elseif SN > "COMBATBASETYPEMP" then
										if SN < "CONSTSTATC" then
											if SN == "COMBATINHEAL" then
												return CalcStat("InHeal",L,2.0);
											else
												return 0;
											end
										elseif SN > "CONSTSTATC" then
											if SN == "CORSAIRCDAGILITYTOCRITHIT" then
												return 1;
											else
												return 0;
											end
										else
											return CalcStat(C,1,L);
										end
									else
										if Lm <= 0 then
											return 0;
										else
											return DataTableValue({1,1.4,1.4},L);
										end
									end
								else
									if Lm <= 0 then
										return 0;
									elseif Lm <= 1 then
										return CalcStat("CombatBaseHQtyMP",N);
									else
										return CalcStat("CombatBaseLQtyMP",N);
									end
								end
							else
								if Lm <= 0 then
									return 0;
								else
									return DataTableValue({1,1,1,1,1},L);
								end
							end
						else
							if Lm <= 10 then
								return 34*L+51;
							elseif Lm <= 20 then
								return 34*L+36;
							elseif Lm <= 65 then
								return 22*L+276;
							elseif Lm <= 71 then
								return DataTableValue({1733,1766,1804,1848,1897,1952},L-65);
							else
								return 66*L-2740;
							end
						end
					elseif SN > "CORSAIRCDAGILITYTOEVADE" then
						if SN < "CORSAIRCDTACMASTOOUTHEAL" then
							if SN < "CORSAIRCDBASENCPR" then
								if SN < "CORSAIRCDBASEAGILITY" then
									if SN < "CORSAIRCDARMOURTOOFMIT" then
										if SN > "CORSAIRCDAGILITYTOPARRY" then
											if SN == "CORSAIRCDAGILITYTOPHYMAS" then
												return 3;
											else
												return 0;
											end
										elseif SN == "CORSAIRCDAGILITYTOPARRY" then
											return 2;
										else
											return 0;
										end
									elseif SN > "CORSAIRCDARMOURTOOFMIT" then
										if SN < "CORSAIRCDARMOURTOTACMIT" then
											if SN == "CORSAIRCDARMOURTOPHYMIT" then
												return 1;
											else
												return 0;
											end
										elseif SN > "CORSAIRCDARMOURTOTACMIT" then
											if SN == "CORSAIRCDARMOURTYPE" then
												return 2;
											else
												return 0;
											end
										else
											return 0.2;
										end
									else
										return 0.2;
									end
								elseif SN > "CORSAIRCDBASEAGILITY" then
									if SN < "CORSAIRCDBASEICPR" then
										if SN > "CORSAIRCDBASEFATE" then
											if SN == "CORSAIRCDBASEICMR" then
												return CalcStat("ClassBaseICMRL",L);
											else
												return 0;
											end
										elseif SN == "CORSAIRCDBASEFATE" then
											return CalcStat("ClassBaseMainC",L);
										else
											return 0;
										end
									elseif SN > "CORSAIRCDBASEICPR" then
										if SN < "CORSAIRCDBASEMORALE" then
											if SN == "CORSAIRCDBASEMIGHT" then
												return CalcStat("ClassBaseMainH",L);
											else
												return 0;
											end
										elseif SN > "CORSAIRCDBASEMORALE" then
											if SN == "CORSAIRCDBASENCMR" then
												return CalcStat("ClassBaseNCMRL",L);
											else
												return 0;
											end
										else
											if Lm <= 120 then
												return CalcStat("ClassBaseMoraleMa",L);
											else
												return CalcStat("ClassBaseMoraleMa",120);
											end
										end
									else
										return CalcStat("ClassBaseICPR",L);
									end
								else
									return CalcStat("ClassBaseMainC",L);
								end
							elseif SN > "CORSAIRCDBASENCPR" then
								if SN < "CORSAIRCDFATETONCPR" then
									if SN < "CORSAIRCDBASEWILL" then
										if SN > "CORSAIRCDBASEPOWER" then
											if SN == "CORSAIRCDBASEVITALITY" then
												return CalcStat("ClassBaseMainJ",L);
											else
												return 0;
											end
										elseif SN == "CORSAIRCDBASEPOWER" then
											return CalcStat("ClassBasePowerL",L);
										else
											return 0;
										end
									elseif SN > "CORSAIRCDBASEWILL" then
										if SN < "CORSAIRCDFATETOFINESSE" then
											if SN == "CORSAIRCDFATETOCRITHIT" then
												return 2.5;
											else
												return 0;
											end
										elseif SN > "CORSAIRCDFATETOFINESSE" then
											if SN == "CORSAIRCDFATETOICMR" then
												return 0.025;
											else
												return 0;
											end
										else
											return 1;
										end
									else
										return CalcStat("ClassBaseMainF",L);
									end
								elseif SN > "CORSAIRCDFATETONCPR" then
									if SN < "CORSAIRCDHASPOWER" then
										if SN < "CORSAIRCDFATETORESIST" then
											if SN == "CORSAIRCDFATETOPOWER" then
												return 1;
											else
												return 0;
											end
										elseif SN > "CORSAIRCDFATETORESIST" then
											if SN == "CORSAIRCDFATETOTACMIT" then
												return 1;
											else
												return 0;
											end
										else
											return 1;
										end
									elseif SN > "CORSAIRCDHASPOWER" then
										if SN < "CORSAIRCDMIGHTTOPARRY" then
											if SN == "CORSAIRCDMIGHTTOBLOCK" then
												return 3;
											else
												return 0;
											end
										elseif SN > "CORSAIRCDMIGHTTOPARRY" then
											if SN == "CORSAIRCDPHYMITTOOFMIT" then
												return 1;
											else
												return 0;
											end
										else
											return 2;
										end
									else
										return 1;
									end
								else
									return 0.05;
								end
							else
								return CalcStat("ClassBaseNCPR",L);
							end
						elseif SN > "CORSAIRCDTACMASTOOUTHEAL" then
							if SN < "CPTIDOMEMAIN" then
								if SN < "CPTBLADECRITDEF" then
									if SN < "CORSAIRCDVITALITYTORESIST" then
										if SN > "CORSAIRCDVITALITYTOMORALE" then
											if SN == "CORSAIRCDVITALITYTONCMR" then
												return 0.12;
											else
												return 0;
											end
										elseif SN == "CORSAIRCDVITALITYTOMORALE" then
											return 4.5;
										else
											return 0;
										end
									elseif SN > "CORSAIRCDVITALITYTORESIST" then
										if SN < "CORSAIRCDWILLTOTACMAS" then
											if SN == "CORSAIRCDWILLTORESIST" then
												return 2;
											else
												return 0;
											end
										elseif SN > "CORSAIRCDWILLTOTACMAS" then
											if SN == "CORSAIRCDWILLTOTACMIT" then
												return 1;
											else
												return 0;
											end
										else
											return 1;
										end
									else
										return 1;
									end
								elseif SN > "CPTBLADECRITDEF" then
									if SN < "CPTCOVMAIN" then
										if SN > "CPTBLADEPHYMAS" then
											if SN == "CPTBLADETACMAS" then
												return CalcStat("TacMasT",L,0.8);
											else
												return 0;
											end
										elseif SN == "CPTBLADEPHYMAS" then
											return CalcStat("PhyMasT",L,1.2);
										else
											return 0;
										end
									elseif SN > "CPTCOVMAIN" then
										if SN < "CPTCOVVITALITY" then
											if SN == "CPTCOVPHYMIT" then
												return CalcStat("PhyMitT",L,2.4);
											else
												return 0;
											end
										elseif SN > "CPTCOVVITALITY" then
											if SN == "CPTCRITDEF" then
												return CalcStat("CritDef",L,0.6);
											else
												return 0;
											end
										else
											return CalcStat("VitalityT",L,0.4);
										end
									else
										return CalcStat("MainT",L,0.4);
									end
								else
									return CalcStat("CritDefT",L,0.8);
								end
							elseif SN > "CPTIDOMEMAIN" then
								if SN < "CPTSONGTACMAS" then
									if SN < "CPTSHIELDPHYMAS" then
										if SN > "CPTIDOMEVITALITY" then
											if SN == "CPTSHIELDCRITDEF" then
												return CalcStat("CritDefT",L,1.2);
											else
												return 0;
											end
										elseif SN == "CPTIDOMEVITALITY" then
											return CalcStat("VitalityT",L,0.4);
										else
											return 0;
										end
									elseif SN > "CPTSHIELDPHYMAS" then
										if SN < "CPTSONGCRITDEF" then
											if SN == "CPTSHIELDTACMAS" then
												return CalcStat("TacMasT",L,0.8);
											else
												return 0;
											end
										elseif SN > "CPTSONGCRITDEF" then
											if SN == "CPTSONGPHYMAS" then
												return CalcStat("PhyMasT",L,0.8);
											else
												return 0;
											end
										else
											return CalcStat("CritDefT",L,0.8);
										end
									else
										return CalcStat("PhyMasT",L,0.8);
									end
								elseif SN > "CPTSONGTACMAS" then
									if SN < "CREEPAUDACITYDMGP" then
										if SN < "CREEPAUDACITYCOST" then
											if SN == "CREEPAUDACITYCCDP" then
												if Lm <= 0 then
													return 0;
												elseif Lm <= 15 then
													return LinFmod(1,0.5,0.5,1,15,L);
												elseif Lm <= 16 then
													return LinFmod(1,0.5,0.4,15,16,L);
												elseif Lm <= 41 then
													return LinFmod(1,0.4,0.4,16,41,L);
												elseif Lm <= 60 then
													return LinFmod(1,0.4,0.4,41,60,L);
												else
													return CalcStat("CreepAudacityCCDP",60);
												end
											else
												return 0;
											end
										elseif SN > "CREEPAUDACITYCOST" then
											if SN == "CREEPAUDACITYCOSTBASE" then
												if Lm <= 0 then
													return 0;
												elseif Lm <= 2 then
													return 2*L;
												elseif Lm <= 9 then
													return 2*L-1;
												elseif Lm <= 15 then
													return 3*L;
												elseif Lm <= 25 then
													return 6*L;
												elseif Lm <= 29 then
													return 9*L;
												elseif Lm <= 36 then
													return 300;
												else
													return 0;
												end
											else
												return 0;
											end
										else
											return CalcStat("CreepAudacityCostBase",L)*25;
										end
									elseif SN > "CREEPAUDACITYDMGP" then
										if SN < "CREEPAUDACITYMELREDP" then
											if SN == "CREEPAUDACITYMELDMGP" then
												return CalcStat("CreepAudacityDmgP",L);
											else
												return 0;
											end
										elseif SN > "CREEPAUDACITYMELREDP" then
											if SN == "CREEPAUDACITYREDP" then
												if Lm <= 0 then
													return 0;
												elseif Lm <= 10 then
													return LinFmod(1,0.45,0.45,1,10,L);
												elseif Lm <= 36 then
													return LinFmod(1,0.45,0.45,10,36,L);
												elseif Lm <= 41 then
													return LinFmod(1,0.45,0.45,36,41,L);
												elseif Lm <= 60 then
													return LinFmod(1,0.45,0.45,41,60,L);
												else
													return CalcStat("CreepAudacityRedP",60);
												end
											else
												return 0;
											end
										else
											return CalcStat("CreepAudacityRedP",L);
										end
									else
										if Lm <= 0 then
											return 0;
										elseif Lm <= 10 then
											return LinFmod(1,1,1.2,1,10,L);
										elseif Lm <= 36 then
											return LinFmod(1,1.2,1.25,10,36,L);
										elseif Lm <= 41 then
											return LinFmod(1,1.25,1.3,36,41,L);
										elseif Lm <= 60 then
											return LinFmod(1,1.3,1.25,41,60,L);
										else
											return CalcStat("CreepAudacityDmgP",60);
										end
									end
								else
									return CalcStat("TacMasT",L,1.2);
								end
							else
								return CalcStat("MainT",L,0.4);
							end
						else
							return 1;
						end
					else
						return 3;
					end
				else
					return CalcStat("ICPRT",L,0.4);
				end
			else
				return CalcStat("ClassBaseMainJ",L);
			end
		elseif SN > "CREEPAUDACITYRNGDMGP" then
			if SN < "HOBBITRDTRAITVITALITY" then
				if SN < "FINESSEPPRAT" then
					if SN < "DISEASERESISTT" then
						if SN < "CRITHITADJ" then
							if SN < "CREEPBATPROMVITALP" then
								if SN < "CREEPBATPROMHEALTHP" then
									if SN < "CREEPAUDACITYTACREDP" then
										if SN > "CREEPAUDACITYRNGREDP" then
											if SN == "CREEPAUDACITYTACDMGP" then
												return CalcStat("CreepAudacityDmgP",L);
											else
												return 0;
											end
										elseif SN == "CREEPAUDACITYRNGREDP" then
											return CalcStat("CreepAudacityRedP",L);
										else
											return 0;
										end
									elseif SN > "CREEPAUDACITYTACREDP" then
										if SN < "CREEPBATPROMDMGP" then
											if SN == "CREEPBASEPROG" then
												return LinFmod(1,LotroDbl(N),LotroDbl(100*N),1,140,L);
											else
												return 0;
											end
										elseif SN > "CREEPBATPROMDMGP" then
											if SN == "CREEPBATPROMFINESSE" then
												return 0;
											else
												return 0;
											end
										else
											if Lm <= 0 then
												return 0;
											elseif Lm <= 5 then
												return LinFmod(1,0.005,0.02,1,5,L);
											elseif Lm <= 10 then
												return LinFmod(1,0.02,0.045,5,10,L);
											elseif Lm <= 15 then
												return LinFmod(1,0.045,0.075,10,15,L);
											else
												return CalcStat("CreepBatPromDmgP",15);
											end
										end
									else
										return CalcStat("CreepAudacityRedP",L);
									end
								elseif SN > "CREEPBATPROMHEALTHP" then
									if SN < "CREEPBATPROMOUTHEALP" then
										if SN > "CREEPBATPROMINHEALP" then
											if SN == "CREEPBATPROMMELDMGP" then
												return CalcStat("CreepBatPromDmgP",L);
											else
												return 0;
											end
										elseif SN == "CREEPBATPROMINHEALP" then
											return 0;
										else
											return 0;
										end
									elseif SN > "CREEPBATPROMOUTHEALP" then
										if SN < "CREEPBATPROMRNGDMGP" then
											if SN == "CREEPBATPROMPOWERP" then
												return CalcStat("CreepBatPromVitalP",L);
											else
												return 0;
											end
										elseif SN > "CREEPBATPROMRNGDMGP" then
											if SN == "CREEPBATPROMTACDMGP" then
												return CalcStat("CreepBatPromDmgP",L);
											else
												return 0;
											end
										else
											return CalcStat("CreepBatPromDmgP",L);
										end
									else
										if Lm <= 0 then
											return 0;
										elseif Lm <= 5 then
											return LinFmod(1,0.02,0.1,1,5,L);
										elseif Lm <= 10 then
											return LinFmod(1,0.1,0.15,5,10,L);
										elseif Lm <= 15 then
											return LinFmod(1,0.15,0.2,10,15,L);
										else
											return CalcStat("CreepBatPromOutHealP",15);
										end
									end
								else
									return CalcStat("CreepBatPromVitalP",L);
								end
							elseif SN > "CREEPBATPROMVITALP" then
								if SN < "CRITDEFPRATPB" then
									if SN < "CRITDEFPBONUS" then
										if SN > "CRITDEF" then
											if SN == "CRITDEFADJ" then
												if Lm <= 449 then
													return CalcStat("AdjItemProgRatings",L);
												else
													return 100/90;
												end
											else
												return 0;
											end
										elseif SN == "CRITDEF" then
											return StatLinInter("PntMPRatings","ItemMedProgAlt","ProgBLow","CritDefAdj",L,N);
										else
											return 0;
										end
									elseif SN > "CRITDEFPBONUS" then
										if SN < "CRITDEFPRATP" then
											if SN == "CRITDEFPPRAT" then
												return CalcRatAB(CalcStat("CritDefPRatPA",L),CalcStat("CritDefPRatPB",L),CalcStat("CritDefPRatPCapR",L),N);
											else
												return 0;
											end
										elseif SN > "CRITDEFPRATP" then
											if SN == "CRITDEFPRATPA" then
												if Lm <= 130 then
													return 160;
												else
													return 240;
												end
											else
												return 0;
											end
										else
											return CalcPercAB(CalcStat("CritDefPRatPA",L),CalcStat("CritDefPRatPB",L),CalcStat("CritDefPRatPCap",L),N);
										end
									else
										return 0;
									end
								elseif SN > "CRITDEFPRATPB" then
									if SN < "CRITDEFPRATPCAPR" then
										if SN > "CRITDEFPRATPC" then
											if SN == "CRITDEFPRATPCAP" then
												return 80;
											else
												return 0;
											end
										elseif SN == "CRITDEFPRATPC" then
											if Lm <= 130 then
												return 1;
											else
												return 0.5;
											end
										else
											return 0;
										end
									elseif SN > "CRITDEFPRATPCAPR" then
										if SN < "CRITDEFTADJ" then
											if SN == "CRITDEFT" then
												return StatLinInter("PntMPRatings","TraitProgAlt","ProgBLow","CritDefTAdj",L,N);
											else
												return 0;
											end
										elseif SN > "CRITDEFTADJ" then
											if SN == "CRITHIT" then
												return StatLinInter("PntMPCritHit","ItemMedProgAlt","ProgBLow","CritHitAdj",L,N);
											else
												return 0;
											end
										else
											if Lm <= 1 then
												return 1;
											elseif Lm <= 75 then
												return 0.8;
											elseif Lm <= 121 then
												return 1;
											elseif Lm <= 130 then
												return 0.9;
											else
												return 100/90;
											end
										end
									else
										return CalcStat("CritDefPRatPB",L)*CalcStat("CritDefPRatPC",L);
									end
								else
									if Lm <= 130 then
										return CalcStat("BratProgAlt",L,CalcStat("ProgBLow",L));
									else
										return CalcStat("BratProgAlt",L,CalcStat("ProgBLowNew",L));
									end
								end
							else
								if Lm <= 0 then
									return 0;
								elseif Lm <= 5 then
									return LinFmod(1,1.02,1.1,1,5,L);
								elseif Lm <= 10 then
									return LinFmod(1,1.1,1.15,5,10,L);
								elseif Lm <= 15 then
									return LinFmod(1,1.15,1.2,10,15,L);
								else
									return CalcStat("CreepBatPromVitalP",15);
								end
							end
						elseif SN > "CRITHITADJ" then
							if SN < "CRITMAGNPRATP" then
								if SN < "CRITHITPRATPC" then
									if SN < "CRITHITPPRAT" then
										if SN > "CRITHITOLD" then
											if SN == "CRITHITPBONUS" then
												return 0;
											else
												return 0;
											end
										elseif SN == "CRITHITOLD" then
											return CalcStat("CritHit",L,N);
										else
											return 0;
										end
									elseif SN > "CRITHITPPRAT" then
										if SN < "CRITHITPRATPA" then
											if SN == "CRITHITPRATP" then
												return CalcPercAB(CalcStat("CritHitPRatPA",L),CalcStat("CritHitPRatPB",L),CalcStat("CritHitPRatPCap",L),N);
											else
												return 0;
											end
										elseif SN > "CRITHITPRATPA" then
											if SN == "CRITHITPRATPB" then
												if Lm <= 130 then
													return CalcStat("BratProgAlt",L,CalcStat("ProgBLow",L));
												else
													return CalcStat("BratProgAlt",L,CalcStat("ProgBLowNew",L));
												end
											else
												return 0;
											end
										else
											if Lm <= 130 then
												return 50;
											else
												return 75;
											end
										end
									else
										return CalcRatAB(CalcStat("CritHitPRatPA",L),CalcStat("CritHitPRatPB",L),CalcStat("CritHitPRatPCapR",L),N);
									end
								elseif SN > "CRITHITPRATPC" then
									if SN < "CRITHITT" then
										if SN > "CRITHITPRATPCAP" then
											if SN == "CRITHITPRATPCAPR" then
												return CalcStat("CritHitPRatPB",L)*CalcStat("CritHitPRatPC",L);
											else
												return 0;
											end
										elseif SN == "CRITHITPRATPCAP" then
											return 25;
										else
											return 0;
										end
									elseif SN > "CRITHITT" then
										if SN < "CRITMAGNPBONUS" then
											if SN == "CRITHITTADJ" then
												if Lm <= 130 then
													return 1;
												else
													return 80/90;
												end
											else
												return 0;
											end
										elseif SN > "CRITMAGNPBONUS" then
											if SN == "CRITMAGNPPRAT" then
												return CalcRatAB(CalcStat("CritMagnPRatPA",L),CalcStat("CritMagnPRatPB",L),CalcStat("CritMagnPRatPCapR",L),N);
											else
												return 0;
											end
										else
											return 0;
										end
									else
										return StatLinInter("PntMPCritHit","TraitProgAlt","ProgBLow","CritHitTAdj",L,N);
									end
								else
									if Lm <= 130 then
										return 1;
									else
										return 0.5;
									end
								end
							elseif SN > "CRITMAGNPRATP" then
								if SN < "DEVHITPBONUS" then
									if SN < "CRITMAGNPRATPC" then
										if SN > "CRITMAGNPRATPA" then
											if SN == "CRITMAGNPRATPB" then
												if Lm <= 130 then
													return CalcStat("BratProg",L,CalcStat("ProgBHigh",L));
												else
													return CalcStat("BratProg",L,CalcStat("ProgBHighNew",L));
												end
											else
												return 0;
											end
										elseif SN == "CRITMAGNPRATPA" then
											if Lm <= 120 then
												return 200;
											elseif Lm <= 127 then
												return (-5)*L+750;
											elseif Lm <= 130 then
												return 112.5;
											else
												return 225;
											end
										else
											return 0;
										end
									elseif SN > "CRITMAGNPRATPC" then
										if SN < "CRITMAGNPRATPCAPR" then
											if SN == "CRITMAGNPRATPCAP" then
												if Lm <= 120 then
													return 100;
												else
													return 75;
												end
											else
												return 0;
											end
										elseif SN > "CRITMAGNPRATPCAPR" then
											if SN == "CRYRESISTT" then
												return CalcStat("ResistAddT",L,N);
											else
												return 0;
											end
										else
											return CalcStat("CritMagnPRatPB",L)*CalcStat("CritMagnPRatPC",L);
										end
									else
										return CalcStat("CritMagnPRatPCAP",L)/(CalcStat("CritMagnPRatPA",L)-CalcStat("CritMagnPRatPCAP",L));
									end
								elseif SN > "DEVHITPBONUS" then
									if SN < "DEVHITPRATPB" then
										if SN < "DEVHITPRATP" then
											if SN == "DEVHITPPRAT" then
												return CalcRatAB(CalcStat("DevHitPRatPA",L),CalcStat("DevHitPRatPB",L),CalcStat("DevHitPRatPCapR",L),N);
											else
												return 0;
											end
										elseif SN > "DEVHITPRATP" then
											if SN == "DEVHITPRATPA" then
												if Lm <= 130 then
													return 20;
												else
													return 30;
												end
											else
												return 0;
											end
										else
											return CalcPercAB(CalcStat("DevHitPRatPA",L),CalcStat("DevHitPRatPB",L),CalcStat("DevHitPRatPCap",L),N);
										end
									elseif SN > "DEVHITPRATPB" then
										if SN < "DEVHITPRATPCAP" then
											if SN == "DEVHITPRATPC" then
												if Lm <= 130 then
													return 1;
												else
													return 0.5;
												end
											else
												return 0;
											end
										elseif SN > "DEVHITPRATPCAP" then
											if SN == "DEVHITPRATPCAPR" then
												return CalcStat("DevHitPRatPB",L)*CalcStat("DevHitPRatPC",L);
											else
												return 0;
											end
										else
											return 10;
										end
									else
										if Lm <= 130 then
											return CalcStat("BratProg",L,CalcStat("ProgBMedium",L));
										else
											return CalcStat("BratProg",L,CalcStat("ProgBMediumNew",L));
										end
									end
								else
									return 0;
								end
							else
								return CalcPercAB(CalcStat("CritMagnPRatPA",L),CalcStat("CritMagnPRatPB",L),CalcStat("CritMagnPRatPCap",L),N);
							end
						else
							if Lm <= 449 then
								return CalcStat("AdjItemProgRatings",L);
							elseif Lm <= 450 then
								return 83/90;
							else
								return 70/90;
							end
						end
					elseif SN > "DISEASERESISTT" then
						if SN < "DWARFUNWEARBATTLENCPR" then
							if SN < "DWARFRDTRAITICMR" then
								if SN < "DWARFLOSTDWARFKDSFATE" then
									if SN < "DMGTYPEMITT" then
										if SN > "DMGTYPEMIT" then
											if SN == "DMGTYPEMITADJ" then
												if Lm <= 449 then
													return CalcStat("AdjItemProgLow",L);
												else
													return 10/9.0;
												end
											else
												return 0;
											end
										elseif SN == "DMGTYPEMIT" then
											return StatLinInter("PntMPDmgTypeMit","ItemMedProg","ProgBMitigation","DmgTypeMitAdj",L,N);
										else
											return 0;
										end
									elseif SN > "DMGTYPEMITT" then
										if SN < "DWARFENDURVITALITY" then
											if SN == "DMGTYPEMITTADJ" then
												if Lm <= 130 then
													return 1;
												else
													return 10/9.0;
												end
											else
												return 0;
											end
										elseif SN > "DWARFENDURVITALITY" then
											if SN == "DWARFFATEFULDWARFFATE" then
												return CalcStat("FateT",L,1.0);
											else
												return 0;
											end
										else
											if Lm <= 105 then
												return RoundDbl(1.2*L);
											else
												return CalcStat("ProgExtMpExpRnd",L,CalcStat("DwarfEndurVitality",105));
											end
										end
									else
										return StatLinInter("PntMPDmgTypeMit","TraitProg","ProgBMitigation","DmgTypeMitTAdj",L,N);
									end
								elseif SN > "DWARFLOSTDWARFKDSFATE" then
									if SN < "DWARFRDPSVTWOBLOCK" then
										if SN > "DWARFRDPSVONEFATE" then
											if SN == "DWARFRDPSVONENAME" then
												return "Fateful Dwarf";
											else
												return 0;
											end
										elseif SN == "DWARFRDPSVONEFATE" then
											return CalcStat("DwarfFatefulDwarfFate",L);
										else
											return 0;
										end
									elseif SN > "DWARFRDPSVTWOBLOCK" then
										if SN < "DWARFRDTRAITAGILITY" then
											if SN == "DWARFRDPSVTWONAME" then
												return "Shield Brawler";
											else
												return 0;
											end
										elseif SN > "DWARFRDTRAITAGILITY" then
											if SN == "DWARFRDTRAITFATE" then
												return CalcStat("DwarfLostDwarfKdsFate",L);
											else
												return 0;
											end
										else
											return CalcStat("DwarfStockyAgility",L);
										end
									else
										return CalcStat("DwarfShieldBrwlBlock",L);
									end
								else
									return -7;
								end
							elseif SN > "DWARFRDTRAITICMR" then
								if SN < "DWARFSHIELDBRWLBLOCK" then
									if SN < "DWARFRDTRAITNCMR" then
										if SN > "DWARFRDTRAITICPR" then
											if SN == "DWARFRDTRAITMIGHT" then
												return CalcStat("DwarfSturdinessMight",L);
											else
												return 0;
											end
										elseif SN == "DWARFRDTRAITICPR" then
											return CalcStat("DwarfUnwearBattleICPR",L);
										else
											return 0;
										end
									elseif SN > "DWARFRDTRAITNCMR" then
										if SN < "DWARFRDTRAITPHYMITP" then
											if SN == "DWARFRDTRAITNCPR" then
												return CalcStat("DwarfUnwearBattleNCPR",L);
											else
												return 0;
											end
										elseif SN > "DWARFRDTRAITPHYMITP" then
											if SN == "DWARFRDTRAITVITALITY" then
												return CalcStat("DwarfSturdinessVitality",L);
											else
												return 0;
											end
										else
											return CalcStat("DwarfSturdinessPhyMitP",L);
										end
									else
										return CalcStat("DwarfUnwearBattleNCMR",L);
									end
								elseif SN > "DWARFSHIELDBRWLBLOCK" then
									if SN < "DWARFSTURDINESSVITALITY" then
										if SN < "DWARFSTURDINESSMIGHT" then
											if SN == "DWARFSTOCKYAGILITY" then
												return -7;
											else
												return 0;
											end
										elseif SN > "DWARFSTURDINESSMIGHT" then
											if SN == "DWARFSTURDINESSPHYMITP" then
												return 1;
											else
												return 0;
											end
										else
											return 15;
										end
									elseif SN > "DWARFSTURDINESSVITALITY" then
										if SN < "DWARFUNWEARBATTLEICPR" then
											if SN == "DWARFUNWEARBATTLEICMR" then
												return 0.5;
											else
												return 0;
											end
										elseif SN > "DWARFUNWEARBATTLEICPR" then
											if SN == "DWARFUNWEARBATTLENCMR" then
												return -1;
											else
												return 0;
											end
										else
											return 0.5;
										end
									else
										return 10;
									end
								else
									if Lm <= 105 then
										return RoundDbl(20.2*L);
									else
										return CalcStat("ProgExtHighLinExpRnd",L,CalcStat("DwarfShieldBrwlBlock",105));
									end
								end
							else
								return CalcStat("DwarfUnwearBattleICMR",L);
							end
						elseif SN > "DWARFUNWEARBATTLENCPR" then
							if SN < "EVADEPBONUS" then
								if SN < "ELFRDTRAITAGILITY" then
									if SN < "ELFFRIENDOFMANFATE" then
										if SN > "ELFAGILITYWOODSAGILITY" then
											if SN == "ELFFADINGFIRSTBORNFATE" then
												return -7;
											else
												return 0;
											end
										elseif SN == "ELFAGILITYWOODSAGILITY" then
											return 15;
										else
											return 0;
										end
									elseif SN > "ELFFRIENDOFMANFATE" then
										if SN < "ELFRDPSVONENAME" then
											if SN == "ELFRDPSVONEFATE" then
												return CalcStat("ElfFriendOfManFate",L);
											else
												return 0;
											end
										elseif SN > "ELFRDPSVONENAME" then
											if SN == "ELFRDPSVTWONAME" then
												return "";
											else
												return 0;
											end
										else
											return "Friend Of Man";
										end
									else
										return CalcStat("FateT",L,1.0);
									end
								elseif SN > "ELFRDTRAITAGILITY" then
									if SN < "ELFRDTRAITNCMR" then
										if SN > "ELFRDTRAITFATE" then
											if SN == "ELFRDTRAITMORALE" then
												return CalcStat("ElfSorrowFirstbornMorale",L);
											else
												return 0;
											end
										elseif SN == "ELFRDTRAITFATE" then
											return CalcStat("ElfFadingFirstbornFate",L);
										else
											return 0;
										end
									elseif SN > "ELFRDTRAITNCMR" then
										if SN < "ELFSORROWFIRSTBORNNCMR" then
											if SN == "ELFSORROWFIRSTBORNMORALE" then
												return -20;
											else
												return 0;
											end
										elseif SN > "ELFSORROWFIRSTBORNNCMR" then
											if SN == "EVADE" then
												return CalcStat("BPE",L,N);
											else
												return 0;
											end
										else
											return -1;
										end
									else
										return CalcStat("ElfSorrowFirstbornNCMR",L);
									end
								else
									return CalcStat("ElfAgilityWoodsAgility",L);
								end
							elseif SN > "EVADEPBONUS" then
								if SN < "EVADEPRATPCAPR" then
									if SN < "EVADEPRATPA" then
										if SN > "EVADEPPRAT" then
											if SN == "EVADEPRATP" then
												return CalcStat("BPEPRatP",L,N);
											else
												return 0;
											end
										elseif SN == "EVADEPPRAT" then
											return CalcStat("BPEPPRat",L,N);
										else
											return 0;
										end
									elseif SN > "EVADEPRATPA" then
										if SN < "EVADEPRATPC" then
											if SN == "EVADEPRATPB" then
												return CalcStat("BPEPRatPB",L);
											else
												return 0;
											end
										elseif SN > "EVADEPRATPC" then
											if SN == "EVADEPRATPCAP" then
												return CalcStat("BPEPRatPCap",L);
											else
												return 0;
											end
										else
											return CalcStat("BPEPRatPC",L);
										end
									else
										return CalcStat("BPEPRatPA",L);
									end
								elseif SN > "EVADEPRATPCAPR" then
									if SN < "FEARRESISTT" then
										if SN < "FATE" then
											if SN == "EVADET" then
												return CalcStat("BPET",L,N);
											else
												return 0;
											end
										elseif SN > "FATE" then
											if SN == "FATET" then
												return CalcStat("MainT",L,N);
											else
												return 0;
											end
										else
											return CalcStat("Main",L,N);
										end
									elseif SN > "FEARRESISTT" then
										if SN < "FINESSEADJ" then
											if SN == "FINESSE" then
												return StatLinInter("PntMPRatings","ItemMedProgAlt","ProgBLow","FinesseAdj",L,N);
											else
												return 0;
											end
										elseif SN > "FINESSEADJ" then
											if SN == "FINESSEPBONUS" then
												return 0;
											else
												return 0;
											end
										else
											if Lm <= 449 then
												return CalcStat("AdjItemProgRatings",L);
											elseif Lm <= 450 then
												return 83/90;
											elseif Lm <= 499 then
												return 100/90;
											else
												return 1;
											end
										end
									else
										return CalcStat("ResistAddT",L,N);
									end
								else
									return CalcStat("BPEPRatPCapR",L);
								end
							else
								return CalcStat("BPEPBonus",L);
							end
						else
							return -0.5;
						end
					else
						return CalcStat("ResistAddT",L,N);
					end
				elseif SN > "FINESSEPPRAT" then
					if SN < "GUARDIANCDBASEFATE" then
						if SN < "FREEPAUDACITYRNGREDP" then
							if SN < "FOODNCMRM" then
								if SN < "FINESSET" then
									if SN < "FINESSEPRATPB" then
										if SN > "FINESSEPRATP" then
											if SN == "FINESSEPRATPA" then
												if Lm <= 130 then
													return 100;
												else
													return 150;
												end
											else
												return 0;
											end
										elseif SN == "FINESSEPRATP" then
											return CalcPercAB(CalcStat("FinessePRatPA",L),CalcStat("FinessePRatPB",L),CalcStat("FinessePRatPCap",L),N);
										else
											return 0;
										end
									elseif SN > "FINESSEPRATPB" then
										if SN < "FINESSEPRATPCAP" then
											if SN == "FINESSEPRATPC" then
												if Lm <= 130 then
													return 1;
												else
													return 0.5;
												end
											else
												return 0;
											end
										elseif SN > "FINESSEPRATPCAP" then
											if SN == "FINESSEPRATPCAPR" then
												return CalcStat("FinessePRatPB",L)*CalcStat("FinessePRatPC",L);
											else
												return 0;
											end
										else
											return 50;
										end
									else
										if Lm <= 130 then
											return CalcStat("BratProgAlt",L,CalcStat("ProgBLow",L));
										else
											return CalcStat("BratProgAlt",L,CalcStat("ProgBLowNew",L));
										end
									end
								elseif SN > "FINESSET" then
									if SN < "FIREMITT" then
										if SN > "FINESSETADJ" then
											if SN == "FIREMIT" then
												return CalcStat("DmgTypeMit",L,N);
											else
												return 0;
											end
										elseif SN == "FINESSETADJ" then
											if Lm <= 130 then
												return CalcStat("AdjTraitProgRatings",L);
											elseif Lm <= 131 then
												return 80/90;
											else
												return 1;
											end
										else
											return 0;
										end
									elseif SN > "FIREMITT" then
										if SN < "FOODNCMRH" then
											if SN == "FOODNCMRBASEPROG" then
												if Lm <= 1 then
													return (N*70.2+210)/60;
												elseif Lm <= 2 then
													return (N*84+216)/120;
												else
													return (N*83.7+270)/90;
												end
											else
												return 0;
											end
										elseif SN > "FOODNCMRH" then
											if SN == "FOODNCMRL" then
												return CalcStat("FoodNCMRProg",L,2)*N;
											else
												return 0;
											end
										else
											return CalcStat("FoodNCMRProg",L,1)*N;
										end
									else
										return CalcStat("DmgTypeMitT",L,N);
									end
								else
									return StatLinInter("PntMPRatings","TraitProgAlt","ProgBLow","FinesseTAdj",L,N);
								end
							elseif SN > "FOODNCMRM" then
								if SN < "FOODRESIST" then
									if SN < "FOODNCPRH" then
										if SN > "FOODNCMRPROG" then
											if SN == "FOODNCPRBASEPROG" then
												if Lm <= 1 then
													return (N*75+300)/60;
												elseif Lm <= 2 then
													return (N*100+350)/120;
												else
													return (N*90+337.5)/90;
												end
											else
												return 0;
											end
										elseif SN == "FOODNCMRPROG" then
											if Lm <= 50 then
												return CalcStat("FoodNCMRBaseProg",N,L);
											elseif Lm <= 52 then
												return CalcStat("FoodNCMRBaseProg",N,50);
											elseif Lm <= 77 then
												return CalcStat("FoodNCMRBaseProg",N,L-3);
											elseif Lm <= 111 then
												return CalcStat("FoodNCMRBaseProg",N,RoundDbl((L+143)/3));
											elseif Lm <= 140 then
												return CalcStat("FoodNCMRBaseProg",N,85);
											elseif Lm <= 217 then
												return CalcStat("FoodNCMRBaseProg",N,RoundDbl((L+200)/4));
											elseif Lm <= 221 then
												return CalcStat("FoodNCMRBaseProg",N,104);
											elseif Lm <= 299 then
												return CalcStat("FoodNCMRBaseProg",N,105);
											elseif Lm <= 320 then
												return CalcStat("FoodNCMRBaseProg",N,RoundDbl((L-53)/(7/3)));
											elseif Lm <= 325 then
												return CalcStat("FoodNCMRBaseProg",N,114);
											elseif Lm <= 326 then
												return CalcStat("FoodNCMRBaseProg",N,115);
											else
												return ExpFmod(CalcStat("FoodNCMRProg",326,N),327,1,L,1);
											end
										else
											return 0;
										end
									elseif SN > "FOODNCPRH" then
										if SN < "FOODNCPRM" then
											if SN == "FOODNCPRL" then
												return CalcStat("FoodNCPRProg",L,2)*N;
											else
												return 0;
											end
										elseif SN > "FOODNCPRM" then
											if SN == "FOODNCPRPROG" then
												if Lm <= 1 then
													return CalcStat("FoodNCPRBaseProg",N,L);
												elseif Lm <= 6 then
													return CalcStat("FoodNCPRBaseProg",N,L)-0.25;
												elseif Lm <= 24 then
													return CalcStat("FoodNCPRBaseProg",N,L)-0.5;
												elseif Lm <= 48 then
													return CalcStat("FoodNCPRBaseProg",N,L)-0.75;
												elseif Lm <= 61 then
													return FloorDbl(CalcStat("FoodNCPRProg",48,N))+1;
												elseif Lm <= 66 then
													return FloorDbl(CalcStat("FoodNCPRProg",48,N))+2;
												elseif Lm <= 72 then
													return FloorDbl(CalcStat("FoodNCPRProg",48,N))+3;
												elseif Lm <= 326 then
													return FloorDbl(CalcStat("FoodNCPRProg",48,N))+4;
												else
													return ExpFmod(CalcStat("FoodNCPRProg",326,N),327,1,L,1);
												end
											else
												return 0;
											end
										else
											return CalcStat("FoodNCPRProg",L,3)*N;
										end
									else
										return CalcStat("FoodNCPRProg",L,1)*N;
									end
								elseif SN > "FOODRESIST" then
									if SN < "FREEPAUDACITYMELDMGP" then
										if SN < "FREEPAUDACITYCCDP" then
											if SN == "FOODRESISTADJ" then
												if Lm <= 399 then
													return 1;
												elseif Lm <= 449 then
													return 0.9;
												elseif Lm <= 450 then
													return 1;
												else
													return 100/90;
												end
											else
												return 0;
											end
										elseif SN > "FREEPAUDACITYCCDP" then
											if SN == "FREEPAUDACITYDMGP" then
												if Lm <= 0 then
													return 0;
												elseif Lm <= 15 then
													return LinFmod(1,0.75,0.75,1,15,L);
												elseif Lm <= 16 then
													return LinFmod(1,0.75,1.2,15,16,L);
												elseif Lm <= 36 then
													return LinFmod(1,1.2,1.25,16,36,L);
												elseif Lm <= 60 then
													return LinFmod(1,1.25,1.25,36,60,L);
												else
													return CalcStat("FreepAudacityDmgP",60);
												end
											else
												return 0;
											end
										else
											if Lm <= 0 then
												return 0;
											elseif Lm <= 15 then
												return LinFmod(1,0.5,0.5,1,15,L);
											elseif Lm <= 16 then
												return LinFmod(1,0.5,0.4,15,16,L);
											elseif Lm <= 41 then
												return LinFmod(1,0.4,0.4,16,41,L);
											elseif Lm <= 60 then
												return LinFmod(1,0.4,0.4,41,60,L);
											else
												return CalcStat("FreepAudacityCCDP",60);
											end
										end
									elseif SN > "FREEPAUDACITYMELDMGP" then
										if SN < "FREEPAUDACITYREDP" then
											if SN == "FREEPAUDACITYMELREDP" then
												return CalcStat("FreepAudacityRedP",L);
											else
												return 0;
											end
										elseif SN > "FREEPAUDACITYREDP" then
											if SN == "FREEPAUDACITYRNGDMGP" then
												return CalcStat("FreepAudacityDmgP",L);
											else
												return 0;
											end
										else
											if Lm <= 0 then
												return 0;
											elseif Lm <= 15 then
												return LinFmod(1,1.5,1.5,1,15,L);
											elseif Lm <= 16 then
												return LinFmod(1,1.5,0.45,15,16,L);
											elseif Lm <= 36 then
												return LinFmod(1,0.45,0.45,16,36,L);
											elseif Lm <= 60 then
												return LinFmod(1,0.45,0.45,36,60,L);
											else
												return CalcStat("FreepAudacityRedP",60);
											end
										end
									else
										return CalcStat("FreepAudacityDmgP",L);
									end
								else
									return StatLinInter("PntMPRatings","ItemMedProgAlt","ProgBLow","FoodResistAdj",L,N);
								end
							else
								return CalcStat("FoodNCMRProg",L,3)*N;
							end
						elseif SN > "FREEPAUDACITYRNGREDP" then
							if SN < "GRDTENDERIZECRITHIT" then
								if SN < "FREEPBATPROMRNGDMGP" then
									if SN < "FREEPBATPROMDMGP" then
										if SN > "FREEPAUDACITYTACDMGP" then
											if SN == "FREEPAUDACITYTACREDP" then
												return CalcStat("FreepAudacityRedP",L);
											else
												return 0;
											end
										elseif SN == "FREEPAUDACITYTACDMGP" then
											return CalcStat("FreepAudacityDmgP",L);
										else
											return 0;
										end
									elseif SN > "FREEPBATPROMDMGP" then
										if SN < "FREEPBATPROMMELDMGP" then
											if SN == "FREEPBATPROMHEALTHP" then
												return CalcStat("FreepBatPromVitalP",L);
											else
												return 0;
											end
										elseif SN > "FREEPBATPROMMELDMGP" then
											if SN == "FREEPBATPROMPOWERP" then
												return CalcStat("FreepBatPromVitalP",L);
											else
												return 0;
											end
										else
											return CalcStat("FreepBatPromDmgP",L);
										end
									else
										if Lm <= 0 then
											return 0;
										elseif Lm <= 1 then
											return 0.005;
										elseif Lm <= 14 then
											return LinFmod(1,0.005,0.065,2,14,L);
										else
											return 0.075;
										end
									end
								elseif SN > "FREEPBATPROMRNGDMGP" then
									if SN < "FROSTMIT" then
										if SN > "FREEPBATPROMTACDMGP" then
											if SN == "FREEPBATPROMVITALP" then
												if Lm <= 0 then
													return 0;
												elseif Lm <= 5 then
													return LinFmod(1,1.02,1.1,1,5,L);
												elseif Lm <= 10 then
													return LinFmod(1,1.1,1.15,5,10,L);
												elseif Lm <= 15 then
													return LinFmod(1,1.15,1.2,10,15,L);
												else
													return CalcStat("FreepBatPromVitalP",15);
												end
											else
												return 0;
											end
										elseif SN == "FREEPBATPROMTACDMGP" then
											return CalcStat("FreepBatPromDmgP",L);
										else
											return 0;
										end
									elseif SN > "FROSTMIT" then
										if SN < "GRDCRITDEF" then
											if SN == "FROSTMITT" then
												return CalcStat("DmgTypeMitT",L,N);
											else
												return 0;
											end
										elseif SN > "GRDCRITDEF" then
											if SN == "GRDRELENTLASSFINESSE" then
												return CalcStat("FinesseT",L,CalcStat("Trait12345Choice",N)*0.2);
											else
												return 0;
											end
										else
											return CalcStat("CritDef",L);
										end
									else
										return CalcStat("DmgTypeMit",L,N);
									end
								else
									return CalcStat("FreepBatPromDmgP",L);
								end
							elseif SN > "GRDTENDERIZECRITHIT" then
								if SN < "GUARDIANCDAGILITYTOCRITHIT" then
									if SN < "GRDTENDERIZET4CRITHIT" then
										if SN > "GRDTENDERIZET2CRITHIT" then
											if SN == "GRDTENDERIZET3CRITHIT" then
												return CalcStat("CritHitT",L,CalcStat("Trait357912Choice",N)*0.2);
											else
												return 0;
											end
										elseif SN == "GRDTENDERIZET2CRITHIT" then
											return CalcStat("CritHitT",L,CalcStat("Trait12345Choice",N)*0.4);
										else
											return 0;
										end
									elseif SN > "GRDTENDERIZET4CRITHIT" then
										if SN < "GRDWARDTACTBASE" then
											if SN == "GRDTENDERIZET5CRITHIT" then
												return CalcStat("CritHitT",L,CalcStat("Trait58121620Choice",N)*0.2);
											else
												return 0;
											end
										elseif SN > "GRDWARDTACTBASE" then
											if SN == "GRDWARDTACTTACMIT" then
												if Lm <= 105 then
													return RoundDbl(CalcStat("GrdWardTactBase",L,CalcStat("Trait56789Choice",N)));
												else
													return CalcStat("ProgExtHighLinExpRaw",L,CalcStat("GrdWardTactTacMit",105,N));
												end
											else
												return 0;
											end
										else
											return (3.6*L+0.2)*N;
										end
									else
										return CalcStat("CritHitT",L,CalcStat("Trait47101316Choice",N)*0.2);
									end
								elseif SN > "GUARDIANCDAGILITYTOCRITHIT" then
									if SN < "GUARDIANCDARMOURTOPHYMIT" then
										if SN < "GUARDIANCDAGILITYTOPARRY" then
											if SN == "GUARDIANCDAGILITYTOEVADE" then
												return 3;
											else
												return 0;
											end
										elseif SN > "GUARDIANCDAGILITYTOPARRY" then
											if SN == "GUARDIANCDARMOURTOOFMIT" then
												return 0.2;
											else
												return 0;
											end
										else
											return 2;
										end
									elseif SN > "GUARDIANCDARMOURTOPHYMIT" then
										if SN < "GUARDIANCDARMOURTYPE" then
											if SN == "GUARDIANCDARMOURTOTACMIT" then
												return 0.2;
											else
												return 0;
											end
										elseif SN > "GUARDIANCDARMOURTYPE" then
											if SN == "GUARDIANCDBASEAGILITY" then
												return CalcStat("ClassBaseMainC",L);
											else
												return 0;
											end
										else
											return 3;
										end
									else
										return 1;
									end
								else
									return 1;
								end
							else
								return CalcStat("CritHitT",L,CalcStat("Trait12345Choice",N)*0.2);
							end
						else
							return CalcStat("FreepAudacityRedP",L);
						end
					elseif SN > "GUARDIANCDBASEFATE" then
						if SN < "GUARDIANCDWILLTOTACMIT" then
							if SN < "GUARDIANCDFATETONCPR" then
								if SN < "GUARDIANCDBASEPOWER" then
									if SN < "GUARDIANCDBASEMIGHT" then
										if SN > "GUARDIANCDBASEICMR" then
											if SN == "GUARDIANCDBASEICPR" then
												return CalcStat("ClassBaseICPR",L);
											else
												return 0;
											end
										elseif SN == "GUARDIANCDBASEICMR" then
											return CalcStat("ClassBaseICMRH",L);
										else
											return 0;
										end
									elseif SN > "GUARDIANCDBASEMIGHT" then
										if SN < "GUARDIANCDBASENCMR" then
											if SN == "GUARDIANCDBASEMORALE" then
												if Lm <= 120 then
													return CalcStat("ClassBaseMoraleHb",L);
												else
													return CalcStat("ClassBaseMoraleHb",120);
												end
											else
												return 0;
											end
										elseif SN > "GUARDIANCDBASENCMR" then
											if SN == "GUARDIANCDBASENCPR" then
												return CalcStat("ClassBaseNCPR",L);
											else
												return 0;
											end
										else
											return CalcStat("ClassBaseNCMRH",L);
										end
									else
										return CalcStat("ClassBaseMainH",L);
									end
								elseif SN > "GUARDIANCDBASEPOWER" then
									if SN < "GUARDIANCDCANBLOCK" then
										if SN > "GUARDIANCDBASEVITALITY" then
											if SN == "GUARDIANCDBASEWILL" then
												return CalcStat("ClassBaseMainF",L);
											else
												return 0;
											end
										elseif SN == "GUARDIANCDBASEVITALITY" then
											return CalcStat("ClassBaseMainJ",L);
										else
											return 0;
										end
									elseif SN > "GUARDIANCDCANBLOCK" then
										if SN < "GUARDIANCDFATETOFINESSE" then
											if SN == "GUARDIANCDFATETOCRITHIT" then
												return 2.5;
											else
												return 0;
											end
										elseif SN > "GUARDIANCDFATETOFINESSE" then
											if SN == "GUARDIANCDFATETOICMR" then
												return 0.025;
											else
												return 0;
											end
										else
											return 1;
										end
									else
										return 1;
									end
								else
									return CalcStat("ClassBasePowerL",L);
								end
							elseif SN > "GUARDIANCDFATETONCPR" then
								if SN < "GUARDIANCDMIGHTTOPHYMAS" then
									if SN < "GUARDIANCDFATETOTACMIT" then
										if SN > "GUARDIANCDFATETOPOWER" then
											if SN == "GUARDIANCDFATETORESIST" then
												return 1;
											else
												return 0;
											end
										elseif SN == "GUARDIANCDFATETOPOWER" then
											return 1;
										else
											return 0;
										end
									elseif SN > "GUARDIANCDFATETOTACMIT" then
										if SN < "GUARDIANCDMIGHTTOBLOCK" then
											if SN == "GUARDIANCDHASPOWER" then
												return 1;
											else
												return 0;
											end
										elseif SN > "GUARDIANCDMIGHTTOBLOCK" then
											if SN == "GUARDIANCDMIGHTTOPARRY" then
												return 2;
											else
												return 0;
											end
										else
											return 3;
										end
									else
										return 1;
									end
								elseif SN > "GUARDIANCDMIGHTTOPHYMAS" then
									if SN < "GUARDIANCDVITALITYTONCMR" then
										if SN < "GUARDIANCDTACMASTOOUTHEAL" then
											if SN == "GUARDIANCDPHYMITTOOFMIT" then
												return 1;
											else
												return 0;
											end
										elseif SN > "GUARDIANCDTACMASTOOUTHEAL" then
											if SN == "GUARDIANCDVITALITYTOMORALE" then
												return 4.8;
											else
												return 0;
											end
										else
											return 1;
										end
									elseif SN > "GUARDIANCDVITALITYTONCMR" then
										if SN < "GUARDIANCDWILLTORESIST" then
											if SN == "GUARDIANCDVITALITYTORESIST" then
												return 1;
											else
												return 0;
											end
										elseif SN > "GUARDIANCDWILLTORESIST" then
											if SN == "GUARDIANCDWILLTOTACMAS" then
												return 1;
											else
												return 0;
											end
										else
											return 2;
										end
									else
										return 0.12;
									end
								else
									return 3;
								end
							else
								return 0.05;
							end
						elseif SN > "GUARDIANCDWILLTOTACMIT" then
							if SN < "HNTARMOURRENDEVADE" then
								if SN < "HIGHELFRDPSVONEWILL" then
									if SN < "HELFPEACEELDARNCMR" then
										if SN > "HELFFADINGFIRSTBORNFATE" then
											if SN == "HELFPEACEELDARMORALE" then
												return 20;
											else
												return 0;
											end
										elseif SN == "HELFFADINGFIRSTBORNFATE" then
											return -7;
										else
											return 0;
										end
									elseif SN > "HELFPEACEELDARNCMR" then
										if SN < "HELFTHOSEWHOREMAINWILL" then
											if SN == "HELFSORROWUNDYINGWILL" then
												return -7;
											else
												return 0;
											end
										elseif SN > "HELFTHOSEWHOREMAINWILL" then
											if SN == "HIGHELFRDPSVONENAME" then
												return "Those Who Remain";
											else
												return 0;
											end
										else
											return CalcStat("WillT",L,1.0);
										end
									else
										return 1;
									end
								elseif SN > "HIGHELFRDPSVONEWILL" then
									if SN < "HIGHELFRDTRAITMORALE" then
										if SN > "HIGHELFRDPSVTWONAME" then
											if SN == "HIGHELFRDTRAITFATE" then
												return CalcStat("HElfFadingFirstbornFate",L);
											else
												return 0;
											end
										elseif SN == "HIGHELFRDPSVTWONAME" then
											return "";
										else
											return 0;
										end
									elseif SN > "HIGHELFRDTRAITMORALE" then
										if SN < "HIGHELFRDTRAITWILL" then
											if SN == "HIGHELFRDTRAITNCMR" then
												return CalcStat("HElfPeaceEldarNCMR",L);
											else
												return 0;
											end
										elseif SN > "HIGHELFRDTRAITWILL" then
											if SN == "HNTARMOURRENDBLOCK" then
												return -CalcStat("Block",L,CalcStat("Trait23456Choice",N)*0.66);
											else
												return 0;
											end
										else
											return CalcStat("HElfSorrowUndyingWill",L);
										end
									else
										return CalcStat("HElfPeaceEldarMorale",L);
									end
								else
									return CalcStat("HElfThoseWhoRemainWill",L);
								end
							elseif SN > "HNTARMOURRENDEVADE" then
								if SN < "HNTRAPIDFIREPHYMAS" then
									if SN < "HNTCAMPFIRENCMR" then
										if SN > "HNTARMOURRENDPARRY" then
											if SN == "HNTBREACHFINDERRNGMIT" then
												return (-20)*L;
											else
												return 0;
											end
										elseif SN == "HNTARMOURRENDPARRY" then
											return -CalcStat("ParryT",L,CalcStat("Trait23456Choice",N)*0.4);
										else
											return 0;
										end
									elseif SN > "HNTCAMPFIRENCMR" then
										if SN < "HNTPRECISIONSTANCEFINESSE" then
											if SN == "HNTCAMPFIRENCPR" then
												return CalcStat("NCPRT",L,1.2);
											else
												return 0;
											end
										elseif SN > "HNTPRECISIONSTANCEFINESSE" then
											if SN == "HNTPURGEPOISONRESIST" then
												return CalcStat("PoisonResistT",L,4);
											else
												return 0;
											end
										else
											return CalcStat("FinesseT",L,1.6);
										end
									else
										return CalcStat("NCMRT",L,1.2);
									end
								elseif SN > "HNTRAPIDFIREPHYMAS" then
									if SN < "HOBBITRDPSVONENAME" then
										if SN < "HNTSTRENGTHSTANCECRITHIT" then
											if SN == "HNTRAPIDFIRESEL" then
												if Lm <= 0 then
													return 0;
												elseif Lm <= 8 then
													return L+2;
												elseif Lm <= 10 then
													return 2*L-6;
												else
													return CalcStat("HntRapidFireSel",10);
												end
											else
												return 0;
											end
										elseif SN > "HNTSTRENGTHSTANCECRITHIT" then
											if SN == "HOBBITRDPSVONEMIGHT" then
												return CalcStat("HobHobbitStatureMight",L);
											else
												return 0;
											end
										else
											return CalcStat("CritHitT",L,4);
										end
									elseif SN > "HOBBITRDPSVONENAME" then
										if SN < "HOBBITRDTRAITMIGHT" then
											if SN == "HOBBITRDPSVTWONAME" then
												return "";
											else
												return 0;
											end
										elseif SN > "HOBBITRDTRAITMIGHT" then
											if SN == "HOBBITRDTRAITNCMR" then
												return CalcStat("HobRapidRecoveryNCMR",L);
											else
												return 0;
											end
										else
											return CalcStat("HobSmallSizeMight",L);
										end
									else
										return "Hobbit-stature";
									end
								else
									return CalcStat("PhyMasT",L,CalcStat("HntRapidFireSel",N)*0.2);
								end
							else
								return -CalcStat("EvadeT",L,CalcStat("Trait23456Choice",N)*0.4);
							end
						else
							return 1;
						end
					else
						return CalcStat("ClassBaseMainA",L);
					end
				else
					return CalcRatAB(CalcStat("FinessePRatPA",L),CalcStat("FinessePRatPB",L),CalcStat("FinessePRatPCapR",L),N);
				end
			elseif SN > "HOBBITRDTRAITVITALITY" then
				if SN < "LMKNOWLEDGELMPHYRES" then
					if SN < "INDMGPRATPC" then
						if SN < "HUNTERCDFATETOPOWER" then
							if SN < "HUNTERCDBASEAGILITY" then
								if SN < "HUNTERCDAGILITYTOEVADE" then
									if SN < "HOBRAPIDRECOVERYNCMR" then
										if SN > "HOBHOBBITSTATUREMIGHT" then
											if SN == "HOBHOBBITTOUGHNVITALITY" then
												return 15;
											else
												return 0;
											end
										elseif SN == "HOBHOBBITSTATUREMIGHT" then
											return CalcStat("MightT",L,1.0);
										else
											return 0;
										end
									elseif SN > "HOBRAPIDRECOVERYNCMR" then
										if SN < "HOPEMORALEP" then
											if SN == "HOBSMALLSIZEMIGHT" then
												return -7;
											else
												return 0;
											end
										elseif SN > "HOPEMORALEP" then
											if SN == "HUNTERCDAGILITYTOCRITHIT" then
												return 1;
											else
												return 0;
											end
										else
											if Lm <= 5 then
												return DataTableValue({-0.99,-0.97,-0.95,-0.9,-0.85,-0.8,-0.65,-0.6,-0.5,-0.4,-0.3,-0.2,-0.15,-0.1,-0.05,0,0.01,0.02,0.03,0.04,0.05},L+16);
											else
												return 0.05;
											end
										end
									else
										return 1;
									end
								elseif SN > "HUNTERCDAGILITYTOEVADE" then
									if SN < "HUNTERCDARMOURTOOFMIT" then
										if SN > "HUNTERCDAGILITYTOPARRY" then
											if SN == "HUNTERCDAGILITYTOPHYMAS" then
												return 3;
											else
												return 0;
											end
										elseif SN == "HUNTERCDAGILITYTOPARRY" then
											return 2;
										else
											return 0;
										end
									elseif SN > "HUNTERCDARMOURTOOFMIT" then
										if SN < "HUNTERCDARMOURTOTACMIT" then
											if SN == "HUNTERCDARMOURTOPHYMIT" then
												return 1;
											else
												return 0;
											end
										elseif SN > "HUNTERCDARMOURTOTACMIT" then
											if SN == "HUNTERCDARMOURTYPE" then
												return 2;
											else
												return 0;
											end
										else
											return 0.2;
										end
									else
										return 0.2;
									end
								else
									return 3;
								end
							elseif SN > "HUNTERCDBASEAGILITY" then
								if SN < "HUNTERCDBASENCPR" then
									if SN < "HUNTERCDBASEICPR" then
										if SN > "HUNTERCDBASEFATE" then
											if SN == "HUNTERCDBASEICMR" then
												return CalcStat("ClassBaseICMRM",L);
											else
												return 0;
											end
										elseif SN == "HUNTERCDBASEFATE" then
											return CalcStat("ClassBaseMainE",L);
										else
											return 0;
										end
									elseif SN > "HUNTERCDBASEICPR" then
										if SN < "HUNTERCDBASEMORALE" then
											if SN == "HUNTERCDBASEMIGHT" then
												return CalcStat("ClassBaseMainA",L);
											else
												return 0;
											end
										elseif SN > "HUNTERCDBASEMORALE" then
											if SN == "HUNTERCDBASENCMR" then
												return CalcStat("ClassBaseNCMRM",L);
											else
												return 0;
											end
										else
											if Lm <= 120 then
												return CalcStat("ClassBaseMoraleMa",L);
											else
												return CalcStat("ClassBaseMoraleMa",120);
											end
										end
									else
										return CalcStat("ClassBaseICPR",L);
									end
								elseif SN > "HUNTERCDBASENCPR" then
									if SN < "HUNTERCDFATETOCRITHIT" then
										if SN < "HUNTERCDBASEVITALITY" then
											if SN == "HUNTERCDBASEPOWER" then
												return CalcStat("ClassBasePowerL",L);
											else
												return 0;
											end
										elseif SN > "HUNTERCDBASEVITALITY" then
											if SN == "HUNTERCDBASEWILL" then
												return CalcStat("ClassBaseMainH",L);
											else
												return 0;
											end
										else
											return CalcStat("ClassBaseMainC",L);
										end
									elseif SN > "HUNTERCDFATETOCRITHIT" then
										if SN < "HUNTERCDFATETOICMR" then
											if SN == "HUNTERCDFATETOFINESSE" then
												return 1;
											else
												return 0;
											end
										elseif SN > "HUNTERCDFATETOICMR" then
											if SN == "HUNTERCDFATETONCPR" then
												return 0.05;
											else
												return 0;
											end
										else
											return 0.025;
										end
									else
										return 2.5;
									end
								else
									return CalcStat("ClassBaseNCPR",L);
								end
							else
								return CalcStat("ClassBaseMainL",L);
							end
						elseif SN > "HUNTERCDFATETOPOWER" then
							if SN < "HUNTERCDWILLTOTACMIT" then
								if SN < "HUNTERCDTACMASTOOUTHEAL" then
									if SN < "HUNTERCDHASPOWER" then
										if SN > "HUNTERCDFATETORESIST" then
											if SN == "HUNTERCDFATETOTACMIT" then
												return 1;
											else
												return 0;
											end
										elseif SN == "HUNTERCDFATETORESIST" then
											return 1;
										else
											return 0;
										end
									elseif SN > "HUNTERCDHASPOWER" then
										if SN < "HUNTERCDMIGHTTOPARRY" then
											if SN == "HUNTERCDMIGHTTOBLOCK" then
												return 3;
											else
												return 0;
											end
										elseif SN > "HUNTERCDMIGHTTOPARRY" then
											if SN == "HUNTERCDPHYMITTOOFMIT" then
												return 1;
											else
												return 0;
											end
										else
											return 2;
										end
									else
										return 1;
									end
								elseif SN > "HUNTERCDTACMASTOOUTHEAL" then
									if SN < "HUNTERCDVITALITYTORESIST" then
										if SN > "HUNTERCDVITALITYTOMORALE" then
											if SN == "HUNTERCDVITALITYTONCMR" then
												return 0.12;
											else
												return 0;
											end
										elseif SN == "HUNTERCDVITALITYTOMORALE" then
											return 4;
										else
											return 0;
										end
									elseif SN > "HUNTERCDVITALITYTORESIST" then
										if SN < "HUNTERCDWILLTORESIST" then
											if SN == "HUNTERCDVITALITYTOTACMIT" then
												return 1;
											else
												return 0;
											end
										elseif SN > "HUNTERCDWILLTORESIST" then
											if SN == "HUNTERCDWILLTOTACMAS" then
												return 1;
											else
												return 0;
											end
										else
											return 2;
										end
									else
										return 1;
									end
								else
									return 1;
								end
							elseif SN > "HUNTERCDWILLTOTACMIT" then
								if SN < "ICPRT" then
									if SN < "ICMRT" then
										if SN > "ICMR" then
											if SN == "ICMRADJ" then
												return CalcStat("AdjItemProgMorReg",L);
											else
												return 0;
											end
										elseif SN == "ICMR" then
											return StatLinInter("PntMPICMR","ItemHighProg","ProgBMorReg","ICMRAdj",L,N);
										else
											return 0;
										end
									elseif SN > "ICMRT" then
										if SN < "ICPR" then
											if SN == "ICMRTADJ" then
												return CalcStat("AdjTraitProgMorReg",L);
											else
												return 0;
											end
										elseif SN > "ICPR" then
											if SN == "ICPRADJ" then
												return CalcStat("AdjItemProgPower",L);
											else
												return 0;
											end
										else
											return StatLinInter("PntMPICPR","ItemHighProgAlt","ProgBPowReg","ICPRAdj",L,N);
										end
									else
										return StatLinInter("PntMPICMR","TraitProg","ProgBMorReg","ICMRTAdj",L,N);
									end
								elseif SN > "ICPRT" then
									if SN < "INDMGPPRAT" then
										if SN < "ILVLTOLVL" then
											if SN == "ICPRTADJ" then
												return CalcStat("AdjTraitProgPower",L);
											else
												return 0;
											end
										elseif SN > "ILVLTOLVL" then
											if SN == "INDMGPBONUS" then
												return 0;
											else
												return 0;
											end
										else
											if Lm <= 79 then
												return LinFmod(1,1,75,1,79,L);
											elseif Lm <= 80 then
												return LinFmod(1,75,76,79,80,L);
											elseif Lm <= 200 then
												return LinFmod(1,76,100,80,200,L);
											elseif Lm <= 205 then
												return LinFmod(1,100,101,200,205,L);
											elseif Lm <= 225 then
												return LinFmod(1,101,105,205,225,L);
											elseif Lm <= 300 then
												return LinFmod(1,105,106,225,300,L);
											elseif Lm <= 349 then
												return LinFmod(1,106,115,300,349,L);
											elseif Lm <= 350 then
												return LinFmod(1,115,116,349,350,L);
											elseif Lm <= 399 then
												return LinFmod(1,116,120,350,399,L);
											elseif Lm <= 400 then
												return LinFmod(1,120,121,399,400,L);
											elseif Lm <= 449 then
												return LinFmod(1,121,130,400,449,L);
											elseif Lm <= 450 then
												return LinFmod(1,130,131,449,450,L);
											elseif Lm <= 499 then
												return LinFmod(1,131,140,450,499,L);
											elseif Lm <= 500 then
												return LinFmod(1,140,141,499,500,L);
											else
												return LinFmod(1,141,150,500,549,L);
											end
										end
									elseif SN > "INDMGPPRAT" then
										if SN < "INDMGPRATPA" then
											if SN == "INDMGPRATP" then
												return CalcPercAB(CalcStat("InDmgPRatPA",L),CalcStat("InDmgPRatPB",L),CalcStat("InDmgPRatPCap",L),N);
											else
												return 0;
											end
										elseif SN > "INDMGPRATPA" then
											if SN == "INDMGPRATPB" then
												if Lm <= 130 then
													return CalcStat("BratProg",L,CalcStat("ProgBDefence",L));
												else
													return CalcStat("BratProg",L,CalcStat("ProgBDefenceNew",L));
												end
											else
												return 0;
											end
										else
											if Lm <= 130 then
												return 800;
											else
												return 1200;
											end
										end
									else
										return CalcRatAB(CalcStat("InDmgPRatPA",L),CalcStat("InDmgPRatPB",L),CalcStat("InDmgPRatPCapR",L),N);
									end
								else
									return StatLinInter("PntMPICPR","TraitProgAlt","ProgBPowReg","ICPRTAdj",L,N);
								end
							else
								return 1;
							end
						else
							return 1;
						end
					elseif SN > "INDMGPRATPC" then
						if SN < "ITEMMEDPROG" then
							if SN < "INHEALTADJ" then
								if SN < "INHEALPRATP" then
									if SN < "INHEAL" then
										if SN > "INDMGPRATPCAP" then
											if SN == "INDMGPRATPCAPR" then
												return CalcStat("InDmgPRatPB",L)*CalcStat("InDmgPRatPC",L);
											else
												return 0;
											end
										elseif SN == "INDMGPRATPCAP" then
											return 400;
										else
											return 0;
										end
									elseif SN > "INHEAL" then
										if SN < "INHEALPBONUS" then
											if SN == "INHEALADJ" then
												if Lm <= 449 then
													return CalcStat("AdjItemProgRatings",L);
												else
													return 11/9.0;
												end
											else
												return 0;
											end
										elseif SN > "INHEALPBONUS" then
											if SN == "INHEALPPRAT" then
												return CalcRatAB(CalcStat("InHealPRatPA",L),CalcStat("InHealPRatPB",L),CalcStat("InHealPRatPCapR",L),N);
											else
												return 0;
											end
										else
											return 0;
										end
									else
										return StatLinInter("PntMPRatings","ItemMedProgAlt","ProgBLow","InHealAdj",L,N);
									end
								elseif SN > "INHEALPRATP" then
									if SN < "INHEALPRATPC" then
										if SN > "INHEALPRATPA" then
											if SN == "INHEALPRATPB" then
												if Lm <= 130 then
													return CalcStat("BratProgAlt",L,CalcStat("ProgBLow",L));
												else
													return CalcStat("BratProgAlt",L,CalcStat("ProgBLowNew",L));
												end
											else
												return 0;
											end
										elseif SN == "INHEALPRATPA" then
											if Lm <= 130 then
												return 50;
											else
												return 75;
											end
										else
											return 0;
										end
									elseif SN > "INHEALPRATPC" then
										if SN < "INHEALPRATPCAPR" then
											if SN == "INHEALPRATPCAP" then
												return 25;
											else
												return 0;
											end
										elseif SN > "INHEALPRATPCAPR" then
											if SN == "INHEALT" then
												return StatLinInter("PntMPRatings","TraitProgAlt","ProgBLow","InHealTAdj",L,N);
											else
												return 0;
											end
										else
											return CalcStat("InHealPRatPB",L)*CalcStat("InHealPRatPC",L);
										end
									else
										if Lm <= 130 then
											return 1;
										else
											return 0.5;
										end
									end
								else
									return CalcPercAB(CalcStat("InHealPRatPA",L),CalcStat("InHealPRatPB",L),CalcStat("InHealPRatPCap",L),N);
								end
							elseif SN > "INHEALTADJ" then
								if SN < "ITEMHIGHPROGLPH" then
									if SN < "ITEMHIGHPROG" then
										if SN > "INSTRMORALE" then
											if SN == "INSTRPOWER" then
												if Lm <= 9 then
													return RoundDbl(0.95*L+12.6);
												elseif Lm <= 18 then
													return RoundDbl(1.95*L+3);
												elseif Lm <= 26 then
													return RoundDbl(2.95*L-15.55);
												elseif Lm <= 35 then
													return RoundDbl(3.95*L-42.15);
												elseif Lm <= 42 then
													return RoundDbl(4.95*L-77.7);
												elseif Lm <= 45 then
													return RoundDbl(5.95*L-120.35);
												elseif Lm <= 105 then
													return RoundDbl(6*L-124);
												else
													return CalcStat("ProgExtMpExpRnd",L,CalcStat("InstrPower",105));
												end
											else
												return 0;
											end
										elseif SN == "INSTRMORALE" then
											if Lm <= 105 then
												return RoundDbl(4.04*L);
											else
												return CalcStat("ProgExtLowExpRnd",L,CalcStat("InstrMorale",105));
											end
										else
											return 0;
										end
									elseif SN > "ITEMHIGHPROG" then
										if SN < "ITEMHIGHPROGALTLPH" then
											if SN == "ITEMHIGHPROGALT" then
												return CalcStat("ItemProgAlt",L,N);
											else
												return 0;
											end
										elseif SN > "ITEMHIGHPROGALTLPH" then
											if SN == "ITEMHIGHPROGALTLPL" then
												return CalcStat("ItemProgAltLPL",L);
											else
												return 0;
											end
										else
											return CalcStat("ItemProgAltLPH",L);
										end
									else
										return CalcStat("ItemProg",L,N);
									end
								elseif SN > "ITEMHIGHPROGLPH" then
									if SN < "ITEMLOWPROGALTLPH" then
										if SN < "ITEMLOWPROG" then
											if SN == "ITEMHIGHPROGLPL" then
												return CalcStat("ItemProgLPL",L);
											else
												return 0;
											end
										elseif SN > "ITEMLOWPROG" then
											if SN == "ITEMLOWPROGALT" then
												if Lm <= 25 then
													return LinFmod(1,CalcStat("ItemProgAlt",1,N),RoundDbl(N)*15.2,1,25,L);
												elseif Lm <= 50 then
													return LinFmod(RoundDbl(N),15.2,30,25,50,L);
												elseif Lm <= 80 then
													return LinFmod(1,RoundDbl(N)*30,CalcStat("ItemProgAlt",80,N),50,80,L);
												else
													return CalcStat("ItemProgAlt",L,N);
												end
											else
												return 0;
											end
										else
											if Lm <= 25 then
												return LinFmod(1,CalcStat("ItemProg",1,N),RoundDbl(N)*15.2,1,25,L);
											elseif Lm <= 50 then
												return LinFmod(RoundDbl(N),15.2,30,25,50,L);
											elseif Lm <= 80 then
												return LinFmod(1,RoundDbl(N)*30,CalcStat("ItemProg",80,N),50,80,L);
											else
												return CalcStat("ItemProg",L,N);
											end
										end
									elseif SN > "ITEMLOWPROGALTLPH" then
										if SN < "ITEMLOWPROGLPH" then
											if SN == "ITEMLOWPROGALTLPL" then
												if Lm <= 25 then
													return 1;
												elseif Lm <= 50 then
													return 25;
												elseif Lm <= 80 then
													return 50;
												else
													return CalcStat("ItemProgAltLPL",L);
												end
											else
												return 0;
											end
										elseif SN > "ITEMLOWPROGLPH" then
											if SN == "ITEMLOWPROGLPL" then
												if Lm <= 25 then
													return 1;
												elseif Lm <= 50 then
													return 25;
												elseif Lm <= 80 then
													return 50;
												else
													return CalcStat("ItemProgLPL",L);
												end
											else
												return 0;
											end
										else
											if Lm <= 25 then
												return 25;
											elseif Lm <= 50 then
												return 50;
											elseif Lm <= 80 then
												return 80;
											else
												return CalcStat("ItemProgLPH",L);
											end
										end
									else
										if Lm <= 25 then
											return 25;
										elseif Lm <= 50 then
											return 50;
										elseif Lm <= 80 then
											return 80;
										else
											return CalcStat("ItemProgAltLPH",L);
										end
									end
								else
									return CalcStat("ItemProgLPH",L);
								end
							else
								if Lm <= 1 then
									return 1;
								elseif Lm <= 75 then
									return 0.8;
								elseif Lm <= 121 then
									return 1;
								elseif Lm <= 130 then
									return 0.9;
								else
									return 11/9.0;
								end
							end
						elseif SN > "ITEMMEDPROG" then
							if SN < "LI2ILVLCAP" then
								if SN < "ITEMPROGALT" then
									if SN < "ITEMMEDPROGALTLPL" then
										if SN > "ITEMMEDPROGALT" then
											if SN == "ITEMMEDPROGALTLPH" then
												if Lm <= 25 then
													return 25;
												elseif Lm <= 79 then
													return 79;
												else
													return CalcStat("ItemProgAltLPH",L);
												end
											else
												return 0;
											end
										elseif SN == "ITEMMEDPROGALT" then
											if Lm <= 25 then
												return LinFmod(1,CalcStat("ItemProgAlt",1,N),RoundDbl(N)*25,1,25,L);
											elseif Lm <= 79 then
												return LinFmod(1,RoundDbl(N)*25,CalcStat("ItemProgAlt",79,N),25,79,L);
											else
												return CalcStat("ItemProgAlt",L,N);
											end
										else
											return 0;
										end
									elseif SN > "ITEMMEDPROGALTLPL" then
										if SN < "ITEMMEDPROGLPL" then
											if SN == "ITEMMEDPROGLPH" then
												if Lm <= 25 then
													return 25;
												elseif Lm <= 79 then
													return 79;
												else
													return CalcStat("ItemProgLPH",L);
												end
											else
												return 0;
											end
										elseif SN > "ITEMMEDPROGLPL" then
											if SN == "ITEMPROG" then
												return CalcStat("StatProg",CalcStat("ILvlToLvl",L),N);
											else
												return 0;
											end
										else
											if Lm <= 25 then
												return 1;
											elseif Lm <= 79 then
												return 25;
											else
												return CalcStat("ItemProgLPL",L);
											end
										end
									else
										if Lm <= 25 then
											return 1;
										elseif Lm <= 79 then
											return 25;
										else
											return CalcStat("ItemProgAltLPL",L);
										end
									end
								elseif SN > "ITEMPROGALT" then
									if SN < "ITEMPROGLPH" then
										if SN > "ITEMPROGALTLPH" then
											if SN == "ITEMPROGALTLPL" then
												return CalcStat("ItemProgLPL",L);
											else
												return 0;
											end
										elseif SN == "ITEMPROGALTLPH" then
											return CalcStat("ItemProgLPH",L);
										else
											return 0;
										end
									elseif SN > "ITEMPROGLPH" then
										if SN < "L" then
											if SN == "ITEMPROGLPL" then
												if Lm <= 79 then
													return 1;
												elseif Lm <= 80 then
													return 79;
												elseif Lm <= 200 then
													return 80;
												elseif Lm <= 225 then
													return 200;
												elseif Lm <= 300 then
													return 225;
												elseif Lm <= 349 then
													return 300;
												elseif Lm <= 350 then
													return 349;
												elseif Lm <= 399 then
													return 350;
												elseif Lm <= 400 then
													return 399;
												elseif Lm <= 449 then
													return 400;
												elseif Lm <= 450 then
													return 449;
												elseif Lm <= 499 then
													return 450;
												elseif Lm <= 500 then
													return 499;
												else
													return 500;
												end
											else
												return 0;
											end
										elseif SN > "L" then
											if SN == "LEVELCAP" then
												return 140;
											else
												return 0;
											end
										else
											return L;
										end
									else
										if Lm <= 79 then
											return 79;
										elseif Lm <= 80 then
											return 80;
										elseif Lm <= 200 then
											return 200;
										elseif Lm <= 225 then
											return 225;
										elseif Lm <= 300 then
											return 300;
										elseif Lm <= 349 then
											return 349;
										elseif Lm <= 350 then
											return 350;
										elseif Lm <= 399 then
											return 399;
										elseif Lm <= 400 then
											return 400;
										elseif Lm <= 449 then
											return 449;
										elseif Lm <= 450 then
											return 450;
										elseif Lm <= 499 then
											return 499;
										elseif Lm <= 500 then
											return 500;
										else
											return 549;
										end
									end
								else
									return CalcStat("StatProgAlt",CalcStat("ILvlToLvl",L),N);
								end
							elseif SN > "LI2ILVLCAP" then
								if SN < "LMANCIENTCRAFTARMOUR" then
									if SN < "LIGHTMITT" then
										if SN > "LI2REFORGEILVL" then
											if SN == "LIGHTMIT" then
												return CalcStat("DmgTypeMit",L,N);
											else
												return 0;
											end
										elseif SN == "LI2REFORGEILVL" then
											if Lm <= 135 then
												return CalcStat("AwardILvlI",L);
											else
												return CalcStat("Li2ILvlCap",L);
											end
										else
											return 0;
										end
									elseif SN > "LIGHTMITT" then
										if SN < "LIGHTNINGMITT" then
											if SN == "LIGHTNINGMIT" then
												return CalcStat("DmgTypeMit",L,N);
											else
												return 0;
											end
										elseif SN > "LIGHTNINGMITT" then
											if SN == "LINEAR1TOCAP" then
												return LinFmod(1,1,N,1,CalcStat("LevelCap",L),L);
											else
												return 0;
											end
										else
											return CalcStat("DmgTypeMitT",L,N);
										end
									else
										return CalcStat("DmgTypeMitT",L,N);
									end
								elseif SN > "LMANCIENTCRAFTARMOUR" then
									if SN < "LMEVASIONRAVENARMOUR" then
										if SN < "LMCATMINTBEARARMOUR" then
											if SN == "LMANCIENTWISDOMWILL" then
												if Lm <= 105 then
													return RoundDbl(1.1*L);
												else
													return CalcStat("ProgExtLowExpRnd",L,CalcStat("LmAncientWisdomWill",105));
												end
											else
												return 0;
											end
										elseif SN > "LMCATMINTBEARARMOUR" then
											if SN == "LMEAGLENOBILITYICPR" then
												return CalcStat("ICPRT",L,0.8);
											else
												return 0;
											end
										else
											if Lm <= 0 then
												return 0;
											elseif Lm <= 105 then
												return 27*L;
											elseif Lm <= 115 then
												return LinFmod(27,210,408,106,115,L,-1);
											elseif Lm <= 116 then
												return ExpFmod(CalcStat("LMCatmintBearArmour",115),116,20,L,0);
											elseif Lm <= 120 then
												return ExpFmod(CalcStat("LMCatmintBearArmour",116),117,10,L,0);
											elseif Lm <= 121 then
												return ExpFmod(CalcStat("LMCatmintBearArmour",120),121,20,L,0);
											elseif Lm <= 130 then
												return ExpFmod(CalcStat("LMCatmintBearArmour",121),122,5.5,L,0);
											elseif Lm <= 131 then
												return ExpFmod(CalcStat("LMCatmintBearArmour",130),131,20,L,0);
											elseif Lm <= 140 then
												return ExpFmod(CalcStat("LMCatmintBearArmour",131),132,5.5,L,0);
											else
												return CalcStat("LMCatmintBearArmour",140);
											end
										end
									elseif SN > "LMEVASIONRAVENARMOUR" then
										if SN < "LMHEARTYDIETMORALE" then
											if SN == "LMHEARTYDIETBASE" then
												if Lm <= 50 then
													return RoundDbl((0.8982*L+0.605)*N);
												else
													return RoundDbl((4*L-154.5)*N);
												end
											else
												return 0;
											end
										elseif SN > "LMHEARTYDIETMORALE" then
											if SN == "LMKNOWLEDGELMCRYRES" then
												return -CalcStat("CryResistT",L,0.6);
											else
												return 0;
											end
										else
											if Lm <= 105 then
												return CalcStat("LmHeartyDietBase",L,CalcStat("Trait23456Choice",N));
											else
												return CalcStat("ProgExtLowExpRaw",L,CalcStat("LmHeartyDietMorale",105,N));
											end
										end
									else
										return CalcStat("ArmourT",L,0.8);
									end
								else
									return -CalcStat("ArmourT",L,2.4);
								end
							else
								return 485;
							end
						else
							if Lm <= 25 then
								return LinFmod(1,CalcStat("ItemProg",1,N),RoundDbl(N)*25,1,25,L);
							elseif Lm <= 79 then
								return LinFmod(1,RoundDbl(N)*25,CalcStat("ItemProg",79,N),25,79,L);
							else
								return CalcStat("ItemProg",L,N);
							end
						end
					else
						if Lm <= 130 then
							return 1;
						else
							return 0.5;
						end
					end
				elseif SN > "LMKNOWLEDGELMPHYRES" then
					if SN < "LVLBONUSTACDMG" then
						if SN < "LOREMASTERCDBASEVITALITY" then
							if SN < "LOREMASTERCDAGILITYTOEVADE" then
								if SN < "LMRINGOFFIREEVADE" then
									if SN < "LMPREPFORWARTACMAS" then
										if SN > "LMKNOWLEDGELMSONGRES" then
											if SN == "LMKNOWLEDGELMTACRES" then
												return -CalcStat("TacResistT",L,0.6);
											else
												return 0;
											end
										elseif SN == "LMKNOWLEDGELMSONGRES" then
											return -CalcStat("SongResistT",L,0.6);
										else
											return 0;
										end
									elseif SN > "LMPREPFORWARTACMAS" then
										if SN < "LMRAVENSHOTRAVWINGTACMIT" then
											if SN == "LMRAVENSHOTRAVWINGFIXTACMIT" then
												return CalcStat("TacMitT",L,2);
											else
												return 0;
											end
										elseif SN > "LMRAVENSHOTRAVWINGTACMIT" then
											if SN == "LMRINGOFFIREBLOCK" then
												return -CalcStat("BlockT",L,2.4);
											else
												return 0;
											end
										else
											return CalcStat("TacMit",L,2);
										end
									else
										if Lm <= 105 then
											return CalcStat("Trait23456Choice",N)*4*L;
										else
											return CalcStat("ProgExtLowLinExpRaw",L,CalcStat("LmPrepforWarTacMas",105,N));
										end
									end
								elseif SN > "LMRINGOFFIREEVADE" then
									if SN < "LMSWSTAFFBUGPARRY" then
										if SN > "LMRINGOFFIREPARRY" then
											if SN == "LMSWSTAFFBUGMORALE" then
												if Lm <= 105 then
													return RoundDbl(LinFmod(1,16.2,696.9,1,105,L));
												else
													return CalcStat("ProgExtLowExpRnd",L,CalcStat("LmSwStaffBugMorale",105));
												end
											else
												return 0;
											end
										elseif SN == "LMRINGOFFIREPARRY" then
											return -CalcStat("ParryT",L,2.4);
										else
											return 0;
										end
									elseif SN > "LMSWSTAFFBUGPARRY" then
										if SN < "LOEPASSIVE" then
											if SN == "LOE" then
												return 2*N;
											else
												return 0;
											end
										elseif SN > "LOEPASSIVE" then
											if SN == "LOREMASTERCDAGILITYTOCRITHIT" then
												return 1;
											else
												return 0;
											end
										else
											if Lm <= 115 then
												return 0;
											elseif Lm <= 119 then
												return 20*L-2300;
											else
												return CalcStat("LoEPassive",119);
											end
										end
									else
										if Lm <= 105 then
											return RoundDbl(44.44*L);
										else
											return CalcStat("ProgExtHighLinExpRnd",L,CalcStat("LmSwStaffBugParry",105));
										end
									end
								else
									return -CalcStat("EvadeT",L,2.4);
								end
							elseif SN > "LOREMASTERCDAGILITYTOEVADE" then
								if SN < "LOREMASTERCDBASEFATE" then
									if SN < "LOREMASTERCDARMOURTOPHYMIT" then
										if SN > "LOREMASTERCDAGILITYTOPARRY" then
											if SN == "LOREMASTERCDARMOURTOOFMIT" then
												return 0.2;
											else
												return 0;
											end
										elseif SN == "LOREMASTERCDAGILITYTOPARRY" then
											return 2;
										else
											return 0;
										end
									elseif SN > "LOREMASTERCDARMOURTOPHYMIT" then
										if SN < "LOREMASTERCDARMOURTYPE" then
											if SN == "LOREMASTERCDARMOURTOTACMIT" then
												return 0.2;
											else
												return 0;
											end
										elseif SN > "LOREMASTERCDARMOURTYPE" then
											if SN == "LOREMASTERCDBASEAGILITY" then
												return CalcStat("ClassBaseMainF",L);
											else
												return 0;
											end
										else
											return 1;
										end
									else
										return 1;
									end
								elseif SN > "LOREMASTERCDBASEFATE" then
									if SN < "LOREMASTERCDBASEMORALE" then
										if SN < "LOREMASTERCDBASEICPR" then
											if SN == "LOREMASTERCDBASEICMR" then
												return CalcStat("ClassBaseICMRL",L);
											else
												return 0;
											end
										elseif SN > "LOREMASTERCDBASEICPR" then
											if SN == "LOREMASTERCDBASEMIGHT" then
												return CalcStat("ClassBaseMainA",L);
											else
												return 0;
											end
										else
											return CalcStat("ClassBaseICPR",L);
										end
									elseif SN > "LOREMASTERCDBASEMORALE" then
										if SN < "LOREMASTERCDBASENCPR" then
											if SN == "LOREMASTERCDBASENCMR" then
												return CalcStat("ClassBaseNCMRL",L);
											else
												return 0;
											end
										elseif SN > "LOREMASTERCDBASENCPR" then
											if SN == "LOREMASTERCDBASEPOWER" then
												return CalcStat("ClassBasePowerH",L);
											else
												return 0;
											end
										else
											return CalcStat("ClassBaseNCPR",L);
										end
									else
										if Lm <= 120 then
											return CalcStat("ClassBaseMoraleL",L);
										else
											return CalcStat("ClassBaseMoraleL",120);
										end
									end
								else
									return CalcStat("ClassBaseMainJ",L);
								end
							else
								return 3;
							end
						elseif SN > "LOREMASTERCDBASEVITALITY" then
							if SN < "LOREMASTERCDVITALITYTONCMR" then
								if SN < "LOREMASTERCDFATETOTACMIT" then
									if SN < "LOREMASTERCDFATETOICMR" then
										if SN > "LOREMASTERCDBASEWILL" then
											if SN == "LOREMASTERCDFATETOCRITHIT" then
												return 2.5;
											else
												return 0;
											end
										elseif SN == "LOREMASTERCDBASEWILL" then
											return CalcStat("ClassBaseMainH",L);
										else
											return 0;
										end
									elseif SN > "LOREMASTERCDFATETOICMR" then
										if SN < "LOREMASTERCDFATETOPOWER" then
											if SN == "LOREMASTERCDFATETONCPR" then
												return 0.05;
											else
												return 0;
											end
										elseif SN > "LOREMASTERCDFATETOPOWER" then
											if SN == "LOREMASTERCDFATETORESIST" then
												return 1;
											else
												return 0;
											end
										else
											return 1;
										end
									else
										return 0.025;
									end
								elseif SN > "LOREMASTERCDFATETOTACMIT" then
									if SN < "LOREMASTERCDMIGHTTOPARRY" then
										if SN > "LOREMASTERCDHASPOWER" then
											if SN == "LOREMASTERCDMIGHTTOBLOCK" then
												return 3;
											else
												return 0;
											end
										elseif SN == "LOREMASTERCDHASPOWER" then
											return 1;
										else
											return 0;
										end
									elseif SN > "LOREMASTERCDMIGHTTOPARRY" then
										if SN < "LOREMASTERCDTACMASTOOUTHEAL" then
											if SN == "LOREMASTERCDPHYMITTOOFMIT" then
												return 1;
											else
												return 0;
											end
										elseif SN > "LOREMASTERCDTACMASTOOUTHEAL" then
											if SN == "LOREMASTERCDVITALITYTOMORALE" then
												return 4;
											else
												return 0;
											end
										else
											return 1;
										end
									else
										return 2;
									end
								else
									return 1;
								end
							elseif SN > "LOREMASTERCDVITALITYTONCMR" then
								if SN < "LOREMASTERCDWILLTOTACMIT" then
									if SN < "LOREMASTERCDWILLTOEVADE" then
										if SN > "LOREMASTERCDVITALITYTORESIST" then
											if SN == "LOREMASTERCDVITALITYTOTACMIT" then
												return 1;
											else
												return 0;
											end
										elseif SN == "LOREMASTERCDVITALITYTORESIST" then
											return 1;
										else
											return 0;
										end
									elseif SN > "LOREMASTERCDWILLTOEVADE" then
										if SN < "LOREMASTERCDWILLTORESIST" then
											if SN == "LOREMASTERCDWILLTOFINESSE" then
												return 1;
											else
												return 0;
											end
										elseif SN > "LOREMASTERCDWILLTORESIST" then
											if SN == "LOREMASTERCDWILLTOTACMAS" then
												return 3;
											else
												return 0;
											end
										else
											return 2;
										end
									else
										return 1;
									end
								elseif SN > "LOREMASTERCDWILLTOTACMIT" then
									if SN < "LVLBONUSMORRES" then
										if SN < "LVLBONUS116SEC" then
											if SN == "LVLBONUS106SEC" then
												return 7*L-639;
											else
												return 0;
											end
										elseif SN > "LVLBONUS116SEC" then
											if SN == "LVLBONUS121SEC" then
												if Lm <= 121 then
													return ExpFmod(N,121,30,L,nil);
												elseif Lm <= 125 then
													return ExpFmod(CalcStat("LvlBonus121Sec",121,N),122,5.5,L,nil);
												elseif Lm <= 126 then
													return ExpFmod(CalcStat("LvlBonus121Sec",125,N),126,30,L,nil);
												else
													return ExpFmod(CalcStat("LvlBonus121Sec",126,N),127,5.5,L,nil);
												end
											else
												return 0;
											end
										else
											if Lm <= 116 then
												return ExpFmod(N,116,30,L,nil);
											elseif Lm <= 120 then
												return ExpFmod(CalcStat("LvlBonus116Sec",116,N),117,5.5,L,nil);
											else
												return CalcStat("LvlBonus121Sec",L,CalcStat("LvlBonus116Sec",120,N));
											end
										end
									elseif SN > "LVLBONUSMORRES" then
										if SN < "LVLBONUSPOWRES" then
											if SN == "LVLBONUSPHYDMG" then
												if Lm <= 1 then
													return 1;
												elseif Lm <= 50 then
													return 0.94*L;
												elseif Lm <= 75 then
													return LinFmod(1,48,70,51,75,L);
												elseif Lm <= 105 then
													return LinFmod(1,74,94,76,105,L);
												elseif Lm <= 115 then
													return CalcStat("LvlBonus106Sec",L);
												elseif Lm <= 140 then
													return CalcStat("LvlBonus116Sec",L,CalcStat("LvlBonusPhyDmg",115));
												else
													return CalcStat("LvlBonusPhyDmg",140);
												end
											else
												return 0;
											end
										elseif SN > "LVLBONUSPOWRES" then
											if SN == "LVLBONUSRUNEOFRES" then
												if Lm <= 104 then
													return LinFmod(1,5,206.0766,1,104,L)*N;
												elseif Lm <= 105 then
													return 600*N;
												elseif Lm <= 106 then
													return ExpFmod(CalcStat("LvlBonusRuneofRes",105,N),106,10,L,nil);
												elseif Lm <= 115 then
													return ExpFmod(CalcStat("LvlBonusRuneofRes",106,N),107,5.5,L,nil);
												elseif Lm <= 116 then
													return ExpFmod(CalcStat("LvlBonusRuneofRes",115,N),116,20,L,nil);
												elseif Lm <= 120 then
													return ExpFmod(CalcStat("LvlBonusRuneofRes",116,N),117,10,L,nil);
												elseif Lm <= 121 then
													return ExpFmod(CalcStat("LvlBonusRuneofRes",120,N),121,20,L,nil);
												elseif Lm <= 130 then
													return ExpFmod(CalcStat("LvlBonusRuneofRes",121,N),122,5.5,L,nil);
												elseif Lm <= 131 then
													return ExpFmod(CalcStat("LvlBonusRuneofRes",130,N),131,20,L,nil);
												elseif Lm <= 140 then
													return ExpFmod(CalcStat("LvlBonusRuneofRes",131,N),132,5.5,L,nil);
												else
													return CalcStat("LvlBonusRuneofRes",140,N);
												end
											else
												return 0;
											end
										else
											return CalcStat("SkillPowerCost",L,N);
										end
									else
										return 0.1;
									end
								else
									return 1;
								end
							else
								return 0.12;
							end
						else
							return CalcStat("ClassBaseMainC",L);
						end
					elseif SN > "LVLBONUSTACDMG" then
						if SN < "MIGHT" then
							if SN < "MANRDPSVTWOBLOCK" then
								if SN < "MAINTADJ" then
									if SN < "LVLTOILVL" then
										if SN > "LVLEXPCOST" then
											if SN == "LVLEXPCOSTTOT" then
												if Lm <= 1 then
													return 0;
												else
													return CalcStat("LvlExpCostTot",L-1)+CalcStat("LvlExpCost",L);
												end
											else
												return 0;
											end
										elseif SN == "LVLEXPCOST" then
											if Lm <= 1 then
												return 0;
											elseif Lm <= 5 then
												return RoundDbl(12.5*L*L+12.5666666666667*L+24.8666666666667);
											elseif Lm <= 10 then
												return RoundDbl(33.8*L*L-179.48*L+452.6);
											elseif Lm <= 15 then
												return RoundDbl(55.05*L*L-583.77*L+2370.5);
											elseif Lm <= 20 then
												return RoundDbl(76.2*L*L-1196.96*L+6809);
											elseif Lm <= 25 then
												return RoundDbl(97.4*L*L-2023*L+14849.8);
											elseif Lm <= 30 then
												return RoundDbl(118.7*L*L-3066.02 *L+27612.8);
											elseif Lm <= 35 then
												return RoundDbl(139.95*L*L-4319.23*L+46084.1);
											elseif Lm <= 40 then
												return RoundDbl(161.2*L*L-5785.04*L+71356.2);
											elseif Lm <= 45 then
												return RoundDbl(182.5*L*L-7467.38*L+104569.8);
											elseif Lm <= 50 then
												return RoundDbl(203.8*L*L-9363.48*L+146761.8);
											elseif Lm <= 55 then
												return RoundDbl(225.05*L*L-11467.77*L+198851.3);
											elseif Lm <= 60 then
												return RoundDbl(246.3*L*L-13784.46*L+261988);
											elseif Lm <= 70 then
												return RoundDbl(ExpFmod(CalcStat("LvlExpCost",60),61,5.071,L,nil,3.485));
											elseif Lm <= 75 then
												return RoundDbl(ExpFmod(CalcStat("LvlExpCost",70),71,5.072,L,nil,-0.95));
											else
												return ExpFmod(CalcStat("LvlExpCost",75),76,5,L,0,-0.5);
											end
										else
											return 0;
										end
									elseif SN > "LVLTOILVL" then
										if SN < "MAINADJ" then
											if SN == "MAIN" then
												return FloorDbl(StatLinInter("PntMPMain","ItemMedProgAlt","ProgBMain","MainAdj",L,N));
											else
												return 0;
											end
										elseif SN > "MAINADJ" then
											if SN == "MAINT" then
												return FloorDbl(StatLinInter("PntMPMain","TraitProgAlt","ProgBMain","MainTAdj",L,N));
											else
												return 0;
											end
										else
											if Lm <= 25 then
												return 0.5;
											elseif Lm <= 200 then
												return 0.8;
											elseif Lm <= 400 then
												return 1;
											elseif Lm <= 449 then
												return 0.9;
											else
												return 100/90;
											end
										end
									else
										if Lm <= 75 then
											return LinFmod(1,1,79,1,75,L);
										elseif Lm <= 76 then
											return LinFmod(1,79,80,75,76,L);
										elseif Lm <= 100 then
											return LinFmod(1,80,200,76,100,L);
										elseif Lm <= 101 then
											return LinFmod(1,200,205,100,101,L);
										elseif Lm <= 105 then
											return LinFmod(1,205,225,101,105,L);
										elseif Lm <= 106 then
											return LinFmod(1,225,300,105,106,L);
										elseif Lm <= 115 then
											return LinFmod(1,300,349,106,115,L);
										elseif Lm <= 116 then
											return LinFmod(1,349,350,115,116,L);
										elseif Lm <= 120 then
											return LinFmod(1,350,399,116,120,L);
										elseif Lm <= 121 then
											return LinFmod(1,399,400,120,121,L);
										elseif Lm <= 130 then
											return LinFmod(1,400,449,121,130,L);
										elseif Lm <= 131 then
											return LinFmod(1,449,450,130,131,L);
										elseif Lm <= 140 then
											return LinFmod(1,450,499,131,140,L);
										elseif Lm <= 141 then
											return LinFmod(1,499,500,140,141,L);
										else
											return LinFmod(1,500,549,141,150,L);
										end
									end
								elseif SN > "MAINTADJ" then
									if SN < "MANFOURTHAGEWILL" then
										if SN > "MANDIMMANKINDWILL" then
											if SN == "MANEASILYINSPINHEALP" then
												return 5;
											else
												return 0;
											end
										elseif SN == "MANDIMMANKINDWILL" then
											return -7;
										else
											return 0;
										end
									elseif SN > "MANFOURTHAGEWILL" then
										if SN < "MANRDPSVONENAME" then
											if SN == "MANGIFTOFMENFATE" then
												return 15;
											else
												return 0;
											end
										elseif SN > "MANRDPSVONENAME" then
											if SN == "MANRDPSVONEWILL" then
												return CalcStat("ManFourthAgeWill",L);
											else
												return 0;
											end
										else
											return "Man of the Fourth Age";
										end
									else
										return CalcStat("WillT",L,1.0);
									end
								else
									if Lm <= 1 then
										return 1;
									elseif Lm <= 75 then
										return 0.85;
									elseif Lm <= 105 then
										return 0.9;
									elseif Lm <= 121 then
										return 1;
									elseif Lm <= 130 then
										return 0.9;
									else
										return 100/90;
									end
								end
							elseif SN > "MANRDPSVTWOBLOCK" then
								if SN < "MANRDTRAITWILL" then
									if SN < "MANRDPSVTWOPARRY" then
										if SN > "MANRDPSVTWOEVADE" then
											if SN == "MANRDPSVTWONAME" then
												return "Balance of Man";
											else
												return 0;
											end
										elseif SN == "MANRDPSVTWOEVADE" then
											return CalcStat("BalanceOfManAvoid",L);
										else
											return 0;
										end
									elseif SN > "MANRDPSVTWOPARRY" then
										if SN < "MANRDTRAITINHEALP" then
											if SN == "MANRDTRAITFATE" then
												return CalcStat("ManGiftOfMenFate",L);
											else
												return 0;
											end
										elseif SN > "MANRDTRAITINHEALP" then
											if SN == "MANRDTRAITMIGHT" then
												return CalcStat("ManStrongMenMight",L);
											else
												return 0;
											end
										else
											return CalcStat("ManEasilyInspInHealP",L);
										end
									else
										return CalcStat("BalanceOfManAvoid",L);
									end
								elseif SN > "MANRDTRAITWILL" then
									if SN < "MASTERYOLD" then
										if SN < "MASTERY" then
											if SN == "MANSTRONGMENMIGHT" then
												return 15;
											else
												return 0;
											end
										elseif SN > "MASTERY" then
											if SN == "MASTERYADJ" then
												if Lm <= 449 then
													return CalcStat("AdjItemProgRatings",L);
												elseif Lm <= 450 then
													return 83/90;
												else
													return 70/90;
												end
											else
												return 0;
											end
										else
											return StatLinInter("PntMPMastery","ItemMedProg","ProgBMastery","MasteryAdj",L,N);
										end
									elseif SN > "MASTERYOLD" then
										if SN < "MASTERYTADJ" then
											if SN == "MASTERYT" then
												return StatLinInter("PntMPMastery","TraitProg","ProgBMastery","MasteryTAdj",L,N);
											else
												return 0;
											end
										elseif SN > "MASTERYTADJ" then
											if SN == "MATHOMLVLTOILVL" then
												return CalcStat("AwardLvlToILvl",L);
											else
												return 0;
											end
										else
											if Lm <= 1 then
												return 1;
											elseif Lm <= 75 then
												return 0.8;
											elseif Lm <= 121 then
												return 1;
											elseif Lm <= 130 then
												return 0.9;
											else
												return 70/90;
											end
										end
									else
										return CalcStat("Mastery",L,N);
									end
								else
									return CalcStat("ManDimMankindWill",L);
								end
							else
								return CalcStat("BalanceOfManAvoid",L);
							end
						elseif SN > "MIGHT" then
							if SN < "MINSTRELCDAGILITYTOPARRY" then
								if SN < "MINCOURAGERESIST" then
									if SN < "MINCALLOROMELIGHTMIT" then
										if SN > "MIGHTT" then
											if SN == "MINCALLEARENDILLIGHTMIT" then
												return -CalcStat("LightMitT",L,1.2);
											else
												return 0;
											end
										elseif SN == "MIGHTT" then
											return CalcStat("MainT",L,N);
										else
											return 0;
										end
									elseif SN > "MINCALLOROMELIGHTMIT" then
										if SN < "MINCOMPOSURERESIST" then
											if SN == "MINCALLOROMEMELLIGHTMIT" then
												return -CalcStat("LightMitT",L,1.4);
											else
												return 0;
											end
										elseif SN > "MINCOMPOSURERESIST" then
											if SN == "MINCOMPOSURETACMIT" then
												return CalcStat("TacMitT",L,1.0);
											else
												return 0;
											end
										else
											return CalcStat("ResistT",L,1.6);
										end
									else
										return -CalcStat("LightMitT",L,1.2);
									end
								elseif SN > "MINCOURAGERESIST" then
									if SN < "MINENDMORALE" then
										if SN > "MINECHOESBATTLECRITDEF" then
											if SN == "MINECHOESBATTLERESIST" then
												return -CalcStat("SongResistT",L,1.0);
											else
												return 0;
											end
										elseif SN == "MINECHOESBATTLECRITDEF" then
											return -CalcStat("CritDefT",L,2.0);
										else
											return 0;
										end
									elseif SN > "MINENDMORALE" then
										if SN < "MINSTRELCDAGILITYTOCRITHIT" then
											if SN == "MINPIERCINGBALFINESSE" then
												return CalcStat("FinesseT",L,CalcStat("Trait12345Choice",N)*0.4);
											else
												return 0;
											end
										elseif SN > "MINSTRELCDAGILITYTOCRITHIT" then
											if SN == "MINSTRELCDAGILITYTOEVADE" then
												return 3;
											else
												return 0;
											end
										else
											return 1;
										end
									else
										return CalcStat("MoraleT",L,CalcStat("Trait12345Choice",N)*0.8);
									end
								else
									return CalcStat("FearResistT",L,1.0);
								end
							elseif SN > "MINSTRELCDAGILITYTOPARRY" then
								if SN < "MINSTRELCDBASEICMR" then
									if SN < "MINSTRELCDARMOURTOTACMIT" then
										if SN > "MINSTRELCDARMOURTOOFMIT" then
											if SN == "MINSTRELCDARMOURTOPHYMIT" then
												return 1;
											else
												return 0;
											end
										elseif SN == "MINSTRELCDARMOURTOOFMIT" then
											return 0.2;
										else
											return 0;
										end
									elseif SN > "MINSTRELCDARMOURTOTACMIT" then
										if SN < "MINSTRELCDBASEAGILITY" then
											if SN == "MINSTRELCDARMOURTYPE" then
												return 1;
											else
												return 0;
											end
										elseif SN > "MINSTRELCDBASEAGILITY" then
											if SN == "MINSTRELCDBASEFATE" then
												return CalcStat("ClassBaseMainH",L);
											else
												return 0;
											end
										else
											return CalcStat("ClassBaseMainA",L);
										end
									else
										return 0.2;
									end
								elseif SN > "MINSTRELCDBASEICMR" then
									if SN < "MINSTRELCDBASENCMR" then
										if SN < "MINSTRELCDBASEMIGHT" then
											if SN == "MINSTRELCDBASEICPR" then
												return CalcStat("ClassBaseICPR",L);
											else
												return 0;
											end
										elseif SN > "MINSTRELCDBASEMIGHT" then
											if SN == "MINSTRELCDBASEMORALE" then
												if Lm <= 120 then
													return CalcStat("ClassBaseMoraleL",L);
												else
													return CalcStat("ClassBaseMoraleL",120);
												end
											else
												return 0;
											end
										else
											return CalcStat("ClassBaseMainF",L);
										end
									elseif SN > "MINSTRELCDBASENCMR" then
										if SN < "MINSTRELCDBASEPOWER" then
											if SN == "MINSTRELCDBASENCPR" then
												return CalcStat("ClassBaseNCPR",L);
											else
												return 0;
											end
										elseif SN > "MINSTRELCDBASEPOWER" then
											if SN == "MINSTRELCDBASEVITALITY" then
												return CalcStat("ClassBaseMainC",L);
											else
												return 0;
											end
										else
											return CalcStat("ClassBasePowerH",L);
										end
									else
										return CalcStat("ClassBaseNCMRL",L);
									end
								else
									return CalcStat("ClassBaseICMRL",L);
								end
							else
								return 2;
							end
						else
							return CalcStat("Main",L,N);
						end
					else
						if Lm <= 1 then
							return 0.2;
						elseif Lm <= 50 then
							return 0.2*L;
						elseif Lm <= 75 then
							return LinFmod(1,10.5,50,51,75,L);
						elseif Lm <= 105 then
							return LinFmod(1,52,94,76,105,L);
						elseif Lm <= 115 then
							return CalcStat("LvlBonus106Sec",L);
						elseif Lm <= 130 then
							return CalcStat("LvlBonus116Sec",L,CalcStat("LvlBonusTacDmg",115));
						elseif Lm <= 131 then
							return ExpFmod(CalcStat("LvlBonusTacDmg",130),131,2.75,L,nil);
						elseif Lm <= 140 then
							return ExpFmod(CalcStat("LvlBonusTacDmg",131),132,5.5,L,nil);
						else
							return CalcStat("LvlBonusTacDmg",140);
						end
					end
				else
					return -CalcStat("PhyResistT",L,0.6);
				end
			else
				return CalcStat("HobHobbitToughnVitality",L);
			end
		else
			return CalcStat("CreepAudacityDmgP",L);
		end
	elseif SN > "MINSTRELCDBASEWILL" then
		if SN < "TRAIT58121620CHOICE" then
			if SN < "POISONRESISTT" then
				if SN < "PARTBLOCKPRATPA" then
					if SN < "MITMEDIUMPRATPC" then
						if SN < "MINTOTFINESSE" then
							if SN < "MINSTRELCDVITALITYTONCMR" then
								if SN < "MINSTRELCDFATETOTACMIT" then
									if SN < "MINSTRELCDFATETOICMR" then
										if SN > "MINSTRELCDCANBLOCK" then
											if SN == "MINSTRELCDFATETOCRITHIT" then
												return 2.5;
											else
												return 0;
											end
										elseif SN == "MINSTRELCDCANBLOCK" then
											if Lm <= 19 then
												return 0;
											else
												return 1;
											end
										else
											return 0;
										end
									elseif SN > "MINSTRELCDFATETOICMR" then
										if SN < "MINSTRELCDFATETOPOWER" then
											if SN == "MINSTRELCDFATETONCPR" then
												return 0.05;
											else
												return 0;
											end
										elseif SN > "MINSTRELCDFATETOPOWER" then
											if SN == "MINSTRELCDFATETORESIST" then
												return 1;
											else
												return 0;
											end
										else
											return 1;
										end
									else
										return 0.025;
									end
								elseif SN > "MINSTRELCDFATETOTACMIT" then
									if SN < "MINSTRELCDMIGHTTOPARRY" then
										if SN > "MINSTRELCDHASPOWER" then
											if SN == "MINSTRELCDMIGHTTOBLOCK" then
												return 3;
											else
												return 0;
											end
										elseif SN == "MINSTRELCDHASPOWER" then
											return 1;
										else
											return 0;
										end
									elseif SN > "MINSTRELCDMIGHTTOPARRY" then
										if SN < "MINSTRELCDTACMASTOOUTHEAL" then
											if SN == "MINSTRELCDPHYMITTOOFMIT" then
												return 1;
											else
												return 0;
											end
										elseif SN > "MINSTRELCDTACMASTOOUTHEAL" then
											if SN == "MINSTRELCDVITALITYTOMORALE" then
												return 4;
											else
												return 0;
											end
										else
											return 1;
										end
									else
										return 2;
									end
								else
									return 1;
								end
							elseif SN > "MINSTRELCDVITALITYTONCMR" then
								if SN < "MINSTRELCDWILLTOTACMIT" then
									if SN < "MINSTRELCDWILLTOEVADE" then
										if SN > "MINSTRELCDVITALITYTORESIST" then
											if SN == "MINSTRELCDVITALITYTOTACMIT" then
												return 1;
											else
												return 0;
											end
										elseif SN == "MINSTRELCDVITALITYTORESIST" then
											return 1;
										else
											return 0;
										end
									elseif SN > "MINSTRELCDWILLTOEVADE" then
										if SN < "MINSTRELCDWILLTORESIST" then
											if SN == "MINSTRELCDWILLTOFINESSE" then
												return 1;
											else
												return 0;
											end
										elseif SN > "MINSTRELCDWILLTORESIST" then
											if SN == "MINSTRELCDWILLTOTACMAS" then
												return 3;
											else
												return 0;
											end
										else
											return 2;
										end
									else
										return 1;
									end
								elseif SN > "MINSTRELCDWILLTOTACMIT" then
									if SN < "MINTOTCRITHIT" then
										if SN > "MINTACMAS" then
											if SN == "MINTIMEECHOESBATTLERESIST" then
												return -CalcStat("SongResistT",L,0.6);
											else
												return 0;
											end
										elseif SN == "MINTACMAS" then
											return CalcStat("TacMasT",L,CalcStat("Trait12345Choice",N)*0.4);
										else
											return 0;
										end
									elseif SN > "MINTOTCRITHIT" then
										if SN < "MINTOTFATE" then
											if SN == "MINTOTCRITHITSEL" then
												if Lm <= 0 then
													return 0;
												else
													return DataTableValue({0,0,0,0.4,0.6,0},L);
												end
											else
												return 0;
											end
										elseif SN > "MINTOTFATE" then
											if SN == "MINTOTFATESEL" then
												if Lm <= 0 then
													return 0;
												else
													return DataTableValue({0.2,0.3,0.4,0.5,0.6,0},L);
												end
											else
												return 0;
											end
										else
											return CalcStat("FateT",L,CalcStat("MinToTFateSel",N));
										end
									else
										return CalcStat("CritHitT",L,CalcStat("MinToTCritHitSel",N));
									end
								else
									return 1;
								end
							else
								return 0.12;
							end
						elseif SN > "MINTOTFINESSE" then
							if SN < "MITIGATION" then
								if SN < "MITHEAVYPPRAT" then
									if SN < "MINTOTRESISTSEL" then
										if SN > "MINTOTFINESSESEL" then
											if SN == "MINTOTRESIST" then
												return CalcStat("ResistT",L,CalcStat("MinToTResistSel",N));
											else
												return 0;
											end
										elseif SN == "MINTOTFINESSESEL" then
											if Lm <= 0 then
												return 0;
											else
												return DataTableValue({0,0,0.2,0.4,0.6,0},L);
											end
										else
											return 0;
										end
									elseif SN > "MINTOTRESISTSEL" then
										if SN < "MINTOTVITALITYSEL" then
											if SN == "MINTOTVITALITY" then
												return CalcStat("VitalityT",L,CalcStat("MinToTVitalitySel",N));
											else
												return 0;
											end
										elseif SN > "MINTOTVITALITYSEL" then
											if SN == "MITHEAVYPBONUS" then
												return 0;
											else
												return 0;
											end
										else
											if Lm <= 0 then
												return 0;
											else
												return DataTableValue({0,0,0,0,0.4,0},L);
											end
										end
									else
										if Lm <= 0 then
											return 0;
										else
											return DataTableValue({0,0.2,0.3,0.4,0.5,0},L);
										end
									end
								elseif SN > "MITHEAVYPPRAT" then
									if SN < "MITHEAVYPRATPB" then
										if SN > "MITHEAVYPRATP" then
											if SN == "MITHEAVYPRATPA" then
												if Lm <= 130 then
													return 110;
												else
													return 180;
												end
											else
												return 0;
											end
										elseif SN == "MITHEAVYPRATP" then
											return CalcPercAB(CalcStat("MitHeavyPRatPA",L),CalcStat("MitHeavyPRatPB",L),CalcStat("MitHeavyPRatPCap",L),N);
										else
											return 0;
										end
									elseif SN > "MITHEAVYPRATPB" then
										if SN < "MITHEAVYPRATPCAP" then
											if SN == "MITHEAVYPRATPC" then
												if Lm <= 130 then
													return 1.2;
												else
													return 0.5;
												end
											else
												return 0;
											end
										elseif SN > "MITHEAVYPRATPCAP" then
											if SN == "MITHEAVYPRATPCAPR" then
												return CalcStat("MitHeavyPRatPB",L)*CalcStat("MitHeavyPRatPC",L);
											else
												return 0;
											end
										else
											return 60;
										end
									else
										if Lm <= 130 then
											return CalcStat("BratProg",L,CalcStat("ProgBMitHeavy",L));
										else
											return CalcStat("BratProg",L,CalcStat("ProgBMitHeavyNew",L));
										end
									end
								else
									return CalcRatAB(CalcStat("MitHeavyPRatPA",L),CalcStat("MitHeavyPRatPB",L),CalcStat("MitHeavyPRatPCapR",L),N);
								end
							elseif SN > "MITIGATION" then
								if SN < "MITLIGHTPRATPC" then
									if SN < "MITLIGHTPPRAT" then
										if SN > "MITIGATIONADJ" then
											if SN == "MITLIGHTPBONUS" then
												return 0;
											else
												return 0;
											end
										elseif SN == "MITIGATIONADJ" then
											if Lm <= 400 then
												return CalcStat("AdjItemProgLow",L);
											elseif Lm <= 449 then
												return 0.9;
											elseif Lm <= 450 then
												return 83/90;
											elseif Lm <= 499 then
												return 80/90;
											elseif Lm <= 500 then
												return 70/90;
											else
												return 60/90;
											end
										else
											return 0;
										end
									elseif SN > "MITLIGHTPPRAT" then
										if SN < "MITLIGHTPRATPA" then
											if SN == "MITLIGHTPRATP" then
												return CalcPercAB(CalcStat("MitLightPRatPA",L),CalcStat("MitLightPRatPB",L),CalcStat("MitLightPRatPCap",L),N);
											else
												return 0;
											end
										elseif SN > "MITLIGHTPRATPA" then
											if SN == "MITLIGHTPRATPB" then
												if Lm <= 130 then
													return CalcStat("BratProg",L,CalcStat("ProgBMitLight",L));
												else
													return CalcStat("BratProg",L,CalcStat("ProgBMitLightNew",L));
												end
											else
												return 0;
											end
										else
											if Lm <= 130 then
												return 65;
											else
												return 120;
											end
										end
									else
										return CalcRatAB(CalcStat("MitLightPRatPA",L),CalcStat("MitLightPRatPB",L),CalcStat("MitLightPRatPCapR",L),N);
									end
								elseif SN > "MITLIGHTPRATPC" then
									if SN < "MITMEDIUMPPRAT" then
										if SN < "MITLIGHTPRATPCAPR" then
											if SN == "MITLIGHTPRATPCAP" then
												return 40;
											else
												return 0;
											end
										elseif SN > "MITLIGHTPRATPCAPR" then
											if SN == "MITMEDIUMPBONUS" then
												return 0;
											else
												return 0;
											end
										else
											return CalcStat("MitLightPRatPB",L)*CalcStat("MitLightPRatPC",L);
										end
									elseif SN > "MITMEDIUMPPRAT" then
										if SN < "MITMEDIUMPRATPA" then
											if SN == "MITMEDIUMPRATP" then
												return CalcPercAB(CalcStat("MitMediumPRatPA",L),CalcStat("MitMediumPRatPB",L),CalcStat("MitMediumPRatPCap",L),N);
											else
												return 0;
											end
										elseif SN > "MITMEDIUMPRATPA" then
											if SN == "MITMEDIUMPRATPB" then
												if Lm <= 130 then
													return CalcStat("BratProg",L,CalcStat("ProgBMitMedium",L));
												else
													return CalcStat("BratProg",L,CalcStat("ProgBMitMediumNew",L));
												end
											else
												return 0;
											end
										else
											if Lm <= 130 then
												return 85;
											else
												return 150;
											end
										end
									else
										return CalcRatAB(CalcStat("MitMediumPRatPA",L),CalcStat("MitMediumPRatPB",L),CalcStat("MitMediumPRatPCapR",L),N);
									end
								else
									if Lm <= 130 then
										return 1.6;
									else
										return 0.5;
									end
								end
							else
								return StatLinInter("PntMPMitigation","ItemMedProg","ProgBMitigation","MitigationAdj",L,N);
							end
						else
							return CalcStat("FinesseT",L,CalcStat("MinToTFinesseSel",N));
						end
					elseif SN > "MITMEDIUMPRATPC" then
						if SN < "OUTHEALPRATP" then
							if SN < "NCPRT" then
								if SN < "N" then
									if SN < "MORALE" then
										if SN > "MITMEDIUMPRATPCAP" then
											if SN == "MITMEDIUMPRATPCAPR" then
												return CalcStat("MitMediumPRatPB",L)*CalcStat("MitMediumPRatPC",L);
											else
												return 0;
											end
										elseif SN == "MITMEDIUMPRATPCAP" then
											return 50;
										else
											return 0;
										end
									elseif SN > "MORALE" then
										if SN < "MORALET" then
											if SN == "MORALEADJ" then
												if Lm <= 25 then
													return 0.5;
												elseif Lm <= 350 then
													return 1;
												elseif Lm <= 399 then
													return 0.8;
												elseif Lm <= 400 then
													return 22/35;
												elseif Lm <= 449 then
													return 40/70;
												elseif Lm <= 450 then
													return 0.582;
												elseif Lm <= 499 then
													return 0.635;
												elseif Lm <= 500 then
													return 0.582;
												else
													return 0.635;
												end
											else
												return 0;
											end
										elseif SN > "MORALET" then
											if SN == "MORALETADJ" then
												return CalcStat("AdjTraitProgMorale",L);
											else
												return 0;
											end
										else
											return StatLinInter("PntMPMorale","TraitProg","ProgBMorale","MoraleTAdj",L,N);
										end
									else
										return StatLinInter("PntMPMorale","ItemLowProg","ProgBMorale","MoraleAdj",L,N);
									end
								elseif SN > "N" then
									if SN < "NCMRT" then
										if SN > "NCMR" then
											if SN == "NCMRADJ" then
												return CalcStat("AdjItemProgMorReg",L);
											else
												return 0;
											end
										elseif SN == "NCMR" then
											return StatLinInter("PntMPNCMR","ItemHighProg","ProgBMorReg","NCMRAdj",L,N);
										else
											return 0;
										end
									elseif SN > "NCMRT" then
										if SN < "NCPR" then
											if SN == "NCMRTADJ" then
												return CalcStat("AdjTraitProgMorReg",L);
											else
												return 0;
											end
										elseif SN > "NCPR" then
											if SN == "NCPRADJ" then
												return CalcStat("AdjItemProgPower",L);
											else
												return 0;
											end
										else
											return StatLinInter("PntMPNCPR","ItemHighProgAlt","ProgBPowReg","NCPRAdj",L,N);
										end
									else
										return StatLinInter("PntMPNCMR","TraitProg","ProgBMorReg","NCMRTAdj",L,N);
									end
								else
									return N;
								end
							elseif SN > "NCPRT" then
								if SN < "OUTDMGPRATPB" then
									if SN < "OUTDMGPBONUS" then
										if SN > "NCPRTADJ" then
											if SN == "OFFSET" then
												return L+N;
											else
												return 0;
											end
										elseif SN == "NCPRTADJ" then
											return CalcStat("AdjTraitProgPower",L);
										else
											return 0;
										end
									elseif SN > "OUTDMGPBONUS" then
										if SN < "OUTDMGPRATP" then
											if SN == "OUTDMGPPRAT" then
												return CalcRatAB(CalcStat("OutDmgPRatPA",L),CalcStat("OutDmgPRatPB",L),CalcStat("OutDmgPRatPCapR",L),N);
											else
												return 0;
											end
										elseif SN > "OUTDMGPRATP" then
											if SN == "OUTDMGPRATPA" then
												if Lm <= 130 then
													return 400;
												else
													return 600;
												end
											else
												return 0;
											end
										else
											return CalcPercAB(CalcStat("OutDmgPRatPA",L),CalcStat("OutDmgPRatPB",L),CalcStat("OutDmgPRatPCap",L),N);
										end
									else
										return 0;
									end
								elseif SN > "OUTDMGPRATPB" then
									if SN < "OUTHEAL" then
										if SN < "OUTDMGPRATPCAP" then
											if SN == "OUTDMGPRATPC" then
												if Lm <= 130 then
													return 1;
												else
													return 0.5;
												end
											else
												return 0;
											end
										elseif SN > "OUTDMGPRATPCAP" then
											if SN == "OUTDMGPRATPCAPR" then
												return CalcStat("OutDmgPRatPB",L)*CalcStat("OutDmgPRatPC",L);
											else
												return 0;
											end
										else
											return 200;
										end
									elseif SN > "OUTHEAL" then
										if SN < "OUTHEALPBONUS" then
											if SN == "OUTHEALADJ" then
												if Lm <= 449 then
													return CalcStat("AdjItemProgRatings",L);
												elseif Lm <= 450 then
													return 83/90;
												else
													return 0.778;
												end
											else
												return 0;
											end
										elseif SN > "OUTHEALPBONUS" then
											if SN == "OUTHEALPPRAT" then
												return CalcRatAB(CalcStat("OutHealPRatPA",L),CalcStat("OutHealPRatPB",L),CalcStat("OutHealPRatPCapR",L),N);
											else
												return 0;
											end
										else
											return 0;
										end
									else
										return StatLinInter("PntMPratings","ItemMedProg","ProgBMedium","OutHealAdj",L,N);
									end
								else
									if Lm <= 130 then
										return CalcStat("BratProg",L,CalcStat("ProgBMastery",L));
									else
										return CalcStat("BratProg",L,CalcStat("ProgBMasteryNew",L));
									end
								end
							else
								return StatLinInter("PntMPNCPR","TraitProgAlt","ProgBPowReg","NCPRTAdj",L,N);
							end
						elseif SN > "OUTHEALPRATP" then
							if SN < "PARRYPRATPC" then
								if SN < "OUTHEALTADJ" then
									if SN < "OUTHEALPRATPC" then
										if SN > "OUTHEALPRATPA" then
											if SN == "OUTHEALPRATPB" then
												if Lm <= 130 then
													return CalcStat("BratProg",L,CalcStat("ProgBMedium",L));
												else
													return CalcStat("BratProg",L,CalcStat("ProgBMediumNew",L));
												end
											else
												return 0;
											end
										elseif SN == "OUTHEALPRATPA" then
											if Lm <= 130 then
												return 140;
											else
												return 210;
											end
										else
											return 0;
										end
									elseif SN > "OUTHEALPRATPC" then
										if SN < "OUTHEALPRATPCAPR" then
											if SN == "OUTHEALPRATPCAP" then
												return 70;
											else
												return 0;
											end
										elseif SN > "OUTHEALPRATPCAPR" then
											if SN == "OUTHEALT" then
												return StatLinInter("PntMPRatings","TraitProg","ProgBMedium","OutHealTAdj",L,N);
											else
												return 0;
											end
										else
											return CalcStat("OutHealPRatPB",L)*CalcStat("OutHealPRatPC",L);
										end
									else
										if Lm <= 130 then
											return 1;
										else
											return 0.5;
										end
									end
								elseif SN > "OUTHEALTADJ" then
									if SN < "PARRYPPRAT" then
										if SN > "PARRY" then
											if SN == "PARRYPBONUS" then
												return CalcStat("BPEPBonus",L);
											else
												return 0;
											end
										elseif SN == "PARRY" then
											return CalcStat("BPE",L,N);
										else
											return 0;
										end
									elseif SN > "PARRYPPRAT" then
										if SN < "PARRYPRATPA" then
											if SN == "PARRYPRATP" then
												return CalcStat("BPEPRatP",L,N);
											else
												return 0;
											end
										elseif SN > "PARRYPRATPA" then
											if SN == "PARRYPRATPB" then
												return CalcStat("BPEPRatPB",L);
											else
												return 0;
											end
										else
											return CalcStat("BPEPRatPA",L);
										end
									else
										return CalcStat("BPEPPRat",L,N);
									end
								else
									if Lm <= 1 then
										return 1;
									elseif Lm <= 75 then
										return 0.8;
									elseif Lm <= 121 then
										return 1;
									elseif Lm <= 130 then
										return 0.9;
									else
										return 70/90;
									end
								end
							elseif SN > "PARRYPRATPC" then
								if SN < "PARTBLOCKMITPRATPA" then
									if SN < "PARRYT" then
										if SN > "PARRYPRATPCAP" then
											if SN == "PARRYPRATPCAPR" then
												return CalcStat("BPEPRatPCapR",L);
											else
												return 0;
											end
										elseif SN == "PARRYPRATPCAP" then
											return CalcStat("BPEPRatPCap",L);
										else
											return 0;
										end
									elseif SN > "PARRYT" then
										if SN < "PARTBLOCKMITPPRAT" then
											if SN == "PARTBLOCKMITPBONUS" then
												return CalcStat("PartMitPBonus",L);
											else
												return 0;
											end
										elseif SN > "PARTBLOCKMITPPRAT" then
											if SN == "PARTBLOCKMITPRATP" then
												return CalcStat("PartMitPRatP",L,N);
											else
												return 0;
											end
										else
											return CalcStat("PartMitPPRat",L,N);
										end
									else
										return CalcStat("BPET",L,N);
									end
								elseif SN > "PARTBLOCKMITPRATPA" then
									if SN < "PARTBLOCKMITPRATPCAPR" then
										if SN < "PARTBLOCKMITPRATPC" then
											if SN == "PARTBLOCKMITPRATPB" then
												return CalcStat("PartMitPRatPB",L);
											else
												return 0;
											end
										elseif SN > "PARTBLOCKMITPRATPC" then
											if SN == "PARTBLOCKMITPRATPCAP" then
												return CalcStat("PartMitPRatPCap",L);
											else
												return 0;
											end
										else
											return CalcStat("PartMitPRatPC",L);
										end
									elseif SN > "PARTBLOCKMITPRATPCAPR" then
										if SN < "PARTBLOCKPPRAT" then
											if SN == "PARTBLOCKPBONUS" then
												return CalcStat("PartBPEPBonus",L);
											else
												return 0;
											end
										elseif SN > "PARTBLOCKPPRAT" then
											if SN == "PARTBLOCKPRATP" then
												return CalcStat("PartBPEPRatP",L,N);
											else
												return 0;
											end
										else
											return CalcStat("PartBPEPPRat",L,N);
										end
									else
										return CalcStat("PartMitPRatPCapR",L);
									end
								else
									return CalcStat("PartMitPRatPA",L);
								end
							else
								return CalcStat("BPEPRatPC",L);
							end
						else
							return CalcPercAB(CalcStat("OutHealPRatPA",L),CalcStat("OutHealPRatPB",L),CalcStat("OutHealPRatPCap",L),N);
						end
					else
						if Lm <= 130 then
							return 100/70;
						else
							return 0.5;
						end
					end
				elseif SN > "PARTBLOCKPRATPA" then
					if SN < "PERKTACMIT" then
						if SN < "PARTMITPBONUS" then
							if SN < "PARTEVADEMITPPRAT" then
								if SN < "PARTBPEPRATP" then
									if SN < "PARTBLOCKPRATPCAP" then
										if SN > "PARTBLOCKPRATPB" then
											if SN == "PARTBLOCKPRATPC" then
												return CalcStat("PartBPEPRatPC",L);
											else
												return 0;
											end
										elseif SN == "PARTBLOCKPRATPB" then
											return CalcStat("PartBPEPRatPB",L);
										else
											return 0;
										end
									elseif SN > "PARTBLOCKPRATPCAP" then
										if SN < "PARTBPEPBONUS" then
											if SN == "PARTBLOCKPRATPCAPR" then
												return CalcStat("PartBPEPRatPCapR",L);
											else
												return 0;
											end
										elseif SN > "PARTBPEPBONUS" then
											if SN == "PARTBPEPPRAT" then
												return CalcRatAB(CalcStat("PartBPEPRatPA",L),CalcStat("PartBPEPRatPB",L),CalcStat("PartBPEPRatPCapR",L),N);
											else
												return 0;
											end
										else
											return 0;
										end
									else
										return CalcStat("PartBPEPRatPCap",L);
									end
								elseif SN > "PARTBPEPRATP" then
									if SN < "PARTBPEPRATPC" then
										if SN > "PARTBPEPRATPA" then
											if SN == "PARTBPEPRATPB" then
												if Lm <= 130 then
													return CalcStat("BratProgAlt",L,CalcStat("ProgBPartial",L));
												else
													return CalcStat("BratProgAlt",L,CalcStat("ProgBPartialNew",L));
												end
											else
												return 0;
											end
										elseif SN == "PARTBPEPRATPA" then
											if Lm <= 130 then
												return 70;
											else
												return 75;
											end
										else
											return 0;
										end
									elseif SN > "PARTBPEPRATPC" then
										if SN < "PARTBPEPRATPCAPR" then
											if SN == "PARTBPEPRATPCAP" then
												if Lm <= 130 then
													return 35;
												else
													return 25;
												end
											else
												return 0;
											end
										elseif SN > "PARTBPEPRATPCAPR" then
											if SN == "PARTEVADEMITPBONUS" then
												return CalcStat("PartMitPBonus",L);
											else
												return 0;
											end
										else
											return CalcStat("PartBPEPRatPB",L)*CalcStat("PartBPEPRatPC",L);
										end
									else
										if Lm <= 130 then
											return 1;
										else
											return 0.5;
										end
									end
								else
									return CalcPercAB(CalcStat("PartBPEPRatPA",L),CalcStat("PartBPEPRatPB",L),CalcStat("PartBPEPRatPCap",L),N);
								end
							elseif SN > "PARTEVADEMITPPRAT" then
								if SN < "PARTEVADEPBONUS" then
									if SN < "PARTEVADEMITPRATPB" then
										if SN > "PARTEVADEMITPRATP" then
											if SN == "PARTEVADEMITPRATPA" then
												return CalcStat("PartMitPRatPA",L);
											else
												return 0;
											end
										elseif SN == "PARTEVADEMITPRATP" then
											return CalcStat("PartMitPRatP",L,N);
										else
											return 0;
										end
									elseif SN > "PARTEVADEMITPRATPB" then
										if SN < "PARTEVADEMITPRATPCAP" then
											if SN == "PARTEVADEMITPRATPC" then
												return CalcStat("PartMitPRatPC",L);
											else
												return 0;
											end
										elseif SN > "PARTEVADEMITPRATPCAP" then
											if SN == "PARTEVADEMITPRATPCAPR" then
												return CalcStat("PartMitPRatPCapR",L);
											else
												return 0;
											end
										else
											return CalcStat("PartMitPRatPCap",L);
										end
									else
										return CalcStat("PartMitPRatPB",L);
									end
								elseif SN > "PARTEVADEPBONUS" then
									if SN < "PARTEVADEPRATPB" then
										if SN < "PARTEVADEPRATP" then
											if SN == "PARTEVADEPPRAT" then
												return CalcStat("PartBPEPPRat",L,N);
											else
												return 0;
											end
										elseif SN > "PARTEVADEPRATP" then
											if SN == "PARTEVADEPRATPA" then
												return CalcStat("PartBPEPRatPA",L);
											else
												return 0;
											end
										else
											return CalcStat("PartBPEPRatP",L,N);
										end
									elseif SN > "PARTEVADEPRATPB" then
										if SN < "PARTEVADEPRATPCAP" then
											if SN == "PARTEVADEPRATPC" then
												return CalcStat("PartBPEPRatPC",L);
											else
												return 0;
											end
										elseif SN > "PARTEVADEPRATPCAP" then
											if SN == "PARTEVADEPRATPCAPR" then
												return CalcStat("PartBPEPRatPCapR",L);
											else
												return 0;
											end
										else
											return CalcStat("PartBPEPRatPCap",L);
										end
									else
										return CalcStat("PartBPEPRatPB",L);
									end
								else
									return CalcStat("PartBPEPBonus",L);
								end
							else
								return CalcStat("PartMitPPRat",L,N);
							end
						elseif SN > "PARTMITPBONUS" then
							if SN < "PARTPARRYMITPRATPCAP" then
								if SN < "PARTMITPRATPCAPR" then
									if SN < "PARTMITPRATPA" then
										if SN > "PARTMITPPRAT" then
											if SN == "PARTMITPRATP" then
												return CalcPercAB(CalcStat("PartMitPRatPA",L),CalcStat("PartMitPRatPB",L),CalcStat("PartMitPRatPCap",L),N);
											else
												return 0;
											end
										elseif SN == "PARTMITPPRAT" then
											return CalcRatAB(CalcStat("PartMitPRatPA",L),CalcStat("PartMitPRatPB",L),CalcStat("PartMitPRatPCapR",L),N);
										else
											return 0;
										end
									elseif SN > "PARTMITPRATPA" then
										if SN < "PARTMITPRATPC" then
											if SN == "PARTMITPRATPB" then
												if Lm <= 130 then
													return CalcStat("BratProgAlt",L,CalcStat("ProgBPartial",L));
												else
													return CalcStat("BratProgAlt",L,CalcStat("ProgBPartialNew",L));
												end
											else
												return 0;
											end
										elseif SN > "PARTMITPRATPC" then
											if SN == "PARTMITPRATPCAP" then
												if Lm <= 130 then
													return 50;
												else
													return 35;
												end
											else
												return 0;
											end
										else
											if Lm <= 130 then
												return 1;
											else
												return 0.5;
											end
										end
									else
										if Lm <= 130 then
											return 100;
										else
											return 105;
										end
									end
								elseif SN > "PARTMITPRATPCAPR" then
									if SN < "PARTPARRYMITPRATP" then
										if SN > "PARTPARRYMITPBONUS" then
											if SN == "PARTPARRYMITPPRAT" then
												return CalcStat("PartMitPPRat",L,N);
											else
												return 0;
											end
										elseif SN == "PARTPARRYMITPBONUS" then
											return CalcStat("PartMitPBonus",L);
										else
											return 0;
										end
									elseif SN > "PARTPARRYMITPRATP" then
										if SN < "PARTPARRYMITPRATPB" then
											if SN == "PARTPARRYMITPRATPA" then
												return CalcStat("PartMitPRatPA",L);
											else
												return 0;
											end
										elseif SN > "PARTPARRYMITPRATPB" then
											if SN == "PARTPARRYMITPRATPC" then
												return CalcStat("PartMitPRatPC",L);
											else
												return 0;
											end
										else
											return CalcStat("PartMitPRatPB",L);
										end
									else
										return CalcStat("PartMitPRatP",L,N);
									end
								else
									return CalcStat("PartMitPRatPB",L)*CalcStat("PartMitPRatPC",L);
								end
							elseif SN > "PARTPARRYMITPRATPCAP" then
								if SN < "PARTPARRYPRATPC" then
									if SN < "PARTPARRYPPRAT" then
										if SN > "PARTPARRYMITPRATPCAPR" then
											if SN == "PARTPARRYPBONUS" then
												return CalcStat("PartBPEPBonus",L);
											else
												return 0;
											end
										elseif SN == "PARTPARRYMITPRATPCAPR" then
											return CalcStat("PartMitPRatPCapR",L);
										else
											return 0;
										end
									elseif SN > "PARTPARRYPPRAT" then
										if SN < "PARTPARRYPRATPA" then
											if SN == "PARTPARRYPRATP" then
												return CalcStat("PartBPEPRatP",L,N);
											else
												return 0;
											end
										elseif SN > "PARTPARRYPRATPA" then
											if SN == "PARTPARRYPRATPB" then
												return CalcStat("PartBPEPRatPB",L);
											else
												return 0;
											end
										else
											return CalcStat("PartBPEPRatPA",L);
										end
									else
										return CalcStat("PartBPEPPRat",L,N);
									end
								elseif SN > "PARTPARRYPRATPC" then
									if SN < "PERKNCMR" then
										if SN < "PARTPARRYPRATPCAPR" then
											if SN == "PARTPARRYPRATPCAP" then
												return CalcStat("PartBPEPRatPCap",L);
											else
												return 0;
											end
										elseif SN > "PARTPARRYPRATPCAPR" then
											if SN == "PERKMORALE" then
												return DataTableValue({149,215,246,262},L);
											else
												return 0;
											end
										else
											return CalcStat("PartBPEPRatPCapR",L);
										end
									elseif SN > "PERKNCMR" then
										if SN < "PERKPHYMIT" then
											if SN == "PERKNCPR" then
												return CalcStat("FoodNCPRL",L);
											else
												return 0;
											end
										elseif SN > "PERKPHYMIT" then
											if SN == "PERKPOWER" then
												return DataTableValue({95,131,146,153},L);
											else
												return 0;
											end
										else
											return CalcStat("PhyMitT",L,0.2*N);
										end
									else
										return CalcStat("FoodNCMRL",L);
									end
								else
									return CalcStat("PartBPEPRatPC",L);
								end
							else
								return CalcStat("PartMitPRatPCap",L);
							end
						else
							return 0.1;
						end
					elseif SN > "PERKTACMIT" then
						if SN < "PHYMITLPRATPCAPR" then
							if SN < "PHYMITHPBONUS" then
								if SN < "PHYDMGPRATPCAP" then
									if SN < "PHYDMGPRATP" then
										if SN > "PHYDMGPBONUS" then
											if SN == "PHYDMGPPRAT" then
												return CalcStat("OutDmgPPRat",L,N);
											else
												return 0;
											end
										elseif SN == "PHYDMGPBONUS" then
											return CalcStat("OutDmgPBonus",L);
										else
											return 0;
										end
									elseif SN > "PHYDMGPRATP" then
										if SN < "PHYDMGPRATPB" then
											if SN == "PHYDMGPRATPA" then
												return CalcStat("OutDmgPRatPA",L);
											else
												return 0;
											end
										elseif SN > "PHYDMGPRATPB" then
											if SN == "PHYDMGPRATPC" then
												return CalcStat("OutDmgPRatPC",L);
											else
												return 0;
											end
										else
											return CalcStat("OutDmgPRatPB",L);
										end
									else
										return CalcStat("OutDmgPRatP",L,N);
									end
								elseif SN > "PHYDMGPRATPCAP" then
									if SN < "PHYMASOLD" then
										if SN > "PHYDMGPRATPCAPR" then
											if SN == "PHYMAS" then
												return CalcStat("Mastery",L,N);
											else
												return 0;
											end
										elseif SN == "PHYDMGPRATPCAPR" then
											return CalcStat("OutDmgPRatPCapR",L);
										else
											return 0;
										end
									elseif SN > "PHYMASOLD" then
										if SN < "PHYMIT" then
											if SN == "PHYMAST" then
												return CalcStat("MasteryT",L,N);
											else
												return 0;
											end
										elseif SN > "PHYMIT" then
											if SN == "PHYMITADJ" then
												if Lm <= 80 then
													return CalcStat("AdjItemProgRatings",L);
												elseif Lm <= 399 then
													return 1;
												elseif Lm <= 449 then
													return 0.9;
												elseif Lm <= 450 then
													return 83/90;
												else
													return 60/90;
												end
											else
												return 0;
											end
										else
											return StatLinInter("PntMPPhyMit","ItemMedProg","ProgBMitigation","PhyMitAdj",L,N);
										end
									else
										return CalcStat("Mastery",L,N);
									end
								else
									return CalcStat("OutDmgPRatPCap",L);
								end
							elseif SN > "PHYMITHPBONUS" then
								if SN < "PHYMITHPRATPCAPR" then
									if SN < "PHYMITHPRATPA" then
										if SN > "PHYMITHPPRAT" then
											if SN == "PHYMITHPRATP" then
												return CalcStat("MitHeavyPRatP",L,N);
											else
												return 0;
											end
										elseif SN == "PHYMITHPPRAT" then
											return CalcStat("MitHeavyPPRat",L,N);
										else
											return 0;
										end
									elseif SN > "PHYMITHPRATPA" then
										if SN < "PHYMITHPRATPC" then
											if SN == "PHYMITHPRATPB" then
												return CalcStat("MitHeavyPRatPB",L);
											else
												return 0;
											end
										elseif SN > "PHYMITHPRATPC" then
											if SN == "PHYMITHPRATPCAP" then
												return CalcStat("MitHeavyPRatPCap",L);
											else
												return 0;
											end
										else
											return CalcStat("MitHeavyPRatPC",L);
										end
									else
										return CalcStat("MitHeavyPRatPA",L);
									end
								elseif SN > "PHYMITHPRATPCAPR" then
									if SN < "PHYMITLPRATPA" then
										if SN < "PHYMITLPPRAT" then
											if SN == "PHYMITLPBONUS" then
												return CalcStat("MitLightPBonus",L);
											else
												return 0;
											end
										elseif SN > "PHYMITLPPRAT" then
											if SN == "PHYMITLPRATP" then
												return CalcStat("MitLightPRatP",L,N);
											else
												return 0;
											end
										else
											return CalcStat("MitLightPPRat",L,N);
										end
									elseif SN > "PHYMITLPRATPA" then
										if SN < "PHYMITLPRATPC" then
											if SN == "PHYMITLPRATPB" then
												return CalcStat("MitLightPRatPB",L);
											else
												return 0;
											end
										elseif SN > "PHYMITLPRATPC" then
											if SN == "PHYMITLPRATPCAP" then
												return CalcStat("MitLightPRatPCap",L);
											else
												return 0;
											end
										else
											return CalcStat("MitLightPRatPC",L);
										end
									else
										return CalcStat("MitLightPRatPA",L);
									end
								else
									return CalcStat("MitHeavyPRatPCapR",L);
								end
							else
								return CalcStat("MitHeavyPBonus",L);
							end
						elseif SN > "PHYMITLPRATPCAPR" then
							if SN < "PNTMPDMGTYPEMIT" then
								if SN < "PHYMITMPRATPCAP" then
									if SN < "PHYMITMPRATP" then
										if SN > "PHYMITMPBONUS" then
											if SN == "PHYMITMPPRAT" then
												return CalcStat("MitMediumPPRat",L,N);
											else
												return 0;
											end
										elseif SN == "PHYMITMPBONUS" then
											return CalcStat("MitMediumPBonus",L);
										else
											return 0;
										end
									elseif SN > "PHYMITMPRATP" then
										if SN < "PHYMITMPRATPB" then
											if SN == "PHYMITMPRATPA" then
												return CalcStat("MitMediumPRatPA",L);
											else
												return 0;
											end
										elseif SN > "PHYMITMPRATPB" then
											if SN == "PHYMITMPRATPC" then
												return CalcStat("MitMediumPRatPC",L);
											else
												return 0;
											end
										else
											return CalcStat("MitMediumPRatPB",L);
										end
									else
										return CalcStat("MitMediumPRatP",L,N);
									end
								elseif SN > "PHYMITMPRATPCAP" then
									if SN < "PHYMITTADJ" then
										if SN > "PHYMITMPRATPCAPR" then
											if SN == "PHYMITT" then
												return StatLinInter("PntMPPhyMit","TraitProg","ProgBMitigation","PhyMitTAdj",L,N);
											else
												return 0;
											end
										elseif SN == "PHYMITMPRATPCAPR" then
											return CalcStat("MitMediumPRatPCapR",L);
										else
											return 0;
										end
									elseif SN > "PHYMITTADJ" then
										if SN < "PNTMPARMOUR" then
											if SN == "PHYRESISTT" then
												return CalcStat("ResistAddT",L,N);
											else
												return 0;
											end
										elseif SN > "PNTMPARMOUR" then
											if SN == "PNTMPCRITHIT" then
												return 12597/247000;
											else
												return 0;
											end
										else
											return 24375/247000;
										end
									else
										if Lm <= 130 then
											return CalcStat("AdjTraitProgRatings",L);
										elseif Lm <= 131 then
											return 70/90;
										else
											return 60/90;
										end
									end
								else
									return CalcStat("MitMediumPRatPCap",L);
								end
							elseif SN > "PNTMPDMGTYPEMIT" then
								if SN < "PNTMPNCMR" then
									if SN < "PNTMPMAIN" then
										if SN > "PNTMPICMR" then
											if SN == "PNTMPICPR" then
												return (1/12)/40;
											else
												return 0;
											end
										elseif SN == "PNTMPICMR" then
											return 0.01;
										else
											return 0;
										end
									elseif SN > "PNTMPMAIN" then
										if SN < "PNTMPMITIGATION" then
											if SN == "PNTMPMASTERY" then
												return 8892/247000;
											else
												return 0;
											end
										elseif SN > "PNTMPMITIGATION" then
											if SN == "PNTMPMORALE" then
												return 7600/247000;
											else
												return 0;
											end
										else
											return 17550/247000;
										end
									else
										return 6669/247000;
									end
								elseif SN > "PNTMPNCMR" then
									if SN < "PNTMPRATADD" then
										if SN < "PNTMPPHYMIT" then
											if SN == "PNTMPNCPR" then
												return (2/3)/40;
											else
												return 0;
											end
										elseif SN > "PNTMPPHYMIT" then
											if SN == "PNTMPPOWER" then
												return (2/3)/40;
											else
												return 0;
											end
										else
											return 29250/247000;
										end
									elseif SN > "PNTMPRATADD" then
										if SN < "PNTMPTACMIT" then
											if SN == "PNTMPRATINGS" then
												return 14820/247000;
											else
												return 0;
											end
										elseif SN > "PNTMPTACMIT" then
											if SN == "PNTMPVITALITY" then
												return 30875/247000;
											else
												return 0;
											end
										else
											return 21450/247000;
										end
									else
										return 23267.4/247000;
									end
								else
									return 0.1;
								end
							else
								return 39000/247000;
							end
						else
							return CalcStat("MitLightPRatPCapR",L);
						end
					else
						return CalcStat("TacMitT",L,0.2*N);
					end
				else
					return CalcStat("PartBPEPRatPA",L);
				end
			elseif SN > "POISONRESISTT" then
				if SN < "RUNEKEEPERCDWILLTOFINESSE" then
					if SN < "REPMORALE" then
						if SN < "PROGBVITALITY" then
							if SN < "PROGBMEDIUM" then
								if SN < "PROGBHIGH" then
									if SN < "POWERT" then
										if SN > "POWER" then
											if SN == "POWERADJ" then
												return CalcStat("AdjItemProgPower",L)*2.5;
											else
												return 0;
											end
										elseif SN == "POWER" then
											return StatLinInter("PntMPPower","ItemHighProgAlt","ProgBPower","PowerAdj",L,N);
										else
											return 0;
										end
									elseif SN > "POWERT" then
										if SN < "PROGBDEFENCE" then
											if SN == "POWERTADJ" then
												return CalcStat("AdjTraitProgPower",L);
											else
												return 0;
											end
										elseif SN > "PROGBDEFENCE" then
											if SN == "PROGBDEFENCENEW" then
												return 532;
											else
												return 0;
											end
										else
											return 266;
										end
									else
										return StatLinInter("PntMPPower","TraitProgAlt","ProgBPower","PowerTAdj",L,N);
									end
								elseif SN > "PROGBHIGH" then
									if SN < "PROGBLOWNEW" then
										if SN > "PROGBHIGHNEW" then
											if SN == "PROGBLOW" then
												return 200;
											else
												return 0;
											end
										elseif SN == "PROGBHIGHNEW" then
											return 10000/6;
										else
											return 0;
										end
									elseif SN > "PROGBLOWNEW" then
										if SN < "PROGBMASTERY" then
											if SN == "PROGBMAIN" then
												return 40;
											else
												return 0;
											end
										elseif SN > "PROGBMASTERY" then
											if SN == "PROGBMASTERYNEW" then
												return 540;
											else
												return 0;
											end
										else
											return 270;
										end
									else
										return 400;
									end
								else
									return 500;
								end
							elseif SN > "PROGBMEDIUM" then
								if SN < "PROGBMITMEDIUM" then
									if SN < "PROGBMITHEAVYNEW" then
										if SN > "PROGBMEDIUMNEW" then
											if SN == "PROGBMITHEAVY" then
												return 174;
											else
												return 0;
											end
										elseif SN == "PROGBMEDIUMNEW" then
											return 800;
										else
											return 0;
										end
									elseif SN > "PROGBMITHEAVYNEW" then
										if SN < "PROGBMITLIGHT" then
											if SN == "PROGBMITIGATION" then
												return CalcStat("ProgBMitMedium",L);
											else
												return 0;
											end
										elseif SN > "PROGBMITLIGHT" then
											if SN == "PROGBMITLIGHTNEW" then
												return 800/3;
											else
												return 0;
											end
										else
											return 280/3;
										end
									else
										return 401.6;
									end
								elseif SN > "PROGBMITMEDIUM" then
									if SN < "PROGBPARTIAL" then
										if SN < "PROGBMORALE" then
											if SN == "PROGBMITMEDIUMNEW" then
												return 7040/21;
											else
												return 0;
											end
										elseif SN > "PROGBMORALE" then
											if SN == "PROGBMORREG" then
												return 10;
											else
												return 0;
											end
										else
											return 130;
										end
									elseif SN > "PROGBPARTIAL" then
										if SN < "PROGBPOWER" then
											if SN == "PROGBPARTIALNEW" then
												return 500;
											else
												return 0;
											end
										elseif SN > "PROGBPOWER" then
											if SN == "PROGBPOWREG" then
												return 40;
											else
												return 0;
											end
										else
											return 40;
										end
									else
										return 350;
									end
								else
									return 382/3;
								end
							else
								return 400;
							end
						elseif SN > "PROGBVITALITY" then
							if SN < "PROGEXTMEDEXPRAW" then
								if SN < "PROGEXTHIGHLINEXPDECA" then
									if SN < "PROGEXTCOMLOWRAW" then
										if SN > "PROGEXTCOMHIGHRAW" then
											if SN == "PROGEXTCOMHIGHRND" then
												if Lm <= 121 then
													return ExpFmod(N,121,20,L,0);
												elseif Lm <= 125 then
													return ExpFmod(CalcStat("ProgExtComHighRnd",121,N),122,5.5,L,0);
												elseif Lm <= 126 then
													return ExpFmod(CalcStat("ProgExtComHighRnd",125,N),126,20,L,0);
												elseif Lm <= 130 then
													return ExpFmod(CalcStat("ProgExtComHighRnd",126,N),127,5.5,L,0);
												elseif Lm <= 131 then
													return ExpFmod(CalcStat("ProgExtComHighRnd",130,N),131,20,L,0);
												elseif Lm <= 140 then
													return ExpFmod(CalcStat("ProgExtComHighRnd",131,N),132,5.5,L,0);
												else
													return CalcStat("ProgExtComHighRnd",140,N);
												end
											else
												return 0;
											end
										elseif SN == "PROGEXTCOMHIGHRAW" then
											if Lm <= 121 then
												return ExpFmod(N,121,20,L,nil);
											elseif Lm <= 125 then
												return ExpFmod(CalcStat("ProgExtComHighRaw",121,N),122,5.5,L,nil);
											elseif Lm <= 126 then
												return ExpFmod(CalcStat("ProgExtComHighRaw",125,N),126,20,L,nil);
											elseif Lm <= 130 then
												return ExpFmod(CalcStat("ProgExtComHighRaw",126,N),127,5.5,L,nil);
											elseif Lm <= 131 then
												return ExpFmod(CalcStat("ProgExtComHighRaw",130,N),131,20,L,nil);
											elseif Lm <= 140 then
												return ExpFmod(CalcStat("ProgExtComHighRaw",131,N),132,5.5,L,nil);
											else
												return CalcStat("ProgExtComHighRaw",140,N);
											end
										else
											return 0;
										end
									elseif SN > "PROGEXTCOMLOWRAW" then
										if SN < "PROGEXTHIGHEXPRAW" then
											if SN == "PROGEXTCOMLOWRND" then
												if Lm <= 116 then
													return ExpFmod(N,116,20,L,0);
												elseif Lm <= 120 then
													return ExpFmod(CalcStat("ProgExtComLowRnd",116,N),117,5.5,L,0);
												else
													return CalcStat("ProgExtComHighRnd",L,CalcStat("ProgExtComLowRnd",120,N));
												end
											else
												return 0;
											end
										elseif SN > "PROGEXTHIGHEXPRAW" then
											if SN == "PROGEXTHIGHEXPRND" then
												if Lm <= 106 then
													return ExpFmod(N,106,20,L,0);
												elseif Lm <= 115 then
													return ExpFmod(CalcStat("ProgExtHighExpRnd",106,N),107,5.5,L,0);
												else
													return CalcStat("ProgExtComLowRnd",L,CalcStat("ProgExtHighExpRnd",115,N));
												end
											else
												return 0;
											end
										else
											if Lm <= 106 then
												return ExpFmod(N,106,20,L,nil);
											elseif Lm <= 115 then
												return ExpFmod(CalcStat("ProgExtHighExpRaw",106,N),107,5.5,L,nil);
											else
												return CalcStat("ProgExtComLowRaw",L,CalcStat("ProgExtHighExpRaw",115,N));
											end
										end
									else
										if Lm <= 116 then
											return ExpFmod(N,116,20,L,nil);
										elseif Lm <= 120 then
											return ExpFmod(CalcStat("ProgExtComLowRaw",116,N),117,5.5,L,nil);
										else
											return CalcStat("ProgExtComHighRaw",L,CalcStat("ProgExtComLowRaw",120,N));
										end
									end
								elseif SN > "PROGEXTHIGHLINEXPDECA" then
									if SN < "PROGEXTLOWEXPRAW" then
										if SN > "PROGEXTHIGHLINEXPRAW" then
											if SN == "PROGEXTHIGHLINEXPRND" then
												if Lm <= 115 then
													return LinFmod(N,2,4,106,115,L,-1);
												else
													return CalcStat("ProgExtComLowRnd",L,CalcStat("ProgExtHighLinExpRnd",115,N));
												end
											else
												return 0;
											end
										elseif SN == "PROGEXTHIGHLINEXPRAW" then
											if Lm <= 115 then
												return LinFmod(N,2,4,106,115,L,-1);
											else
												return CalcStat("ProgExtComLowRaw",L,CalcStat("ProgExtHighLinExpRaw",115,N));
											end
										else
											return 0;
										end
									elseif SN > "PROGEXTLOWEXPRAW" then
										if SN < "PROGEXTLOWLINEXPRAW" then
											if SN == "PROGEXTLOWEXPRND" then
												if Lm <= 115 then
													return ExpFmod(N,106,5.5,L,0);
												else
													return CalcStat("ProgExtComLowRnd",L,CalcStat("ProgExtLowExpRnd",115,N));
												end
											else
												return 0;
											end
										elseif SN > "PROGEXTLOWLINEXPRAW" then
											if SN == "PROGEXTLOWLINEXPRND" then
												if Lm <= 115 then
													return LinFmod(N,1.25,1.5,106,115,L,-1);
												else
													return CalcStat("ProgExtComLowRnd",L,CalcStat("ProgExtLowLinExpRnd",115,N));
												end
											else
												return 0;
											end
										else
											if Lm <= 115 then
												return LinFmod(N,1.25,1.5,106,115,L,-1);
											else
												return CalcStat("ProgExtComLowRaw",L,CalcStat("ProgExtLowLinExpRaw",115,N));
											end
										end
									else
										if Lm <= 115 then
											return ExpFmod(N,106,5.5,L,nil);
										else
											return CalcStat("ProgExtComLowRaw",L,CalcStat("ProgExtLowExpRaw",115,N));
										end
									end
								else
									if Lm <= 115 then
										return LinFmod(N,2,4,106,115,L,-1);
									else
										return CalcStat("ProgExtComLowRnd",L,CalcStat("ProgExtHighLinExpDeca",115,N)/10)*10;
									end
								end
							elseif SN > "PROGEXTMEDEXPRAW" then
								if SN < "REPCRITHIT" then
									if SN < "PROGEXTMPEXPRND" then
										if SN > "PROGEXTMEDEXPRND" then
											if SN == "PROGEXTMPEXPRAW" then
												if Lm <= 114 then
													return ExpFmod(N,106,7.5,L,nil);
												elseif Lm <= 115 then
													return 2*N;
												elseif Lm <= 119 then
													return ExpFmod(CalcStat("ProgExtMpExpRaw",115,N),116,25,L,nil);
												elseif Lm <= 120 then
													return (16/3)*N;
												else
													return CalcStat("ProgExtComHighRaw",L,CalcStat("ProgExtMpExpRaw",120,N));
												end
											else
												return 0;
											end
										elseif SN == "PROGEXTMEDEXPRND" then
											if Lm <= 106 then
												return ExpFmod(N,106,10,L,0);
											elseif Lm <= 115 then
												return ExpFmod(CalcStat("ProgExtMedExpRnd",106,N),107,5.5,L,0);
											else
												return CalcStat("ProgExtComLowRnd",L,CalcStat("ProgExtMedExpRnd",115,N));
											end
										else
											return 0;
										end
									elseif SN > "PROGEXTMPEXPRND" then
										if SN < "REPAGILITYL" then
											if SN == "REPAGILITYH" then
												return CalcStat("RepMainH",L);
											else
												return 0;
											end
										elseif SN > "REPAGILITYL" then
											if SN == "REPCRITDEF" then
												if Lm <= 50 then
													return LinFmod(1,900,1488,1,50,L);
												elseif Lm <= 85 then
													return LinFmod(1,1488,1908,50,85,L);
												elseif Lm <= 105 then
													return LinFmod(1,1908,2148,85,105,L);
												else
													return LinFmod(1,2148,2328,105,120,L);
												end
											else
												return 0;
											end
										else
											return CalcStat("RepMainL",L);
										end
									else
										if Lm <= 114 then
											return ExpFmod(N,106,7.5,L,0);
										elseif Lm <= 115 then
											return 2*N;
										elseif Lm <= 119 then
											return ExpFmod(CalcStat("ProgExtMpExpRnd",115,N),116,25,L,0);
										elseif Lm <= 120 then
											return RoundDbl((16/3)*N);
										else
											return CalcStat("ProgExtComHighRnd",L,CalcStat("ProgExtMpExpRnd",120,N));
										end
									end
								elseif SN > "REPCRITHIT" then
									if SN < "REPMAINH" then
										if SN < "REPFATEL" then
											if SN == "REPFATEH" then
												return CalcStat("RepMainH",L);
											else
												return 0;
											end
										elseif SN > "REPFATEL" then
											if SN == "REPFINESSE" then
												if Lm <= 50 then
													return LinFmod(1,322,557,1,50,L);
												elseif Lm <= 85 then
													return LinFmod(1,557,749.9477,50,85,L);
												elseif Lm <= 105 then
													return LinFmod(1,749.9477,859.1634,85,105,L);
												else
													return LinFmod(1,859.1634,939.2549,105,120,L);
												end
											else
												return 0;
											end
										else
											return CalcStat("RepMainL",L);
										end
									elseif SN > "REPMAINH" then
										if SN < "REPMIGHTH" then
											if SN == "REPMAINL" then
												if Lm <= 50 then
													return FloorDbl(LinFmod(1,53,102,1,50,L));
												elseif Lm <= 85 then
													return FloorDbl(LinFmod(1,102,137,50,85,L));
												elseif Lm <= 105 then
													return FloorDbl(LinFmod(1,137,157,85,105,L));
												else
													return FloorDbl(LinFmod(1,157,172,105,120,L));
												end
											else
												return 0;
											end
										elseif SN > "REPMIGHTH" then
											if SN == "REPMIGHTL" then
												return CalcStat("RepMainL",L);
											else
												return 0;
											end
										else
											return CalcStat("RepMainH",L);
										end
									else
										if Lm <= 50 then
											return FloorDbl(LinFmod(1,80,153,1,50,L));
										elseif Lm <= 85 then
											return FloorDbl(LinFmod(1,153,206,50,85,L));
										elseif Lm <= 105 then
											return FloorDbl(LinFmod(1,206,236,85,105,L));
										else
											return FloorDbl(LinFmod(1,236,258,105,120,L));
										end
									end
								else
									if Lm <= 50 then
										return LinFmod(1,300,496,1,50,L);
									elseif Lm <= 85 then
										return LinFmod(1,496,636,50,85,L);
									elseif Lm <= 105 then
										return LinFmod(1,636,716,85,105,L);
									else
										return LinFmod(1,716,776,105,120,L);
									end
								end
							else
								if Lm <= 106 then
									return ExpFmod(N,106,10,L,nil);
								elseif Lm <= 115 then
									return ExpFmod(CalcStat("ProgExtMedExpRaw",106,N),107,5.5,L,nil);
								else
									return CalcStat("ProgExtComLowRaw",L,CalcStat("ProgExtMedExpRaw",115,N));
								end
							end
						else
							return 10;
						end
					elseif SN > "REPMORALE" then
						if SN < "RUNEKEEPERCDARMOURTOTACMIT" then
							if SN < "RESISTPRATPA" then
								if SN < "RESIST" then
									if SN < "REPVITALITYH" then
										if SN > "REPPOWER" then
											if SN == "REPTACMIT" then
												if Lm <= 50 then
													return LinFmod(1,675,1116,1,50,L);
												elseif Lm <= 85 then
													return LinFmod(1,1116,1431,50,85,L);
												elseif Lm <= 105 then
													return LinFmod(1,1431,1611,85,105,L);
												else
													return LinFmod(1,1611,1746,105,120,L);
												end
											else
												return 0;
											end
										elseif SN == "REPPOWER" then
											if Lm <= 50 then
												return LinFmod(1,94,212,1,50,L);
											elseif Lm <= 85 then
												return LinFmod(1,212,296,50,85,L);
											elseif Lm <= 105 then
												return LinFmod(1,296,344,85,105,L);
											else
												return LinFmod(1,344,380,105,120,L);
											end
										else
											return 0;
										end
									elseif SN > "REPVITALITYH" then
										if SN < "REPWILLH" then
											if SN == "REPVITALITYL" then
												return CalcStat("RepMainL",L);
											else
												return 0;
											end
										elseif SN > "REPWILLH" then
											if SN == "REPWILLL" then
												return CalcStat("RepMainL",L);
											else
												return 0;
											end
										else
											return CalcStat("RepMainH",L);
										end
									else
										return CalcStat("RepMainH",L);
									end
								elseif SN > "RESIST" then
									if SN < "RESISTADJ" then
										if SN > "RESISTADDT" then
											if SN == "RESISTADDTADJ" then
												if Lm <= 121 then
													return CalcStat("AdjTraitProgRatings",L);
												elseif Lm <= 130 then
													return 1;
												elseif Lm <= 131 then
													return 11/9.0;
												else
													return 12/9.0;
												end
											else
												return 0;
											end
										elseif SN == "RESISTADDT" then
											return StatLinInter("PntMPRatAdd","TraitProgAlt","ProgBLow","ResistAddTAdj",L,N);
										else
											return 0;
										end
									elseif SN > "RESISTADJ" then
										if SN < "RESISTPPRAT" then
											if SN == "RESISTPBONUS" then
												return 0;
											else
												return 0;
											end
										elseif SN > "RESISTPPRAT" then
											if SN == "RESISTPRATP" then
												return CalcPercAB(CalcStat("ResistPRatPA",L),CalcStat("ResistPRatPB",L),CalcStat("ResistPRatPCap",L),N);
											else
												return 0;
											end
										else
											return CalcRatAB(CalcStat("ResistPRatPA",L),CalcStat("ResistPRatPB",L),CalcStat("ResistPRatPCapR",L),N);
										end
									else
										if Lm <= 449 then
											return CalcStat("AdjItemProgRatings",L);
										elseif Lm <= 450 then
											return 1;
										else
											return 40/30;
										end
									end
								else
									return StatLinInter("PntMPRatings","ItemMedProgAlt","ProgBLow","ResistAdj",L,N);
								end
							elseif SN > "RESISTPRATPA" then
								if SN < "REVERSE" then
									if SN < "RESISTPRATPCAP" then
										if SN > "RESISTPRATPB" then
											if SN == "RESISTPRATPC" then
												if Lm <= 130 then
													return 1;
												else
													return 0.5;
												end
											else
												return 0;
											end
										elseif SN == "RESISTPRATPB" then
											if Lm <= 130 then
												return CalcStat("BratProgAlt",L,CalcStat("ProgBLow",L));
											else
												return CalcStat("BratProgAlt",L,CalcStat("ProgBLowNew",L));
											end
										else
											return 0;
										end
									elseif SN > "RESISTPRATPCAP" then
										if SN < "RESISTT" then
											if SN == "RESISTPRATPCAPR" then
												return CalcStat("ResistPRatPB",L)*CalcStat("ResistPRatPC",L);
											else
												return 0;
											end
										elseif SN > "RESISTT" then
											if SN == "RESISTTADJ" then
												if Lm <= 130 then
													return CalcStat("AdjTraitProgRatings",L);
												elseif Lm <= 131 then
													return 11/9.0;
												else
													return 12/9.0;
												end
											else
												return 0;
											end
										else
											return StatLinInter("PntMPRatings","TraitProgAlt","ProgBLow","ResistTAdj",L,N);
										end
									else
										return 50;
									end
								elseif SN > "REVERSE" then
									if SN < "RUNEKEEPERCDAGILITYTOEVADE" then
										if SN < "RKFORTUNESMILESFATE" then
											if SN == "RKDETERMINATIONWILL" then
												return CalcStat("WillT",L,CalcStat("Trait567810Choice",N)*0.4);
											else
												return 0;
											end
										elseif SN > "RKFORTUNESMILESFATE" then
											if SN == "RUNEKEEPERCDAGILITYTOCRITHIT" then
												return 1;
											else
												return 0;
											end
										else
											return CalcStat("FateT",L,CalcStat("Trait567810Choice",N)*0.4);
										end
									elseif SN > "RUNEKEEPERCDAGILITYTOEVADE" then
										if SN < "RUNEKEEPERCDARMOURTOOFMIT" then
											if SN == "RUNEKEEPERCDAGILITYTOPARRY" then
												return 2;
											else
												return 0;
											end
										elseif SN > "RUNEKEEPERCDARMOURTOOFMIT" then
											if SN == "RUNEKEEPERCDARMOURTOPHYMIT" then
												return 1;
											else
												return 0;
											end
										else
											return 0.2;
										end
									else
										return 3;
									end
								else
									return ReverseCalc(C,L);
								end
							else
								if Lm <= 130 then
									return 100;
								else
									return 150;
								end
							end
						elseif SN > "RUNEKEEPERCDARMOURTOTACMIT" then
							if SN < "RUNEKEEPERCDFATETOICMR" then
								if SN < "RUNEKEEPERCDBASEMORALE" then
									if SN < "RUNEKEEPERCDBASEFATE" then
										if SN > "RUNEKEEPERCDARMOURTYPE" then
											if SN == "RUNEKEEPERCDBASEAGILITY" then
												return CalcStat("ClassBaseMainG",L);
											else
												return 0;
											end
										elseif SN == "RUNEKEEPERCDARMOURTYPE" then
											return 1;
										else
											return 0;
										end
									elseif SN > "RUNEKEEPERCDBASEFATE" then
										if SN < "RUNEKEEPERCDBASEICPR" then
											if SN == "RUNEKEEPERCDBASEICMR" then
												return CalcStat("ClassBaseICMRL",L);
											else
												return 0;
											end
										elseif SN > "RUNEKEEPERCDBASEICPR" then
											if SN == "RUNEKEEPERCDBASEMIGHT" then
												return CalcStat("ClassBaseMainB",L);
											else
												return 0;
											end
										else
											return CalcStat("ClassBaseICPR",L);
										end
									else
										return CalcStat("ClassBaseMainK",L);
									end
								elseif SN > "RUNEKEEPERCDBASEMORALE" then
									if SN < "RUNEKEEPERCDBASEPOWER" then
										if SN > "RUNEKEEPERCDBASENCMR" then
											if SN == "RUNEKEEPERCDBASENCPR" then
												return CalcStat("ClassBaseNCPR",L);
											else
												return 0;
											end
										elseif SN == "RUNEKEEPERCDBASENCMR" then
											return CalcStat("ClassBaseNCMRL",L);
										else
											return 0;
										end
									elseif SN > "RUNEKEEPERCDBASEPOWER" then
										if SN < "RUNEKEEPERCDBASEWILL" then
											if SN == "RUNEKEEPERCDBASEVITALITY" then
												return CalcStat("ClassBaseMainD",L);
											else
												return 0;
											end
										elseif SN > "RUNEKEEPERCDBASEWILL" then
											if SN == "RUNEKEEPERCDFATETOCRITHIT" then
												return 2.5;
											else
												return 0;
											end
										else
											return CalcStat("ClassBaseMainI",L);
										end
									else
										return CalcStat("ClassBasePowerH",L);
									end
								else
									if Lm <= 120 then
										return CalcStat("ClassBaseMoraleL",L);
									else
										return CalcStat("ClassBaseMoraleL",120);
									end
								end
							elseif SN > "RUNEKEEPERCDFATETOICMR" then
								if SN < "RUNEKEEPERCDMIGHTTOPARRY" then
									if SN < "RUNEKEEPERCDFATETORESIST" then
										if SN > "RUNEKEEPERCDFATETONCPR" then
											if SN == "RUNEKEEPERCDFATETOPOWER" then
												return 1;
											else
												return 0;
											end
										elseif SN == "RUNEKEEPERCDFATETONCPR" then
											return 0.05;
										else
											return 0;
										end
									elseif SN > "RUNEKEEPERCDFATETORESIST" then
										if SN < "RUNEKEEPERCDHASPOWER" then
											if SN == "RUNEKEEPERCDFATETOTACMIT" then
												return 1;
											else
												return 0;
											end
										elseif SN > "RUNEKEEPERCDHASPOWER" then
											if SN == "RUNEKEEPERCDMIGHTTOBLOCK" then
												return 3;
											else
												return 0;
											end
										else
											return 1;
										end
									else
										return 1;
									end
								elseif SN > "RUNEKEEPERCDMIGHTTOPARRY" then
									if SN < "RUNEKEEPERCDVITALITYTONCMR" then
										if SN < "RUNEKEEPERCDTACMASTOOUTHEAL" then
											if SN == "RUNEKEEPERCDPHYMITTOOFMIT" then
												return 1;
											else
												return 0;
											end
										elseif SN > "RUNEKEEPERCDTACMASTOOUTHEAL" then
											if SN == "RUNEKEEPERCDVITALITYTOMORALE" then
												return 4;
											else
												return 0;
											end
										else
											return 1;
										end
									elseif SN > "RUNEKEEPERCDVITALITYTONCMR" then
										if SN < "RUNEKEEPERCDVITALITYTOTACMIT" then
											if SN == "RUNEKEEPERCDVITALITYTORESIST" then
												return 1;
											else
												return 0;
											end
										elseif SN > "RUNEKEEPERCDVITALITYTOTACMIT" then
											if SN == "RUNEKEEPERCDWILLTOEVADE" then
												return 1;
											else
												return 0;
											end
										else
											return 1;
										end
									else
										return 0.12;
									end
								else
									return 2;
								end
							else
								return 0.025;
							end
						else
							return 0.2;
						end
					else
						if Lm <= 50 then
							return LinFmod(1,187,427,1,50,L);
						elseif Lm <= 85 then
							return LinFmod(1,427,599,50,85,L);
						elseif Lm <= 105 then
							return LinFmod(1,599,697,85,105,L);
						else
							return LinFmod(1,697,770,105,120,L);
						end
					end
				elseif SN > "RUNEKEEPERCDWILLTOFINESSE" then
					if SN < "TACDMGPRATPC" then
						if SN < "STOUTAXERDPSVONENAME" then
							if SN < "STATPROGLPH" then
								if SN < "SKILLPOWERCOST" then
									if SN < "RUNEKEEPERCDWILLTOTACMIT" then
										if SN > "RUNEKEEPERCDWILLTORESIST" then
											if SN == "RUNEKEEPERCDWILLTOTACMAS" then
												return 3;
											else
												return 0;
											end
										elseif SN == "RUNEKEEPERCDWILLTORESIST" then
											return 2;
										else
											return 0;
										end
									elseif SN > "RUNEKEEPERCDWILLTOTACMIT" then
										if SN < "SHADOWMITT" then
											if SN == "SHADOWMIT" then
												return CalcStat("DmgTypeMit",L,N);
											else
												return 0;
											end
										elseif SN > "SHADOWMITT" then
											if SN == "SHIELDBRAWLERBLOCK" then
												return CalcStat("DwarfShieldBrwlBlock",L);
											else
												return 0;
											end
										else
											return CalcStat("DmgTypeMitT",L,N);
										end
									else
										return 1;
									end
								elseif SN > "SKILLPOWERCOST" then
									if SN < "STATPROG" then
										if SN > "SONGRESISTT" then
											if SN == "STATC" then
												return CalcStat(C,L);
											else
												return 0;
											end
										elseif SN == "SONGRESISTT" then
											return CalcStat("ResistAddT",L,N);
										else
											return 0;
										end
									elseif SN > "STATPROG" then
										if SN < "STATPROGALTLPH" then
											if SN == "STATPROGALT" then
												if Lm <= 75 then
													return LinFmod(RoundDbl(N),1,75,1,75,L);
												elseif Lm <= 76 then
													return LinFmod(1,RoundDbl(N)*75,CalcStat("StdProgAlt",76,N),75,76,L);
												else
													return CalcStat("StdProgAlt",L,N);
												end
											else
												return 0;
											end
										elseif SN > "STATPROGALTLPH" then
											if SN == "STATPROGALTLPL" then
												return CalcStat("StdProgAltLPL",L);
											else
												return 0;
											end
										else
											return CalcStat("StdProgAltLPH",L);
										end
									else
										if Lm <= 75 then
											return LinFmod(RoundDbl(N),1,75,1,75,L);
										elseif Lm <= 76 then
											return LinFmod(1,RoundDbl(N)*75,CalcStat("StdProg",76,N),75,76,L);
										else
											return CalcStat("StdProg",L,N);
										end
									end
								else
									return CalcStat("PowerT",L,N*0.28);
								end
							elseif SN > "STATPROGLPH" then
								if SN < "STDPOWERL" then
									if SN < "STDMORALEL" then
										if SN > "STATPROGLPL" then
											if SN == "STDMORALEH" then
												if Lm <= 105 then
													return RoundDbl(2*CalcStat("StdMoraleRaw",L));
												else
													return CalcStat("ProgExtLowExpRnd",L,CalcStat("StdMoraleH",105));
												end
											else
												return 0;
											end
										elseif SN == "STATPROGLPL" then
											return CalcStat("StdProgLPL",L);
										else
											return 0;
										end
									elseif SN > "STDMORALEL" then
										if SN < "STDMORALERAW" then
											if SN == "STDMORALEM" then
												if Lm <= 105 then
													return RoundDbl(1.5*CalcStat("StdMoraleRaw",L));
												else
													return CalcStat("ProgExtLowExpRnd",L,CalcStat("StdMoraleM",105));
												end
											else
												return 0;
											end
										elseif SN > "STDMORALERAW" then
											if SN == "STDPOWERH" then
												if Lm <= 105 then
													return RoundDbl(2*CalcStat("StdPowerRaw",L));
												else
													return CalcStat("ProgExtLowExpRnd",L,CalcStat("StdPowerH",105));
												end
											else
												return 0;
											end
										else
											if Lm <= 50 then
												return LinFmod(1,7.51,227.59,1,50,L);
											else
												return LinFmod(1,227.59,1327.5,50,105,L);
											end
										end
									else
										if Lm <= 105 then
											return RoundDbl(CalcStat("StdMoraleRaw",L));
										else
											return CalcStat("ProgExtLowExpRnd",L,CalcStat("StdMoraleL",105));
										end
									end
								elseif SN > "STDPOWERL" then
									if SN < "STDPROGALTLPH" then
										if SN < "STDPROG" then
											if SN == "STDPOWERRAW" then
												if Lm <= 50 then
													return LinFmod(1,3,91.0375,1,50,L);
												else
													return LinFmod(1,91.0375,421,50,105,L);
												end
											else
												return 0;
											end
										elseif SN > "STDPROG" then
											if SN == "STDPROGALT" then
												if Lm <= 130 then
													return CalcStat("StdProg",L,N);
												elseif Lm <= 131 then
													return LinFmod(N,3150,3117.5,130,131,L);
												elseif Lm <= 140 then
													return LinFmod(N,3117.5,6235,131,140,L);
												elseif Lm <= 141 then
													return LinFmod(N,6235,7482,140,141,L);
												else
													return LinFmod(N,7482,12470,141,150,L);
												end
											else
												return 0;
											end
										else
											if Lm <= 75 then
												return LinFmod(N,1,75,1,75,L);
											elseif Lm <= 76 then
												return LinFmod(1,N*75,RoundDbl(N*82.5,-2),75,76,L);
											elseif Lm <= 100 then
												return LinFmod(1,RoundDbl(N*82.5,-2),N*150,76,100,L);
											elseif Lm <= 101 then
												return LinFmod(N,150,165,100,101,L);
											elseif Lm <= 105 then
												return LinFmod(N,165,225,101,105,L);
											elseif Lm <= 106 then
												return LinFmod(N,225,270,105,106,L);
											elseif Lm <= 115 then
												return LinFmod(N,270,450,106,115,L);
											elseif Lm <= 116 then
												return LinFmod(N,450,495,115,116,L);
											elseif Lm <= 120 then
												return LinFmod(N,495,1125,116,120,L);
											elseif Lm <= 121 then
												return LinFmod(N,1125,1575,120,121,L);
											elseif Lm <= 130 then
												return LinFmod(N,1575,3150,121,130,L);
											elseif Lm <= 131 then
												return LinFmod(N,3150,3118.5,130,131,L);
											elseif Lm <= 140 then
												return LinFmod(N,3118.5,6237,131,140,L);
											elseif Lm <= 141 then
												return LinFmod(N,6237,7484.4,140,141,L);
											else
												return LinFmod(N,7484.4,12474,141,150,L);
											end
										end
									elseif SN > "STDPROGALTLPH" then
										if SN < "STDPROGLPH" then
											if SN == "STDPROGALTLPL" then
												return CalcStat("StdProgLPL",L);
											else
												return 0;
											end
										elseif SN > "STDPROGLPH" then
											if SN == "STDPROGLPL" then
												if Lm <= 75 then
													return 1;
												elseif Lm <= 76 then
													return 75;
												elseif Lm <= 100 then
													return 76;
												elseif Lm <= 101 then
													return 100;
												elseif Lm <= 105 then
													return 101;
												elseif Lm <= 106 then
													return 105;
												elseif Lm <= 115 then
													return 106;
												elseif Lm <= 116 then
													return 115;
												elseif Lm <= 120 then
													return 116;
												elseif Lm <= 121 then
													return 120;
												elseif Lm <= 130 then
													return 121;
												elseif Lm <= 131 then
													return 130;
												elseif Lm <= 140 then
													return 131;
												elseif Lm <= 141 then
													return 140;
												else
													return 141;
												end
											else
												return 0;
											end
										else
											if Lm <= 75 then
												return 75;
											elseif Lm <= 76 then
												return 76;
											elseif Lm <= 100 then
												return 100;
											elseif Lm <= 101 then
												return 101;
											elseif Lm <= 105 then
												return 105;
											elseif Lm <= 106 then
												return 106;
											elseif Lm <= 115 then
												return 115;
											elseif Lm <= 116 then
												return 116;
											elseif Lm <= 120 then
												return 120;
											elseif Lm <= 121 then
												return 121;
											elseif Lm <= 130 then
												return 130;
											elseif Lm <= 131 then
												return 131;
											elseif Lm <= 140 then
												return 140;
											elseif Lm <= 141 then
												return 141;
											else
												return 150;
											end
										end
									else
										return CalcStat("StdProgLPH",L);
									end
								else
									if Lm <= 105 then
										return RoundDbl(CalcStat("StdPowerRaw",L));
									else
										return CalcStat("ProgExtLowExpRnd",L,CalcStat("StdPowerL",105));
									end
								end
							else
								return CalcStat("StdProgLPH",L);
							end
						elseif SN > "STOUTAXERDPSVONENAME" then
							if SN < "STOUTUNYIELDINGPHYMITP" then
								if SN < "STOUTAXERDTRAITPHYMITP" then
									if SN < "STOUTAXERDTRAITAGILITY" then
										if SN > "STOUTAXERDPSVONEVITALITY" then
											if SN == "STOUTAXERDPSVTWONAME" then
												return "";
											else
												return 0;
											end
										elseif SN == "STOUTAXERDPSVONEVITALITY" then
											return CalcStat("StoutUnwritDestVitality",L);
										else
											return 0;
										end
									elseif SN > "STOUTAXERDTRAITAGILITY" then
										if SN < "STOUTAXERDTRAITFATE" then
											if SN == "STOUTAXERDTRAITDISEASERESISTP" then
												return CalcStat("StoutWrBlackLDiseaseResistP",L);
											else
												return 0;
											end
										elseif SN > "STOUTAXERDTRAITFATE" then
											if SN == "STOUTAXERDTRAITMIGHT" then
												return CalcStat("StoutWrBlackLMight",L);
											else
												return 0;
											end
										else
											return CalcStat("StoutDoomDrasaFate",L);
										end
									else
										return CalcStat("StoutWrBlackLAgility",L);
									end
								elseif SN > "STOUTAXERDTRAITPHYMITP" then
									if SN < "STOUTAXERDTRAITWILL" then
										if SN > "STOUTAXERDTRAITSHADOWMITP" then
											if SN == "STOUTAXERDTRAITVITALITY" then
												return CalcStat("StoutShadowEyeVitality",L);
											else
												return 0;
											end
										elseif SN == "STOUTAXERDTRAITSHADOWMITP" then
											return CalcStat("StoutWrBlackLShadowMitP",L);
										else
											return 0;
										end
									elseif SN > "STOUTAXERDTRAITWILL" then
										if SN < "STOUTSHADOWEYEVITALITY" then
											if SN == "STOUTDOOMDRASAFATE" then
												return -10;
											else
												return 0;
											end
										elseif SN > "STOUTSHADOWEYEVITALITY" then
											if SN == "STOUTUNWRITDESTVITALITY" then
												return CalcStat("VitalityT",L,1.0);
											else
												return 0;
											end
										else
											return -7;
										end
									else
										return CalcStat("StoutUnyieldingWill",L);
									end
								else
									return CalcStat("StoutUnyieldingPhyMitP",L);
								end
							elseif SN > "STOUTUNYIELDINGPHYMITP" then
								if SN < "T2PENBPE" then
									if SN < "STOUTWRBLACKLDISEASERESISTP" then
										if SN > "STOUTUNYIELDINGWILL" then
											if SN == "STOUTWRBLACKLAGILITY" then
												return 5;
											else
												return 0;
											end
										elseif SN == "STOUTUNYIELDINGWILL" then
											return 15;
										else
											return 0;
										end
									elseif SN > "STOUTWRBLACKLDISEASERESISTP" then
										if SN < "STOUTWRBLACKLSHADOWMITP" then
											if SN == "STOUTWRBLACKLMIGHT" then
												return 15;
											else
												return 0;
											end
										elseif SN > "STOUTWRBLACKLSHADOWMITP" then
											if SN == "T2PENARMOUR" then
												return CalcStat("T2penMit",L);
											else
												return 0;
											end
										else
											return 1;
										end
									else
										return 1;
									end
								elseif SN > "T2PENBPE" then
									if SN < "TACDMGPPRAT" then
										if SN < "T2PENRESIST" then
											if SN == "T2PENMIT" then
												if Lm <= 115 then
													return FloorDbl(L*13.5)*-5;
												else
													return CalcStat("ProgExtComLowRaw",L,CalcStat("T2PenMit",115));
												end
											else
												return 0;
											end
										elseif SN > "T2PENRESIST" then
											if SN == "TACDMGPBONUS" then
												return CalcStat("OutDmgPBonus",L);
											else
												return 0;
											end
										else
											if Lm <= 115 then
												return (-90)*L;
											else
												return CalcStat("ProgExtComLowRaw",L,CalcStat("T2PenResist",115));
											end
										end
									elseif SN > "TACDMGPPRAT" then
										if SN < "TACDMGPRATPA" then
											if SN == "TACDMGPRATP" then
												return CalcStat("OutDmgPRatP",L,N);
											else
												return 0;
											end
										elseif SN > "TACDMGPRATPA" then
											if SN == "TACDMGPRATPB" then
												return CalcStat("OutDmgPRatPB",L);
											else
												return 0;
											end
										else
											return CalcStat("OutDmgPRatPA",L);
										end
									else
										return CalcStat("OutDmgPPRat",L,N);
									end
								else
									if Lm <= 115 then
										return (-40)*L;
									else
										return CalcStat("ProgExtComLowRaw",L,CalcStat("T2PenBPE",115));
									end
								end
							else
								return 1;
							end
						else
							return "Unwritten Destiny";
						end
					elseif SN > "TACDMGPRATPC" then
						if SN < "TACMITMPRATPC" then
							if SN < "TACMITHPRATPCAP" then
								if SN < "TACMITADJ" then
									if SN < "TACMAS" then
										if SN > "TACDMGPRATPCAP" then
											if SN == "TACDMGPRATPCAPR" then
												return CalcStat("OutDmgPRatPCapR",L);
											else
												return 0;
											end
										elseif SN == "TACDMGPRATPCAP" then
											return CalcStat("OutDmgPRatPCap",L);
										else
											return 0;
										end
									elseif SN > "TACMAS" then
										if SN < "TACMAST" then
											if SN == "TACMASOLD" then
												return CalcStat("Mastery",L,N);
											else
												return 0;
											end
										elseif SN > "TACMAST" then
											if SN == "TACMIT" then
												return StatLinInter("PntMPTacMit","ItemMedProg","ProgBMitigation","TacMitAdj",L,N);
											else
												return 0;
											end
										else
											return CalcStat("MasteryT",L,N);
										end
									else
										return CalcStat("Mastery",L,N);
									end
								elseif SN > "TACMITADJ" then
									if SN < "TACMITHPRATP" then
										if SN > "TACMITHPBONUS" then
											if SN == "TACMITHPPRAT" then
												return CalcStat("MitHeavyPPRat",L,N);
											else
												return 0;
											end
										elseif SN == "TACMITHPBONUS" then
											return CalcStat("MitHeavyPBonus",L);
										else
											return 0;
										end
									elseif SN > "TACMITHPRATP" then
										if SN < "TACMITHPRATPB" then
											if SN == "TACMITHPRATPA" then
												return CalcStat("MitHeavyPRatPA",L);
											else
												return 0;
											end
										elseif SN > "TACMITHPRATPB" then
											if SN == "TACMITHPRATPC" then
												return CalcStat("MitHeavyPRatPC",L);
											else
												return 0;
											end
										else
											return CalcStat("MitHeavyPRatPB",L);
										end
									else
										return CalcStat("MitHeavyPRatP",L,N);
									end
								else
									if Lm <= 449 then
										return CalcStat("AdjItemProgRatings",L);
									elseif Lm <= 450 then
										return 1;
									elseif Lm <= 499 then
										return 85/90;
									elseif Lm <= 500 then
										return 75/90;
									else
										return 60/90;
									end
								end
							elseif SN > "TACMITHPRATPCAP" then
								if SN < "TACMITLPRATPC" then
									if SN < "TACMITLPPRAT" then
										if SN > "TACMITHPRATPCAPR" then
											if SN == "TACMITLPBONUS" then
												return CalcStat("MitLightPBonus",L);
											else
												return 0;
											end
										elseif SN == "TACMITHPRATPCAPR" then
											return CalcStat("MitHeavyPRatPCapR",L);
										else
											return 0;
										end
									elseif SN > "TACMITLPPRAT" then
										if SN < "TACMITLPRATPA" then
											if SN == "TACMITLPRATP" then
												return CalcStat("MitLightPRatP",L,N);
											else
												return 0;
											end
										elseif SN > "TACMITLPRATPA" then
											if SN == "TACMITLPRATPB" then
												return CalcStat("MitLightPRatPB",L);
											else
												return 0;
											end
										else
											return CalcStat("MitLightPRatPA",L);
										end
									else
										return CalcStat("MitLightPPRat",L,N);
									end
								elseif SN > "TACMITLPRATPC" then
									if SN < "TACMITMPPRAT" then
										if SN < "TACMITLPRATPCAPR" then
											if SN == "TACMITLPRATPCAP" then
												return CalcStat("MitLightPRatPCap",L);
											else
												return 0;
											end
										elseif SN > "TACMITLPRATPCAPR" then
											if SN == "TACMITMPBONUS" then
												return CalcStat("MitMediumPBonus",L);
											else
												return 0;
											end
										else
											return CalcStat("MitLightPRatPCapR",L);
										end
									elseif SN > "TACMITMPPRAT" then
										if SN < "TACMITMPRATPA" then
											if SN == "TACMITMPRATP" then
												return CalcStat("MitMediumPRatP",L,N);
											else
												return 0;
											end
										elseif SN > "TACMITMPRATPA" then
											if SN == "TACMITMPRATPB" then
												return CalcStat("MitMediumPRatPB",L);
											else
												return 0;
											end
										else
											return CalcStat("MitMediumPRatPA",L);
										end
									else
										return CalcStat("MitMediumPPRat",L,N);
									end
								else
									return CalcStat("MitLightPRatPC",L);
								end
							else
								return CalcStat("MitHeavyPRatPCap",L);
							end
						elseif SN > "TACMITMPRATPC" then
							if SN < "TOMEVITALITYDEC" then
								if SN < "TOMEMAINDEC" then
									if SN < "TACMITT" then
										if SN > "TACMITMPRATPCAP" then
											if SN == "TACMITMPRATPCAPR" then
												return CalcStat("MitMediumPRatPCapR",L);
											else
												return 0;
											end
										elseif SN == "TACMITMPRATPCAP" then
											return CalcStat("MitMediumPRatPCap",L);
										else
											return 0;
										end
									elseif SN > "TACMITT" then
										if SN < "TACRESISTT" then
											if SN == "TACMITTADJ" then
												if Lm <= 121 then
													return 1;
												elseif Lm <= 130 then
													return 0.9;
												elseif Lm <= 131 then
													return 1;
												elseif Lm <= 140 then
													return 80/90;
												elseif Lm <= 141 then
													return 70/90;
												else
													return 60/90;
												end
											else
												return 0;
											end
										elseif SN > "TACRESISTT" then
											if SN == "TOMEMAIN" then
												return CalcStat("TomeMainDec",RomanRankDecode(C));
											else
												return 0;
											end
										else
											return CalcStat("ResistAddT",L,N);
										end
									else
										return StatLinInter("PntMPTacMit","TraitProg","ProgBMitigation","TacMitTAdj",L,N);
									end
								elseif SN > "TOMEMAINDEC" then
									if SN < "TOMETOTALMAINDEC" then
										if SN > "TOMETOTALLEVEL" then
											if SN == "TOMETOTALMAIN" then
												return CalcStat("TomeTotalMainDec",RomanRankDecode(C));
											else
												return 0;
											end
										elseif SN == "TOMETOTALLEVEL" then
											if Lm <= 0 then
												return 0;
											elseif Lm <= 3 then
												return 6*L+1;
											elseif Lm <= 10 then
												return 5*L+5;
											elseif Lm <= 11 then
												return 5*L+10;
											elseif Lm <= 18 then
												return 5*L+15;
											elseif Lm <= 22 then
												return RoundDbl(3.2*L+45.4);
											else
												return 0*L+118;
											end
										else
											return 0;
										end
									elseif SN > "TOMETOTALMAINDEC" then
										if SN < "TOMETOTALVITALITYDEC" then
											if SN == "TOMETOTALVITALITY" then
												return CalcStat("TomeTotalVitalityDec",RomanRankDecode(C));
											else
												return 0;
											end
										elseif SN > "TOMETOTALVITALITYDEC" then
											if SN == "TOMEVITALITY" then
												return CalcStat("TomeVitalityDec",RomanRankDecode(C));
											else
												return 0;
											end
										else
											return CalcStat("VitalityT",CalcStat("TomeTotalLevel",L),2.0);
										end
									else
										return CalcStat("MainT",CalcStat("TomeTotalLevel",L),2.0);
									end
								else
									return CalcStat("TomeTotalMainDec",L)-CalcStat("TomeTotalMainDec",L-1);
								end
							elseif SN > "TOMEVITALITYDEC" then
								if SN < "TRAIT123CHOICE" then
									if SN < "TPENCHOICE" then
										if SN > "TPENARMOUR" then
											if SN == "TPENBPE" then
												return -CalcStat("BPET",L,CalcStat("TpenChoice",N));
											else
												return 0;
											end
										elseif SN == "TPENARMOUR" then
											return -CalcStat("ArmourPenT",L,CalcStat("TpenChoice",N)*2);
										else
											return 0;
										end
									elseif SN > "TPENCHOICE" then
										if SN < "TRAIT12345CHOICE" then
											if SN == "TPENRESIST" then
												return -CalcStat("ResistT",L,CalcStat("TpenChoice",N)*2);
											else
												return 0;
											end
										elseif SN > "TRAIT12345CHOICE" then
											if SN == "TRAIT12347CHOICE" then
												if Lm <= 0 then
													return 0;
												else
													return DataTableValue({1,2,3,4,7},L);
												end
											else
												return 0;
											end
										else
											if Lm <= 0 then
												return 0;
											else
												return DataTableValue({1,2,3,4,5},L);
											end
										end
									else
										return DataTableValue({0,1,2},L);
									end
								elseif SN > "TRAIT123CHOICE" then
									if SN < "TRAIT357912CHOICE" then
										if SN < "TRAIT23456CHOICE" then
											if SN == "TRAIT13510CHOICE" then
												if Lm <= 0 then
													return 0;
												else
													return DataTableValue({1,3,5,10},L);
												end
											else
												return 0;
											end
										elseif SN > "TRAIT23456CHOICE" then
											if SN == "TRAIT234CHOICE" then
												if Lm <= 0 then
													return 0;
												else
													return DataTableValue({2,3,4},L);
												end
											else
												return 0;
											end
										else
											if Lm <= 0 then
												return 0;
											else
												return DataTableValue({2,3,4,5,6},L);
											end
										end
									elseif SN > "TRAIT357912CHOICE" then
										if SN < "TRAIT567810CHOICE" then
											if SN == "TRAIT47101316CHOICE" then
												if Lm <= 0 then
													return 0;
												else
													return DataTableValue({4,7,10,13,16},L);
												end
											else
												return 0;
											end
										elseif SN > "TRAIT567810CHOICE" then
											if SN == "TRAIT56789CHOICE" then
												if Lm <= 0 then
													return 0;
												else
													return DataTableValue({5,6,7,8,9},L);
												end
											else
												return 0;
											end
										else
											if Lm <= 0 then
												return 0;
											else
												return DataTableValue({5,6,7,8,10},L);
											end
										end
									else
										if Lm <= 0 then
											return 0;
										else
											return DataTableValue({3,5,7,9,12},L);
										end
									end
								else
									if Lm <= 0 then
										return 0;
									else
										return DataTableValue({1,2,3},L);
									end
								end
							else
								return CalcStat("TomeTotalVitalityDec",L)-CalcStat("TomeTotalVitalityDec",L-1);
							end
						else
							return CalcStat("MitMediumPRatPC",L);
						end
					else
						return CalcStat("OutDmgPRatPC",L);
					end
				else
					return 1;
				end
			else
				return CalcStat("ResistAddT",L,N);
			end
		elseif SN > "TRAIT58121620CHOICE" then
			if SN < "WARDENCDVITALITYTOMORALE" then
				if SN < "VMASPROGALTLPH" then
					if SN < "VIRTHONOURVPMORALE" then
						if SN < "VIRTDETERMINATIONAGILITY" then
							if SN < "VARMOURADJ" then
								if SN < "TRAITVITALITYPROG" then
									if SN < "TRAITPROGALTLPH" then
										if SN > "TRAITPROG" then
											if SN == "TRAITPROGALT" then
												if Lm <= 75 then
													return CalcStat("StatProgAlt",L,N);
												elseif Lm <= 105 then
													return LinFmod(1,CalcStat("StatProgAlt",75,N),CalcStat("StatProgAlt",105,N),75,105,L);
												else
													return CalcStat("StatProgAlt",L,N);
												end
											else
												return 0;
											end
										elseif SN == "TRAITPROG" then
											if Lm <= 75 then
												return CalcStat("StatProg",L,N);
											elseif Lm <= 105 then
												return LinFmod(1,CalcStat("StatProg",75,N),CalcStat("StatProg",105,N),75,105,L);
											else
												return CalcStat("StatProg",L,N);
											end
										else
											return 0;
										end
									elseif SN > "TRAITPROGALTLPH" then
										if SN < "TRAITPROGLPH" then
											if SN == "TRAITPROGALTLPL" then
												if Lm <= 75 then
													return CalcStat("StatProgAltLPL",L);
												elseif Lm <= 105 then
													return 75;
												else
													return CalcStat("StatProgAltLPL",L);
												end
											else
												return 0;
											end
										elseif SN > "TRAITPROGLPH" then
											if SN == "TRAITPROGLPL" then
												if Lm <= 75 then
													return CalcStat("StatProgLPL",L);
												elseif Lm <= 105 then
													return 75;
												else
													return CalcStat("StatProgLPL",L);
												end
											else
												return 0;
											end
										else
											if Lm <= 75 then
												return CalcStat("StatProgLPH",L);
											elseif Lm <= 105 then
												return 105;
											else
												return CalcStat("StatProgLPH",L);
											end
										end
									else
										if Lm <= 75 then
											return CalcStat("StatProgAltLPH",L);
										elseif Lm <= 105 then
											return 105;
										else
											return CalcStat("StatProgAltLPH",L);
										end
									end
								elseif SN > "TRAITVITALITYPROG" then
									if SN < "TRAITVITALITYPROGALTLPL" then
										if SN > "TRAITVITALITYPROGALT" then
											if SN == "TRAITVITALITYPROGALTLPH" then
												if Lm <= 50 then
													return 50;
												elseif Lm <= 105 then
													return 105;
												else
													return CalcStat("StatProgAltLPH",L);
												end
											else
												return 0;
											end
										elseif SN == "TRAITVITALITYPROGALT" then
											if Lm <= 50 then
												return LinFmod(1,CalcStat("StatProgAlt",1,N),RoundDbl(N)*30,1,50,L);
											elseif Lm <= 105 then
												return LinFmod(1,RoundDbl(N)*30,CalcStat("StatProgAlt",105,N),50,105,L);
											else
												return CalcStat("StatProgAlt",L,N);
											end
										else
											return 0;
										end
									elseif SN > "TRAITVITALITYPROGALTLPL" then
										if SN < "TRAITVITALITYPROGLPL" then
											if SN == "TRAITVITALITYPROGLPH" then
												if Lm <= 50 then
													return 50;
												elseif Lm <= 105 then
													return 105;
												else
													return CalcStat("StatProgLPH",L);
												end
											else
												return 0;
											end
										elseif SN > "TRAITVITALITYPROGLPL" then
											if SN == "VARMOUR" then
												return RoundDbl(StatLinInter("VarmourPntMP","ItemMedProg","ProgBMitLight","VarmourAdj",L,N));
											else
												return 0;
											end
										else
											if Lm <= 50 then
												return 1;
											elseif Lm <= 105 then
												return 50;
											else
												return CalcStat("StatProgLPL",L);
											end
										end
									else
										if Lm <= 50 then
											return 1;
										elseif Lm <= 105 then
											return 50;
										else
											return CalcStat("StatProgAltLPL",L);
										end
									end
								else
									if Lm <= 50 then
										return LinFmod(1,CalcStat("StatProg",1,N),RoundDbl(N)*30,1,50,L);
									elseif Lm <= 105 then
										return LinFmod(1,RoundDbl(N)*30,CalcStat("StatProg",105,N),50,105,L);
									else
										return CalcStat("StatProg",L,N);
									end
								end
							elseif SN > "VARMOURADJ" then
								if SN < "VIRTCOMPASSIONPHYMIT" then
									if SN < "VIRTCHARITYRESIST" then
										if SN > "VARMOURPNTMP" then
											if SN == "VIRTCHARITYPHYMIT" then
												return CalcStat("VSPhyMitM",L);
											else
												return 0;
											end
										elseif SN == "VARMOURPNTMP" then
											return 3/35;
										else
											return 0;
										end
									elseif SN > "VIRTCHARITYRESIST" then
										if SN < "VIRTCHARITYVPMORALE" then
											if SN == "VIRTCHARITYVITALITY" then
												return CalcStat("VSVitalityL",L);
											else
												return 0;
											end
										elseif SN > "VIRTCHARITYVPMORALE" then
											if SN == "VIRTCOMPASSIONARMOUR" then
												return CalcStat("VSArmourL",L);
											else
												return 0;
											end
										else
											return CalcStat("VSVPMorale",L);
										end
									else
										return CalcStat("VSResistH",L);
									end
								elseif SN > "VIRTCOMPASSIONPHYMIT" then
									if SN < "VIRTCONFIDENCEEVADE" then
										if SN < "VIRTCOMPASSIONVPMORALE" then
											if SN == "VIRTCOMPASSIONTACMIT" then
												return CalcStat("VSTacMitM",L);
											else
												return 0;
											end
										elseif SN > "VIRTCOMPASSIONVPMORALE" then
											if SN == "VIRTCONFIDENCECRITHIT" then
												return CalcStat("VSCritHitH",L);
											else
												return 0;
											end
										else
											return CalcStat("VSVPMorale",L);
										end
									elseif SN > "VIRTCONFIDENCEEVADE" then
										if SN < "VIRTCONFIDENCEVPPHYMAS" then
											if SN == "VIRTCONFIDENCEFINESSE" then
												return CalcStat("VSFinesseM",L);
											else
												return 0;
											end
										elseif SN > "VIRTCONFIDENCEVPPHYMAS" then
											if SN == "VIRTCONFIDENCEVPTACMAS" then
												return CalcStat("VSVPTacMas",L);
											else
												return 0;
											end
										else
											return CalcStat("VSVPPhyMas",L);
										end
									else
										return CalcStat("VSEvadeL",L);
									end
								else
									return CalcStat("VSPhyMitH",L);
								end
							else
								return CalcStat("ArmourAdj",L);
							end
						elseif SN > "VIRTDETERMINATIONAGILITY" then
							if SN < "VIRTFIDELITYTACMIT" then
								if SN < "VIRTDISCIPLINERESIST" then
									if SN < "VIRTDETERMINATIONVPPHYMAS" then
										if SN > "VIRTDETERMINATIONCRITHIT" then
											if SN == "VIRTDETERMINATIONPHYMAS" then
												return CalcStat("VSPhyMasM",L);
											else
												return 0;
											end
										elseif SN == "VIRTDETERMINATIONCRITHIT" then
											return CalcStat("VSCritHitL",L);
										else
											return 0;
										end
									elseif SN > "VIRTDETERMINATIONVPPHYMAS" then
										if SN < "VIRTDISCIPLINEINHEAL" then
											if SN == "VIRTDETERMINATIONVPTACMAS" then
												return CalcStat("VSVPTacMas",L);
											else
												return 0;
											end
										elseif SN > "VIRTDISCIPLINEINHEAL" then
											if SN == "VIRTDISCIPLINEPHYMIT" then
												return CalcStat("VSPhyMitL",L);
											else
												return 0;
											end
										else
											return CalcStat("VSInHealM",L);
										end
									else
										return CalcStat("VSVPPhyMas",L);
									end
								elseif SN > "VIRTDISCIPLINERESIST" then
									if SN < "VIRTEMPATHYCRITDEF" then
										if SN > "VIRTDISCIPLINEVPMORALE" then
											if SN == "VIRTEMPATHYARMOUR" then
												return CalcStat("VSArmourH",L);
											else
												return 0;
											end
										elseif SN == "VIRTDISCIPLINEVPMORALE" then
											return CalcStat("VSVPMorale",L);
										else
											return 0;
										end
									elseif SN > "VIRTEMPATHYCRITDEF" then
										if SN < "VIRTEMPATHYVPMORALE" then
											if SN == "VIRTEMPATHYRESIST" then
												return CalcStat("VSResistL",L);
											else
												return 0;
											end
										elseif SN > "VIRTEMPATHYVPMORALE" then
											if SN == "VIRTFIDELITYPHYMIT" then
												return CalcStat("VSPhyMitL",L);
											else
												return 0;
											end
										else
											return CalcStat("VSVPMorale",L);
										end
									else
										return CalcStat("VSCritDefM",L);
									end
								else
									return CalcStat("VSResistH",L);
								end
							elseif SN > "VIRTFIDELITYTACMIT" then
								if SN < "VIRTHONESTYCRITHIT" then
									if SN < "VIRTFORTITUDECRITDEF" then
										if SN > "VIRTFIDELITYVITALITY" then
											if SN == "VIRTFIDELITYVPMORALE" then
												return CalcStat("VSVPMorale",L);
											else
												return 0;
											end
										elseif SN == "VIRTFIDELITYVITALITY" then
											return CalcStat("VSVitalityM",L);
										else
											return 0;
										end
									elseif SN > "VIRTFORTITUDECRITDEF" then
										if SN < "VIRTFORTITUDERESIST" then
											if SN == "VIRTFORTITUDEMORALE" then
												return CalcStat("VSMoraleH",L);
											else
												return 0;
											end
										elseif SN > "VIRTFORTITUDERESIST" then
											if SN == "VIRTFORTITUDEVPMORALE" then
												return CalcStat("VSVPMorale",L);
											else
												return 0;
											end
										else
											return CalcStat("VSResistL",L);
										end
									else
										return CalcStat("VSCritDefM",L);
									end
								elseif SN > "VIRTHONESTYCRITHIT" then
									if SN < "VIRTHONESTYWILL" then
										if SN < "VIRTHONESTYVPPHYMAS" then
											if SN == "VIRTHONESTYTACMAS" then
												return CalcStat("VSTacMasH",L);
											else
												return 0;
											end
										elseif SN > "VIRTHONESTYVPPHYMAS" then
											if SN == "VIRTHONESTYVPTACMAS" then
												return CalcStat("VSVPTacMas",L);
											else
												return 0;
											end
										else
											return CalcStat("VSVPPhyMas",L);
										end
									elseif SN > "VIRTHONESTYWILL" then
										if SN < "VIRTHONOURMORALE" then
											if SN == "VIRTHONOURCRITDEF" then
												return CalcStat("VSCritDefL",L);
											else
												return 0;
											end
										elseif SN > "VIRTHONOURMORALE" then
											if SN == "VIRTHONOURTACMIT" then
												return CalcStat("VSTacMitM",L);
											else
												return 0;
											end
										else
											return CalcStat("VSMoraleH",L);
										end
									else
										return CalcStat("VSWillM",L);
									end
								else
									return CalcStat("VSCritHitL",L);
								end
							else
								return CalcStat("VSTacMitH",L);
							end
						else
							return CalcStat("VSAgilityH",L);
						end
					elseif SN > "VIRTHONOURVPMORALE" then
						if SN < "VIRTTOLERANCETACMIT" then
							if SN < "VIRTLOYALTYINHEAL" then
								if SN < "VIRTINNOCENCETACMIT" then
									if SN < "VIRTIDEALISMMORALE" then
										if SN > "VIRTIDEALISMFATE" then
											if SN == "VIRTIDEALISMINHEAL" then
												return CalcStat("VSInHealM",L);
											else
												return 0;
											end
										elseif SN == "VIRTIDEALISMFATE" then
											return CalcStat("VSFateH",L);
										else
											return 0;
										end
									elseif SN > "VIRTIDEALISMMORALE" then
										if SN < "VIRTINNOCENCEPHYMIT" then
											if SN == "VIRTIDEALISMVPMORALE" then
												return CalcStat("VSVPMorale",L);
											else
												return 0;
											end
										elseif SN > "VIRTINNOCENCEPHYMIT" then
											if SN == "VIRTINNOCENCERESIST" then
												return CalcStat("VSResistM",L);
											else
												return 0;
											end
										else
											return CalcStat("VSPhyMitH",L);
										end
									else
										return CalcStat("VSMoraleL",L);
									end
								elseif SN > "VIRTINNOCENCETACMIT" then
									if SN < "VIRTJUSTICEMORALE" then
										if SN > "VIRTINNOCENCEVPMORALE" then
											if SN == "VIRTJUSTICEICMR" then
												return CalcStat("VSICMRH",L);
											else
												return 0;
											end
										elseif SN == "VIRTINNOCENCEVPMORALE" then
											return CalcStat("VSVPMorale",L);
										else
											return 0;
										end
									elseif SN > "VIRTJUSTICEMORALE" then
										if SN < "VIRTJUSTICEVPMORALE" then
											if SN == "VIRTJUSTICETACMIT" then
												return CalcStat("VSTacMitL",L);
											else
												return 0;
											end
										elseif SN > "VIRTJUSTICEVPMORALE" then
											if SN == "VIRTLOYALTYARMOUR" then
												return CalcStat("VSArmourM",L);
											else
												return 0;
											end
										else
											return CalcStat("VSVPMorale",L);
										end
									else
										return CalcStat("VSMoraleM",L);
									end
								else
									return CalcStat("VSTacMitL",L);
								end
							elseif SN > "VIRTLOYALTYINHEAL" then
								if SN < "VIRTPATIENCECRITHIT" then
									if SN < "VIRTMERCYEVADE" then
										if SN > "VIRTLOYALTYVITALITY" then
											if SN == "VIRTLOYALTYVPMORALE" then
												return CalcStat("VSVPMorale",L);
											else
												return 0;
											end
										elseif SN == "VIRTLOYALTYVITALITY" then
											return CalcStat("VSVitalityH",L);
										else
											return 0;
										end
									elseif SN > "VIRTMERCYEVADE" then
										if SN < "VIRTMERCYVITALITY" then
											if SN == "VIRTMERCYFATE" then
												return CalcStat("VSFateM",L);
											else
												return 0;
											end
										elseif SN > "VIRTMERCYVITALITY" then
											if SN == "VIRTMERCYVPMORALE" then
												return CalcStat("VSVPMorale",L);
											else
												return 0;
											end
										else
											return CalcStat("VSVitalityL",L);
										end
									else
										return CalcStat("VSEvadeH",L);
									end
								elseif SN > "VIRTPATIENCECRITHIT" then
									if SN < "VIRTRNKCOST" then
										if SN < "VIRTPATIENCEPOWER" then
											if SN == "VIRTPATIENCEEVADE" then
												return CalcStat("VSEvadeM",L);
											else
												return 0;
											end
										elseif SN > "VIRTPATIENCEPOWER" then
											if SN == "VIRTPATIENCEVPMORALE" then
												return CalcStat("VSVPMorale",L);
											else
												return 0;
											end
										else
											return CalcStat("VSPowerH",L);
										end
									elseif SN > "VIRTRNKCOST" then
										if SN < "VIRTTOLERANCEPHYMIT" then
											if SN == "VIRTRNKCOSTTOT" then
												if Lm <= 0 then
													return 0;
												else
													return CalcStat("VirtRnkCostTot",L-1)+CalcStat("VirtRnkCost",L);
												end
											else
												return 0;
											end
										elseif SN > "VIRTTOLERANCEPHYMIT" then
											if SN == "VIRTTOLERANCERESIST" then
												return CalcStat("VSResistM",L);
											else
												return 0;
											end
										else
											return CalcStat("VSPhyMitL",L);
										end
									else
										if Lm <= 0 then
											return 0;
										elseif Lm <= 10 then
											return 1000;
										elseif Lm <= 60 then
											return RoundDbl(18*L+878,-2);
										elseif Lm <= 73 then
											return RoundDbl(18.75*L+878,-2);
										else
											return RoundDbl(17.45*L+878,-2);
										end
									end
								else
									return CalcStat("VSCritHitL",L);
								end
							else
								return CalcStat("VSInHealL",L);
							end
						elseif SN > "VIRTTOLERANCETACMIT" then
							if SN < "VIRTWITPHYMAS" then
								if SN < "VIRTWISDOMFINESSE" then
									if SN < "VIRTVALOURFINESSE" then
										if SN > "VIRTTOLERANCEVPMORALE" then
											if SN == "VIRTVALOURCRITHIT" then
												return CalcStat("VSCritHitL",L);
											else
												return 0;
											end
										elseif SN == "VIRTTOLERANCEVPMORALE" then
											return CalcStat("VSVPMorale",L);
										else
											return 0;
										end
									elseif SN > "VIRTVALOURFINESSE" then
										if SN < "VIRTVALOURVPPHYMAS" then
											if SN == "VIRTVALOURPHYMAS" then
												return CalcStat("VSPhyMasH",L);
											else
												return 0;
											end
										elseif SN > "VIRTVALOURVPPHYMAS" then
											if SN == "VIRTVALOURVPTACMAS" then
												return CalcStat("VSVPTacMas",L);
											else
												return 0;
											end
										else
											return CalcStat("VSVPPhyMas",L);
										end
									else
										return CalcStat("VSFinesseM",L);
									end
								elseif SN > "VIRTWISDOMFINESSE" then
									if SN < "VIRTWISDOMVPTACMAS" then
										if SN > "VIRTWISDOMTACMAS" then
											if SN == "VIRTWISDOMVPPHYMAS" then
												return CalcStat("VSVPPhyMas",L);
											else
												return 0;
											end
										elseif SN == "VIRTWISDOMTACMAS" then
											return CalcStat("VSTacMasM",L);
										else
											return 0;
										end
									elseif SN > "VIRTWISDOMVPTACMAS" then
										if SN < "VIRTWITCRITHIT" then
											if SN == "VIRTWISDOMWILL" then
												return CalcStat("VSWillH",L);
											else
												return 0;
											end
										elseif SN > "VIRTWITCRITHIT" then
											if SN == "VIRTWITFINESSE" then
												return CalcStat("VSFinesseH",L);
											else
												return 0;
											end
										else
											return CalcStat("VSCritHitM",L);
										end
									else
										return CalcStat("VSVPTacMas",L);
									end
								else
									return CalcStat("VSFinesseL",L);
								end
							elseif SN > "VIRTWITPHYMAS" then
								if SN < "VIRTZEALVPPHYMAS" then
									if SN < "VIRTWITVPTACMAS" then
										if SN > "VIRTWITTACMAS" then
											if SN == "VIRTWITVPPHYMAS" then
												return CalcStat("VSVPPhyMas",L);
											else
												return 0;
											end
										elseif SN == "VIRTWITTACMAS" then
											return CalcStat("VSTacMasL",L);
										else
											return 0;
										end
									elseif SN > "VIRTWITVPTACMAS" then
										if SN < "VIRTZEALMIGHT" then
											if SN == "VIRTZEALCRITHIT" then
												return CalcStat("VSCritHitL",L);
											else
												return 0;
											end
										elseif SN > "VIRTZEALMIGHT" then
											if SN == "VIRTZEALPHYMAS" then
												return CalcStat("VSPhyMasM",L);
											else
												return 0;
											end
										else
											return CalcStat("VSMightH",L);
										end
									else
										return CalcStat("VSVPTacMas",L);
									end
								elseif SN > "VIRTZEALVPPHYMAS" then
									if SN < "VITALITYT" then
										if SN < "VITALITY" then
											if SN == "VIRTZEALVPTACMAS" then
												return CalcStat("VSVPTacMas",L);
											else
												return 0;
											end
										elseif SN > "VITALITY" then
											if SN == "VITALITYADJ" then
												if Lm <= 25 then
													return 0.5;
												elseif Lm <= 349 then
													return 1;
												elseif Lm <= 350 then
													return 95/99;
												elseif Lm <= 399 then
													return 38/45;
												elseif Lm <= 400 then
													return 76/105;
												elseif Lm <= 449 then
													return 38/63;
												elseif Lm <= 499 then
													return 1.0055;
												elseif Lm <= 500 then
													return 0.8715;
												else
													return 0.8045;
												end
											else
												return 0;
											end
										else
											return FloorDbl(StatLinInter("PntMPVitality","ItemLowProgAlt","ProgBVitality","VitalityAdj",L,N));
										end
									elseif SN > "VITALITYT" then
										if SN < "VMASPROG" then
											if SN == "VITALITYTADJ" then
												if Lm <= 115 then
													return 1;
												elseif Lm <= 116 then
													return 95/99;
												elseif Lm <= 120 then
													return 0.8;
												elseif Lm <= 121 then
													return 0.6878;
												elseif Lm <= 130 then
													return 0.573;
												else
													return 0.6368;
												end
											else
												return 0;
											end
										elseif SN > "VMASPROG" then
											if SN == "VMASPROGALT" then
												if Lm <= 1 then
													return LinFmod(1,0,CalcStat("ItemProgAlt",1,N),0,1,L);
												elseif Lm <= 25 then
													return LinFmod(1,CalcStat("ItemProgAlt",1,N),RoundDbl(N)*25,1,25,L);
												elseif Lm <= 79 then
													return LinFmod(1,RoundDbl(N)*25,CalcStat("ItemProgAlt",79,N),25,79,L);
												elseif Lm <= 350 then
													return CalcStat("ItemProgAlt",L,N);
												elseif Lm <= 400 then
													return LinFmod(1,CalcStat("ItemProgAlt",350,N),CalcStat("ItemProgAlt",400,N),350,400,L);
												else
													return CalcStat("ItemProgAlt",L,N);
												end
											else
												return 0;
											end
										else
											if Lm <= 1 then
												return LinFmod(1,0,CalcStat("ItemProg",1,N),0,1,L);
											elseif Lm <= 25 then
												return LinFmod(1,CalcStat("ItemProg",1,N),RoundDbl(N)*25,1,25,L);
											elseif Lm <= 79 then
												return LinFmod(1,RoundDbl(N)*25,CalcStat("ItemProg",79,N),25,79,L);
											elseif Lm <= 350 then
												return CalcStat("ItemProg",L,N);
											elseif Lm <= 400 then
												return LinFmod(1,CalcStat("ItemProg",350,N),CalcStat("ItemProg",400,N),350,400,L);
											else
												return CalcStat("ItemProg",L,N);
											end
										end
									else
										return FloorDbl(StatLinInter("PntMPVitality","TraitVitalityProgAlt","ProgBVitality","VitalityTAdj",L,N));
									end
								else
									return CalcStat("VSVPPhyMas",L);
								end
							else
								return CalcStat("VSPhyMasL",L);
							end
						else
							return CalcStat("VSTacMitH",L);
						end
					else
						return CalcStat("VSVPMorale",L);
					end
				elseif SN > "VMASPROGALTLPH" then
					if SN < "VSPHYMASM" then
						if SN < "VSCRITDEFH" then
							if SN < "VMORPROG" then
								if SN < "VMHIGH" then
									if SN < "VMASPROGLPL" then
										if SN > "VMASPROGALTLPL" then
											if SN == "VMASPROGLPH" then
												if Lm <= 1 then
													return 1;
												elseif Lm <= 25 then
													return 25;
												elseif Lm <= 79 then
													return 79;
												elseif Lm <= 350 then
													return CalcStat("ItemProgLPH",L);
												elseif Lm <= 400 then
													return 400;
												else
													return CalcStat("ItemProgLPH",L);
												end
											else
												return 0;
											end
										elseif SN == "VMASPROGALTLPL" then
											if Lm <= 1 then
												return 0;
											elseif Lm <= 25 then
												return 1;
											elseif Lm <= 79 then
												return 25;
											elseif Lm <= 350 then
												return CalcStat("ItemProgAltLPL",L);
											elseif Lm <= 400 then
												return 350;
											else
												return CalcStat("ItemProgAltLPL",L);
											end
										else
											return 0;
										end
									elseif SN > "VMASPROGLPL" then
										if SN < "VMASTERYADJ" then
											if SN == "VMASTERY" then
												return StatLinInter("PntMPMastery","VmasProg","ProgBMastery","VmasteryAdj",L,N);
											else
												return 0;
											end
										elseif SN > "VMASTERYADJ" then
											if SN == "VMASTERYOLD" then
												return CalcStat("VMastery",L,N);
											else
												return 0;
											end
										else
											if Lm <= 0 then
												return 0;
											elseif Lm <= 1 then
												return 0.5;
											elseif Lm <= 80 then
												return 0.8;
											elseif Lm <= 400 then
												return 1;
											elseif Lm <= 449 then
												return 0.9;
											elseif Lm <= 450 then
												return 83/90;
											else
												return 70/90;
											end
										end
									else
										if Lm <= 1 then
											return 0;
										elseif Lm <= 25 then
											return 1;
										elseif Lm <= 79 then
											return 25;
										elseif Lm <= 350 then
											return CalcStat("ItemProgLPL",L);
										elseif Lm <= 400 then
											return 350;
										else
											return CalcStat("ItemProgLPL",L);
										end
									end
								elseif SN > "VMHIGH" then
									if SN < "VMMEDIUM" then
										if SN > "VMLOW" then
											if SN == "VMMASTERYPSV" then
												return 0.2;
											else
												return 0;
											end
										elseif SN == "VMLOW" then
											return 0.6;
										else
											return 0;
										end
									elseif SN > "VMMEDIUM" then
										if SN < "VMORALE" then
											if SN == "VMMORALEPSV" then
												return 0.3;
											else
												return 0;
											end
										elseif SN > "VMORALE" then
											if SN == "VMORALEADJ" then
												if Lm <= 0 then
													return 0;
												elseif Lm <= 350 then
													return 1;
												elseif Lm <= 399 then
													return 0.8;
												elseif Lm <= 400 then
													return 22/35;
												elseif Lm <= 449 then
													return 40/70;
												elseif Lm <= 450 then
													return 0.582;
												elseif Lm <= 499 then
													return 0.635;
												elseif Lm <= 500 then
													return 0.582;
												else
													return 0.635;
												end
											else
												return 0;
											end
										else
											return StatLinInter("PntMPMorale","VmorProg","ProgBMorale","VmoraleAdj",L,N);
										end
									else
										return 1;
									end
								else
									return 2;
								end
							elseif SN > "VMORPROG" then
								if SN < "VRNKLVLCAP" then
									if SN < "VMORPROGALTLPL" then
										if SN > "VMORPROGALT" then
											if SN == "VMORPROGALTLPH" then
												if Lm <= 1 then
													return 1;
												elseif Lm <= 2 then
													return 2;
												elseif Lm <= 50 then
													return 50;
												elseif Lm <= 80 then
													return 80;
												else
													return CalcStat("ItemProgAltLPH",L);
												end
											else
												return 0;
											end
										elseif SN == "VMORPROGALT" then
											if Lm <= 1 then
												return LinFmod(1,0,CalcStat("ItemProgAlt",1,N),0,1,L);
											elseif Lm <= 2 then
												return LinFmod(1,CalcStat("ItemProgAlt",1,N),RoundDbl(N)*1.6,1,2,L);
											elseif Lm <= 50 then
												return LinFmod(1,RoundDbl(N)*1.6,RoundDbl(N)*45,2,50,L);
											elseif Lm <= 80 then
												return LinFmod(1,RoundDbl(N)*45,CalcStat("ItemProgAlt",80,N),50,80,L);
											else
												return CalcStat("ItemProgAlt",L,N);
											end
										else
											return 0;
										end
									elseif SN > "VMORPROGALTLPL" then
										if SN < "VMORPROGLPL" then
											if SN == "VMORPROGLPH" then
												if Lm <= 1 then
													return 1;
												elseif Lm <= 2 then
													return 2;
												elseif Lm <= 50 then
													return 50;
												elseif Lm <= 80 then
													return 80;
												else
													return CalcStat("ItemProgLPH",L);
												end
											else
												return 0;
											end
										elseif SN > "VMORPROGLPL" then
											if SN == "VRNKCAP" then
												return 85;
											else
												return 0;
											end
										else
											if Lm <= 1 then
												return 0;
											elseif Lm <= 2 then
												return 1;
											elseif Lm <= 50 then
												return 2;
											elseif Lm <= 80 then
												return 50;
											else
												return CalcStat("ItemProgLPL",L);
											end
										end
									else
										if Lm <= 1 then
											return 0;
										elseif Lm <= 2 then
											return 1;
										elseif Lm <= 50 then
											return 2;
										elseif Lm <= 80 then
											return 50;
										else
											return CalcStat("ItemProgAltLPL",L);
										end
									end
								elseif SN > "VRNKLVLCAP" then
									if SN < "VSAGILITYM" then
										if SN < "VSAGILITYH" then
											if SN == "VRNKTOILVL" then
												if Lm <= 0 then
													return 0;
												elseif Lm <= 38 then
													return LinFmod(1,4,78,1,38,L)*N;
												elseif Lm <= 48 then
													return LinFmod(1,78,178,38,48,L)*N;
												elseif Lm <= 49 then
													return LinFmod(1,178,190,48,49,L)*N;
												elseif Lm <= 50 then
													return LinFmod(1,190,210,49,50,L)*N;
												elseif Lm <= 51 then
													return LinFmod(1,210,222,50,51,L)*N;
												elseif Lm <= 52 then
													return LinFmod(1,222,236,51,52,L)*N;
												elseif Lm <= 53 then
													return LinFmod(1,236,260,52,53,L)*N;
												elseif Lm <= 55 then
													return LinFmod(1,260,292,53,55,L)*N;
												elseif Lm <= 68 then
													return LinFmod(1,292,396,55,68,L)*N;
												else
													return LinFmod(1,396,706,68,130,L)*N;
												end
											else
												return 0;
											end
										elseif SN > "VSAGILITYH" then
											if SN == "VSAGILITYL" then
												if Lm <= 0 then
													return 0;
												else
													return CalcStat("Agility",CalcStat("VRnkToILvl",L),CalcStat("VMLow",L));
												end
											else
												return 0;
											end
										else
											if Lm <= 0 then
												return 0;
											else
												return CalcStat("Agility",CalcStat("VRnkToILvl",L),CalcStat("VMHigh",L));
											end
										end
									elseif SN > "VSAGILITYM" then
										if SN < "VSARMOURL" then
											if SN == "VSARMOURH" then
												if Lm <= 0 then
													return 0;
												else
													return CalcStat("Varmour",CalcStat("VRnkToILvl",L),CalcStat("VMHigh",L));
												end
											else
												return 0;
											end
										elseif SN > "VSARMOURL" then
											if SN == "VSARMOURM" then
												if Lm <= 0 then
													return 0;
												else
													return CalcStat("Varmour",CalcStat("VRnkToILvl",L),CalcStat("VMMedium",L));
												end
											else
												return 0;
											end
										else
											if Lm <= 0 then
												return 0;
											else
												return CalcStat("Varmour",CalcStat("VRnkToILvl",L),CalcStat("VMLow",L));
											end
										end
									else
										if Lm <= 0 then
											return 0;
										else
											return CalcStat("Agility",CalcStat("VRnkToILvl",L),CalcStat("VMMedium",L));
										end
									end
								else
									if Lm <= 4 then
										return 2;
									elseif Lm <= 110 then
										return FloorDbl(L/2);
									elseif Lm <= 139 then
										return L-55;
									else
										return 88;
									end
								end
							else
								if Lm <= 1 then
									return LinFmod(1,0,CalcStat("ItemProg",1,N),0,1,L);
								elseif Lm <= 2 then
									return LinFmod(1,CalcStat("ItemProg",1,N),RoundDbl(N)*1.6,1,2,L);
								elseif Lm <= 50 then
									return LinFmod(1,RoundDbl(N)*1.6,RoundDbl(N)*45,2,50,L);
								elseif Lm <= 80 then
									return LinFmod(1,RoundDbl(N)*45,CalcStat("ItemProg",80,N),50,80,L);
								else
									return CalcStat("ItemProg",L,N);
								end
							end
						elseif SN > "VSCRITDEFH" then
							if SN < "VSFINESSEM" then
								if SN < "VSEVADEL" then
									if SN < "VSCRITHITH" then
										if SN > "VSCRITDEFL" then
											if SN == "VSCRITDEFM" then
												if Lm <= 0 then
													return 0;
												else
													return CalcStat("CritDef",CalcStat("VRnkToILvl",L),CalcStat("VMMedium",L));
												end
											else
												return 0;
											end
										elseif SN == "VSCRITDEFL" then
											if Lm <= 0 then
												return 0;
											else
												return CalcStat("CritDef",CalcStat("VRnkToILvl",L),CalcStat("VMLow",L));
											end
										else
											return 0;
										end
									elseif SN > "VSCRITHITH" then
										if SN < "VSCRITHITM" then
											if SN == "VSCRITHITL" then
												if Lm <= 0 then
													return 0;
												else
													return CalcStat("CritHit",CalcStat("VRnkToILvl",L),CalcStat("VMLow",L));
												end
											else
												return 0;
											end
										elseif SN > "VSCRITHITM" then
											if SN == "VSEVADEH" then
												if Lm <= 0 then
													return 0;
												else
													return CalcStat("Evade",CalcStat("VRnkToILvl",L),CalcStat("VMHigh",L));
												end
											else
												return 0;
											end
										else
											if Lm <= 0 then
												return 0;
											else
												return CalcStat("CritHit",CalcStat("VRnkToILvl",L),CalcStat("VMMedium",L));
											end
										end
									else
										if Lm <= 0 then
											return 0;
										else
											return CalcStat("CritHit",CalcStat("VRnkToILvl",L),CalcStat("VMHigh",L));
										end
									end
								elseif SN > "VSEVADEL" then
									if SN < "VSFATEL" then
										if SN > "VSEVADEM" then
											if SN == "VSFATEH" then
												if Lm <= 0 then
													return 0;
												else
													return CalcStat("Fate",CalcStat("VRnkToILvl",L),CalcStat("VMHigh",L));
												end
											else
												return 0;
											end
										elseif SN == "VSEVADEM" then
											if Lm <= 0 then
												return 0;
											else
												return CalcStat("Evade",CalcStat("VRnkToILvl",L),CalcStat("VMMedium",L));
											end
										else
											return 0;
										end
									elseif SN > "VSFATEL" then
										if SN < "VSFINESSEH" then
											if SN == "VSFATEM" then
												if Lm <= 0 then
													return 0;
												else
													return CalcStat("Fate",CalcStat("VRnkToILvl",L),CalcStat("VMMedium",L));
												end
											else
												return 0;
											end
										elseif SN > "VSFINESSEH" then
											if SN == "VSFINESSEL" then
												if Lm <= 0 then
													return 0;
												else
													return CalcStat("Finesse",CalcStat("VRnkToILvl",L),CalcStat("VMLow",L));
												end
											else
												return 0;
											end
										else
											if Lm <= 0 then
												return 0;
											else
												return CalcStat("Finesse",CalcStat("VRnkToILvl",L),CalcStat("VMHigh",L));
											end
										end
									else
										if Lm <= 0 then
											return 0;
										else
											return CalcStat("Fate",CalcStat("VRnkToILvl",L),CalcStat("VMLow",L));
										end
									end
								else
									if Lm <= 0 then
										return 0;
									else
										return CalcStat("Evade",CalcStat("VRnkToILvl",L),CalcStat("VMLow",L));
									end
								end
							elseif SN > "VSFINESSEM" then
								if SN < "VSMIGHTH" then
									if SN < "VSICMRM" then
										if SN > "VSICMRH" then
											if SN == "VSICMRL" then
												if Lm <= 0 then
													return 0;
												else
													return CalcStat("ICMR",CalcStat("VRnkToILvl",L),CalcStat("VMLow",L));
												end
											else
												return 0;
											end
										elseif SN == "VSICMRH" then
											if Lm <= 0 then
												return 0;
											else
												return CalcStat("ICMR",CalcStat("VRnkToILvl",L),CalcStat("VMHigh",L));
											end
										else
											return 0;
										end
									elseif SN > "VSICMRM" then
										if SN < "VSINHEALL" then
											if SN == "VSINHEALH" then
												if Lm <= 0 then
													return 0;
												else
													return CalcStat("InHeal",CalcStat("VRnkToILvl",L),CalcStat("VMHigh",L));
												end
											else
												return 0;
											end
										elseif SN > "VSINHEALL" then
											if SN == "VSINHEALM" then
												if Lm <= 0 then
													return 0;
												else
													return CalcStat("InHeal",CalcStat("VRnkToILvl",L),CalcStat("VMMedium",L));
												end
											else
												return 0;
											end
										else
											if Lm <= 0 then
												return 0;
											else
												return CalcStat("InHeal",CalcStat("VRnkToILvl",L),CalcStat("VMLow",L));
											end
										end
									else
										if Lm <= 0 then
											return 0;
										else
											return CalcStat("ICMR",CalcStat("VRnkToILvl",L),CalcStat("VMMedium",L));
										end
									end
								elseif SN > "VSMIGHTH" then
									if SN < "VSMORALEL" then
										if SN < "VSMIGHTM" then
											if SN == "VSMIGHTL" then
												if Lm <= 0 then
													return 0;
												else
													return CalcStat("Might",CalcStat("VRnkToILvl",L),CalcStat("VMLow",L));
												end
											else
												return 0;
											end
										elseif SN > "VSMIGHTM" then
											if SN == "VSMORALEH" then
												if Lm <= 0 then
													return 0;
												else
													return CalcStat("Vmorale",CalcStat("VRnkToILvl",L),CalcStat("VMHigh",L));
												end
											else
												return 0;
											end
										else
											if Lm <= 0 then
												return 0;
											else
												return CalcStat("Might",CalcStat("VRnkToILvl",L),CalcStat("VMMedium",L));
											end
										end
									elseif SN > "VSMORALEL" then
										if SN < "VSPHYMASH" then
											if SN == "VSMORALEM" then
												if Lm <= 0 then
													return 0;
												else
													return CalcStat("Vmorale",CalcStat("VRnkToILvl",L),CalcStat("VMMedium",L));
												end
											else
												return 0;
											end
										elseif SN > "VSPHYMASH" then
											if SN == "VSPHYMASL" then
												if Lm <= 0 then
													return 0;
												else
													return CalcStat("PhyMas",CalcStat("VRnkToILvl",L),CalcStat("VMLow",L));
												end
											else
												return 0;
											end
										else
											if Lm <= 0 then
												return 0;
											else
												return CalcStat("PhyMas",CalcStat("VRnkToILvl",L),CalcStat("VMHigh",L));
											end
										end
									else
										if Lm <= 0 then
											return 0;
										else
											return CalcStat("Vmorale",CalcStat("VRnkToILvl",L),CalcStat("VMLow",L));
										end
									end
								else
									if Lm <= 0 then
										return 0;
									else
										return CalcStat("Might",CalcStat("VRnkToILvl",L),CalcStat("VMHigh",L));
									end
								end
							else
								if Lm <= 0 then
									return 0;
								else
									return CalcStat("Finesse",CalcStat("VRnkToILvl",L),CalcStat("VMMedium",L));
								end
							end
						else
							if Lm <= 0 then
								return 0;
							else
								return CalcStat("CritDef",CalcStat("VRnkToILvl",L),CalcStat("VMHigh",L));
							end
						end
					elseif SN > "VSPHYMASM" then
						if SN < "WARDENCDARMOURTOOFMIT" then
							if SN < "VSTACMITL" then
								if SN < "VSRESISTH" then
									if SN < "VSPHYMITM" then
										if SN > "VSPHYMITH" then
											if SN == "VSPHYMITL" then
												if Lm <= 0 then
													return 0;
												else
													return CalcStat("PhyMit",CalcStat("VRnkToILvl",L),CalcStat("VMLow",L));
												end
											else
												return 0;
											end
										elseif SN == "VSPHYMITH" then
											if Lm <= 0 then
												return 0;
											else
												return CalcStat("PhyMit",CalcStat("VRnkToILvl",L),CalcStat("VMHigh",L));
											end
										else
											return 0;
										end
									elseif SN > "VSPHYMITM" then
										if SN < "VSPOWERL" then
											if SN == "VSPOWERH" then
												if Lm <= 0 then
													return 0;
												else
													return CalcStat("Power",CalcStat("VRnkToILvl",L),CalcStat("VMHigh",L));
												end
											else
												return 0;
											end
										elseif SN > "VSPOWERL" then
											if SN == "VSPOWERM" then
												if Lm <= 0 then
													return 0;
												else
													return CalcStat("Power",CalcStat("VRnkToILvl",L),CalcStat("VMMedium",L));
												end
											else
												return 0;
											end
										else
											if Lm <= 0 then
												return 0;
											else
												return CalcStat("Power",CalcStat("VRnkToILvl",L),CalcStat("VMLow",L));
											end
										end
									else
										if Lm <= 0 then
											return 0;
										else
											return CalcStat("PhyMit",CalcStat("VRnkToILvl",L),CalcStat("VMMedium",L));
										end
									end
								elseif SN > "VSRESISTH" then
									if SN < "VSTACMASH" then
										if SN > "VSRESISTL" then
											if SN == "VSRESISTM" then
												if Lm <= 0 then
													return 0;
												else
													return CalcStat("Resist",CalcStat("VRnkToILvl",L),CalcStat("VMMedium",L));
												end
											else
												return 0;
											end
										elseif SN == "VSRESISTL" then
											if Lm <= 0 then
												return 0;
											else
												return CalcStat("Resist",CalcStat("VRnkToILvl",L),CalcStat("VMLow",L));
											end
										else
											return 0;
										end
									elseif SN > "VSTACMASH" then
										if SN < "VSTACMASM" then
											if SN == "VSTACMASL" then
												if Lm <= 0 then
													return 0;
												else
													return CalcStat("TacMas",CalcStat("VRnkToILvl",L),CalcStat("VMLow",L));
												end
											else
												return 0;
											end
										elseif SN > "VSTACMASM" then
											if SN == "VSTACMITH" then
												if Lm <= 0 then
													return 0;
												else
													return CalcStat("TacMit",CalcStat("VRnkToILvl",L),CalcStat("VMHigh",L));
												end
											else
												return 0;
											end
										else
											if Lm <= 0 then
												return 0;
											else
												return CalcStat("TacMas",CalcStat("VRnkToILvl",L),CalcStat("VMMedium",L));
											end
										end
									else
										if Lm <= 0 then
											return 0;
										else
											return CalcStat("TacMas",CalcStat("VRnkToILvl",L),CalcStat("VMHigh",L));
										end
									end
								else
									if Lm <= 0 then
										return 0;
									else
										return CalcStat("Resist",CalcStat("VRnkToILvl",L),CalcStat("VMHigh",L));
									end
								end
							elseif SN > "VSTACMITL" then
								if SN < "VSVPTACMAS" then
									if SN < "VSVITALITYL" then
										if SN > "VSTACMITM" then
											if SN == "VSVITALITYH" then
												if Lm <= 0 then
													return 0;
												else
													return CalcStat("Vitality",CalcStat("VRnkToILvl",L),CalcStat("VMHigh",L));
												end
											else
												return 0;
											end
										elseif SN == "VSTACMITM" then
											if Lm <= 0 then
												return 0;
											else
												return CalcStat("TacMit",CalcStat("VRnkToILvl",L),CalcStat("VMMedium",L));
											end
										else
											return 0;
										end
									elseif SN > "VSVITALITYL" then
										if SN < "VSVPMORALE" then
											if SN == "VSVITALITYM" then
												if Lm <= 0 then
													return 0;
												else
													return CalcStat("Vitality",CalcStat("VRnkToILvl",L),CalcStat("VMMedium",L));
												end
											else
												return 0;
											end
										elseif SN > "VSVPMORALE" then
											if SN == "VSVPPHYMAS" then
												if Lm <= 0 then
													return 0;
												else
													return CalcStat("Vmastery",CalcStat("VRnkToILvl",L),CalcStat("VMMasteryPsv",L));
												end
											else
												return 0;
											end
										else
											if Lm <= 0 then
												return 0;
											else
												return CalcStat("Vmorale",CalcStat("VRnkToILvl",L),CalcStat("VMMoralePsv",L));
											end
										end
									else
										if Lm <= 0 then
											return 0;
										else
											return CalcStat("Vitality",CalcStat("VRnkToILvl",L),CalcStat("VMLow",L));
										end
									end
								elseif SN > "VSVPTACMAS" then
									if SN < "WARDENCDAGILITYTOCRITHIT" then
										if SN < "VSWILLL" then
											if SN == "VSWILLH" then
												if Lm <= 0 then
													return 0;
												else
													return CalcStat("Will",CalcStat("VRnkToILvl",L),CalcStat("VMHigh",L));
												end
											else
												return 0;
											end
										elseif SN > "VSWILLL" then
											if SN == "VSWILLM" then
												if Lm <= 0 then
													return 0;
												else
													return CalcStat("Will",CalcStat("VRnkToILvl",L),CalcStat("VMMedium",L));
												end
											else
												return 0;
											end
										else
											if Lm <= 0 then
												return 0;
											else
												return CalcStat("Will",CalcStat("VRnkToILvl",L),CalcStat("VMLow",L));
											end
										end
									elseif SN > "WARDENCDAGILITYTOCRITHIT" then
										if SN < "WARDENCDAGILITYTOPARRY" then
											if SN == "WARDENCDAGILITYTOEVADE" then
												return 3;
											else
												return 0;
											end
										elseif SN > "WARDENCDAGILITYTOPARRY" then
											if SN == "WARDENCDAGILITYTOPHYMAS" then
												return 3;
											else
												return 0;
											end
										else
											return 2;
										end
									else
										return 1;
									end
								else
									if Lm <= 0 then
										return 0;
									else
										return CalcStat("Vmastery",CalcStat("VRnkToILvl",L),CalcStat("VMMasteryPsv",L));
									end
								end
							else
								if Lm <= 0 then
									return 0;
								else
									return CalcStat("TacMit",CalcStat("VRnkToILvl",L),CalcStat("VMLow",L));
								end
							end
						elseif SN > "WARDENCDARMOURTOOFMIT" then
							if SN < "WARDENCDBASEWILL" then
								if SN < "WARDENCDBASEICPR" then
									if SN < "WARDENCDARMOURTYPE" then
										if SN > "WARDENCDARMOURTOPHYMIT" then
											if SN == "WARDENCDARMOURTOTACMIT" then
												return 0.2;
											else
												return 0;
											end
										elseif SN == "WARDENCDARMOURTOPHYMIT" then
											return 1;
										else
											return 0;
										end
									elseif SN > "WARDENCDARMOURTYPE" then
										if SN < "WARDENCDBASEFATE" then
											if SN == "WARDENCDBASEAGILITY" then
												return CalcStat("ClassBaseMainJ",L);
											else
												return 0;
											end
										elseif SN > "WARDENCDBASEFATE" then
											if SN == "WARDENCDBASEICMR" then
												return CalcStat("ClassBaseICMRH",L);
											else
												return 0;
											end
										else
											return CalcStat("ClassBaseMainF",L);
										end
									else
										return 2;
									end
								elseif SN > "WARDENCDBASEICPR" then
									if SN < "WARDENCDBASENCMR" then
										if SN > "WARDENCDBASEMIGHT" then
											if SN == "WARDENCDBASEMORALE" then
												if Lm <= 120 then
													return CalcStat("ClassBaseMoraleHb",L);
												else
													return CalcStat("ClassBaseMoraleHb",120);
												end
											else
												return 0;
											end
										elseif SN == "WARDENCDBASEMIGHT" then
											return CalcStat("ClassBaseMainH",L);
										else
											return 0;
										end
									elseif SN > "WARDENCDBASENCMR" then
										if SN < "WARDENCDBASEPOWER" then
											if SN == "WARDENCDBASENCPR" then
												return CalcStat("ClassBaseNCPR",L);
											else
												return 0;
											end
										elseif SN > "WARDENCDBASEPOWER" then
											if SN == "WARDENCDBASEVITALITY" then
												return CalcStat("ClassBaseMainC",L);
											else
												return 0;
											end
										else
											return CalcStat("ClassBasePowerL",L);
										end
									else
										return CalcStat("ClassBaseNCMRH",L);
									end
								else
									return CalcStat("ClassBaseICPR",L);
								end
							elseif SN > "WARDENCDBASEWILL" then
								if SN < "WARDENCDFATETORESIST" then
									if SN < "WARDENCDFATETOFINESSE" then
										if SN > "WARDENCDCANBLOCK" then
											if SN == "WARDENCDFATETOCRITHIT" then
												return 2.5;
											else
												return 0;
											end
										elseif SN == "WARDENCDCANBLOCK" then
											return 1;
										else
											return 0;
										end
									elseif SN > "WARDENCDFATETOFINESSE" then
										if SN < "WARDENCDFATETONCPR" then
											if SN == "WARDENCDFATETOICMR" then
												return 0.025;
											else
												return 0;
											end
										elseif SN > "WARDENCDFATETONCPR" then
											if SN == "WARDENCDFATETOPOWER" then
												return 1;
											else
												return 0;
											end
										else
											return 0.05;
										end
									else
										return 1;
									end
								elseif SN > "WARDENCDFATETORESIST" then
									if SN < "WARDENCDMIGHTTOPARRY" then
										if SN < "WARDENCDHASPOWER" then
											if SN == "WARDENCDFATETOTACMIT" then
												return 1;
											else
												return 0;
											end
										elseif SN > "WARDENCDHASPOWER" then
											if SN == "WARDENCDMIGHTTOBLOCK" then
												return 3;
											else
												return 0;
											end
										else
											return 1;
										end
									elseif SN > "WARDENCDMIGHTTOPARRY" then
										if SN < "WARDENCDPHYMITTOOFMIT" then
											if SN == "WARDENCDMIGHTTOPHYMAS" then
												return 2;
											else
												return 0;
											end
										elseif SN > "WARDENCDPHYMITTOOFMIT" then
											if SN == "WARDENCDTACMASTOOUTHEAL" then
												return 1;
											else
												return 0;
											end
										else
											return 1;
										end
									else
										return 2;
									end
								else
									return 1;
								end
							else
								return CalcStat("ClassBaseMainA",L);
							end
						else
							return 0.2;
						end
					else
						if Lm <= 0 then
							return 0;
						else
							return CalcStat("PhyMas",CalcStat("VRnkToILvl",L),CalcStat("VMMedium",L));
						end
					end
				else
					if Lm <= 1 then
						return 1;
					elseif Lm <= 25 then
						return 25;
					elseif Lm <= 79 then
						return 79;
					elseif Lm <= 350 then
						return CalcStat("ItemProgAltLPH",L);
					elseif Lm <= 400 then
						return 400;
					else
						return CalcStat("ItemProgAltLPH",L);
					end
				end
			elseif SN > "WARDENCDVITALITYTOMORALE" then
				if SN < "WORTHTABY" then
					if SN < "WORTHTABBH" then
						if SN < "WORTHTABAH" then
							if SN < "WORTHMPE" then
								if SN < "WILL" then
									if SN < "WARDENCDWILLTORESIST" then
										if SN > "WARDENCDVITALITYTONCMR" then
											if SN == "WARDENCDVITALITYTORESIST" then
												return 1;
											else
												return 0;
											end
										elseif SN == "WARDENCDVITALITYTONCMR" then
											return 0.12;
										else
											return 0;
										end
									elseif SN > "WARDENCDWILLTORESIST" then
										if SN < "WARDINGLOREPHYMIT" then
											if SN == "WARDENCDWILLTOTACMIT" then
												return 1;
											else
												return 0;
											end
										elseif SN > "WARDINGLOREPHYMIT" then
											if SN == "WARDINGLORETACMIT" then
												if Lm <= 105 then
													return CalcStat("Mitigation",L,1.6);
												elseif Lm <= 119 then
													return CalcStat("TacMitT",L,1.2);
												elseif Lm <= 120 then
													return CalcStat("TacMitT",L,1.6);
												elseif Lm <= 129 then
													return CalcStat("TacMitT",L,1.2);
												elseif Lm <= 130 then
													return CalcStat("TacMitT",L,1.6);
												elseif Lm <= 139 then
													return CalcStat("TacMitT",L,1.2);
												else
													return CalcStat("TacMitT",L,1.6);
												end
											else
												return 0;
											end
										else
											if Lm <= 105 then
												return CalcStat("Mitigation",L,1.6);
											elseif Lm <= 119 then
												return CalcStat("PhyMitT",L,1.2);
											elseif Lm <= 120 then
												return CalcStat("PhyMitT",L,1.6);
											elseif Lm <= 129 then
												return CalcStat("PhyMitT",L,1.2);
											elseif Lm <= 130 then
												return CalcStat("PhyMitT",L,1.6);
											elseif Lm <= 139 then
												return CalcStat("PhyMitT",L,1.2);
											else
												return CalcStat("PhyMitT",L,1.6);
											end
										end
									else
										return 2;
									end
								elseif SN > "WILL" then
									if SN < "WORTHMPA" then
										if SN > "WILLT" then
											if SN == "WORTHEXT" then
												if Lm <= 360 then
													return RoundDbl(CalcStat("StatC",L,C));
												elseif Lm <= 501 then
													return RoundDbl(CalcStat("StatC",L-1,C));
												else
													return 0;
												end
											else
												return 0;
											end
										elseif SN == "WILLT" then
											return CalcStat("MainT",L,N);
										else
											return 0;
										end
									elseif SN > "WORTHMPA" then
										if SN < "WORTHMPC" then
											if SN == "WORTHMPB" then
												if Lm <= 0 then
													return 0;
												else
													return DataTableValue({1,1.2,2,3,4},L);
												end
											else
												return 0;
											end
										elseif SN > "WORTHMPC" then
											if SN == "WORTHMPD" then
												if Lm <= 0 then
													return 0;
												else
													return DataTableValue({1,1,1,2,3},L);
												end
											else
												return 0;
											end
										else
											if Lm <= 0 then
												return 0;
											else
												return 1;
											end
										end
									else
										if Lm <= 0 then
											return 0;
										else
											return DataTableValue({1,1.1,1.15,1.2,1.3},L);
										end
									end
								else
									return CalcStat("Main",L,N);
								end
							elseif SN > "WORTHMPE" then
								if SN < "WORTHTABA" then
									if SN < "WORTHMPH" then
										if SN > "WORTHMPF" then
											if SN == "WORTHMPG" then
												if Lm <= 0 then
													return 0;
												else
													return DataTableValue({1,2,3,4,5},L);
												end
											else
												return 0;
											end
										elseif SN == "WORTHMPF" then
											if Lm <= 0 then
												return 0;
											else
												return DataTableValue({0.5,1,1.25,1.5,2},L);
											end
										else
											return 0;
										end
									elseif SN > "WORTHMPH" then
										if SN < "WORTHMPJ" then
											if SN == "WORTHMPI" then
												if Lm <= 0 then
													return 0;
												else
													return DataTableValue({1,2,2.5,3,10},L);
												end
											else
												return 0;
											end
										elseif SN > "WORTHMPJ" then
											if SN == "WORTHMPK" then
												if Lm <= 0 then
													return 0;
												else
													return DataTableValue({1,1.2,1.3,1.35,1.4},L);
												end
											else
												return 0;
											end
										else
											if Lm <= 0 then
												return 0;
											else
												return DataTableValue({1,1,1,1,5},L);
											end
										end
									else
										if Lm <= 0 then
											return 0;
										else
											return DataTableValue({1,1.2,1.8,3.2,5},L);
										end
									end
								elseif SN > "WORTHTABA" then
									if SN < "WORTHTABAD" then
										if SN < "WORTHTABAB" then
											if SN == "WORTHTABAA" then
												return CalcStat("WorthTabD",L)+20;
											else
												return 0;
											end
										elseif SN > "WORTHTABAB" then
											if SN == "WORTHTABAC" then
												return CalcStat("WorthTabE",L)-30;
											else
												return 0;
											end
										else
											return 7*L+50;
										end
									elseif SN > "WORTHTABAD" then
										if SN < "WORTHTABAF" then
											if SN == "WORTHTABAE" then
												return CalcStat("WorthTabE",L);
											else
												return 0;
											end
										elseif SN > "WORTHTABAF" then
											if SN == "WORTHTABAG" then
												return CalcStat("WorthTabAF",L)+25;
											else
												return 0;
											end
										else
											if Lm <= 49 then
												return 2.5*L;
											else
												return 3*L-25;
											end
										end
									else
										return 7*L+100;
									end
								else
									if Lm <= 1 then
										return 1;
									else
										return CalcStat("WorthTabAF",L);
									end
								end
							else
								if Lm <= 0 then
									return 0;
								else
									return DataTableValue({1,1.1,1.15,1.2,1.25},L);
								end
							end
						elseif SN > "WORTHTABAH" then
							if SN < "WORTHTABAU" then
								if SN < "WORTHTABAN" then
									if SN < "WORTHTABAK" then
										if SN > "WORTHTABAI" then
											if SN == "WORTHTABAJ" then
												return CalcStat("WorthTabAH",L);
											else
												return 0;
											end
										elseif SN == "WORTHTABAI" then
											if Lm <= 16 then
												return 10.73*L+54.3;
											elseif Lm <= 34 then
												return 10.735*L+54;
											elseif Lm <= 35 then
												return 429;
											elseif Lm <= 41 then
												return 10.65*L+57.1;
											elseif Lm <= 49 then
												return 10.7*L+55.3;
											else
												return 9*L+141;
											end
										else
											return 0;
										end
									elseif SN > "WORTHTABAK" then
										if SN < "WORTHTABALBASE" then
											if SN == "WORTHTABAL" then
												if Lm <= 49 then
													return CalcStat("WorthTabALBase",L);
												else
													return 9*L+69;
												end
											else
												return 0;
											end
										elseif SN > "WORTHTABALBASE" then
											if SN == "WORTHTABAM" then
												return CalcStat("WorthTabB",L);
											else
												return 0;
											end
										else
											return 9.86*L+23.51+RoundDbl(L*0.1+0.3)*0.4;
										end
									else
										if Lm <= 49 then
											return CalcStat("WorthTabALBase",L+1);
										else
											return 9*L+78;
										end
									end
								elseif SN > "WORTHTABAN" then
									if SN < "WORTHTABAQ" then
										if SN > "WORTHTABAO" then
											if SN == "WORTHTABAP" then
												return CalcStat("WorthTabAQ",L);
											else
												return 0;
											end
										elseif SN == "WORTHTABAO" then
											return CalcStat("WorthTabE",L);
										else
											return 0;
										end
									elseif SN > "WORTHTABAQ" then
										if SN < "WORTHTABAS" then
											if SN == "WORTHTABAR" then
												return CalcStat("WorthTabD",L)+37.5;
											else
												return 0;
											end
										elseif SN > "WORTHTABAS" then
											if SN == "WORTHTABAT" then
												if Lm <= 4 then
													return RoundDbl(3*L+20,-1);
												elseif Lm <= 7 then
													return 60;
												elseif Lm <= 10 then
													return 100;
												elseif Lm <= 13 then
													return 180;
												elseif Lm <= 16 then
													return 270;
												elseif Lm <= 19 then
													return 310;
												elseif Lm <= 40 then
													return RoundDbl(3.2*L+274,-1);
												elseif Lm <= 43 then
													return 400;
												elseif Lm <= 53 then
													return RoundDbl(1.9*L+334,-1);
												elseif Lm <= 56 then
													return 460;
												elseif Lm <= 59 then
													return 480;
												else
													return 20*L-680;
												end
											else
												return 0;
											end
										else
											return CalcStat("WorthTabU",L);
										end
									else
										if Lm <= 10 then
											return 7.5*L+60;
										elseif Lm <= 49 then
											return 5.5*L+80;
										else
											return 6*L+55;
										end
									end
								else
									if Lm <= 50 then
										return 8.25*L+27.75;
									else
										return 8*L+40;
									end
								end
							elseif SN > "WORTHTABAU" then
								if SN < "WORTHTABB" then
									if SN < "WORTHTABAX" then
										if SN > "WORTHTABAV" then
											if SN == "WORTHTABAW" then
												if Lm <= 1 then
													return 50;
												elseif Lm <= 49 then
													return 2.5*L+102.5;
												elseif Lm <= 80 then
													return 3*L+78;
												elseif Lm <= 120 then
													return 2.97*L+79.5;
												else
													return 3*L+75;
												end
											else
												return 0;
											end
										elseif SN == "WORTHTABAV" then
											if Lm <= 4 then
												return RoundDbl(3*L+20,-1);
											elseif Lm <= 7 then
												return 70;
											elseif Lm <= 10 then
												return 140;
											elseif Lm <= 13 then
												return 270;
											elseif Lm <= 16 then
												return 400;
											elseif Lm <= 19 then
												return 460;
											elseif Lm <= 25 then
												return RoundDbl(3*L+447.5,-1);
											elseif Lm <= 46 then
												return RoundDbl(3.2*L+455,-1);
											elseif Lm <= 50 then
												return 620;
											else
												return 20*L-360;
											end
										else
											return 0;
										end
									elseif SN > "WORTHTABAX" then
										if SN < "WORTHTABAZ" then
											if SN == "WORTHTABAY" then
												return 5*L;
											else
												return 0;
											end
										elseif SN > "WORTHTABAZ" then
											if SN == "WORTHTABAZBASE" then
												if Lm <= 44 then
													return RoundDbl(0.0525*L+0.7);
												elseif Lm <= 65 then
													return RoundDbl(0.19*L-4.85);
												elseif Lm <= 81 then
													return RoundDbl(0.19*L+28.15);
												else
													return RoundDbl(0.19*L+28.15+RoundDbl(L*0.05-4.55)*0.2);
												end
											else
												return 0;
											end
										else
											if Lm <= 10 then
												return CalcStat("WorthTabAZBase",L)*62.5;
											elseif Lm <= 65 then
												return CalcStat("WorthTabAZBase",L)*125;
											else
												return CalcStat("WorthTabAZBase",L)*25;
											end
										end
									else
										if Lm <= 16 then
											return 10.75*L+54;
										elseif Lm <= 34 then
											return 10.75*L+53.7;
										elseif Lm <= 35 then
											return 429;
										elseif Lm <= 41 then
											return 10.65*L+57.1;
										elseif Lm <= 49 then
											return 10.68*L+56.25;
										else
											return 12*L-9;
										end
									end
								elseif SN > "WORTHTABB" then
									if SN < "WORTHTABBD" then
										if SN < "WORTHTABBB" then
											if SN == "WORTHTABBA" then
												return 5*L+385;
											else
												return 0;
											end
										elseif SN > "WORTHTABBB" then
											if SN == "WORTHTABBC" then
												if Lm <= 34 then
													return RoundDbl(L/15+0.8)*3750+1250;
												elseif Lm <= 35 then
													return 100000;
												else
													return 125500;
												end
											else
												return 0;
											end
										else
											if Lm <= 1 then
												return 40;
											elseif Lm <= 10 then
												return RoundDbl(0.35*L-0.1)*20;
											elseif Lm <= 13 then
												return 100;
											elseif Lm <= 19 then
												return RoundDbl(0.35*L+1.6)*20;
											elseif Lm <= 25 then
												return RoundDbl(2*L+150,-1);
											elseif Lm <= 40 then
												return RoundDbl(2*L+164,-1);
											elseif Lm <= 49 then
												return RoundDbl(L+201,-1);
											else
												return 20*L-740;
											end
										end
									elseif SN > "WORTHTABBD" then
										if SN < "WORTHTABBF" then
											if SN == "WORTHTABBE" then
												if Lm <= 1 then
													return 60;
												elseif Lm <= 7 then
													return RoundDbl(L/3)*40+30;
												elseif Lm <= 13 then
													return RoundDbl(L/3)*130-210;
												elseif Lm <= 19 then
													return RoundDbl(L/3)*60+140;
												elseif Lm <= 25 then
													return RoundDbl(L/3)*10+480;
												elseif Lm <= 46 then
													return RoundDbl(L/3)*10+490;
												elseif Lm <= 50 then
													return 660;
												else
													return 20*L-320;
												end
											else
												return 0;
											end
										elseif SN > "WORTHTABBF" then
											if SN == "WORTHTABBG" then
												if Lm <= 7 then
													return RoundDbl(0.2*L-0.4)*2+1;
												elseif Lm <= 16 then
													return RoundDbl(L/3-2)*6;
												elseif Lm <= 22 then
													return RoundDbl(L/3+1)*3;
												elseif Lm <= 25 then
													return RoundDbl(L/3+1)*3-2;
												elseif Lm <= 80 then
													return RoundDbl(L/3+18)-2;
												else
													return L-37;
												end
											else
												return 0;
											end
										else
											return CalcStat("WorthTabAV",L)+20;
										end
									else
										return CalcStat("WorthTabK",L)+1;
									end
								else
									if Lm <= 50 then
										return 8.25*L+22.25;
									else
										return 8*L+35;
									end
								end
							else
								return CalcStat("WorthTabBN",L)*1.25;
							end
						else
							if Lm <= 49 then
								return CalcStat("WorthTabALBase",L+7)-66;
							else
								return 9*L+72;
							end
						end
					elseif SN > "WORTHTABBH" then
						if SN < "WORTHTABCJ" then
							if SN < "WORTHTABBV" then
								if SN < "WORTHTABBO" then
									if SN < "WORTHTABBK" then
										if SN > "WORTHTABBI" then
											if SN == "WORTHTABBJ" then
												return RoundDbl(0.1*L+0.45)*3;
											else
												return 0;
											end
										elseif SN == "WORTHTABBI" then
											return CalcStat("WorthTabG",L)-25;
										else
											return 0;
										end
									elseif SN > "WORTHTABBK" then
										if SN < "WORTHTABBM" then
											if SN == "WORTHTABBL" then
												if Lm <= 35 then
													return 126600;
												elseif Lm <= 46 then
													return 150600;
												elseif Lm <= 47 then
													return 180720;
												else
													return 150600;
												end
											else
												return 0;
											end
										elseif SN > "WORTHTABBM" then
											if SN == "WORTHTABBN" then
												if Lm <= 1 then
													return 400;
												else
													return 20*L+800;
												end
											else
												return 0;
											end
										else
											if Lm <= 1 then
												return 10;
											else
												return 20*L-20;
											end
										end
									else
										if Lm <= 10 then
											return RoundDbl(0.1*L+0.45);
										else
											return RoundDbl(0.1*L-0.6)*2;
										end
									end
								elseif SN > "WORTHTABBO" then
									if SN < "WORTHTABBR" then
										if SN > "WORTHTABBP" then
											if SN == "WORTHTABBQ" then
												if Lm <= 1 then
													return 50;
												elseif Lm <= 49 then
													return RoundDbl(2.5*L+100);
												else
													return 3*L+75;
												end
											else
												return 0;
											end
										elseif SN == "WORTHTABBP" then
											if Lm <= 10 then
												return 156.25*L+1562.5;
											elseif Lm <= 20 then
												return 312.5*L;
											elseif Lm <= 30 then
												return 625*L-6250;
											elseif Lm <= 40 then
												return 1250*L-25000;
											else
												return 2500*L-75000;
											end
										else
											return 0;
										end
									elseif SN > "WORTHTABBR" then
										if SN < "WORTHTABBT" then
											if SN == "WORTHTABBS" then
												return CalcStat("WorthTabBR",L)*2;
											else
												return 0;
											end
										elseif SN > "WORTHTABBT" then
											if SN == "WORTHTABBU" then
												if Lm <= 80 then
													return 20*L+300;
												else
													return 10*L+1100;
												end
											else
												return 0;
											end
										else
											return 62500;
										end
									else
										if Lm <= 49 then
											return CalcStat("WorthTabBQ",L)*2;
										else
											return 4*L+250;
										end
									end
								else
									if Lm <= 10 then
										return 10;
									elseif Lm <= 40 then
										return RoundDbl(0.1*L-0.55)*50-25;
									elseif Lm <= 80 then
										return RoundDbl(0.1*L-0.55)*50;
									else
										return RoundDbl(0.1*L-0.55)*25+175;
									end
								end
							elseif SN > "WORTHTABBV" then
								if SN < "WORTHTABCB" then
									if SN < "WORTHTABBY" then
										if SN > "WORTHTABBW" then
											if SN == "WORTHTABBX" then
												if Lm <= 10 then
													return RoundDbl(0.1*L+0.45)*3;
												elseif Lm <= 140 then
													return RoundDbl(0.1*L-0.6)*6;
												else
													return RoundDbl(0.1*L+0.4)*4+22;
												end
											else
												return 0;
											end
										elseif SN == "WORTHTABBW" then
											if Lm <= 1 then
												return 645;
											elseif Lm <= 9 then
												return 20*L+980;
											else
												return 50*L+920;
											end
										else
											return 0;
										end
									elseif SN > "WORTHTABBY" then
										if SN < "WORTHTABC" then
											if SN == "WORTHTABBZ" then
												if Lm <= 10 then
													return 27.42*L+273.1;
												elseif Lm <= 20 then
													return 54.69*L;
												elseif Lm <= 30 then
													return 109.35*L-1093;
												elseif Lm <= 40 then
													return 218.75*L-4375;
												elseif Lm <= 80 then
													return 437.5*L-13125;
												else
													return 437*L-13085;
												end
											else
												return 0;
											end
										elseif SN > "WORTHTABC" then
											if SN == "WORTHTABCA" then
												if Lm <= 10 then
													return 7.25*L+72.25;
												elseif Lm <= 20 then
													return 14.49*L+0.11;
												elseif Lm <= 30 then
													return 29*L-290;
												elseif Lm <= 35 then
													return 57.99*L-1160.16;
												elseif Lm <= 40 then
													return 57.99*L-1160.12;
												elseif Lm <= 80 then
													return 115.94*L-3478.2;
												else
													return 116*L-3483;
												end
											else
												return 0;
											end
										else
											return CalcStat("WorthTabD",L)+20;
										end
									else
										return 90000;
									end
								elseif SN > "WORTHTABCB" then
									if SN < "WORTHTABCF" then
										if SN < "WORTHTABCD" then
											if SN == "WORTHTABCC" then
												return CalcStat("WorthTabBK",L)*5;
											else
												return 0;
											end
										elseif SN > "WORTHTABCD" then
											if SN == "WORTHTABCE" then
												return CalcStat("WorthTabBN",L)*10;
											else
												return 0;
											end
										else
											return CalcStat("WorthTabBK",L)*25;
										end
									elseif SN > "WORTHTABCF" then
										if SN < "WORTHTABCH" then
											if SN == "WORTHTABCG" then
												return 20;
											else
												return 0;
											end
										elseif SN > "WORTHTABCH" then
											if SN == "WORTHTABCI" then
												return 40000;
											else
												return 0;
											end
										else
											return 50000;
										end
									else
										if Lm <= 20 then
											return RoundDbl(0.1*L-0.55)*600+200;
										elseif Lm <= 40 then
											return RoundDbl(0.1*L-0.55)*1000-500;
										elseif Lm <= 60 then
											return RoundDbl(0.1*L-0.55)*2000-4000;
										elseif Lm <= 70 then
											return 8500;
										elseif Lm <= 140 then
											return RoundDbl(0.1*L-0.55)*2500-7500;
										elseif Lm <= 200 then
											return RoundDbl(0.1*L-0.55)*3000-14000;
										else
											return RoundDbl(0.1*L-0.55)*2500-3500;
										end
									end
								else
									return 0.1;
								end
							else
								if Lm <= 29 then
									return 1250;
								else
									return RoundDbl(0.05*L-1)*2500;
								end
							end
						elseif SN > "WORTHTABCJ" then
							if SN < "WORTHTABJ" then
								if SN < "WORTHTABCQ" then
									if SN < "WORTHTABCM" then
										if SN > "WORTHTABCK" then
											if SN == "WORTHTABCL" then
												return 12500;
											else
												return 0;
											end
										elseif SN == "WORTHTABCK" then
											return 15000;
										else
											return 0;
										end
									elseif SN > "WORTHTABCM" then
										if SN < "WORTHTABCO" then
											if SN == "WORTHTABCN" then
												return RoundDbl(0.1*L+0.5)*10000;
											else
												return 0;
											end
										elseif SN > "WORTHTABCO" then
											if SN == "WORTHTABCP" then
												return 1;
											else
												return 0;
											end
										else
											return CalcStat("WorthTabAB",L);
										end
									else
										return 7500;
									end
								elseif SN > "WORTHTABCQ" then
									if SN < "WORTHTABF" then
										if SN > "WORTHTABD" then
											if SN == "WORTHTABE" then
												if Lm <= 9 then
													return 30*L+50;
												else
													return 7*L+280;
												end
											else
												return 0;
											end
										elseif SN == "WORTHTABD" then
											if Lm <= 49 then
												return 7.5*L;
											else
												return 8*L-25;
											end
										else
											return 0;
										end
									elseif SN > "WORTHTABF" then
										if SN < "WORTHTABH" then
											if SN == "WORTHTABG" then
												if Lm <= 1 then
													return 50;
												else
													return CalcStat("WorthTabAF",L)+100;
												end
											else
												return 0;
											end
										elseif SN > "WORTHTABH" then
											if SN == "WORTHTABI" then
												if Lm <= 4 then
													return 1;
												elseif Lm <= 10 then
													return 0.7*L-1;
												elseif Lm <= 15 then
													return 1.4*L-7;
												elseif Lm <= 24 then
													return 1.25*L-5;
												elseif Lm <= 49 then
													return 2.5*L-35;
												else
													return 3*L-60;
												end
											else
												return 0;
											end
										else
											if Lm <= 2 then
												return L;
											elseif Lm <= 9 then
												return 1.48*L-2.85;
											elseif Lm <= 11 then
												return 2.5*L-13;
											elseif Lm <= 24 then
												return 2.5*L-10;
											else
												return 5*L-70;
											end
										end
									else
										return 0.1;
									end
								else
									if Lm <= 10 then
										return RoundDbl(0.3*L+0.2)*2;
									elseif Lm <= 16 then
										return RoundDbl(0.25*L-1)*6;
									elseif Lm <= 22 then
										return RoundDbl(0.3*L+5.5)*2;
									elseif Lm <= 50 then
										return RoundDbl((1/6)*L+8.75)*2;
									elseif Lm <= 80 then
										return RoundDbl((1/3)*L-11.5)*6;
									else
										return RoundDbl(0.25*L-4.6)*6;
									end
								end
							elseif SN > "WORTHTABJ" then
								if SN < "WORTHTABQ" then
									if SN < "WORTHTABM" then
										if SN > "WORTHTABK" then
											if SN == "WORTHTABL" then
												return CalcStat("WorthTabB",L)+19.25;
											else
												return 0;
											end
										elseif SN == "WORTHTABK" then
											if Lm <= 9 then
												return 12*L+24;
											else
												return 7*L+74;
											end
										else
											return 0;
										end
									elseif SN > "WORTHTABM" then
										if SN < "WORTHTABO" then
											if SN == "WORTHTABN" then
												return CalcStat("WorthTabAF",L)+25;
											else
												return 0;
											end
										elseif SN > "WORTHTABO" then
											if SN == "WORTHTABP" then
												return CalcStat("WorthTabE",L);
											else
												return 0;
											end
										else
											return CalcStat("WorthTabB",L)+11;
										end
									else
										if Lm <= 9 then
											return 10*L+11;
										elseif Lm <= 49 then
											return 4*L+65;
										else
											return 5*L+15;
										end
									end
								elseif SN > "WORTHTABQ" then
									if SN < "WORTHTABU" then
										if SN < "WORTHTABS" then
											if SN == "WORTHTABR" then
												if Lm <= 9 then
													return 12*L+30;
												else
													return 7*L+75;
												end
											else
												return 0;
											end
										elseif SN > "WORTHTABS" then
											if SN == "WORTHTABT" then
												if Lm <= 1 then
													return 54;
												elseif Lm <= 17 then
													return 10.73*L+43.57;
												elseif Lm <= 35 then
													return 10.735*L+43.265;
												elseif Lm <= 36 then
													return 429;
												elseif Lm <= 42 then
													return 10.65*L+46.45;
												elseif Lm <= 49 then
													return 10.7*L+44.6;
												else
													return 9*L+130;
												end
											else
												return 0;
											end
										else
											return CalcStat("WorthTabD",L)+17.5;
										end
									elseif SN > "WORTHTABU" then
										if SN < "WORTHTABW" then
											if SN == "WORTHTABV" then
												return CalcStat("WorthTabB",L)-2.75;
											else
												return 0;
											end
										elseif SN > "WORTHTABW" then
											if SN == "WORTHTABX" then
												return CalcStat("WorthTabAF",L)+75;
											else
												return 0;
											end
										else
											return CalcStat("WorthTabD",L)+25;
										end
									else
										if Lm <= 10 then
											return 9*L+20;
										elseif Lm <= 49 then
											return 5.5*L+55;
										else
											return 6*L+30;
										end
									end
								else
									return 7*L+25;
								end
							else
								if Lm <= 4 then
									return 2.5*L+7.5;
								elseif Lm <= 5 then
									return 23;
								else
									return 4*L;
								end
							end
						else
							return 20000;
						end
					else
						if Lm <= 80 then
							return RoundDbl(0.05*L-0.05)+RoundDbl(0.05*L+0.45);
						else
							return RoundDbl(0.05*L-0.1)+RoundDbl(0.05*L+0.45);
						end
					end
				elseif SN > "WORTHTABY" then
					if SN < "WORTHVALCB" then
						if SN < "WORTHVALB" then
							if SN < "WORTHVALAL" then
								if SN < "WORTHVALAE" then
									if SN < "WORTHVALAA" then
										if SN > "WORTHTABZ" then
											if SN == "WORTHVALA" then
												return RoundDbl(CalcStat("WorthMpA",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabA"));
											else
												return 0;
											end
										elseif SN == "WORTHTABZ" then
											return CalcStat("WorthTabR",L)-15;
										else
											return 0;
										end
									elseif SN > "WORTHVALAA" then
										if SN < "WORTHVALAC" then
											if SN == "WORTHVALAB" then
												return RoundDbl(CalcStat("WorthMpB",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabAB"));
											else
												return 0;
											end
										elseif SN > "WORTHVALAC" then
											if SN == "WORTHVALAD" then
												return RoundDbl(CalcStat("WorthMpB",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabAD"));
											else
												return 0;
											end
										else
											return RoundDbl(CalcStat("WorthMpB",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabAC"));
										end
									else
										return RoundDbl(CalcStat("WorthMpB",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabAA"));
									end
								elseif SN > "WORTHVALAE" then
									if SN < "WORTHVALAH" then
										if SN > "WORTHVALAF" then
											if SN == "WORTHVALAG" then
												return RoundDbl(CalcStat("WorthMpB",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabAG"));
											else
												return 0;
											end
										elseif SN == "WORTHVALAF" then
											return RoundDbl(CalcStat("WorthMpB",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabAF"));
										else
											return 0;
										end
									elseif SN > "WORTHVALAH" then
										if SN < "WORTHVALAJ" then
											if SN == "WORTHVALAI" then
												return RoundDbl(CalcStat("WorthMpB",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabAI"));
											else
												return 0;
											end
										elseif SN > "WORTHVALAJ" then
											if SN == "WORTHVALAK" then
												return RoundDbl(CalcStat("WorthMpB",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabAK"));
											else
												return 0;
											end
										else
											return RoundDbl(CalcStat("WorthMpB",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabAJ"));
										end
									else
										return RoundDbl(CalcStat("WorthMpB",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabAH"));
									end
								else
									return RoundDbl(CalcStat("WorthMpB",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabAE"));
								end
							elseif SN > "WORTHVALAL" then
								if SN < "WORTHVALAS" then
									if SN < "WORTHVALAO" then
										if SN > "WORTHVALAM" then
											if SN == "WORTHVALAN" then
												return RoundDbl(CalcStat("WorthMpB",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabAN"));
											else
												return 0;
											end
										elseif SN == "WORTHVALAM" then
											return RoundDbl(CalcStat("WorthMpB",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabAM"));
										else
											return 0;
										end
									elseif SN > "WORTHVALAO" then
										if SN < "WORTHVALAQ" then
											if SN == "WORTHVALAP" then
												return RoundDbl(CalcStat("WorthMpB",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabAP"));
											else
												return 0;
											end
										elseif SN > "WORTHVALAQ" then
											if SN == "WORTHVALAR" then
												return RoundDbl(CalcStat("WorthMpB",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabAR"));
											else
												return 0;
											end
										else
											return RoundDbl(CalcStat("WorthMpB",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabAQ"));
										end
									else
										return RoundDbl(CalcStat("WorthMpB",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabAO"));
									end
								elseif SN > "WORTHVALAS" then
									if SN < "WORTHVALAW" then
										if SN < "WORTHVALAU" then
											if SN == "WORTHVALAT" then
												return RoundDbl(CalcStat("WorthMpC",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabAT"));
											else
												return 0;
											end
										elseif SN > "WORTHVALAU" then
											if SN == "WORTHVALAV" then
												return RoundDbl(CalcStat("WorthMpC",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabAV"));
											else
												return 0;
											end
										else
											return RoundDbl(CalcStat("WorthMpC",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabAU"));
										end
									elseif SN > "WORTHVALAW" then
										if SN < "WORTHVALAY" then
											if SN == "WORTHVALAX" then
												return RoundDbl(CalcStat("WorthMpB",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabAX"));
											else
												return 0;
											end
										elseif SN > "WORTHVALAY" then
											if SN == "WORTHVALAZ" then
												return RoundDbl(CalcStat("WorthMpA",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabAZ"));
											else
												return 0;
											end
										else
											return RoundDbl(CalcStat("WorthMpA",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabAY"));
										end
									else
										return RoundDbl(CalcStat("WorthMpA",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabAW"));
									end
								else
									return RoundDbl(CalcStat("WorthMpB",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabAS"));
								end
							else
								return RoundDbl(CalcStat("WorthMpB",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabAL"));
							end
						elseif SN > "WORTHVALB" then
							if SN < "WORTHVALBN" then
								if SN < "WORTHVALBG" then
									if SN < "WORTHVALBC" then
										if SN > "WORTHVALBA" then
											if SN == "WORTHVALBB" then
												return RoundDbl(CalcStat("WorthMpC",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabBB"));
											else
												return 0;
											end
										elseif SN == "WORTHVALBA" then
											return RoundDbl(CalcStat("WorthMpC",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabBA"));
										else
											return 0;
										end
									elseif SN > "WORTHVALBC" then
										if SN < "WORTHVALBE" then
											if SN == "WORTHVALBD" then
												return RoundDbl(CalcStat("WorthMpB",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabBD"));
											else
												return 0;
											end
										elseif SN > "WORTHVALBE" then
											if SN == "WORTHVALBF" then
												return RoundDbl(CalcStat("WorthMpC",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabBF"));
											else
												return 0;
											end
										else
											return RoundDbl(CalcStat("WorthMpJ",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabBE"));
										end
									else
										return RoundDbl(CalcStat("WorthMpE",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabBC"));
									end
								elseif SN > "WORTHVALBG" then
									if SN < "WORTHVALBJ" then
										if SN > "WORTHVALBH" then
											if SN == "WORTHVALBI" then
												return RoundDbl(CalcStat("WorthMpA",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabBI"));
											else
												return 0;
											end
										elseif SN == "WORTHVALBH" then
											return RoundDbl(CalcStat("WorthMpC",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabBH"));
										else
											return 0;
										end
									elseif SN > "WORTHVALBJ" then
										if SN < "WORTHVALBL" then
											if SN == "WORTHVALBK" then
												return RoundDbl(CalcStat("WorthMpC",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabBK"));
											else
												return 0;
											end
										elseif SN > "WORTHVALBL" then
											if SN == "WORTHVALBM" then
												return RoundDbl(CalcStat("WorthMpA",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabBM"));
											else
												return 0;
											end
										else
											return RoundDbl(CalcStat("WorthMpE",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabBL"));
										end
									else
										return RoundDbl(CalcStat("WorthMpC",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabBJ"));
									end
								else
									return RoundDbl(CalcStat("WorthMpA",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabBG"));
								end
							elseif SN > "WORTHVALBN" then
								if SN < "WORTHVALBU" then
									if SN < "WORTHVALBQ" then
										if SN > "WORTHVALBO" then
											if SN == "WORTHVALBP" then
												return RoundDbl(CalcStat("WorthMpC",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabBP"));
											else
												return 0;
											end
										elseif SN == "WORTHVALBO" then
											return RoundDbl(CalcStat("WorthMpG",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabBO"));
										else
											return 0;
										end
									elseif SN > "WORTHVALBQ" then
										if SN < "WORTHVALBS" then
											if SN == "WORTHVALBR" then
												return RoundDbl(CalcStat("WorthMpE",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabBR"));
											else
												return 0;
											end
										elseif SN > "WORTHVALBS" then
											if SN == "WORTHVALBT" then
												return RoundDbl(CalcStat("WorthMpC",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabBT"));
											else
												return 0;
											end
										else
											return RoundDbl(CalcStat("WorthMpE",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabBS"));
										end
									else
										return RoundDbl(CalcStat("WorthMpE",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabBQ"));
									end
								elseif SN > "WORTHVALBU" then
									if SN < "WORTHVALBY" then
										if SN < "WORTHVALBW" then
											if SN == "WORTHVALBV" then
												return RoundDbl(CalcStat("WorthMpD",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabBV"));
											else
												return 0;
											end
										elseif SN > "WORTHVALBW" then
											if SN == "WORTHVALBX" then
												return RoundDbl(CalcStat("WorthMpC",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabBX"));
											else
												return 0;
											end
										else
											return RoundDbl(CalcStat("WorthMpC",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabBW"));
										end
									elseif SN > "WORTHVALBY" then
										if SN < "WORTHVALC" then
											if SN == "WORTHVALBZ" then
												return RoundDbl(CalcStat("WorthMpC",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabBZ"));
											else
												return 0;
											end
										elseif SN > "WORTHVALC" then
											if SN == "WORTHVALCA" then
												return RoundDbl(CalcStat("WorthMpC",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabCA"));
											else
												return 0;
											end
										else
											return RoundDbl(CalcStat("WorthMpB",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabC"));
										end
									else
										return RoundDbl(CalcStat("WorthMpE",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabBY"));
									end
								else
									return RoundDbl(CalcStat("WorthMpF",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabBU"));
								end
							else
								return RoundDbl(CalcStat("WorthMpB",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabBN"));
							end
						else
							return RoundDbl(CalcStat("WorthMpB",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabB"));
						end
					elseif SN > "WORTHVALCB" then
						if SN < "WORTHVALQ" then
							if SN < "WORTHVALCP" then
								if SN < "WORTHVALCI" then
									if SN < "WORTHVALCE" then
										if SN > "WORTHVALCC" then
											if SN == "WORTHVALCD" then
												return RoundDbl(CalcStat("WorthMpC",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabCD"));
											else
												return 0;
											end
										elseif SN == "WORTHVALCC" then
											return RoundDbl(CalcStat("WorthMpC",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabCC"));
										else
											return 0;
										end
									elseif SN > "WORTHVALCE" then
										if SN < "WORTHVALCG" then
											if SN == "WORTHVALCF" then
												return RoundDbl(CalcStat("WorthMpA",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabCF"));
											else
												return 0;
											end
										elseif SN > "WORTHVALCG" then
											if SN == "WORTHVALCH" then
												return RoundDbl(CalcStat("WorthMpC",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabCH"));
											else
												return 0;
											end
										else
											return RoundDbl(CalcStat("WorthMpC",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabCG"));
										end
									else
										return RoundDbl(CalcStat("WorthMpH",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabCE"));
									end
								elseif SN > "WORTHVALCI" then
									if SN < "WORTHVALCL" then
										if SN > "WORTHVALCJ" then
											if SN == "WORTHVALCK" then
												return RoundDbl(CalcStat("WorthMpC",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabCK"));
											else
												return 0;
											end
										elseif SN == "WORTHVALCJ" then
											return RoundDbl(CalcStat("WorthMpC",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabCJ"));
										else
											return 0;
										end
									elseif SN > "WORTHVALCL" then
										if SN < "WORTHVALCN" then
											if SN == "WORTHVALCM" then
												return RoundDbl(CalcStat("WorthMpC",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabCM"));
											else
												return 0;
											end
										elseif SN > "WORTHVALCN" then
											if SN == "WORTHVALCO" then
												return RoundDbl(CalcStat("WorthMpB",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabCO"));
											else
												return 0;
											end
										else
											return RoundDbl(CalcStat("WorthMpI",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabCN"));
										end
									else
										return RoundDbl(CalcStat("WorthMpC",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabCL"));
									end
								else
									return RoundDbl(CalcStat("WorthMpC",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabCI"));
								end
							elseif SN > "WORTHVALCP" then
								if SN < "WORTHVALI" then
									if SN < "WORTHVALE" then
										if SN > "WORTHVALCQ" then
											if SN == "WORTHVALD" then
												return RoundDbl(CalcStat("WorthMpB",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabD"));
											else
												return 0;
											end
										elseif SN == "WORTHVALCQ" then
											return RoundDbl(CalcStat("WorthMpK",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabCQ"));
										else
											return 0;
										end
									elseif SN > "WORTHVALE" then
										if SN < "WORTHVALG" then
											if SN == "WORTHVALF" then
												return RoundDbl(CalcStat("WorthMpC",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabF"));
											else
												return 0;
											end
										elseif SN > "WORTHVALG" then
											if SN == "WORTHVALH" then
												return RoundDbl(CalcStat("WorthMpA",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabH"));
											else
												return 0;
											end
										else
											return RoundDbl(CalcStat("WorthMpC",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabG"));
										end
									else
										return RoundDbl(CalcStat("WorthMpB",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabE"));
									end
								elseif SN > "WORTHVALI" then
									if SN < "WORTHVALM" then
										if SN < "WORTHVALK" then
											if SN == "WORTHVALJ" then
												return RoundDbl(CalcStat("WorthMpA",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabJ"));
											else
												return 0;
											end
										elseif SN > "WORTHVALK" then
											if SN == "WORTHVALL" then
												return RoundDbl(CalcStat("WorthMpB",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabL"));
											else
												return 0;
											end
										else
											return RoundDbl(CalcStat("WorthMpB",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabK"));
										end
									elseif SN > "WORTHVALM" then
										if SN < "WORTHVALO" then
											if SN == "WORTHVALN" then
												return RoundDbl(CalcStat("WorthMpB",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabN"));
											else
												return 0;
											end
										elseif SN > "WORTHVALO" then
											if SN == "WORTHVALP" then
												return RoundDbl(CalcStat("WorthMpB",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabP"));
											else
												return 0;
											end
										else
											return RoundDbl(CalcStat("WorthMpB",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabO"));
										end
									else
										return RoundDbl(CalcStat("WorthMpB",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabM"));
									end
								else
									return RoundDbl(CalcStat("WorthMpA",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabI"));
								end
							else
								return RoundDbl(CalcStat("WorthMpA",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabCP"));
							end
						elseif SN > "WORTHVALQ" then
							if SN < "WPNDMGMINMPTYPE" then
								if SN < "WORTHVALX" then
									if SN < "WORTHVALT" then
										if SN > "WORTHVALR" then
											if SN == "WORTHVALS" then
												return RoundDbl(CalcStat("WorthMpB",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabS"));
											else
												return 0;
											end
										elseif SN == "WORTHVALR" then
											return RoundDbl(CalcStat("WorthMpB",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabR"));
										else
											return 0;
										end
									elseif SN > "WORTHVALT" then
										if SN < "WORTHVALV" then
											if SN == "WORTHVALU" then
												return RoundDbl(CalcStat("WorthMpB",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabU"));
											else
												return 0;
											end
										elseif SN > "WORTHVALV" then
											if SN == "WORTHVALW" then
												return RoundDbl(CalcStat("WorthMpB",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabW"));
											else
												return 0;
											end
										else
											return RoundDbl(CalcStat("WorthMpB",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabV"));
										end
									else
										return RoundDbl(CalcStat("WorthMpB",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabT"));
									end
								elseif SN > "WORTHVALX" then
									if SN < "WOUNDRESISTT" then
										if SN > "WORTHVALY" then
											if SN == "WORTHVALZ" then
												return RoundDbl(CalcStat("WorthMpB",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabZ"));
											else
												return 0;
											end
										elseif SN == "WORTHVALY" then
											return RoundDbl(CalcStat("WorthMpB",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabY"));
										else
											return 0;
										end
									elseif SN > "WOUNDRESISTT" then
										if SN < "WPNDMGMAXMPTYPE" then
											if SN == "WPNDMGMAX" then
												return CalcStat("CombatBase",L,C)*CalcStat("WpnDmgMaxMPType",WpnCodeIndex(C,2));
											else
												return 0;
											end
										elseif SN > "WPNDMGMAXMPTYPE" then
											if SN == "WPNDMGMIN" then
												return CalcStat("CombatBase",L,C)*CalcStat("WpnDmgMinMPType",WpnCodeIndex(C,2));
											else
												return 0;
											end
										else
											if Lm <= 0 then
												return 0;
											else
												return DataTableValue({1.25,1.25,40/31},L);
											end
										end
									else
										return CalcStat("ResistAddT",L,N);
									end
								else
									return RoundDbl(CalcStat("WorthMpB",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabX"));
								end
							elseif SN > "WPNDMGMINMPTYPE" then
								if SN < "WRDRECKLESSNCRITHIT" then
									if SN < "WRDCRITDEF" then
										if SN > "WPNDPS" then
											if SN == "WRDBATSTRIKESCRITDEF" then
												return CalcStat("CritDefT",L,CalcStat("Trait123Choice",N)*0.4);
											else
												return 0;
											end
										elseif SN == "WPNDPS" then
											return CalcStat("CombatBase",L,C);
										else
											return 0;
										end
									elseif SN > "WRDCRITDEF" then
										if SN < "WRDIMPRBLADESPARRY" then
											if SN == "WRDFINESSE" then
												return CalcStat("FinesseT",L,CalcStat("Trait12345Choice",N)*0.4);
											else
												return 0;
											end
										elseif SN > "WRDIMPRBLADESPARRY" then
											if SN == "WRDPHYMAS" then
												return CalcStat("PhyMasT",L,CalcStat("Trait12345Choice",N)*0.4);
											else
												return 0;
											end
										else
											return CalcStat("ParryT",L,2.8);
										end
									else
										if Lm <= 105 then
											return RoundDbl(20.2*L);
										else
											return CalcStat("ProgExtHighLinExpRnd",L,CalcStat("WrdCritDef",105));
										end
									end
								elseif SN > "WRDRECKLESSNCRITHIT" then
									if SN < "WRDSTDYOURGRBASE" then
										if SN < "WRDSHIELDTACTCRITDEF" then
											if SN == "WRDSHIELDMASBLOCK" then
												return CalcStat("BlockT",L,2.8);
											else
												return 0;
											end
										elseif SN > "WRDSHIELDTACTCRITDEF" then
											if SN == "WRDSSSHPIERCERBLOCK" then
												return -CalcStat("BlockT",L,4);
											else
												return 0;
											end
										else
											return CalcStat("CritDefT",L,2);
										end
									elseif SN > "WRDSTDYOURGRBASE" then
										if SN < "WRDSTDYOURGREVADE" then
											if SN == "WRDSTDYOURGRBLOCK" then
												if Lm <= 105 then
													return CalcStat("WrdStdYourGrBase",L,CalcStat("Trait123Choice",N));
												else
													return CalcStat("ProgExtHighLinExpRnd",L,CalcStat("WrdStdYourGrBlock",105,N));
												end
											else
												return 0;
											end
										elseif SN > "WRDSTDYOURGREVADE" then
											if SN == "WRDSTDYOURGRPARRY" then
												if Lm <= 105 then
													return CalcStat("WrdStdYourGrBase",L,CalcStat("Trait123Choice",N));
												else
													return CalcStat("ProgExtHighLinExpRnd",L,CalcStat("WrdStdYourGrParry",105,N));
												end
											else
												return 0;
											end
										else
											if Lm <= 105 then
												return -CalcStat("WrdStdYourGrBase",L,CalcStat("Trait123Choice",N));
											else
												return CalcStat("ProgExtHighLinExpRnd",L,CalcStat("WrdStdYourGrEvade",105,N));
											end
										end
									else
										return 4*L*N;
									end
								else
									return CalcStat("CritHitT",L,2.4);
								end
							else
								if Lm <= 0 then
									return 0;
								else
									return DataTableValue({0.75,0.75,22/31},L);
								end
							end
						else
							return RoundDbl(CalcStat("WorthMpB",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabQ"));
						end
					else
						return RoundDbl(CalcStat("WorthMpC",QualityCodeIndex(C))*CalcStat("WorthExt",L,"WorthTabCB"));
					end
				else
					return CalcStat("WorthTabD",L)+30;
				end
			else
				return 4.8;
			end
		else
			if Lm <= 0 then
				return 0;
			else
				return DataTableValue({5,8,12,16,20},L);
			end
		end
	else
		return CalcStat("ClassBaseMainJ",L);
	end

end

-- Support functions for CalcStat. These consist of implementations of more complex calculation types, decode methods for parameter "C" and rounding/min/max/compare functions for floating point numbers.

-- ****************** Calculation Type support functions ******************

-- DDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDDD
-- DataTableValue: Takes a value from an array table.

function DataTableValue(vDataArray, lIndex)

	if lIndex <= 1 then
		return vDataArray[1];
	elseif lIndex > #vDataArray then
		return vDataArray[#vDataArray];
	else
		return vDataArray[lIndex];
	end

end

-- EEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEEE
-- ExpFmod: Exponential function based on percentage.
-- Common percentage values are around ~5.5% for between levels and ~20% jumps between level segments.

function ExpFmod(dVal, dLstart, dPlvl, dLvl, vDec, vAdd)

	local dRng = dLvl-dLstart+1;
	if dRng <= DblCalcDev then
		return dVal;
	else
		local dFac = 1+dPlvl/100;
		local dAdd;
		if vAdd == nil then
			dAdd = 0;
		else
			dAdd = vAdd;
		end
		if vDec == nil then
			local dFacExp = dFac^dRng;
			return dVal*dFacExp+dAdd*((dFacExp-1)/(dFac-1));
		else
			local dResult = dVal;
			local dDec;
			if -DblCalcDev <= vDec and vDec <= DblCalcDev then
				dDec = 1;
			else
				dDec = 10^vDec;
			end
			dFac = dFac*dDec;
			dAdd = dAdd*dDec+0.5+DblCalcDev;
			local dL = dLstart-DblCalcDev;
			while dL <= dLvl do
				dResult = math.floor(dResult*dFac+dAdd)/dDec;
				dL = dL+1;
			end
			return dResult;
		end
	end

end

-- PPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPPP
-- CalcPercAB: Calculates the percentage out of a rating based on the AB formula.

function CalcPercAB(dA, dB, dPCap, dR)

	if dR <= DblCalcDev then
		return 0;
	else
		local dResult = dA/(1+dB/dR);
		if dResult >= dPCap-DblCalcDev then
			return dPCap;
		else
			return dResult;
		end
	end

end

-- RRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRRR
-- CalcRatAB: Calculates the rating out of a percentage based on the AB formula.

function CalcRatAB(dA, dB, dCapR, dP)

	if dP <= DblCalcDev then
		return 0;
	else
		local dResult = dB/(dA/dP-1);
		if dResult >= dCapR-DblCalcDev then
			return dCapR;
		else
			return dResult;
		end
	end

end

-- SSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSSS
-- StatLinInter: (Normalized) Stat Linear Interpolating

function StatLinInter(sPntMP, sProg, sProgB, sAdj, dLvl, vNorC)

	local dLvlLow = CalcStat(sProg.."LPL",dLvl);
	local dLvlHigh = CalcStat(sProg.."LPH",dLvl);
	local dValLow = CalcStat(sProg,dLvlLow,CalcStat(sProgB,dLvlLow,vNorC));
	local dValHigh = CalcStat(sProg,dLvlHigh,CalcStat(sProgB,dLvlHigh,vNorC));

	if type(vNorC) == "number" then
		-- with stat points
		return LinFmod(1,LotroDbl(CalcStat(sPntMP,dLvlLow)*dValLow*CalcStat(sAdj,dLvlLow)*vNorC),LotroDbl(CalcStat(sPntMP,dLvlHigh)*dValHigh*CalcStat(sAdj,dLvlHigh)*vNorC),dLvlLow,dLvlHigh,dLvl);
	else
		-- default
		return LinFmod(1,LotroDbl(CalcStat(sPntMP,dLvlLow,vNorC)*dValLow*CalcStat(sAdj,dLvlLow,vNorC)),LotroDbl(CalcStat(sPntMP,dLvlHigh,vNorC)*dValHigh*CalcStat(sAdj,dLvlHigh,vNorC)),dLvlLow,dLvlHigh,dLvl);
	end

end

-- TTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTTT
-- LinFmod: Linear line function between 2 points with some optional modifications.
-- Connects point (dLstart,dVal*dFstart) with (dLend,dVal*dFend).
-- Usually used with dVal=1 and dFstart/dFend containing unrelated points or dVal=# and dFstart/dFend containing multiplier factors.
-- Modification for in-between points on the line: rounding.

function LinFmod(dVal, dFstart, dFend, dLstart, dLend, dLvl, vDec)

	if dLstart-DblCalcDev <= dLvl and dLvl <= dLstart+DblCalcDev then
		return dVal*dFstart;
	elseif dLend-DblCalcDev <= dLvl and dLvl <= dLend+DblCalcDev then
		return dVal*dFend;
	elseif vDec == nil then
		return dVal*(dFstart*(dLend-dLvl)+(dLvl-dLstart)*dFend)/(dLend-dLstart);
	elseif -DblCalcDev <= vDec and vDec <= DblCalcDev then
		return math.floor(dVal*(dFstart*(dLend-dLvl)+(dLvl-dLstart)*dFend)/(dLend-dLstart)+0.5+DblCalcDev);
	else
		return math.floor((dVal*(dFstart*(dLend-dLvl)+(dLvl-dLstart)*dFend)/(dLend-dLstart))*10^vDec+0.5+DblCalcDev)/10^vDec;
	end

end

-- ****************** Parameter "C" decode support functions ******************

-- ArmCodeIndex: returns a specified index from an Armour Code.
-- sACode string:
-- 1st position: H=heavy, M=medium, L=light
-- 2nd position: H=head, S=shoulders, CL=cloak/back, C=chest, G=gloves, L=leggings, B=boots, Sh=shield
-- 3rd position: W=white/common, Y=yellow/uncommon, P=purple/rare, T=teal/blue/incomparable, G=gold/legendary/epic
-- Note: no such thing exists as a heavy, medium or light cloak, so no H/M/L in cloak codes (cloaks go automatically in the M class since U23, although historically this was L)

function ArmCodeIndex(sACode, iI)

	if sACode == nil or iI == nil then
		return 0;
	end
	if type(sACode) ~= "string" or type(iI) ~= "number" then
		return 0;
	end

	local sArmCode = string.match(sACode,"(%a+)");
	if not sArmCode then
		return 0;
	end
	sArmCode = string.upper(sArmCode).."    ";
	
	local sArmCat = string.sub(sArmCode,1,1);
	local sArmType = string.sub(sArmCode,2,2);
	local sArmCol = string.sub(sArmCode,3,3);

	if sArmType == "S" and sArmCol == "H" then
		sArmType = "SH";
		sArmCol = string.sub(sArmCode,4,4);
	elseif sArmCat == "C" and sArmType == "L" then
		sArmCat = "M";
		sArmType = "CL";
	elseif sArmType then
		sArmType = " "..sArmType;
	end
	
	local result = 0;
	if iI == 1 then
		if sArmCat then
			result = string.find("HML",sArmCat);
		end
	elseif iI == 2 then
		if sArmType then
			result = string.find(" H SCL C G L BSH",sArmType);
			if result then
				result = (result+1)/2;
			end
		end
	elseif iI == 3 then
		if sArmCol then
			result = string.find("WYPTG",sArmCol);
		end
	end

	if result then
		return result;
	else
		return 0;
	end
	
end

-- QualityCodeIndex: returns a quality index from a Quality Code.
-- sQCode string: W=white/common, Y=yellow/uncommon, P=purple/rare, T=teal/blue/incomparable, G=gold/legendary/epic

function QualityCodeIndex(sQCode)

	if sQCode == nil then
		return 0;
	end
	if type(sQCode) ~= "string" then
		return 0;
	end

	local sQtyCode = string.match(sQCode,"(%a+)");
	if not sQtyCode then
		return 0;
	end
	sQtyCode = string.upper(sQtyCode).." ";

	local sQtyCol = string.sub(sQtyCode,1,1);
	
	local result = 0;
	if sQtyCol then
		result = string.find("WYPTG",sQtyCol);
	end
	
	if result then
		return result;
	else
		return 0;
	end
	
end

-- WpnCodeIndex: returns a specified index from a Weapon Code.
-- sWCode string:
-- 1st position: H=heavy, L=light
-- 2nd position: O=one-handed, T=two-handed, B=bow
-- 3rd position: W=white/common, Y=yellow/uncommon, P=purple/rare, T=teal/blue/incomparable, G=gold/legendary/epic

function WpnCodeIndex(sWCode, iI)

	if sWCode == nil or iI == nil then
		return 0;
	end
	if type(sWCode) ~= "string" or type(iI) ~= "number" then
		return 0;
	end

	local sWpnCode = string.match(sWCode,"(%a+)");
	if not sWpnCode then
		return 0;
	end
	sWpnCode = string.upper(sWpnCode).."   ";
	
	local sWpnCat = string.sub(sWpnCode,1,1);
	local sWpnType = string.sub(sWpnCode,2,2);
	local sWpnCol = string.sub(sWpnCode,3,3);

	local result = 0;
	if iI == 1 then
		if sWpnCat then
			result = string.find("HL",sWpnCat);
		end
	elseif iI == 2 then
		if sWpnType then
			result = string.find("OTB",sWpnType);
		end
	elseif iI == 3 then
		if sWpnCol then
			result = string.find("WYPTG",sWpnCol);
		end
	end

	if result then
		return result;
	else
		return 0;
	end
	
end

-- RomanRankDecode: converts a string with a Roman number in characters, to an integer number.
-- used for Legendary Item Title calculation.

local RomanCharsToValues = {["M"]=1000,["CM"]=900,["D"]=500,["CD"]=400,["C"]=100,["XC"]=90,["L"]=50,["XL"]=40,["X"]=10,["IX"]=9,["V"]=5,["IV"]=4,["I"]=1};

function RomanRankDecode(sNumber)

	if sNumber ~= nil and type(sNumber) == "string" and sNumber ~= "" then
		for sRomanRankChar, iRomanRankValue in pairs(RomanCharsToValues) do
			if string.sub(string.upper(sNumber),1,string.len(sRomanRankChar)) == sRomanRankChar then
				return iRomanRankValue+RomanRankDecode(string.sub(sNumber,string.len(sRomanRankChar)+1));
			end
		end
	end
	
	return 0;
	
end

-- ReverseCalc: tries to calculate back a calculation result to the original (integer) level.
-- Does not support N.

function ReverseCalc(sStat, dNum)

	if string.len(string.match(sStat,"([-%w]+)")) > 0 then
		local minlvl = 1;
		local maxlvl = 500;
		local devlvl = 3;
	
		local left = minlvl-1;
		local right = maxlvl;
		local middle;
		
		local count = minlvl;

		while right > left+1 and count <= maxlvl do
			count = count+1;
			middle = math.floor((left+right)/2+DblCalcDev);
			if CalcStat(sStat,middle)+DblCalcDev >= dNum then
				right = middle;
			else
				left = middle;
			end
		end

		local mintest = right-devlvl;
		if mintest < minlvl then
			mintest = minlvl;
		end
		local maxtest = right+devlvl;
		if maxtest > maxlvl then
			maxtest = maxlvl;
		end

		local dFound;
	
		-- we check nearby in case the progression is not completely ascending/sorted.
		for test = mintest, maxtest do
			dFound = CalcStat(sStat,test);
			if  dNum-DblCalcDev <= dFound and dFound <= dNum+DblCalcDev then
				return test;
			end
		end
	end

	return 0;

end

-- ****************** Misc. floating point support functions ******************

-- Misc. functions for floating point rounding.
-- 2nd parameter is number of decimals.

function RoundDbl(dNum, vDec)

	if vDec == nil or (-DblCalcDev <= vDec and vDec <= DblCalcDev) then
		return math.floor(dNum+0.5+DblCalcDev);
	else
		return math.floor(dNum*10^vDec+0.5+DblCalcDev)/10^vDec;
	end
	
end

function FloorDbl(dNum, vDec)

	if vDec == nil or (-DblCalcDev <= vDec and vDec <= DblCalcDev) then
		return math.floor(dNum+DblCalcDev);
	else
		return math.floor(dNum*10^vDec+DblCalcDev)/10^vDec;
	end

end

function CeilDbl(dNum, vDec)

	if vDec == nil or (-DblCalcDev <= vDec and vDec <= DblCalcDev) then
		return math.floor(dNum+1-DblCalcDev);
	else
		return math.floor(dNum*10^vDec+1-DblCalcDev)/10^vDec;
	end
	
end

function LotroDbl(dNum)

	local dNumCeiled = CeilDbl(dNum,0);

	if -DblCalcDev <= dNumCeiled and dNumCeiled <= DblCalcDev then
		return 0;
	else
		local dLen;
		if dNumCeiled > DblCalcDev then
			dLen = math.floor(math.log10(dNumCeiled)+DblCalcDev)+1;
		else
			dLen = math.floor(math.log10(-dNumCeiled)+DblCalcDev)+1;
		end
		local dDec = 3-dLen;
		if dDec < -DblCalcDev then 
			return CeilDbl(dNum,dDec);
		else
			return dNumCeiled;
		end
	end

end

-- to be used by other modules
p.DblCalcDev = DblCalcDev;
p.CalcStat = CalcStat;

-- ******************************* End CalcStat *******************************
